import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$rasterizer$create_image$$=function($uri$jscomp$108$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$22$$){var $image$jscomp$34$$=new Image;$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"onload",function(){$subs$jscomp$22$$.next($image$jscomp$34$$);return $subs$jscomp$22$$.complete()});$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"crossOrigin","anonymous");$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"onerror",function($p1__75930_SHARP_$$){return $subs$jscomp$22$$.error($p1__75930_SHARP_$$)});
$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"onabort",function(){return $subs$jscomp$22$$.error($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("operation aborted",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1549$abort$$,$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$1550$operation_aborted$$,$APP.$cljs$cst$275$hint$$,
"operation aborted"],null),null])),null))});$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"src",$uri$jscomp$108$$);return function(){$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"onload",null);$APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"onerror",null);return $APP.$app$util$object$set_BANG_$$($image$jscomp$34$$,"onabort",null)}})},$app$rasterizer$svg_get_adjusted_size$$=function($width$jscomp$184$$,$height$jscomp$161$$,$max$jscomp$76$$){if($width$jscomp$184$$>0&&$height$jscomp$161$$>
0){var $ratio$jscomp$3$$=$width$jscomp$184$$/$height$jscomp$161$$;return $width$jscomp$184$$<$height$jscomp$161$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$max$jscomp$76$$,1/$ratio$jscomp$3$$*$max$jscomp$76$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$max$jscomp$76$$*$ratio$jscomp$3$$,$max$jscomp$76$$],null)}return null},$app$rasterizer$fetch_as_data_uri$$=function($uri$jscomp$109$$){if($APP.$cljs$core$truth_$$($app$rasterizer$data_uri_cache$$.has($uri$jscomp$109$$))){var $blob$jscomp$38$$=
$app$rasterizer$data_uri_cache$$.get($uri$jscomp$109$$);return $APP.$beicon$v2$core$from$$($blob$jscomp$38$$.text())}return $APP.$beicon$v2$core$mapcat$$(function($response$jscomp$16$$){return $response$jscomp$16$$==null?(0,$APP.$beicon$v2$core$of$$)($uri$jscomp$109$$):$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($data_uri$jscomp$7$$){return $app$rasterizer$data_uri_cache$$.set($uri$jscomp$109$$,$APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($data_uri$jscomp$7$$,
"text/plain"))},$APP.$beicon$v2$core$mapcat$$($APP.$app$util$webapi$read_file_as_data_url$$,(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$1586$body$$.$cljs$core$IFn$_invoke$arity$1$($response$jscomp$16$$))))},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$108$$){$APP.$app$common$logging$enabled_QMARK_$$("app.rasterizer",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"fetching data uri"],null)],null)}),$cause$jscomp$108$$,"app.rasterizer",$APP.$cljs$cst$849$error$$,!1);return(0,$APP.$beicon$v2$core$of$$)(null)},$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1584$uri$$,$uri$jscomp$109$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$1596$blob$$,
$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$1190$cors$$,$APP.$cljs$cst$1587$omit_default_headers$$,!0],null))))},$app$rasterizer$svg_update_image_BANG_$$=function($image$jscomp$35$$){var $temp__5823__auto__$jscomp$212$$=$APP.$app$util$dom$get_attribute$$($image$jscomp$35$$,"href");return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$212$$)?$APP.$cuerdas$core$starts_with_QMARK_$$($temp__5823__auto__$jscomp$212$$,"data:")?(0,$APP.$beicon$v2$core$of$$)($image$jscomp$35$$):
$APP.$beicon$v2$core$map$$(function($url$jscomp$99$$){$APP.$app$util$dom$set_attribute_BANG_$$($image$jscomp$35$$,"href",$url$jscomp$99$$);return $image$jscomp$35$$},$app$rasterizer$fetch_as_data_uri$$($temp__5823__auto__$jscomp$212$$)):$APP.$beicon$v2$core$empty$$()},$app$rasterizer$svg_add_style_BANG_$$=function($svg$jscomp$8$$,$styles$jscomp$20$$){var $doc$jscomp$41$$=$svg$jscomp$8$$.documentElement;var $style$jscomp$70$$=$svg$jscomp$8$$.createElementNS("http://www.w3.org/2000/svg","style");$APP.$app$util$dom$append_child_BANG_$$($style$jscomp$70$$,
$svg$jscomp$8$$.createTextNode($styles$jscomp$20$$));return $APP.$app$util$dom$append_child_BANG_$$($doc$jscomp$41$$,$style$jscomp$70$$)},$app$rasterizer$svg_resolve_external_resources$$=function($styles$jscomp$21$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($styles__$1$jscomp$2$$,$p__75943_uri$jscomp$110$$){var $url$jscomp$100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75943_uri$jscomp$110$$,0,null);$p__75943_uri$jscomp$110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__75943_uri$jscomp$110$$,
1,null);return $APP.$cuerdas$core$replace$$($styles__$1$jscomp$2$$,$url$jscomp$100$$,$p__75943_uri$jscomp$110$$)},$styles$jscomp$21$$,$APP.$beicon$v2$core$mapcat$$(function($url$jscomp$101$$){return $APP.$beicon$v2$core$map$$(function($uri$jscomp$111$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$url$jscomp$101$$,$uri$jscomp$111$$],null)},$app$rasterizer$fetch_as_data_uri$$($url$jscomp$101$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$second$$,
$APP.$beicon$v2$core$from$$($APP.$cljs$core$re_seq$$(/url\((https?:\/\/[^)]+)\)/,$styles$jscomp$21$$)))))},$app$rasterizer$svg_resolve_inline_styles_BANG_$$=function($svg$jscomp$10$$){return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$mapcat$$(function($node$jscomp$387$$){var $styles$jscomp$23$$=$APP.$app$util$dom$get_attribute$$($node$jscomp$387$$,"style");return $APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($styles__$1$jscomp$3$$){return $APP.$app$util$dom$set_attribute_BANG_$$($node$jscomp$387$$,
"style",$styles__$1$jscomp$3$$)},$app$rasterizer$svg_resolve_external_resources$$($styles$jscomp$23$$))},$APP.$beicon$v2$core$from$$($APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($svg$jscomp$10$$,"[style]"))))},$app$rasterizer$svg_resolve_style_elements_BANG_$$=function($svg$jscomp$11$$){return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$mapcat$$(function($node$jscomp$388$$){return $APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($styles__$1$jscomp$4$$){return $APP.$app$util$dom$set_text_BANG_$$($node$jscomp$388$$,
$styles__$1$jscomp$4$$)},$app$rasterizer$svg_resolve_external_resources$$($APP.$app$util$dom$get_text$$($node$jscomp$388$$)))},$APP.$beicon$v2$core$from$$($APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($svg$jscomp$11$$,"style"))))},$app$rasterizer$svg_resolve_all_BANG_$$=function($svg$jscomp$12$$,$styles$jscomp$25$$){return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$mapcat$$($app$rasterizer$svg_update_image_BANG_$$,$APP.$beicon$v2$core$from$$($APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($svg$jscomp$12$$,
"image")))),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$rasterizer$svg_add_style_BANG_$$,$svg$jscomp$12$$),$app$rasterizer$svg_resolve_external_resources$$($styles$jscomp$25$$))),$app$rasterizer$svg_resolve_inline_styles_BANG_$$($svg$jscomp$12$$),$app$rasterizer$svg_resolve_style_elements_BANG_$$($svg$jscomp$12$$),(0,$APP.$beicon$v2$core$of$$)($svg$jscomp$12$$))},$app$rasterizer$svg_parse$$=
function($data$jscomp$464$$){return(new DOMParser).parseFromString($data$jscomp$464$$,"image/svg+xml")},$app$rasterizer$svg_stringify$$=function($doc$jscomp$42_svg$jscomp$13$$){$doc$jscomp$42_svg$jscomp$13$$=$doc$jscomp$42_svg$jscomp$13$$.documentElement;return(new XMLSerializer).serializeToString($doc$jscomp$42_svg$jscomp$13$$)},$app$rasterizer$svg_prepare$$=function($data$jscomp$465_svg$jscomp$14$$,$styles$jscomp$26$$,$width$jscomp$188$$){$data$jscomp$465_svg$jscomp$14$$=$app$rasterizer$svg_parse$$($data$jscomp$465_svg$jscomp$14$$);
return $APP.$beicon$v2$core$map$$($app$rasterizer$svg_stringify$$,$APP.$beicon$v2$core$map$$(function($p1__75950_SHARP_$$){var $doc_76017$jscomp$inline_13409$$=$p1__75950_SHARP_$$.documentElement;var $doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=$p1__75950_SHARP_$$.documentElement;var $JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=
$APP.$app$util$dom$get_attribute$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,"width");$doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=$APP.$app$util$dom$get_attribute$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,
"height");$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$,$doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$)?
($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=$p1__75950_SHARP_$$.documentElement,$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=$APP.$app$util$dom$get_attribute$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,
"width"),$doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=$APP.$app$util$dom$get_attribute$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,"height"),
$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=$app$rasterizer$svg_get_adjusted_size$$($APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$,
0),$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,0),$width$jscomp$188$$)):($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=
$APP.$app$util$dom$get_attribute$$($p1__75950_SHARP_$$.documentElement,"viewBox"),typeof $JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$==="string"?($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=
$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$,/\s+/),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,
0,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,1,null),$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,2,null),$doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,3,null),$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=$app$rasterizer$svg_get_adjusted_size$$($APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$,
0),$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,0),$width$jscomp$188$$)):$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=
null);$doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$)?$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$:
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$width$jscomp$188$$,$width$jscomp$188$$],null);$JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,
0,null);$doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$,
1,null);$APP.$app$util$dom$set_attribute_BANG_$$($doc_76017$jscomp$inline_13409$$,"width",""+($JSCompiler_temp$jscomp$15004_or__5025__auto__$jscomp$inline_13411_vbox$jscomp$inline_15076_w_76019$jscomp$inline_13412_width$jscomp$inline_15065_width$jscomp$inline_15071_width$jscomp$inline_15078$$??""));$APP.$app$util$dom$set_attribute_BANG_$$($doc_76017$jscomp$inline_13409$$,"height",""+($doc$jscomp$inline_15064_doc$jscomp$inline_15070_h_76020$jscomp$inline_13413_height$jscomp$inline_15066_height$jscomp$inline_15072_height$jscomp$inline_15079_vec__75931$jscomp$inline_15077_vec__75935_76018$jscomp$inline_13410$$??
""));return $p1__75950_SHARP_$$},$app$rasterizer$svg_resolve_all_BANG_$$($data$jscomp$465_svg$jscomp$14$$,$styles$jscomp$26$$)))},$app$rasterizer$bitmap__GT_blob$$=function($bitmap$jscomp$8$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$23$$){var $canvas$jscomp$21$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("canvas");$canvas$jscomp$21$$.width=$bitmap$jscomp$8$$.width;$canvas$jscomp$21$$.height=$bitmap$jscomp$8$$.height;$canvas$jscomp$21$$.getContext("bitmaprenderer").transferFromImageBitmap($bitmap$jscomp$8$$);
$canvas$jscomp$21$$.toBlob(function($p1__75963_SHARP_$$){$subs$jscomp$23$$.next($p1__75963_SHARP_$$);return $subs$jscomp$23$$.complete()});return $APP.$cljs$core$constantly$$(null)})},$app$rasterizer$render_image_bitmap$$=function($payload$jscomp$12$$){var $data$jscomp$466$$=$payload$jscomp$12$$.data,$styles$jscomp$27$$=$payload$jscomp$12$$.styles,$width$jscomp$189$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($payload$jscomp$12$$.width,300),$quality$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($payload$jscomp$12$$.quality,
"medium");return $APP.$beicon$v2$core$mapcat$$(function($uri$jscomp$112$$){return $APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$util$webapi$revoke_uri$$($uri$jscomp$112$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__75966_SHARP_$$){var $options$jscomp$inline_8166$$={resizeWidth:$width$jscomp$189$$,resizeQuality:$quality$$};var $JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$=$p1__75966_SHARP_$$.width;var $height$jscomp$inline_13416$$=
$p1__75966_SHARP_$$.height;if("OffscreenCanvas"in window)$JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$=new OffscreenCanvas($JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$,$height$jscomp$inline_13416$$);else{var $canvas$jscomp$inline_14836$$=document.createElement("canvas");$APP.$app$util$object$set_BANG_$$($canvas$jscomp$inline_14836$$,"width",$JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$);
$APP.$app$util$object$set_BANG_$$($canvas$jscomp$inline_14836$$,"height",$height$jscomp$inline_13416$$);$JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$=$canvas$jscomp$inline_14836$$}$JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$.getContext("2d").drawImage($p1__75966_SHARP_$$,0,0);return createImageBitmap($JSCompiler_temp$jscomp$14343_offscreen_canvas$jscomp$inline_8167_width$jscomp$inline_13415$$,$options$jscomp$inline_8166$$)},
$app$rasterizer$create_image$$($uri$jscomp$112$$)))},$APP.$beicon$v2$core$map$$($APP.$app$util$webapi$create_uri$$,$APP.$beicon$v2$core$map$$(function($p1__75965_SHARP_$$){return $APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__75965_SHARP_$$,"image/svg+xml")},$app$rasterizer$svg_prepare$$($data$jscomp$466$$,$styles$jscomp$27$$,$width$jscomp$189$$))))},$app$rasterizer$on_message$$=function($JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$){var $JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$=
$JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$.data;if($APP.$cuerdas$core$starts_with_QMARK_$$($app$rasterizer$parent_origin$$,$JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$.origin)){var $JSCompiler_temp_const$jscomp$1483_id$jscomp$923$$=$JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$.id;$JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$=
$JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$.payload;$JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$=$JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$.scope;if($JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$,"penpot/rasterizer")){$JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$=
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$rasterizer$send_success_BANG_$$,$JSCompiler_temp_const$jscomp$1483_id$jscomp$923$$);$JSCompiler_temp_const$jscomp$1483_id$jscomp$923$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$rasterizer$send_failure_BANG_$$,$JSCompiler_temp_const$jscomp$1483_id$jscomp$923$$);a:switch($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$.result,
"blob")){case "image-bitmap":$JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$=$app$rasterizer$render_image_bitmap$$($JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$);break a;default:$JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$=$APP.$beicon$v2$core$mapcat$$($app$rasterizer$bitmap__GT_blob$$,$app$rasterizer$render_image_bitmap$$($JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$))}$JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$=
$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$,$JSCompiler_temp_const$jscomp$1484_evdata$jscomp$1_scope$jscomp$10$$,$JSCompiler_temp_const$jscomp$1483_id$jscomp$923$$)}else $JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$=null;return $JSCompiler_inline_result$jscomp$1485_JSCompiler_temp$jscomp$1482_event$jscomp$293_payload$jscomp$15$$}return null},
$app$rasterizer$send_answer_BANG_$$=function($id$jscomp$924_message$jscomp$116$$,$type$jscomp$608$$,$payload$jscomp$16$$){$id$jscomp$924_message$jscomp$116$$={id:$id$jscomp$924_message$jscomp$116$$,type:$type$jscomp$608$$,scope:"penpot/rasterizer",payload:$payload$jscomp$16$$};return window===parent?null:$payload$jscomp$16$$ instanceof ImageBitmap?parent.postMessage($id$jscomp$924_message$jscomp$116$$,$app$rasterizer$parent_origin$$,[$payload$jscomp$16$$]):parent.postMessage($id$jscomp$924_message$jscomp$116$$,
$app$rasterizer$parent_origin$$)},$app$rasterizer$send_success_BANG_$$=function($id$jscomp$925$$,$payload$jscomp$17$$){return $app$rasterizer$send_answer_BANG_$$($id$jscomp$925$$,"success",$payload$jscomp$17$$)},$app$rasterizer$send_failure_BANG_$$=function($id$jscomp$926$$,$cause$jscomp$109$$){return $app$rasterizer$send_answer_BANG_$$($id$jscomp$926$$,"failure",$APP.$cljs$core$ex_message$$($cause$jscomp$109$$))},$app$rasterizer$init$$=function(){window.addEventListener("message",$app$rasterizer$on_message$$);
$app$rasterizer$send_answer_BANG_$$(null,"ready",null);$APP.$app$common$logging$enabled_QMARK_$$("app.rasterizer",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"initialized"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3152$public_uri$$,""+($APP.$app$config$public_uri$$??"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5529$parent_uri$$,""+($app$rasterizer$parent_origin$$??"")],null)],null)}),null,"app.rasterizer",$APP.$cljs$cst$1161$info$$,!1);return null},$cljs$cst$5529$parent_uri$$=new $APP.$cljs$core$Keyword$$(null,"parent-uri","parent-uri",-371819908);$APP.$app$common$logging$loggers$$.set("app.rasterizer",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1161$info$$));var $app$rasterizer$data_uri_cache$$=new Map,$app$rasterizer$parent_origin$$=""+($APP.$app$config$public_uri$$??"");$APP.$goog$exportSymbol$$("app.rasterizer.init",$app$rasterizer$init$$);export const init=$app$rasterizer$init$$;
//# sourceMappingURL=rasterizer.js.map
