import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$main$data$profile$access_token_created$$,$app$main$data$profile$delete_access_token$$,$app$main$data$profile$create_access_token$$,$app$main$data$profile$request_email_change$$,$app$main$data$nitrate$go_to_nitrate_billing$$,$app$main$ui$components$forms$textarea$$,$app$main$data$profile$update_photo$$,$app$main$data$profile$delete_subscription$$,$app$main$data$profile$request_account_deletion$$,$app$main$data$profile$update_password$$,$app$main$data$profile$update_notifications$$,$app$main$data$profile$update_profile$$,
$app$main$ui$settings$change_email$on_error$$,$app$main$ui$settings$change_email$on_success$$,$app$main$ui$settings$change_email$on_submit$$,$app$main$ui$settings$change_email$change_email_modal$$,$app$main$ui$settings$delete_account$on_error$$,$app$main$ui$settings$delete_account$delete_account_modal$$,$app$main$ui$settings$feedback$feedback_form_STAR_$$,$app$main$ui$settings$feedback$feedback_page_STAR_$$,$app$main$ui$settings$integrations$input_copy_STAR_$$,$app$main$ui$settings$integrations$token_created_STAR_$$,
$app$main$ui$settings$integrations$create_token_STAR_$$,$app$main$ui$settings$integrations$create_access_token_modal$$,$app$main$ui$settings$integrations$generate_mcp_token_modal$$,$app$main$ui$settings$integrations$mcp_access_token_QMARK_$$,$app$main$ui$settings$integrations$regenerate_mcp_token_modal$$,$app$main$ui$settings$integrations$mcp_server_section_STAR_$$,$app$main$ui$settings$integrations$access_tokens_section_STAR_$$,$app$main$ui$settings$integrations$integrations_page_STAR_$$,$app$main$ui$settings$notifications$on_submit$$,
$app$main$ui$settings$notifications$notifications_page_STAR_$$,$app$main$ui$settings$options$on_success$$,$app$main$ui$settings$options$on_submit$$,$app$main$ui$settings$options$options_form_STAR_$$,$app$main$ui$settings$options$go_settings_feedback$$,$app$main$ui$settings$options$webgl_settings_STAR_$$,$app$main$ui$settings$options$options_page_STAR_$$,$app$main$ui$settings$password$on_error$$,$app$main$ui$settings$password$on_success$$,$app$main$ui$settings$password$on_submit$$,$app$main$ui$settings$password$password_form_STAR_$$,
$app$main$ui$settings$password$password_page_STAR_$$,$app$main$ui$settings$profile$on_submit$$,$app$main$ui$settings$profile$profile_form_STAR_$$,$app$main$ui$settings$profile$profile_photo_form_STAR_$$,$app$main$ui$settings$profile$profile_page_STAR_$$,$app$main$ui$settings$sidebar$go_settings_profile$$,$app$main$ui$settings$sidebar$go_settings_feedback$$,$app$main$ui$settings$sidebar$go_settings_password$$,$app$main$ui$settings$sidebar$go_settings_options$$,$app$main$ui$settings$sidebar$go_settings_subscription$$,
$app$main$ui$settings$sidebar$go_settings_integrations$$,$app$main$ui$settings$sidebar$go_settings_notifications$$,$app$main$ui$settings$sidebar$show_release_notes$$,$app$main$ui$settings$sidebar$sidebar_content_STAR_$$,$app$main$ui$settings$subscription$get_subscription_name$$,$app$main$ui$settings$subscription$editors_section_STAR_$$,$app$main$ui$settings$subscription$subscribe_management_dialog$$,$app$main$ui$settings$subscription$subscription_success_dialog$$,$app$main$ui$settings$subscription$subscription_page_STAR_$$,
$app$main$ui$settings$subscription$subscribe_nitrate_dialog$$,$app$main$ui$settings$subscription$nitrate_contact_sales_dialog$$,$app$main$ui$settings$subscription$nitrate_cancel_contact_sales_dialog$$,$app$main$ui$settings$settings_STAR_$$,$app$main$data$profile$update_profile_55026$$,$app$main$data$profile$request_email_change_55061$$,$app$main$data$profile$update_password_55103$$,$app$main$data$profile$update_notifications_55134$$,$app$main$data$profile$update_photo_55241$$,$app$main$data$profile$request_account_deletion_55335$$,
$app$main$data$profile$access_token_created_55458$$,$app$main$data$profile$create_access_token_55461$$,$app$main$data$profile$delete_access_token_55478$$,$cljs$cst$6760$subscribe_to_trial$$,$cljs$cst$6747$error_report$$,$cljs$cst$6742$get_owned_organizations_summary$$,$cljs$cst$6746$subject$$,$cljs$cst$6741$owner_teams_with_people$$,$cljs$cst$6762$subscription_name$$,$cljs$cst$6759$current_subscription$$,$cljs$cst$6748$feedback_disabled$$,$cljs$cst$6753$regenerate_mcp_token$$,$cljs$cst$6740$email_2$$,
$cljs$cst$6738$email_1$$,$cljs$cst$6744$member_count$$,$cljs$cst$6752$generate_mcp_token$$,$cljs$cst$6751$expiration$$,$cljs$cst$6764$start_date$$,$cljs$cst$6768$app_DOT_main_DOT_ui_DOT_settings_SLASH_dashboard$$,$cljs$cst$6766$nitrate_cancel_contact_sales_dialog$$,$cljs$cst$6749$send_user_feedback$$,$cljs$cst$6745$delete_account$$,$cljs$cst$6765$nitrate_contact_sales_dialog$$,$cljs$cst$6757$redirect_to_payment_details$$,$cljs$cst$6758$subscription_type$$,$cljs$cst$6756$min_members$$,$cljs$cst$6755$activate$$,
$cljs$cst$6743$team_count$$,$cljs$cst$6739$changed$$,$cljs$cst$6767$renovate$$,$cljs$cst$6754$is_valid$$,$cljs$cst$6763$subscription_success$$,$cljs$cst$6761$management_dialog$$,$cljs$cst$6750$perms$$;
$app$main$data$profile$access_token_created$$=function($access_token$$){typeof $app$main$data$profile$access_token_created_55458$$==="undefined"&&($app$main$data$profile$access_token_created_55458$$=function($access_token$jscomp$1$$,$meta55459$$){this.$access_token$=$access_token$jscomp$1$$;this.$meta55459$=$meta55459$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$access_token_created_55458$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$access_token_created_55458$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3274$app_DOT_main_DOT_data_DOT_profile_SLASH_access_token_created$$},$app$main$data$profile$access_token_created_55458$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55460$$,$meta55459__$1$$){return new $app$main$data$profile$access_token_created_55458$$(this.$access_token$,$meta55459__$1$$)},$app$main$data$profile$access_token_created_55458$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55459$},$app$main$data$profile$access_token_created_55458$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$access_token_created_55458$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1699$$,$state$jscomp$208$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$208$$,$APP.$cljs$cst$2253$access_token_created$$,this.$access_token$)});return new $app$main$data$profile$access_token_created_55458$$($access_token$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$delete_access_token$$=function($p__55476$$){var $map__55477__$1$$=$APP.$cljs$core$__destructure_map$$($p__55476$$),$id$jscomp$379$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55477__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$profile$delete_access_token_55478$$==="undefined"&&($app$main$data$profile$delete_access_token_55478$$=function($p__55476$jscomp$1$$,$map__55477$jscomp$1$$,$params$jscomp$192$$,$id$jscomp$380$$,$meta55479$$){this.$p__55476$=$p__55476$jscomp$1$$;
this.$map__55477$=$map__55477$jscomp$1$$;this.params=$params$jscomp$192$$;this.id=$id$jscomp$380$$;this.$meta55479$=$meta55479$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$delete_access_token_55478$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$delete_access_token_55478$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3277$app_DOT_main_DOT_data_DOT_profile_SLASH_delete_access_token$$},
$app$main$data$profile$delete_access_token_55478$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55480$$,$meta55479__$1$$){return new $app$main$data$profile$delete_access_token_55478$$(this.$p__55476$,this.$map__55477$,this.params,this.id,$meta55479__$1$$)},$app$main$data$profile$delete_access_token_55478$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55479$},$app$main$data$profile$delete_access_token_55478$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$delete_access_token_55478$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1701$$,$state$jscomp$209$$){var $self__$jscomp$3646$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$209$$,$APP.$cljs$cst$1177$access_tokens$$,function($tokens$jscomp$20$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__55475_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3646$$.id,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55475_SHARP_$$))}),$tokens$jscomp$20$$)})},$app$main$data$profile$delete_access_token_55478$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$delete_access_token_55478$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55499_on_success$jscomp$9$$=$APP.$cljs$core$meta$$(this.params),$map__55499__$1_on_error$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__55499_on_success$jscomp$9$$);
$map__55499_on_success$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55499__$1_on_error$jscomp$13$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__55499__$1_on_error$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55499__$1_on_error$jscomp$13$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55499__$1_on_error$jscomp$13$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55499_on_success$jscomp$9$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3278$delete_access_token$$,this.params)))});return new $app$main$data$profile$delete_access_token_55478$$($p__55476$$,$map__55477__$1$$,$map__55477__$1$$,$id$jscomp$379$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$create_access_token$$=function($params$jscomp$189$$){typeof $app$main$data$profile$create_access_token_55461$$==="undefined"&&($app$main$data$profile$create_access_token_55461$$=function($params$jscomp$190$$,$meta55462$$){this.params=$params$jscomp$190$$;this.$meta55462$=$meta55462$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$create_access_token_55461$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$create_access_token_55461$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3275$app_DOT_main_DOT_data_DOT_profile_SLASH_create_access_token$$},$app$main$data$profile$create_access_token_55461$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55463$$,$meta55462__$1$$){return new $app$main$data$profile$create_access_token_55461$$(this.params,$meta55462__$1$$)},$app$main$data$profile$create_access_token_55461$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55462$},$app$main$data$profile$create_access_token_55461$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$create_access_token_55461$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55464_on_success$jscomp$8$$=$APP.$cljs$core$meta$$(this.params),$map__55464__$1_on_error$jscomp$12$$=$APP.$cljs$core$__destructure_map$$($map__55464_on_success$jscomp$8$$);$map__55464_on_success$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55464__$1_on_error$jscomp$12$$,
$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__55464__$1_on_error$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55464__$1_on_error$jscomp$12$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55464__$1_on_error$jscomp$12$$,$APP.$beicon$v2$core$mapcat$$(function($token$jscomp$67$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$profile$access_token_created$$($token$jscomp$67$$),
$APP.$app$main$data$profile$fetch_access_tokens$$())},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55464_on_success$jscomp$8$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3276$create_access_token$$,this.params))))});return new $app$main$data$profile$create_access_token_55461$$($params$jscomp$189$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$request_email_change$$=function($p__55058$$){var $map__55059__$1$$=$APP.$cljs$core$__destructure_map$$($p__55058$$),$email$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55059__$1$$,$APP.$cljs$cst$3207$email$$);typeof $app$main$data$profile$request_email_change_55061$$==="undefined"&&($app$main$data$profile$request_email_change_55061$$=function($p__55058$jscomp$1$$,$map__55059$jscomp$1$$,$data$jscomp$268$$,$email$jscomp$1$$,$meta55062$$){this.$p__55058$=$p__55058$jscomp$1$$;
this.$map__55059$=$map__55059$jscomp$1$$;this.data=$data$jscomp$268$$;this.email=$email$jscomp$1$$;this.$meta55062$=$meta55062$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$request_email_change_55061$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$request_email_change_55061$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3235$app_DOT_main_DOT_data_DOT_profile_SLASH_request_email_change$$},
$app$main$data$profile$request_email_change_55061$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55063$$,$meta55062__$1$$){return new $app$main$data$profile$request_email_change_55061$$(this.$p__55058$,this.$map__55059$,this.data,this.email,$meta55062__$1$$)},$app$main$data$profile$request_email_change_55061$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55062$},$app$main$data$profile$request_email_change_55061$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$profile$request_email_change_55061$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3207$email$$,this.email],null)},$app$main$data$profile$request_email_change_55061$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$request_email_change_55061$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55072_on_error$jscomp$6$$=$APP.$cljs$core$meta$$(this.data),
$map__55072__$1_on_success$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__55072_on_error$jscomp$6$$);$map__55072_on_error$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55072__$1_on_success$jscomp$2$$,$APP.$cljs$cst$1300$on_error$$,$APP.$cljs$core$identity$$);$map__55072__$1_on_success$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55072__$1_on_success$jscomp$2$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55072_on_error$jscomp$6$$,
$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55072__$1_on_success$jscomp$2$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3236$request_email_change$$,this.data)))});return new $app$main$data$profile$request_email_change_55061$$($p__55058$$,$map__55059__$1$$,$map__55059__$1$$,$email$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$go_to_nitrate_billing$$=function(){var $href$jscomp$13$$="/admin-console/licenses/billing?callback\x3d"+(encodeURIComponent($APP.$app$main$data$nitrate$go_to_subscription_url$$)??"");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2473$href$$,$href$jscomp$13$$])))};
$app$main$ui$components$forms$textarea$$=function($label$jscomp$27_map__72953_props_72950$$){$label$jscomp$27_map__72953_props_72950$$=$APP.$rumext$v2$util$wrap_props$$($label$jscomp$27_map__72953_props_72950$$);var $map__72953__$1_props__$1$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($label$jscomp$27_map__72953_props_72950$$);$label$jscomp$27_map__72953_props_72950$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72953__$1_props__$1$jscomp$46$$,$APP.$cljs$cst$2296$label$$);var $disabled$jscomp$7_klass$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72953__$1_props__$1$jscomp$46$$,$APP.$cljs$cst$2959$disabled$$),$form$jscomp$161_touched_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72953__$1_props__$1$jscomp$46$$,$APP.$cljs$cst$179$form$$),$hint$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72953__$1_props__$1$jscomp$46$$,$APP.$cljs$cst$275$hint$$),$trim$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72953__$1_props__$1$jscomp$46$$,
$APP.$cljs$cst$3736$trim$$),$input_name$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72953__$1_props__$1$jscomp$46$$,$APP.$cljs$cst$725$name$$),$form__$1$jscomp$7$$=$APP.$cljs$core$truth_$$($form$jscomp$161_touched_QMARK_$jscomp$3$$)?$form$jscomp$161_touched_QMARK_$jscomp$3$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$),$focus_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$form$jscomp$161_touched_QMARK_$jscomp$3$$=
function(){var $and__5023__auto__$jscomp$598$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$7$$)),$input_name$jscomp$1$$);return $and__5023__auto__$jscomp$598$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$7$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$1$$],
null)):$and__5023__auto__$jscomp$598$$}();var $error$jscomp$79$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$7$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$1$$],null)),$value$jscomp$737$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form__$1$jscomp$7$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$input_name$jscomp$1$$],null),"");$disabled$jscomp$7_klass$jscomp$3$$=$APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4857$focus$$,$APP.$cljs$core$_deref$$($focus_QMARK_$jscomp$1$$),$APP.$cljs$cst$4839$valid$$,$APP.$cljs$core$truth_$$($form$jscomp$161_touched_QMARK_$jscomp$3$$)?$APP.$cljs$core$not$$($error$jscomp$79$$):$form$jscomp$161_touched_QMARK_$jscomp$3$$,$APP.$cljs$cst$4858$invalid$$,
$APP.$cljs$core$truth_$$($form$jscomp$161_touched_QMARK_$jscomp$3$$)?$error$jscomp$79$$:$form$jscomp$161_touched_QMARK_$jscomp$3$$,$APP.$cljs$cst$2959$disabled$$,$disabled$jscomp$7_klass$jscomp$3$$]));$map__72953__$1_props__$1$jscomp$46$$=$APP.$rumext$v2$util$map__GT_props$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__72953__$1_props__$1$jscomp$46$$,$APP.$cljs$cst$4850$help_icon$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$179$form$$,$APP.$cljs$cst$3736$trim$$])),$APP.$cljs$cst$260$value$$,$value$jscomp$737$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4853$on_focus$$,function(){return $APP.$cljs$core$reset_BANG_$$($focus_QMARK_$jscomp$1$$,!0)},$APP.$cljs$cst$4854$on_blur$$,function(){$APP.$cljs$core$reset_BANG_$$($focus_QMARK_$jscomp$1$$,!1);return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$7$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$1$$],null)))?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$7$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$1$$],null),!0)},$APP.$cljs$cst$4224$on_change$$,function($event$jscomp$133$$){return $APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form__$1$jscomp$7$$,
$input_name$jscomp$1$$,$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$133$$)),$trim$jscomp$2$$)}])));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:""+($disabled$jscomp$7_klass$jscomp$3$$??"")+" main_ui_components_forms__textarea-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{className:"main_ui_components_forms__textarea-label",children:$label$jscomp$27_map__72953_props_72950$$}),(0,$APP.$rumext$v2$create_element$$)("textarea",$map__72953__$1_props__$1$jscomp$46$$),
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($form$jscomp$161_touched_QMARK_$jscomp$3$$)?$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$79$$):$form$jscomp$161_touched_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__error",children:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$79$$)}):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($form$jscomp$161_touched_QMARK_$jscomp$3$$)?$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$79$$):
$form$jscomp$161_touched_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__error",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$79$$))}):typeof $hint$jscomp$12$$==="string"?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__hint",children:$hint$jscomp$12$$}):null]})};
$app$main$data$profile$update_photo$$=function($file$jscomp$39$$){typeof $app$main$data$profile$update_photo_55241$$==="undefined"&&($app$main$data$profile$update_photo_55241$$=function($file$jscomp$40$$,$meta55242$$){this.file=$file$jscomp$40$$;this.$meta55242$=$meta55242$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$update_photo_55241$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_photo_55241$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3257$app_DOT_main_DOT_data_DOT_profile_SLASH_update_photo$$},$app$main$data$profile$update_photo_55241$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55243$$,$meta55242__$1$$){return new $app$main$data$profile$update_photo_55241$$(this.file,$meta55242__$1$$)},$app$main$data$profile$update_photo_55241$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55242$},$app$main$data$profile$update_photo_55241$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_photo_55241$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},$app$main$data$profile$update_photo_55241$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_photo_55241$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){$APP.$app$main$data$media$notify_start_loading$$();return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55231_SHARP_$$){$APP.$app$main$data$media$notify_finished_loading$$();
return $APP.$app$main$data$media$process_error$$($p1__55231_SHARP_$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$media$notify_finished_loading$$,$APP.$beicon$v2$core$mapcat$$(function($p1__55232_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2294$update_profile_photo$$,$p1__55232_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($file__$1$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$208$file$$,$file__$1$$],null)},$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,(0,$APP.$beicon$v2$core$of$$)(this.file)))))))});return new $app$main$data$profile$update_photo_55241$$($file$jscomp$39$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$delete_subscription$$=function(){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1224$subscriptions$$)?$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$(null),$APP.$app$util$http$fetch$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1584$uri$$,"/payments/subscriptions/delete",$APP.$cljs$cst$1588$credentials$$,
"include",$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$],null)))):$APP.$beicon$v2$core$empty$$()};
$app$main$data$profile$request_account_deletion$$=function(){var $params$jscomp$187$$=$APP.$cljs$core$with_meta$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1300$on_error$$,$app$main$ui$settings$delete_account$on_error$$],null));typeof $app$main$data$profile$request_account_deletion_55335$$==="undefined"&&($app$main$data$profile$request_account_deletion_55335$$=function($params$jscomp$188$$,$meta55336$$){this.params=$params$jscomp$188$$;
this.$meta55336$=$meta55336$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$request_account_deletion_55335$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$request_account_deletion_55335$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3265$app_DOT_main_DOT_data_DOT_profile_SLASH_request_account_deletion$$},$app$main$data$profile$request_account_deletion_55335$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55337$$,$meta55336__$1$$){return new $app$main$data$profile$request_account_deletion_55335$$(this.params,$meta55336__$1$$)},$app$main$data$profile$request_account_deletion_55335$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55336$},$app$main$data$profile$request_account_deletion_55335$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$request_account_deletion_55335$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$3617$$=this,$map__55378_on_error$jscomp$9$$=$APP.$cljs$core$meta$$($self__$jscomp$3617$$.params),$map__55378__$1_on_success$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($map__55378_on_error$jscomp$9$$);$map__55378_on_error$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55378__$1_on_success$jscomp$5$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);$map__55378__$1_on_success$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55378__$1_on_success$jscomp$5$$,
$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);return $APP.$beicon$v2$core$concat$$($app$main$data$profile$delete_subscription$$(),$APP.$beicon$v2$core$delay_at_least$$(300,$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55378_on_error$jscomp$9$$,$APP.$beicon$v2$core$map$$(function(){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3264$app_DOT_main_DOT_data_DOT_profile_SLASH_profile_deleted$$,$self__$jscomp$3617$$.params)},
$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55378__$1_on_success$jscomp$5$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3266$delete_profile$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))))))});return new $app$main$data$profile$request_account_deletion_55335$$($params$jscomp$187$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$update_password$$=function($data$jscomp$269_data__$1$jscomp$9$$){$data$jscomp$269_data__$1$jscomp$9$$=(0,$APP.$app$main$data$profile$check_update_password$$)($data$jscomp$269_data__$1$jscomp$9$$);typeof $app$main$data$profile$update_password_55103$$==="undefined"&&($app$main$data$profile$update_password_55103$$=function($data$jscomp$270$$,$meta55104$$){this.data=$data$jscomp$270$$;this.$meta55104$=$meta55104$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$profile$update_password_55103$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_password_55103$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3242$app_DOT_main_DOT_data_DOT_profile_SLASH_update_password$$},$app$main$data$profile$update_password_55103$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55105$$,$meta55104__$1$$){return new $app$main$data$profile$update_password_55103$$(this.data,
$meta55104__$1$$)},$app$main$data$profile$update_password_55103$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55104$},$app$main$data$profile$update_password_55103$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_password_55103$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},$app$main$data$profile$update_password_55103$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_password_55103$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55108_map__55108__$1_on_success$jscomp$3$$=$APP.$cljs$core$meta$$(this.data);$map__55108_map__55108__$1_on_success$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__55108_map__55108__$1_on_success$jscomp$3$$);var $on_error$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55108_map__55108__$1_on_success$jscomp$3$$,$APP.$cljs$cst$1300$on_error$$,
$APP.$cljs$core$identity$$);$map__55108_map__55108__$1_on_success$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55108_map__55108__$1_on_success$jscomp$3$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);var $params$jscomp$186$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1135$old_password$$,$APP.$cljs$cst$3241$password_old$$.$cljs$core$IFn$_invoke$arity$1$(this.data),$APP.$cljs$cst$751$password$$,$APP.$cljs$cst$3239$password_1$$.$cljs$core$IFn$_invoke$arity$1$(this.data)],
null);return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($err$jscomp$34$$){$on_error$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$on_error$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$34$$):$on_error$jscomp$7$$($err$jscomp$34$$);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55108_map__55108__$1_on_success$jscomp$3$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3243$update_profile_password$$,
$params$jscomp$186$$))))});return new $app$main$data$profile$update_password_55103$$($data$jscomp$269_data__$1$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$update_notifications$$=function($options$jscomp$489_options__$1$jscomp$68$$){$options$jscomp$489_options__$1$jscomp$68$$=(0,$APP.$app$main$data$profile$check_update_notifications_params$$)($options$jscomp$489_options__$1$jscomp$68$$);typeof $app$main$data$profile$update_notifications_55134$$==="undefined"&&($app$main$data$profile$update_notifications_55134$$=function($options$jscomp$490$$,$meta55135$$){this.options=$options$jscomp$490$$;this.$meta55135$=$meta55135$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$update_notifications_55134$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_notifications_55134$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3247$app_DOT_main_DOT_data_DOT_profile_SLASH_update_notifications$$},$app$main$data$profile$update_notifications_55134$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55136$$,$meta55135__$1$$){return new $app$main$data$profile$update_notifications_55134$$(this.options,
$meta55135__$1$$)},$app$main$data$profile$update_notifications_55134$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55135$},$app$main$data$profile$update_notifications_55134$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_notifications_55134$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$},$app$main$data$profile$update_notifications_55134$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_notifications_55134$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1680$$,$state$jscomp$201$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$201$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3248$notifications$$,this.options)},
$app$main$data$profile$update_notifications_55134$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_notifications_55134$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.notifications.notifications-saved"))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3249$update_profile_notifications$$,
this.options))});return new $app$main$data$profile$update_notifications_55134$$($options$jscomp$489_options__$1$jscomp$68$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$profile$update_profile$$=function($profile$jscomp$9_profile__$1$jscomp$2$$){$profile$jscomp$9_profile__$1$jscomp$2$$=(0,$APP.$app$main$data$profile$check_profile$$)($profile$jscomp$9_profile__$1$jscomp$2$$);typeof $app$main$data$profile$update_profile_55026$$==="undefined"&&($app$main$data$profile$update_profile_55026$$=function($profile$jscomp$10$$,$meta55027$$){this.profile=$profile$jscomp$10$$;this.$meta55027$=$meta55027$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$profile$update_profile_55026$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_profile_55026$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3233$app_DOT_main_DOT_data_DOT_profile_SLASH_update_profile$$},$app$main$data$profile$update_profile_55026$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55028$$,$meta55027__$1$$){return new $app$main$data$profile$update_profile_55026$$(this.profile,
$meta55027__$1$$)},$app$main$data$profile$update_profile_55026$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55027$},$app$main$data$profile$update_profile_55026$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$update_profile_55026$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1671_profile_SINGLEQUOTE_$$,$profile__$1$jscomp$3_state$jscomp$198$$){$_$jscomp$1671_profile_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile__$1$jscomp$3_state$jscomp$198$$,
$APP.$cljs$cst$1931$profile$$);$profile__$1$jscomp$3_state$jscomp$198$$=$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1671_profile_SINGLEQUOTE_$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.profile,$APP.$cljs$cst$575$props$$));return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$set_profile$$($profile__$1$jscomp$3_state$jscomp$198$$)),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$3_state$jscomp$198$$),
$APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1671_profile_SINGLEQUOTE_$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"activate-theme",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings",$APP.$cljs$cst$3208$theme$$,$APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$3_state$jscomp$198$$)],
null))):null)});return new $app$main$data$profile$update_profile_55026$$($profile$jscomp$9_profile__$1$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$settings$change_email$on_error$$=function($form$jscomp$220$$,$cause$jscomp$122$$){var $map__93452__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$122$$)),$G__93453$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93452__$1$$,$APP.$cljs$cst$273$code$$);switch($G__93453$$ instanceof $APP.$cljs$core$Keyword$$?$G__93453$$.$fqn$:null){case "email-already-exists":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$220$$,
function($data$jscomp$542$$){var $error__$1$jscomp$9$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-already-exists")],null);return $APP.$cljs$core$assoc_in$$($data$jscomp$542$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$cljs$cst$6738$email_1$$],null),$error__$1$jscomp$9$$)});case "profile-is-muted":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")));
case "email-has-permanent-bounces":case "email-has-complaints":return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-has-permanent-bounces",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($map__93452__$1$$)]))));default:return $APP.$beicon$v2$core$throw$0$$($cause$jscomp$122$$)}};
$app$main$ui$settings$change_email$on_success$$=function($message$jscomp$128_profile$jscomp$102$$,$data$jscomp$543$$){if($APP.$cljs$core$truth_$$($cljs$cst$6739$changed$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$543$$)))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$refresh_profile$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]));$message$jscomp$128_profile$jscomp$102$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("notifications.validation-email-sent",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($message$jscomp$128_profile$jscomp$102$$)]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$02$$($message$jscomp$128_profile$jscomp$102$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))};
$app$main$ui$settings$change_email$on_submit$$=function($profile$jscomp$103$$,$form$jscomp$221$$){var $params$jscomp$475$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3207$email$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$221$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$cljs$cst$6738$email_1$$],null))],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$request_email_change$$($APP.$cljs$core$with_meta$$($params$jscomp$475$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1300$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$settings$change_email$on_error$$,$form$jscomp$221$$),$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$settings$change_email$on_success$$,$profile$jscomp$103$$)],null))))};
$app$main$ui$settings$change_email$change_email_modal$$=function(){var $profile$jscomp$104$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$form$jscomp$222$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$change_email$schema_COLON_email_change_form$$,$APP.$cljs$cst$4840$initial$$,$profile$jscomp$104$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,
$app$main$ui$settings$change_email$schema_COLON_email_change_form$$,$APP.$cljs$cst$4840$initial$$,$profile$jscomp$104$$),$on_submit$jscomp$22$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$104$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$settings$change_email$on_submit$$,$profile$jscomp$104$$));return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_change_email__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_settings_change_email__modal-container",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$222$$,"on-submit":$on_submit$jscomp$22$$,children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_change_email__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{"data-testid":"change-email-title",className:"main_ui_settings_change_email__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.change-email.title")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_settings_change_email__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_change_email__modal-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:$APP.$cljs$cst$1161$info$$,content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.change-email.info",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$104$$)]))}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_change_email__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"email",name:$cljs$cst$6738$email_1$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.change-email.new-email"),trim:!0,"show-success?":!0})}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_settings_change_email__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"email",name:$cljs$cst$6740$email_2$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.change-email.confirm-email"),trim:!0,"show-success?":!0})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_change_email__modal-footer",children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"change-email-submit",className:"main_ui_settings_change_email__action-buttons",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.change-email.submit")})})})]})})})};
$app$main$ui$settings$delete_account$on_error$$=function($cause$jscomp$123_msg$jscomp$52$$){var $code$jscomp$68$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$123_msg$jscomp$52$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6741$owner_teams_with_people$$,$code$jscomp$68$$)?($cause$jscomp$123_msg$jscomp$52$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.profile-deletion-not-allowed"),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($cause$jscomp$123_msg$jscomp$52$$))):
$APP.$beicon$v2$core$throw$0$$($cause$jscomp$123_msg$jscomp$52$$)};
$app$main$ui$settings$delete_account$delete_account_modal$$=function(){var $orgs_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$orgs$jscomp$4$$=$APP.$cljs$core$_deref$$($orgs_STAR_$$),$has_orgs_QMARK_$$=$APP.$cljs$core$seq$$($orgs$jscomp$4$$),$expanded_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$expanded_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($expanded_STAR_$jscomp$2$$),$on_toggle$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($expanded_STAR_$jscomp$2$$,
$APP.$cljs$core$not$$)}),$on_accept$jscomp$23$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$profile$request_account_deletion$$()]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)){var $sub$jscomp$32$$=
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$399$$){return $APP.$cljs$core$reset_BANG_$$($orgs_STAR_$$,$APP.$cljs$core$truth_$$($result$jscomp$399$$)?$result$jscomp$399$$:$APP.$cljs$core$PersistentVector$EMPTY$$)},function(){return $APP.$cljs$core$reset_BANG_$$($orgs_STAR_$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6742$get_owned_organizations_summary$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$));
return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$32$$)}}return $APP.$cljs$core$reset_BANG_$$($orgs_STAR_$$,$APP.$cljs$core$PersistentVector$EMPTY$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_delete_account__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",
{className:"main_ui_settings_delete_account__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-account.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_settings_delete_account__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_delete_account__warning-notice",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:$APP.$cljs$cst$2354$warning$$,content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($has_orgs_QMARK_$$?"modals.delete-account.info.with-orgs":"modals.delete-account.info")})}),$has_orgs_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__orgs-section",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{type:"button","aria-expanded":$expanded_QMARK_$jscomp$5$$,
onClick:$on_toggle$jscomp$4$$,className:"main_ui_settings_delete_account__orgs-section-toggle",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_delete_account__orgs-section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-account.owned-orgs.list-title")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s",className:"main_ui_settings_delete_account__orgs-section-arrow "+($APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$5$$)?
"main_ui_settings_delete_account__expanded":"")})]}),$APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_settings_delete_account__org-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$269$$,$map__93467__$1_p__93466$$){$map__93467__$1_p__93466$$=$APP.$cljs$core$__destructure_map$$($map__93467__$1_p__93466$$);var $id$jscomp$1149$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93467__$1_p__93466$$,
$APP.$cljs$cst$266$id$$),$name$jscomp$531$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93467__$1_p__93466$$,$APP.$cljs$cst$725$name$$),$team_count$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93467__$1_p__93466$$,$cljs$cst$6743$team_count$$),$member_count$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93467__$1_p__93466$$,$cljs$cst$6744$member_count$$);$out_arr__44092__auto__$jscomp$269$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_settings_delete_account__org-item",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$,{org:$map__93467__$1_p__93466$$,size:"xxl"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__org-info",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_delete_account__org-name",children:$name$jscomp$531$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__org-counts",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-account.owned-orgs.teams-count",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$truth_$$($team_count$$)?$team_count$$:0)]))}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-account.owned-orgs.members-count",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$truth_$$($member_count$$)?$member_count$$:0)]))})]})]})]},$id$jscomp$1149$$));return $out_arr__44092__auto__$jscomp$269$$},
[],$orgs$jscomp$4$$)}):null]}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_delete_account__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_delete_account__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_settings_delete_account__cancel-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-account.cancel")}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$on_accept$jscomp$23$$,"data-testid":"delete-account-btn",className:"main_ui_settings_delete_account__accept-button main_ui_settings_delete_account__danger",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-account.confirm")})]})})]})})};
$app$main$ui$settings$feedback$feedback_form_STAR_$$=function($on_submit$jscomp$23_profile$jscomp$105_props_93471$$){var $error_report$$=$on_submit$jscomp$23_profile$jscomp$105_props_93471$$.errorReport,$type$jscomp$758$$=$on_submit$jscomp$23_profile$jscomp$105_props_93471$$.type,$error_href$jscomp$1$$=$on_submit$jscomp$23_profile$jscomp$105_props_93471$$.errorHref;$on_submit$jscomp$23_profile$jscomp$105_props_93471$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);var $initial$jscomp$43_on_download$jscomp$5$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($error_href$jscomp$1$$),$APP.$rumext$v2$adapt$$($error_report$$)],function(){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$6746$subject$$,"",$APP.$cljs$cst$139$type$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$758$$,""),$APP.$cljs$cst$1642$content$$,"",$APP.$cljs$cst$5525$error_href$$,$error_href$jscomp$1$$,
$cljs$cst$6747$error_report$$,$error_report$$],null))}),$form$jscomp$223$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$feedback$schema_COLON_feedback_form$$,$APP.$cljs$cst$4840$initial$$,$initial$jscomp$43_on_download$jscomp$5$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$feedback$schema_COLON_feedback_form$$,$APP.$cljs$cst$4840$initial$$,
$initial$jscomp$43_on_download$jscomp$5$$),$loading$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$report$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($error_report$$)],function(){return $APP.$cljs$core$truth_$$($error_report$$)?$APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($error_report$$,"text/plain"):null});$initial$jscomp$43_on_download$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($report$jscomp$5$$)],
function($event$jscomp$806$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$806$$);var $uri$jscomp$118$$=$APP.$app$util$webapi$create_uri$$($report$jscomp$5$$);$APP.$app$util$dom$trigger_download_uri$$("report","text/plain",$uri$jscomp$118$$);return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$webapi$revoke_uri$$($uri$jscomp$118$$)})});var $on_succes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$23_profile$jscomp$105_props_93471$$)],
function(){$APP.$cljs$core$reset_BANG_$$($loading$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.feedback-sent")));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$223$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1631$touched$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$]))}),$on_error$jscomp$77$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$23_profile$jscomp$105_props_93471$$)],function($code$jscomp$69_map__93473__$1_p__93472$$){$code$jscomp$69_map__93473__$1_p__93472$$=$APP.$cljs$core$__destructure_map$$($code$jscomp$69_map__93473__$1_p__93472$$);$code$jscomp$69_map__93473__$1_p__93472$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$69_map__93473__$1_p__93472$$,
$APP.$cljs$cst$273$code$$);$APP.$cljs$core$reset_BANG_$$($loading$$,!1);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$69_map__93473__$1_p__93472$$,$cljs$cst$6748$feedback_disabled$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.feedback-disabled"))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")))});
$on_submit$jscomp$23_profile$jscomp$105_props_93471$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit$jscomp$23_profile$jscomp$105_props_93471$$)],function($data$jscomp$545_form__$1$jscomp$23$$){$APP.$cljs$core$reset_BANG_$$($loading$$,!0);$data$jscomp$545_form__$1$jscomp$23$$=$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$545_form__$1$jscomp$23$$));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($on_succes$$,
$on_error$jscomp$77$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6749$send_user_feedback$$,$data$jscomp$545_form__$1$jscomp$23$$))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"class":"main_ui_settings_feedback__feedback-form","on-submit":$on_submit$jscomp$23_profile$jscomp$105_props_93471$$,form:$form$jscomp$223$$,children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_settings_feedback__field-title main_ui_settings_feedback__feedback-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.title-contact-us")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_feedback__field-text main_ui_settings_feedback__feedback-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.subtitle")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_feedback__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.subject"),
name:$cljs$cst$6746$subject$$,"show-success?":!0})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_feedback__fields-row",children:[(0,$APP.$rumext$v2$jsx$$)("label",{className:"main_ui_settings_feedback__field-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.type")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.type"),name:$APP.$cljs$cst$139$type$$,options:new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.type.idea"),$APP.$cljs$cst$260$value$$,"idea"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.type.issue"),$APP.$cljs$cst$260$value$$,"issue"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.type.doubt"),$APP.$cljs$cst$260$value$$,"doubt"],null)],null)})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_feedback__fields-row main_ui_settings_feedback__description",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$forms$textarea$$,{"class":"main_ui_settings_feedback__feedback-description",label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.description"),name:$APP.$cljs$cst$1642$content$$,
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.description-placeholder"),rows:5})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_feedback__fields-row",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_feedback__field-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.penpot.link")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{label:"",name:$APP.$cljs$cst$5525$error_href$$,placeholder:"https://penpot.app/",
"show-success?":!0}),$APP.$cljs$core$truth_$$($report$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$initial$jscomp$43_on_download$jscomp$5$$,className:"main_ui_settings_feedback__link main_ui_settings_feedback__download-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.download",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["report.txt"]))}):null]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($loading$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.sending"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.send"),className:"main_ui_settings_feedback__feedback-button-link",disabled:$APP.$cljs$core$_deref$$($loading$$)}),(0,$APP.$rumext$v2$jsx$$)("hr",{}),(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_settings_feedback__feedback-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.other-ways-contact")}),(0,$APP.$rumext$v2$jsx$$)("a",
{href:"https://community.penpot.app",target:"_blank",className:"main_ui_settings_feedback__link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.discourse-title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_feedback__field-text main_ui_settings_feedback__bottom-margin",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.discourse-subtitle1")}),(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://x.com/penpotapp",target:"_blank",className:"main_ui_settings_feedback__link",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.twitter-title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_feedback__field-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("feedback.twitter-subtitle1")})]})};
$app$main$ui$settings$feedback$feedback_page_STAR_$$=function($props_93478$$){var $error_report_id$jscomp$2_report$jscomp$6$$=$props_93478$$.errorReportId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("title.settings.feedback"))});$error_report_id$jscomp$2_report$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($error_report_id$jscomp$2_report$jscomp$6$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$errors$last_report$$))?$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$errors$last_report$$):null;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_feedback__dashboard-settings",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_feedback__form-container",children:(0,$APP.$rumext$v2$create_element$$)($app$main$ui$settings$feedback$feedback_form_STAR_$$,{...$props_93478$$,
errorReport:$error_report_id$jscomp$2_report$jscomp$6$$})})})};
$app$main$ui$settings$integrations$input_copy_STAR_$$=function($props_93479$$){var $on_copy_to_clipboard$$=$props_93479$$.onCopyToClipboard;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__input-copy",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"text",defaultValue:$props_93479$$.value,readOnly:!0}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__input-copy-button-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"secondary",className:"main_ui_settings_integrations__input-copy-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.copy-to-clipboard"),onClick:$on_copy_to_clipboard$$,icon:"clipboard"})})]})};
$app$main$ui$settings$integrations$token_created_STAR_$$=function($props_93480_title$jscomp$57$$){var $is_mcp$$=$props_93480_title$jscomp$57$$.isMcp;$props_93480_title$jscomp$57$$=$props_93480_title$jscomp$57$$.title;var $token_created$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$access_token_created$$),$on_copy_to_clipboard$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_created$$)],function($event$jscomp$807$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$807$$);
$APP.$app$util$clipboard$to_clipboard$$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($token_created$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$1642$content$$,$APP.$cljs$core$truth_$$($is_mcp$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.mcp-key-copied"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.token-copied"),$APP.$cljs$cst$2364$timeout$$,7E3],null)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-form",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"h2",typography:"headline-large",className:"main_ui_settings_integrations__color-primary",children:$props_93480_title$jscomp$57$$}),$APP.$cljs$core$truth_$$($is_mcp$$)?
null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,{level:$APP.$cljs$cst$1161$info$$,type:$APP.$cljs$cst$2320$context$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-small",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.token.info.non-recuperable")})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_settings_integrations__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$input_copy_STAR_$$,{value:$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$2$($token_created$$,""),onCopyToClipboard:$on_copy_to_clipboard$jscomp$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-small",className:"main_ui_settings_integrations__color-secondary",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$4407$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($token_created$$))?
$APP.$cljs$core$truth_$$($is_mcp$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("integrations.mcp-key.will-expire",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4407$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($token_created$$),"PPP")])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("integrations.token.will-expire",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4407$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($token_created$$),
"PPP")])):$APP.$cljs$core$truth_$$($is_mcp$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-key.will-not-expire"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.token.will-not-expire")})]}),$APP.$cljs$core$truth_$$($is_mcp$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-small",className:"main_ui_settings_integrations__color-primary",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.info.mcp-client-config")}),(0,$APP.$rumext$v2$jsx$$)("textarea",{wrap:"off",rows:7,readOnly:!0,value:'{\n  "mcpServers": {\n    "penpot": {\n      "url": "'+($APP.$app$config$mcp_server_url$$??"")+"?userToken\x3d"+($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$2$($token_created$$,"")??"")+'"\n    }\n  }\n}',className:"main_ui_settings_integrations__textarea"})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-footer",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")})})]})};
$app$main$ui$settings$integrations$create_token_STAR_$$=function($info$jscomp$11_props_93481$$){var $is_mcp$jscomp$1$$=$info$jscomp$11_props_93481$$.isMcp,$on_created$$=$info$jscomp$11_props_93481$$.onCreated,$title$jscomp$58$$=$info$jscomp$11_props_93481$$.title;$info$jscomp$11_props_93481$$=$info$jscomp$11_props_93481$$.info;var $form$jscomp$224$$=$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4840$initial$$,
$APP.$cljs$core$truth_$$($is_mcp$jscomp$1$$)?$app$main$ui$settings$integrations$form_initial_data_mcp_token$$:$app$main$ui$settings$integrations$form_initial_data_access_token$$,$APP.$cljs$cst$298$schema$$,$APP.$cljs$core$truth_$$($is_mcp$jscomp$1$$)?$app$main$ui$settings$integrations$schema_COLON_form_mcp_token$$:$app$main$ui$settings$integrations$schema_COLON_form_access_token$$])),$on_error$jscomp$78$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}),$on_success$jscomp$59$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_created$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_created$$)?$on_created$$.$cljs$core$IFn$_invoke$arity$0$?$on_created$$.$cljs$core$IFn$_invoke$arity$0$():$on_created$$():null}),$on_submit$jscomp$24$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_mcp$jscomp$1$$)],
function($form__$1$jscomp$24_mdata$jscomp$32$$){var $G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$=$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$24_mdata$jscomp$32$$));$form__$1$jscomp$24_mdata$jscomp$32$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_success$jscomp$59$$,$form__$1$jscomp$24_mdata$jscomp$32$$),
$APP.$cljs$cst$1300$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_error$jscomp$78$$,$form__$1$jscomp$24_mdata$jscomp$32$$)],null);var $expiration$jscomp$1$$=$APP.$cljs$cst$5223$expiration_date$$.$cljs$core$IFn$_invoke$arity$1$($G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$);$G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$),$cljs$cst$6750$perms$$,$cljs$cst$6750$perms$$.$cljs$core$IFn$_invoke$arity$1$($G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$)],null);$G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("never",
$expiration$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$,$cljs$cst$6751$expiration$$,$expiration$jscomp$1$$):$G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$;$G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$=$is_mcp$jscomp$1$$===!0?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$,
$APP.$cljs$cst$139$type$$,"mcp",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,"MCP key"])):$G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$create_access_token$$($APP.$cljs$core$with_meta$$($G__93482$jscomp$inline_10904_G__93482__$1$jscomp$inline_10905_cdata$jscomp$5_params$jscomp$476$$,$form__$1$jscomp$24_mdata$jscomp$32$$)))});
return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$forms$form_STAR_$$,{form:$form$jscomp$224$$,className:"main_ui_settings_integrations__modal-form",onSubmit:$on_submit$jscomp$24$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"h2",typography:"headline-large",className:"main_ui_settings_integrations__color-primary",children:$title$jscomp$58$$}),$info$jscomp$11_props_93481$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,
{level:$APP.$cljs$cst$1161$info$$,type:$APP.$cljs$cst$2320$context$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-small",className:"main_ui_settings_integrations__color-primary",children:$info$jscomp$11_props_93481$$})}):null,$APP.$cljs$core$truth_$$($is_mcp$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.info.mcp-server")})}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,{type:"text",autoFocus:!0,form:$form$jscomp$224$$,name:$APP.$cljs$cst$725$name$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.name.label"),
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.name.placeholder")})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"label",typography:"body-small",htmlFor:"expiration-date",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.expiration-date.label")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_select_STAR_$$,{options:new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.expiration-never"),$APP.$cljs$cst$260$value$$,"never",$APP.$cljs$cst$266$id$$,"never"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.expiration-30-days"),
$APP.$cljs$cst$260$value$$,"720h",$APP.$cljs$cst$266$id$$,"720h"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.expiration-60-days"),$APP.$cljs$cst$260$value$$,"1440h",$APP.$cljs$cst$266$id$$,"1440h"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.expiration-90-days"),$APP.$cljs$cst$260$value$$,
"2160h",$APP.$cljs$cst$266$id$$,"2160h"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.expiration-180-days"),$APP.$cljs$cst$260$value$$,"4320h",$APP.$cljs$cst$266$id$$,"4320h"],null)],null),defaultSelected:"never",name:$APP.$cljs$cst$5223$expiration_date$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"secondary",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_submit_STAR_$$,{variant:"primary",children:$title$jscomp$58$$})]})]})};
$app$main$ui$settings$integrations$create_access_token_modal$$=function(){var $created_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_close$jscomp$55$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($created_QMARK_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_created$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($created_QMARK_$$,
!0);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.created")))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_settings_integrations__modal-close-button",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$55$$,icon:"close"})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($created_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$token_created_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.create-access-token.title.created")}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$create_token_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.create-access-token.title"),onCreated:$on_created$jscomp$1$$})]})})};
$app$main$ui$settings$integrations$generate_mcp_token_modal$$=function(){var $created_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_close$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($created_QMARK_$jscomp$1$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_created$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$4400$mcp_enabled$$,!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.created")),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"generate-mcp-key",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"integrations"],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"enable-mcp",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"integrations",$APP.$cljs$cst$193$source$$,"key-creation"],null)),$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4411$mcp_SLASH_enable$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]));return $APP.$cljs$core$reset_BANG_$$($created_QMARK_$jscomp$1$$,!0)});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-close-button",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
onClick:$on_close$jscomp$56$$,icon:"close"})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($created_QMARK_$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$token_created_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.generate-mcp-key.title.created"),isMcp:!0}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$create_token_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.generate-mcp-key.title"),
isMcp:!0,onCreated:$on_created$jscomp$2$$})]})})};$app$main$ui$settings$integrations$mcp_access_token_QMARK_$$=function($atoken$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("mcp",$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($atoken$$))};
$app$main$ui$settings$integrations$regenerate_mcp_token_modal$$=function(){var $created_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_close$jscomp$57$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($created_QMARK_$jscomp$2$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_created$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$4400$mcp_enabled$$,!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.created")),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"regenerate-mcp-key",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"integrations"],null)),$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4411$mcp_SLASH_enable$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]));return $APP.$cljs$core$reset_BANG_$$($created_QMARK_$jscomp$2$$,!0)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__modal-close-button",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$57$$,icon:"close"})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($created_QMARK_$jscomp$2$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$token_created_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.regenerate-mcp-key.title.created"),
isMcp:!0}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$create_token_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.regenerate-mcp-key.title"),info:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.regenerate-mcp-key.info"),isMcp:!0,onCreated:$on_created$jscomp$3$$})]})})};
$app$main$ui$settings$integrations$mcp_server_section_STAR_$$=function($props_93490_token$jscomp$230$$){var $access_tokens$jscomp$4$$=$props_93490_token$jscomp$230$$.accessTokens,$enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$props_93490_token$jscomp$230$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($access_tokens$jscomp$4$$)],function(){var $JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$settings$integrations$mcp_access_token_QMARK_$$,$access_tokens$jscomp$4$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$)){var $JSCompiler_temp_const$jscomp$2349$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$map__93489__$1$jscomp$inline_10908$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$),$expires_at$jscomp$inline_10909$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93489__$1$jscomp$inline_10908$$,$APP.$cljs$cst$4407$expires_at$$);$JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$=$JSCompiler_temp_const$jscomp$2349$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$,$cljs$cst$6754$is_valid$$,$APP.$cljs$core$truth_$$($map__93489__$1$jscomp$inline_10908$$)?$expires_at$jscomp$inline_10909$$==null||$expires_at$jscomp$inline_10909$$>$APP.$app$common$time$now$$():
!1)}else $JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$=null;return $JSCompiler_temp$jscomp$2348_temp__5825__auto__$jscomp$491$$});var $token_valid_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_93490_token$jscomp$230$$,$cljs$cst$6754$is_valid$$),$show_enabled_QMARK_$jscomp$1_token_str$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_93490_token$jscomp$230$$,$APP.$cljs$cst$1136$token$$);$enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$=
$APP.$cljs$core$boolean$0$$($APP.$cljs$cst$4400$mcp_enabled$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$)));var $url$jscomp$108$$=""+($APP.$app$config$mcp_server_url$$??"")+"?userToken\x3d"+($show_enabled_QMARK_$jscomp$1_token_str$jscomp$1$$??"");$show_enabled_QMARK_$jscomp$1_token_str$jscomp$1$$=$enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$?$token_valid_QMARK_$$:
$enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$;$enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$=(0,$APP.$rumext$v2$use_id$$)();var $handle_mcp_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$1225$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4400$mcp_enabled$$,$value$jscomp$1225$$],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$1642$content$$,$value$jscomp$1225$$===!0?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.mcp-server-enabled"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.mcp-server-disabled"),
$APP.$cljs$cst$2364$timeout$$,7E3],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$value$jscomp$1225$$===!0?"enable-mcp":"disable-mcp",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"integrations",$APP.$cljs$cst$193$source$$,"toggle"],null)),$APP.$cljs$core$truth_$$($value$jscomp$1225$$)?$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4411$mcp_SLASH_enable$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):
$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4412$mcp_SLASH_disable$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}),$handle_open_modal_generate$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$6752$generate_mcp_token$$],null)))}),$handle_open_modal_regenerate$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$6753$regenerate_mcp_token$$],null)))}),$handle_delete$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1151$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$profile$delete_access_token$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1151$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$fetch_access_tokens$$())}],null))),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4400$mcp_enabled$$,!1],null)),$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4412$mcp_SLASH_disable$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}),$on_copy_to_clipboard$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($url$jscomp$108$$)],function($event$jscomp$808$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$808$$);$APP.$app$util$clipboard$to_clipboard$$($url$jscomp$108$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.notification.success.copied-link"),$APP.$cljs$cst$2364$timeout$$,7E3],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"copy-mcp-url",
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"integrations"],null))]))});return(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_settings_integrations__mcp-server-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"title-medium",className:"main_ui_settings_integrations__color-primary main_ui_settings_integrations__mcp-server-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.title")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_settings_integrations__beta",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.title.beta")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-secondary",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.description")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"h3",typography:"headline-small",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.status")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__mcp-server-block",
children:[$props_93490_token$jscomp$230$$!=null&&$APP.$cljs$core$not$$($token_valid_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,{level:$APP.$cljs$cst$849$error$$,type:$APP.$cljs$cst$2320$context$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__mcp-server-notification",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",
className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.status.expired.0")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.status.expired.1")})]})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__mcp-server-switch",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,{label:$APP.$cljs$core$truth_$$($show_enabled_QMARK_$jscomp$1_token_str$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.status.enabled"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.status.disabled"),defaultChecked:$show_enabled_QMARK_$jscomp$1_token_str$jscomp$1$$,onChange:$handle_mcp_change$$}),$APP.$cljs$core$truth_$$($props_93490_token$jscomp$230$$)?
null:(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$handle_open_modal_generate$$,className:"main_ui_settings_integrations__mcp-server-switch-cover"}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_93490_token$jscomp$230$$)?$APP.$cljs$core$not$$($token_valid_QMARK_$$):$props_93490_token$jscomp$230$$)?(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$handle_open_modal_regenerate$$,className:"main_ui_settings_integrations__mcp-server-switch-cover"}):null]})]})]}),$props_93490_token$jscomp$230$$!=null?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_settings_integrations__mcp-server-key",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"h3",typography:"headline-small",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.mcp-keys.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__mcp-server-block",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__mcp-server-regenerate",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",className:"main_ui_settings_integrations__fit-content",onClick:$handle_open_modal_regenerate$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.mcp-keys.regenerate")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.mcp-keys.tootip"),id:$enabled_QMARK_$jscomp$10_profile$jscomp$106_tooltip_id$jscomp$7$$,
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"info",className:"main_ui_settings_integrations__color-secondary"})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$token_item_STAR_$$,{id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_93490_token$jscomp$230$$),name:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_93490_token$jscomp$230$$),
expiresAt:$APP.$cljs$cst$4407$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($props_93490_token$jscomp$230$$),onDelete:$handle_delete$jscomp$4$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_93490_token$jscomp$230$$))})]})]}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,{level:$APP.$cljs$cst$205$default$$,type:$APP.$cljs$cst$2320$context$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__mcp-server-notification",
children:[$APP.$cljs$core$truth_$$($props_93490_token$jscomp$230$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.mcp-keys.info")}):null,$APP.$cljs$core$truth_$$($props_93490_token$jscomp$230$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$input_copy_STAR_$$,{value:$url$jscomp$108$$,
onCopyToClipboard:$on_copy_to_clipboard$jscomp$2$$}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-secondary",children:(0,$APP.$rumext$v2$jsxs$$)("a",{href:"https://help.penpot.app/mcp/",target:"_blank",rel:"noopener noreferrer",className:"main_ui_settings_integrations__mcp-server-notification-link",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.mcp-server.mcp-keys.help"),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"open-link"})]})})]})})]})};
$app$main$ui$settings$integrations$access_tokens_section_STAR_$$=function($access_tokens__$1_props_93492$$){var $access_tokens$jscomp$5$$=$access_tokens__$1_props_93492$$.accessTokens;$access_tokens__$1_props_93492$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($access_tokens$jscomp$5$$)],function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__93491_SHARP_$$){return $APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__93491_SHARP_$$)==null},
$access_tokens$jscomp$5$$))});var $handle_click$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3276$create_access_token$$],null)))}),$handle_delete$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($token_id$jscomp$27$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$delete_access_token$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$token_id$jscomp$27$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$fetch_access_tokens$$())}],null))))});return(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_settings_integrations__access-tokens-section",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,
typography:"title-medium",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.access-tokens.personal")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.access-tokens.personal.description")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"primary",className:"main_ui_settings_integrations__fit-content",onClick:$handle_click$jscomp$8$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.access-tokens.create")}),$APP.$cljs$core$truth_$$($access_tokens__$1_props_93492$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$270$$,$map__93494__$1_p__93493$$){$map__93494__$1_p__93493$$=
$APP.$cljs$core$__destructure_map$$($map__93494__$1_p__93493$$);var $id$jscomp$1152$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93494__$1_p__93493$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$270$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$token_item_STAR_$$,{id:$id$jscomp$1152$$,name:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__93494__$1_p__93493$$),expiresAt:$APP.$cljs$cst$4407$expires_at$$.$cljs$core$IFn$_invoke$arity$1$($map__93494__$1_p__93493$$),
onDelete:$handle_delete$jscomp$5$$},""+($id$jscomp$1152$$??"")));return $out_arr__44092__auto__$jscomp$270$$},[],$access_tokens__$1_props_93492$$)}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_integrations__frame",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_settings_integrations__color-secondary main_ui_settings_integrations__text-center",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.access-tokens.empty.no-access-tokens")}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.access-tokens.empty.add-one")})]})})]})};
$app$main$ui$settings$integrations$integrations_page_STAR_$$=function(){var $props$jscomp$432$$={accessTokens:$APP.$rumext$v2$deref$$($APP.$app$main$refs$access_tokens$$)},$access_tokens_enabled_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1177$access_tokens$$),$mcp_enabled_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1237$mcp$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("title.settings.integrations"));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$fetch_access_tokens$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__integrations",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:1,typography:"title-large",className:"main_ui_settings_integrations__color-primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.title")}),
$mcp_enabled_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$settings$integrations$mcp_server_section_STAR_$$,$props$jscomp$432$$):null,$mcp_enabled_QMARK_$jscomp$2$$&&$access_tokens_enabled_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_settings_integrations__separator"}):null,$access_tokens_enabled_QMARK_$$?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$settings$integrations$access_tokens_section_STAR_$$,$props$jscomp$432$$):null]})};
$app$main$ui$settings$notifications$on_submit$$=function($form$jscomp$225_params$jscomp$479$$){$form$jscomp$225_params$jscomp$479$$=$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$225_params$jscomp$479$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$update_notifications$$($form$jscomp$225_params$jscomp$479$$))};
$app$main$ui$settings$notifications$notifications_page_STAR_$$=function($form$jscomp$226_props_93496_settings$$){var $profile$jscomp$107$$=$form$jscomp$226_props_93496_settings$$.profile;$form$jscomp$226_props_93496_settings$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$107$$)],function(){return $APP.$cljs$core$update_vals$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$settings$notifications$default_notification_settings$$,
$APP.$cljs$cst$3248$notifications$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$107$$))])),$APP.$app$common$data$name$$)});$form$jscomp$226_props_93496_settings$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$notifications$schema_COLON_notifications_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$226_props_93496_settings$$):
$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$notifications$schema_COLON_notifications_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$226_props_93496_settings$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("title.settings.notifications"))});return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_settings_notifications__notifications-page",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$form$$,{"class":"main_ui_settings_notifications__notifications-form","on-submit":$app$main$ui$settings$notifications$on_submit$$,form:$form$jscomp$226_props_93496_settings$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_notifications__form-container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.title")}),(0,$APP.$rumext$v2$jsx$$)("h3",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.dashboard.title")}),(0,$APP.$rumext$v2$jsx$$)("h4",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.dashboard-comments.title")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_notifications__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$radio_buttons$$,{options:new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.dashboard-comments.all"),$APP.$cljs$cst$260$value$$,"all"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.dashboard-comments.partial"),$APP.$cljs$cst$260$value$$,
"partial"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.dashboard-comments.none"),$APP.$cljs$cst$260$value$$,"none"],null)],null),name:$APP.$cljs$cst$3244$dashboard_comments$$,"class":"main_ui_settings_notifications__radio-btns"})}),(0,$APP.$rumext$v2$jsx$$)("h3",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email.title")}),
(0,$APP.$rumext$v2$jsx$$)("h4",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-comments.title")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_notifications__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$radio_buttons$$,{options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-comments.all"),$APP.$cljs$cst$260$value$$,"all"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-comments.partial"),$APP.$cljs$cst$260$value$$,"partial"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-comments.none"),
$APP.$cljs$cst$260$value$$,"none"],null)],null),name:$APP.$cljs$cst$3245$email_comments$$,"class":"main_ui_settings_notifications__radio-btns"})}),(0,$APP.$rumext$v2$jsx$$)("h4",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-invites.title")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_notifications__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$radio_buttons$$,{options:new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-invites.all"),$APP.$cljs$cst$260$value$$,"all"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.email-invites.none"),$APP.$cljs$cst$260$value$$,"none"],
null)],null),name:$APP.$cljs$cst$3246$email_invites$$,"class":"main_ui_settings_notifications__radio-btns"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.settings.notifications.submit"),disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$226_props_93496_settings$$)),$APP.$cljs$cst$4840$initial$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$226_props_93496_settings$$))),
"data-testid":"submit-settings",className:"main_ui_settings_notifications__update-btn"})]})})})};$app$main$ui$settings$options$on_success$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.profile-saved")))};
$app$main$ui$settings$options$on_submit$$=function($data$jscomp$546_form$jscomp$227$$){$data$jscomp$546_form$jscomp$227$$=$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$546_form$jscomp$227$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$profile$update_profile$$($data$jscomp$546_form$jscomp$227$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$profile$persist_profile$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2499$on_success$$,$app$main$ui$settings$options$on_success$$],null)]))]))};
$app$main$ui$settings$options$options_form_STAR_$$=function(){var $profile$jscomp$108$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$form$jscomp$228_initial$jscomp$44$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$108$$)],function(){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($profile$jscomp$108$$,$APP.$cljs$cst$2839$lang$$,function($p1__93497_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__93497_SHARP_$$)?
$p1__93497_SHARP_$$:""}),$APP.$cljs$cst$3208$theme$$,function($p1__93498_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__93498_SHARP_$$,"default")?"dark":$APP.$cljs$core$truth_$$($p1__93498_SHARP_$$)?$p1__93498_SHARP_$$:"dark"})});$form$jscomp$228_initial$jscomp$44$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$options$schema_COLON_options_form$$,
$APP.$cljs$cst$4840$initial$$,$form$jscomp$228_initial$jscomp$44$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$options$schema_COLON_options_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$228_initial$jscomp$44$$);return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"class":"main_ui_settings_options__options-form","on-submit":$app$main$ui$settings$options$on_submit$$,form:$form$jscomp$228_initial$jscomp$44$$,children:[(0,$APP.$rumext$v2$jsx$$)("h3",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.language")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_options__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{options:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,"Auto (browser)",$APP.$cljs$cst$260$value$$,
""],null)],null),$APP.$app$util$i18n$supported_locales$$),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.select-ui-language"),"default":"",name:$APP.$cljs$cst$2839$lang$$,"data-testid":"setting-lang"})}),(0,$APP.$rumext$v2$jsx$$)("h3",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.theme-change")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_options__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,
{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.select-ui-theme"),name:$APP.$cljs$cst$3208$theme$$,"default":"dark",options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.select-ui-theme.dark"),$APP.$cljs$cst$260$value$$,"dark"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.select-ui-theme.light"),$APP.$cljs$cst$260$value$$,"light"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.select-ui-theme.system"),$APP.$cljs$cst$260$value$$,"system"],null)],null),"data-testid":"setting-theme"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.update-settings"),
disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$228_initial$jscomp$44$$)),$APP.$cljs$cst$4840$initial$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$228_initial$jscomp$44$$))),"data-testid":"submit-lang-change",className:"main_ui_settings_options__btn-primary"})]})};
$app$main$ui$settings$options$go_settings_feedback$$=function($event$jscomp$809$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$809$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2520$settings_feedback$$))};
$app$main$ui$settings$options$webgl_settings_STAR_$$=function($props_93500_wasm_renderer_QMARK_$$){$props_93500_wasm_renderer_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_93500_wasm_renderer_QMARK_$$.renderer,$APP.$cljs$cst$3128$wasm$$);var $handle_render_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($enabled_QMARK_$jscomp$11$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$11$$)?"enable-webgl-rendering":"disable-webgl-rendering",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3129$renderer$$,$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$11$$)?
$APP.$cljs$cst$3128$wasm$$:$APP.$cljs$cst$1543$svg$$],null)),$APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$11$$)?"webgl.toast.webgl-render-enabled":"webgl.toast.webgl-render-disabled"))]))});return(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_settings_options__webgl-container",children:[(0,$APP.$rumext$v2$jsxs$$)("header",{className:"main_ui_settings_options__webgl-header",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{className:"main_ui_settings_options__title",level:2,typography:"title-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.title")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",className:"main_ui_settings_options__beta",typography:"body-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.beta")})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{className:"main_ui_settings_options__description",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.description")}),(0,$APP.$rumext$v2$jsxs$$)("form",{className:"main_ui_settings_options__webgl-form",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:3,typography:"headline-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.status")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,{label:$props_93500_wasm_renderer_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.enabled"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.disabled"),defaultChecked:$props_93500_wasm_renderer_QMARK_$$,onChange:$handle_render_change$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-medium",
className:"main_ui_settings_options__feedback",children:(0,$APP.$rumext$v2$jsxs$$)("a",{href:"#",onClick:$app$main$ui$settings$options$go_settings_feedback$$,className:"main_ui_settings_options__link",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webgl-switch.feedback"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-up-right",size:"s"})]})})]})};
$app$main$ui$settings$options$options_page_STAR_$$=function(){var $profile$jscomp$109$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$renderer$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1523$$=$APP.$cljs$cst$3129$renderer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$109$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1523$$)?$or__5025__auto__$jscomp$1523$$:$APP.$cljs$cst$1543$svg$$}();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("title.settings.options"))});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_options__dashboard-settings",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"settings-form",className:"main_ui_settings_options__form-container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.settings")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$options$options_form_STAR_$$,{})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1198$render_switch$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$options$webgl_settings_STAR_$$,{renderer:$renderer$jscomp$4$$}):null]})})};
$app$main$ui$settings$password$on_error$$=function($form$jscomp$229_msg$jscomp$53$$,$G__93502_error$jscomp$163$$){$G__93502_error$jscomp$163$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($G__93502_error$jscomp$163$$));switch($G__93502_error$jscomp$163$$ instanceof $APP.$cljs$core$Keyword$$?$G__93502_error$jscomp$163$$.$fqn$:null){case "old-password-not-match":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$229_msg$jscomp$53$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$3241$password_old$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.wrong-old-password")],null));case "email-as-password":return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$229_msg$jscomp$53$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$3239$password_1$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.email-as-password")],null));default:return $form$jscomp$229_msg$jscomp$53$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("generic.error"),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($form$jscomp$229_msg$jscomp$53$$))}};
$app$main$ui$settings$password$on_success$$=function($form$jscomp$230_password_old_node$$){$APP.$cljs$core$reset_BANG_$$($form$jscomp$230_password_old_node$$,null);$form$jscomp$230_password_old_node$$=$APP.$goog$dom$getElement$$("password-old");var $msg$jscomp$54$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.notifications.password-saved");$form$jscomp$230_password_old_node$$!=null&&($form$jscomp$230_password_old_node$$.value="");$APP.$app$util$dom$focus_BANG_$$($form$jscomp$230_password_old_node$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$02$$($msg$jscomp$54$$))};
$app$main$ui$settings$password$on_submit$$=function($form$jscomp$231_params$jscomp$480$$,$event$jscomp$810$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$810$$);$form$jscomp$231_params$jscomp$480$$=$APP.$cljs$core$with_meta$$($APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$231_params$jscomp$480$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$settings$password$on_success$$,
$form$jscomp$231_params$jscomp$480$$),$APP.$cljs$cst$1300$on_error$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$settings$password$on_error$$,$form$jscomp$231_params$jscomp$480$$)],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$update_password$$($form$jscomp$231_params$jscomp$480$$))};
$app$main$ui$settings$password$password_form_STAR_$$=function(){var $form$jscomp$232_initial$jscomp$45$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3241$password_old$$,"",$APP.$cljs$cst$3239$password_1$$,"",$APP.$cljs$cst$3240$password_2$$,""],null)});$form$jscomp$232_initial$jscomp$45$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,
$app$main$ui$settings$password$schema_COLON_password_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$232_initial$jscomp$45$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$password$schema_COLON_password_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$232_initial$jscomp$45$$);return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"class":"main_ui_settings_password__password-form","on-submit":$app$main$ui$settings$password$on_submit$$,form:$form$jscomp$232_initial$jscomp$45$$,
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_password__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"password",name:$APP.$cljs$cst$3241$password_old$$,"auto-focus?":!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.old-password")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_password__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"password",
name:$APP.$cljs$cst$3239$password_1$$,"show-success?":!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.new-password")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_password__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"password",name:$APP.$cljs$cst$3240$password_2$$,"show-success?":!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.confirm-password")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,
{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.password-change"),"data-testid":"submit-password",className:"main_ui_settings_password__update-btn"})]})};
$app$main$ui$settings$password$password_page_STAR_$$=function(){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("title.settings.password"))});return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_settings_password__dashboard-settings",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_password__form-container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.password-change")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$password$password_form_STAR_$$,{})]})})};
$app$main$ui$settings$profile$on_submit$$=function($form$jscomp$233$$){var $data$jscomp$548$$=$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$233$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$profile$update_profile$$($data$jscomp$548$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$profile$persist_profile$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2499$on_success$$,function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$233$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1631$touched$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.profile-saved")))}],null)]))]))};
$app$main$ui$settings$profile$profile_form_STAR_$$=function(){var $form$jscomp$234_profile$jscomp$110$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$form$jscomp$234_profile$jscomp$110$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$app$main$ui$settings$profile$schema_COLON_profile_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$234_profile$jscomp$110$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,
$app$main$ui$settings$profile$schema_COLON_profile_form$$,$APP.$cljs$cst$4840$initial$$,$form$jscomp$234_profile$jscomp$110$$);var $on_show_change_email$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$6404$change_email$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}),$on_show_delete_account$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$6745$delete_account$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"on-submit":$app$main$ui$settings$profile$on_submit$$,form:$form$jscomp$234_profile$jscomp$110$$,"class":"main_ui_settings_profile__profile-form",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_profile__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"text",name:$APP.$cljs$cst$1365$fullname$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-name")})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_show_change_email$$,className:"main_ui_settings_profile__fields-row",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"email",name:$APP.$cljs$cst$3207$email$$,disabled:!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-email")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_profile__options",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"change-email",children:(0,$APP.$rumext$v2$jsx$$)("a",
{onClick:$on_show_change_email$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.change-email")})})})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.save-settings"),disabled:$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1631$touched$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$234_profile$jscomp$110$$))),className:"main_ui_settings_profile__btn-primary"}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_profile__links",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_profile__link-item",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_show_delete_account$$,"data-testid":"remove-acount-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.remove-account")})})})]})};
$app$main$ui$settings$profile$profile_photo_form_STAR_$$=function(){var $input_ref$jscomp$17$$=(0,$APP.$rumext$v2$use_ref$$)(null),$profile$jscomp$111$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$has_photo_QMARK_$$=$APP.$cljs$cst$1364$photo_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$111$$)!=null,$photo$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$111$$)],function(){return $APP.$app$config$resolve_profile_photo_url$$($profile$jscomp$111$$)}),
$on_image_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$17$$))}),$on_delete_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$811$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$811$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete-profile-photo.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete-profile-photo.message"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$delete_photo$$)}],
null)))});return(0,$APP.$rumext$v2$jsx$$)("form",{className:"main_ui_settings_profile__avatar-form",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_profile__image-change-field",children:[(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$on_image_click$jscomp$1$$,className:"main_ui_settings_profile__update-overlay",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.update")}),(0,$APP.$rumext$v2$jsx$$)("img",{src:$photo$jscomp$1$$}),$has_photo_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("button",
{type:"button",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),onClick:$on_delete_click$$,"data-testid":"profile-image-delete",className:"main_ui_settings_profile__delete-overlay",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"delete",size:"m"})}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,
{accept:"image/jpeg,image/png",multi:!1,ref:$input_ref$jscomp$17$$,"on-selected":function($file$jscomp$228$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$update_photo$$($file$jscomp$228$$))},"data-testid":"profile-image-input"})]})})};
$app$main$ui$settings$profile$profile_page_STAR_$$=function(){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("title.settings.profile"))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_profile__dashboard-settings",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_profile__form-container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.profile")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$profile$profile_photo_form_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$profile$profile_form_STAR_$$,{})]})})};$app$main$ui$settings$sidebar$go_settings_profile$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5477$settings_profile$$))};
$app$main$ui$settings$sidebar$go_settings_feedback$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2520$settings_feedback$$))};$app$main$ui$settings$sidebar$go_settings_password$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$6466$settings_password$$))};
$app$main$ui$settings$sidebar$go_settings_options$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$6467$settings_options$$))};$app$main$ui$settings$sidebar$go_settings_subscription$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5225$settings_subscription$$))};
$app$main$ui$settings$sidebar$go_settings_integrations$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$6468$settings_integrations$$))};$app$main$ui$settings$sidebar$go_settings_notifications$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$6469$settings_notifications$$))};
$app$main$ui$settings$sidebar$show_release_notes$$=function($event$jscomp$812$$){var $version$jscomp$63$$=$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"show-release-notes",$APP.$cljs$cst$1726$version$$,$version$jscomp$63$$],null)));return $event$jscomp$812$$.altKey&&
$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$812$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1223$onboarding$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$5476$release_notes$$,$APP.$cljs$cst$1726$version$$,$version$jscomp$63$$],null)))};
$app$main$ui$settings$sidebar$sidebar_content_STAR_$$=function($profile_QMARK__props_93511$$){var $profile$jscomp$112$$=$profile_QMARK__props_93511$$.profile,$notifications_QMARK__section$jscomp$59$$=$profile_QMARK__props_93511$$.section;$profile_QMARK__props_93511$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,$APP.$cljs$cst$5477$settings_profile$$);var $password_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,
$APP.$cljs$cst$6466$settings_password$$),$options_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,$APP.$cljs$cst$6467$settings_options$$),$feedback_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,$APP.$cljs$cst$2520$settings_feedback$$),$subscription_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,$APP.$cljs$cst$5225$settings_subscription$$),
$integrations_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,$APP.$cljs$cst$6468$settings_integrations$$);$notifications_QMARK__section$jscomp$59$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($notifications_QMARK__section$jscomp$59$$,$APP.$cljs$cst$6469$settings_notifications$$);var $team_id$jscomp$197$$=function(){var $or__5025__auto__$jscomp$1524$$=$APP.$cljs$cst$3299$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$global$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1524$$)?$or__5025__auto__$jscomp$1524$$:$APP.$cljs$cst$2507$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$112$$)}(),$go_dashboard$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$197$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,
$team_id$jscomp$197$$])))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_sidebar__sidebar-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_sidebar__sidebar-content-section",children:(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$go_dashboard$$,className:"main_ui_settings_sidebar__back-to-dashboard",children:[$app$main$ui$settings$sidebar$arrow_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__back-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.dashboard")})]})}),
(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_settings_sidebar__sidebar-separator"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_sidebar__sidebar-content-section",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_settings_sidebar__sidebar-nav-settings",children:[(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_profile$$,className:($profile_QMARK__props_93511$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.profile")})}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_password$$,className:($password_QMARK_$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.password")})}),
(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_notifications$$,className:($notifications_QMARK__section$jscomp$59$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.notifications")})}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_options$$,
"data-testid":"settings-profile",className:($options_QMARK_$jscomp$1$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.settings")})}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1224$subscriptions$$)?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_subscription$$,
"data-testid":"settings-subscription",className:($subscription_QMARK_$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.labels")})}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1177$access_tokens$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1237$mcp$$)?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_integrations$$,"data-testid":"settings-integrations",className:($integrations_QMARK_$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.integrations")})}):null,(0,$APP.$rumext$v2$jsx$$)("hr",
{className:"main_ui_settings_sidebar__sidebar-separator"}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$app$main$ui$settings$sidebar$show_release_notes$$,"data-testid":"release-notes",className:"main_ui_settings_sidebar__settings-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.release-notes")})}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1228$user_feedback$$)?
(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$app$main$ui$settings$sidebar$go_settings_feedback$$,className:($feedback_QMARK_$$?"main_ui_settings_sidebar__current":"")+" main_ui_settings_sidebar__settings-item",children:[$app$main$ui$settings$sidebar$feedback_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_sidebar__element-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.contact-us")})]}):null]})})]})};
$app$main$ui$settings$subscription$get_subscription_name$$=function($subscription_type$jscomp$13$$,$subscribe_to_trial_QMARK_$$){if($APP.$cljs$core$truth_$$($subscribe_to_trial_QMARK_$$))return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$13$$,"unlimited")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise-trial");switch($subscription_type$jscomp$13$$){case "professional":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional");
case "unlimited":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited");case "enterprise":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$13$$)].join(""));}};
$app$main$ui$settings$subscription$editors_section_STAR_$$=function($editors$jscomp$5_props_93515$$){$editors$jscomp$5_props_93515$$=$editors$jscomp$5_props_93515$$.editors;var $show_editors_list_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_editors_list$$=$APP.$cljs$core$_deref$$($show_editors_list_STAR_$$),$handle_click$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$813$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$813$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_editors_list_STAR_$$,$APP.$cljs$core$not$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__editors-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.management.dialog.currently-editors-title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($editors$jscomp$5_props_93515$$))]))}),
(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$handle_click$jscomp$9$$,className:"main_ui_settings_subscription__cta-button main_ui_settings_subscription__show-editors-button",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management.dialog.editors"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($show_editors_list$$)?"arrow-up":"arrow-down",className:"main_ui_settings_subscription__icon-dropdown",
size:"s"})]}),$APP.$cljs$core$truth_$$($show_editors_list$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__editors-text main_ui_settings_subscription__editors-list-warning",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management.dialog.editors-explanation")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_settings_subscription__editors-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$272$$,
$editor$jscomp$13$$){$out_arr__44092__auto__$jscomp$272$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_settings_subscription__team-name",children:["- ",$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($editor$jscomp$13$$)]},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($editor$jscomp$13$$)??"")));return $out_arr__44092__auto__$jscomp$272$$},[],$editors$jscomp$5_props_93515$$)})]}):null]})};
$app$main$ui$settings$subscription$subscribe_management_dialog$$=function($editors$jscomp$6_map__93517_props_93516$$){$editors$jscomp$6_map__93517_props_93516$$=$APP.$rumext$v2$util$wrap_props$$($editors$jscomp$6_map__93517_props_93516$$);var $map__93517__$1_unlimited_modal_step$$=$APP.$cljs$core$__destructure_map$$($editors$jscomp$6_map__93517_props_93516$$),$subscription_type$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,$cljs$cst$6758$subscription_type$$),
$current_subscription$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,$cljs$cst$6759$current_subscription$$);$editors$jscomp$6_map__93517_props_93516$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,$APP.$cljs$cst$3225$editors$$);var $subscribe_to_trial$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,$cljs$cst$6760$subscribe_to_trial$$),$unlimited_modal_step_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(1);$map__93517__$1_unlimited_modal_step$$=$APP.$cljs$core$_deref$$($unlimited_modal_step_STAR_$$);var $subscription_name$$=$app$main$ui$settings$subscription$get_subscription_name$$($subscription_type$jscomp$14$$,$subscribe_to_trial$$),$min_editors$jscomp$1$$=$APP.$cljs$core$seq$$($editors$jscomp$6_map__93517_props_93516$$)?$APP.$cljs$core$count$$($editors$jscomp$6_map__93517_props_93516$$):1,$initial$jscomp$46_subscribe_to_enterprise$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min_editors$jscomp$1$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$6756$min_members$$,$min_editors$jscomp$1$$,$cljs$cst$6757$redirect_to_payment_details$$,!1],null)}),$handle_accept_dialog_schema$jscomp$247$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min_editors$jscomp$1$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"SeatsForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6756$min_members$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$960$app_DOT_common_DOT_schema_SLASH_number$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$338$min$$,
$min_editors$jscomp$1$$,$APP.$cljs$cst$339$max$$,9999],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6757$redirect_to_payment_details$$,$APP.$cljs$cst$421$boolean$$],null)],null)}),$form$jscomp$235$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,$handle_accept_dialog_schema$jscomp$247$$,$APP.$cljs$cst$4840$initial$$,
$initial$jscomp$46_subscribe_to_enterprise$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$handle_accept_dialog_schema$jscomp$247$$,$APP.$cljs$cst$4840$initial$$,$initial$jscomp$46_subscribe_to_enterprise$$),$submit_in_progress$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$subscribe_to_unlimited$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($min_members$$,$add_payment_details_QMARK__href$jscomp$23$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($submit_in_progress$$)))return null;
$APP.$rumext$v2$set_ref_val_BANG_$$($submit_in_progress$$,!0);var $return_url$$=encodeURIComponent($APP.$app$util$globals$location$$.href);$add_payment_details_QMARK__href$jscomp$23$$="payments/subscriptions/create?type\x3dunlimited\x26show\x3d"+($add_payment_details_QMARK__href$jscomp$23$$??"")+"\x26quantity\x3d"+($min_members$$??"")+"\x26returnUrl\x3d"+($return_url$$??"");$APP.$cljs$core$reset_BANG_$$($form$jscomp$235$$,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-trial-subscription",$APP.$cljs$cst$139$type$$,"unlimited",$APP.$cljs$cst$5232$quantity$$,$min_members$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2473$href$$,$add_payment_details_QMARK__href$jscomp$23$$]))]))});$initial$jscomp$46_subscribe_to_enterprise$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-trial-subscription",$APP.$cljs$cst$139$type$$,"enterprise"],null)));var $href$jscomp$24$$="payments/subscriptions/create?type\x3denterprise\x26returnUrl\x3d"+(encodeURIComponent($APP.$app$util$globals$location$$.href)??
"");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2473$href$$,$href$jscomp$24$$])))});$handle_accept_dialog_schema$jscomp$247$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-subscription-management",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings",$APP.$cljs$cst$1371$section$$,"subscription-management-modal"],null)));var $href_93538$$="payments/subscriptions/show?returnUrl\x3d"+(encodeURIComponent($APP.$app$util$globals$location$$.href)??"");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2473$href$$,
$href_93538$$])));return $APP.$app$main$data$modal$hide_BANG_$$()});var $handle_close_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"close-subscription-modal"],null)));return $APP.$app$main$data$modal$hide_BANG_$$()}),$on_submit$jscomp$25$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_subscription$$),
$APP.$rumext$v2$adapt$$($unlimited_modal_step_STAR_$$)],function($form__$1$jscomp$25_min_members$jscomp$1$$){var $clean_data$jscomp$1_redirect_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$25_min_members$jscomp$1$$),$APP.$cljs$cst$4838$clean_data$$);$form__$1$jscomp$25_min_members$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($clean_data$jscomp$1_redirect_QMARK_$$,$cljs$cst$6756$min_members$$);$clean_data$jscomp$1_redirect_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($clean_data$jscomp$1_redirect_QMARK_$$,$cljs$cst$6757$redirect_to_payment_details$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],null),null),$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($unlimited_modal_step_STAR_$$),
2)?$subscribe_to_unlimited$$.$cljs$core$IFn$_invoke$arity$2$?$subscribe_to_unlimited$$.$cljs$core$IFn$_invoke$arity$2$($form__$1$jscomp$25_min_members$jscomp$1$$,$clean_data$jscomp$1_redirect_QMARK_$$):$subscribe_to_unlimited$$($form__$1$jscomp$25_min_members$jscomp$1$$,$clean_data$jscomp$1_redirect_QMARK_$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($unlimited_modal_step_STAR_$$,$APP.$cljs$core$inc$$)}),$on_add_payments_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$235$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$6757$redirect_to_payment_details$$,!0]))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_close_dialog$$,className:"main_ui_settings_subscription__close-btn",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",size:"m"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-title main_ui_settings_subscription__subscription-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,2)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management-dialog.step-2-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.management.dialog.title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$subscription_name$$]))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-content",children:[$APP.$cljs$core$seq$$($editors$jscomp$6_map__93517_props_93516$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,2)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$editors_section_STAR_$$,{editors:$editors$jscomp$6_map__93517_props_93516$$}):null,
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$14$$,"professional")&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["enterprise",null,"unlimited",null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$14$$,"unlimited")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$),
"enterprise"))&&!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],null),null),$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$))&&$APP.$cljs$core$not$$($subscribe_to_trial$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management.dialog.downgrade")}):
null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1102$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$14$$,"unlimited");return $and__5023__auto__$jscomp$1102$$?$APP.$cljs$core$truth_$$($subscribe_to_trial$$)?$subscribe_to_trial$$:$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],null),null),$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$)):
$and__5023__auto__$jscomp$1102$$}())?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,{"on-submit":$on_submit$jscomp$25$$,"class":"main_ui_settings_subscription__seats-form",form:$form$jscomp$235$$,children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,1)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__editors-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_settings_subscription__fields-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{type:"number",name:$cljs$cst$6756$min_members$$,"show-error":!1,label:"","class":"main_ui_settings_subscription__input-field"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__editors-cost",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_settings_subscription__modal-text-medium",children:[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$235$$),
$APP.$cljs$cst$4838$clean_data$$),$cljs$cst$6756$min_members$$)>25?$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{className:"main_ui_settings_subscription__modal-text-cap",tagName:"span",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.management.dialog.price-month",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["175"]))}):null,$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{className:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$235$$),
$APP.$cljs$cst$4838$clean_data$$),$cljs$cst$6756$min_members$$)>25?"main_ui_settings_subscription__text-strikethrough":"",tagName:"span",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.management.dialog.price-month",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([7*function(){var $or__5025__auto__$jscomp$1527$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$235$$),
$APP.$cljs$cst$4838$clean_data$$),$cljs$cst$6756$min_members$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1527$$)?$or__5025__auto__$jscomp$1527$$:0}()]))})]}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__modal-text-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management.dialog.payment-explanation")})]})]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$235$$),
$APP.$cljs$cst$570$errors$$),$cljs$cst$6756$min_members$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__error-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management.dialog.input-error")}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__unlimited-capped-warning",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management.dialog.unlimited-capped-warning")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel"),onClick:$handle_close_dialog$$,className:"main_ui_settings_subscription__cancel-button"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,
{label:$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],null),null),$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.subscribe"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),className:"main_ui_settings_subscription__primary-button"})]})})]}):null,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__93517__$1_unlimited_modal_step$$,2)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__modal-text-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management-dialog.step-2-description")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_settings_subscription__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"submit",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management-dialog.step-2-skip-button"),className:"main_ui_settings_subscription__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"submit",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.management-dialog.step-2-add-payment-button"),onClick:$on_add_payments_click$$,
className:"main_ui_settings_subscription__primary-button"})]})})]}):null]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel"),onClick:$handle_close_dialog$$,className:"main_ui_settings_subscription__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",
{type:"button",value:$APP.$cljs$core$truth_$$($subscribe_to_trial$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.start-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),onClick:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($subscribe_to_trial$$)?$subscribe_to_trial$$:$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["unpaid",null,"canceled",null],
null),null),$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($current_subscription$$)))?$initial$jscomp$46_subscribe_to_enterprise$$:$handle_accept_dialog_schema$jscomp$247$$,className:"main_ui_settings_subscription__primary-button"})]})})]})]})})};
$app$main$ui$settings$subscription$subscription_success_dialog$$=function($map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$){$map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$=$APP.$rumext$v2$util$wrap_props$$($map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$);$map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$);$map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$,$cljs$cst$6762$subscription_name$$);var $profile$jscomp$114$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$handle_close_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"subscription-success"],null)));return $APP.$app$main$data$modal$hide_BANG_$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-dialog main_ui_settings_subscription__subscription-success",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_close_dialog$jscomp$1$$,className:"main_ui_settings_subscription__close-btn",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"close",size:"m"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-success-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-start",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("light",$APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$114$$))?"logo-subscription-light":"logo-subscription"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-end",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.success.dialog.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$]))}),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$,
"professional")?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__modal-text-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.success.dialog.thanks",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__93519_map__93519__$1_props_93518_subscription_name$jscomp$1$$]))}):null,(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__modal-text-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.success.dialog.description")}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__modal-text-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.success.dialog.footer")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__success-action-buttons",children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$handle_close_dialog$jscomp$1$$,className:"main_ui_settings_subscription__primary-button"})})]})]})]})})};
$app$main$ui$settings$subscription$subscription_page_STAR_$$=function($nitrate_start_error_QMARK__nitrate_start_error_message_props_93521$$){var $profile$jscomp$115$$=$nitrate_start_error_QMARK__nitrate_start_error_message_props_93521$$.profile,$member_since_route$jscomp$28$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$),$authenticated_QMARK_$jscomp$1$$=$APP.$app$main$data$auth$is_authenticated_QMARK_$$($profile$jscomp$115$$),$nitrate_license$jscomp$3$$=$APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$),
$nitrate_QMARK_$jscomp$5$$=$APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$115$$),$params_subscription$$=$APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($member_since_route$jscomp$28$$))),$show_trial_subscription_modal_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscription-to-penpot-unlimited")||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscription-to-penpot-enterprise"),$show_subscription_success_modal_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscribed-to-penpot-unlimited")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscribed-to-penpot-enterprise")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscribed-to-penpot-nitrate"),$nitrate_toast_message$$=
$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("nitrate-checkout-finish-error",$params_subscription$$):$APP.$cljs$core$_EQ_$$("nitrate-checkout-finish-error",$params_subscription$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.error.nitrate.checkout-finish-failed"):$APP.$cljs$core$truth_$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("nitrate-checkout-cancelled",
$params_subscription$$):$APP.$cljs$core$_EQ_$$("nitrate-checkout-cancelled",$params_subscription$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.error.nitrate.checkout-cancelled"):null,$nitrate_toast_level$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"nitrate-checkout-cancelled")?$APP.$cljs$cst$1161$info$$:$nitrate_toast_message$$!=null?$APP.$cljs$cst$849$error$$:null,$show_nitrate_start_error_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,
"nitrate-checkout-error"),$nitrate_start_error_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$nitrate_start_error_QMARK__nitrate_start_error_message_props_93521$$=$APP.$cljs$core$_deref$$($nitrate_start_error_STAR_$$);$nitrate_start_error_QMARK__nitrate_start_error_message_props_93521$$=$APP.$cljs$core$truth_$$($nitrate_start_error_QMARK__nitrate_start_error_message_props_93521$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.error.nitrate.checkout-failed"):
null;var $success_modal_is_trial_QMARK_$$=$APP.$cljs$cst$837$trial$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($member_since_route$jscomp$28$$))),$subscription_editors$$=$APP.$cljs$cst$3225$editors$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$))),$subscription$jscomp$11$$=
$APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$)),$subscription_type$jscomp$15$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)&&$nitrate_QMARK_$jscomp$5$$?$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$):$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($subscription$jscomp$11$$),$subscription_is_trial_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$11$$),"trialing");$member_since_route$jscomp$28$$=$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$),"d MMMM, yyyy");var $subscribed_since$$=$nitrate_QMARK_$jscomp$5$$?$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$),
"d MMMM, yyyy"):$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6764$start_date$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$11$$),"d MMMM, yyyy"),$go_to_pricing_page$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-pricing-click",
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings",$APP.$cljs$cst$1371$section$$,"subscription"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/pricing")}),$go_to_payments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"open-subscription-management",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings",$APP.$cljs$cst$1371$section$$,"subscription"],null)));var $href$jscomp$25$$="payments/subscriptions/show?returnUrl\x3d"+(encodeURIComponent($APP.$app$util$globals$location$$.href)??"");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2473$href$$,
$href$jscomp$25$$])))}),$open_subscription_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($subscription_editors$$),$APP.$rumext$v2$adapt$$($nitrate_license$jscomp$3$$)],function($subscription_type__$1$$,$current_subscription$jscomp$1$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-subscription-modal",
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings"],null)));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type__$1$$,"nitrate")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5226$nitrate_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5227$nitrate_license$$,$nitrate_license$jscomp$3$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$6761$management_dialog$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$6758$subscription_type$$,$subscription_type__$1$$,$cljs$cst$6759$current_subscription$$,$current_subscription$jscomp$1$$,$APP.$cljs$cst$3225$editors$$,$subscription_editors$$,$cljs$cst$6760$subscribe_to_trial$$,$APP.$cljs$core$not$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$11$$))],null)))}),$open_contact_sales_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($nitrate_license$jscomp$3$$)],
function($current_subscription$jscomp$2$$,$subscription_type__$1$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_subscription$jscomp$2$$,"unlimited")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5226$nitrate_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5227$nitrate_license$$,$nitrate_license$jscomp$3$$,$APP.$cljs$cst$5228$show_contact_sales_option$$,
!0],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$6765$nitrate_contact_sales_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$6758$subscription_type$$,$subscription_type__$1$jscomp$1$$],null)))}),$open_cancel_contact_sales_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$6766$nitrate_cancel_contact_sales_dialog$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3207$email$$,$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$)],null)))}),$connectivity_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$connectivity$jscomp$2$$=$APP.$cljs$core$_deref$$($connectivity_STAR_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.labels"))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($nitrate_QMARK_$jscomp$5$$)],function(){return $nitrate_QMARK_$jscomp$5$$?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__93520_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($connectivity_STAR_$$,$p1__93520_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5173$app_DOT_main_DOT_data_DOT_nitrate_SLASH_get_nitrate_connectivity$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)):
null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($authenticated_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($show_subscription_success_modal_QMARK_$$),$APP.$rumext$v2$adapt$$($show_trial_subscription_modal_QMARK_$$),$APP.$rumext$v2$adapt$$($show_nitrate_start_error_QMARK_$$),$APP.$rumext$v2$adapt$$($success_modal_is_trial_QMARK_$$),$APP.$rumext$v2$adapt$$($nitrate_toast_message$$),$APP.$rumext$v2$adapt$$($nitrate_toast_level$$),$APP.$rumext$v2$adapt$$($subscription$jscomp$11$$)],
function(){return $authenticated_QMARK_$jscomp$1$$?($show_nitrate_start_error_QMARK_$$&&$APP.$cljs$core$reset_BANG_$$($nitrate_start_error_STAR_$$,!0),$nitrate_toast_message$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$nitrate_toast_message$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$nitrate_toast_level$$,
$APP.$cljs$cst$2364$timeout$$,7E3],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$5225$settings_subscription$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2466$app_DOT_main_DOT_router_SLASH_replace$$,!0],null)]))])):$show_nitrate_start_error_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$5225$settings_subscription$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2466$app_DOT_main_DOT_router_SLASH_replace$$,!0],null)]))):$show_trial_subscription_modal_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-subscription-modal",
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"settings"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$6761$management_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$6758$subscription_type$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscription-to-penpot-unlimited")?"unlimited":"enterprise",$cljs$cst$6759$current_subscription$$,
$subscription$jscomp$11$$,$APP.$cljs$cst$3225$editors$$,$subscription_editors$$,$cljs$cst$6760$subscribe_to_trial$$,$APP.$cljs$core$not$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$11$$))],null)),$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$5225$settings_subscription$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2466$app_DOT_main_DOT_router_SLASH_replace$$,
!0],null)]))])):$show_subscription_success_modal_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscribed-to-penpot-nitrate")?$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5467$nitrate_activation_success$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$6763$subscription_success$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$6762$subscription_name$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($params_subscription$$,"subscribed-to-penpot-unlimited")?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($success_modal_is_trial_QMARK_$$,"true")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($success_modal_is_trial_QMARK_$$,
"true")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise")],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$5225$settings_subscription$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2466$app_DOT_main_DOT_router_SLASH_replace$$,!0],null)]))])):null):null});return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_settings_subscription__dashboard-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__dashboard-content",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_settings_subscription__title-section",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.labels")}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_settings_subscription__your-subscription",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_settings_subscription__plan-section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.section-plan")}),$nitrate_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{ctaLinkWithIcon:$APP.$cljs$core$not$$($APP.$cljs$cst$1678$manual$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$))?
$APP.$app$main$data$nitrate$go_to_nitrate_ac$$:null,cardTitleIcon:"character-b",cardTitle:"Enterprise",benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["Loren ipsum","Loren ipsum","Loren ipsum"],null),codeAction:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1678$manual$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$))?$cljs$cst$6767$renovate$$:null,ctaTextWithIcon:$APP.$cljs$core$not$$($APP.$cljs$cst$1678$manual$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$))?
"Admin Console":null,ctaLink:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1103$$=$APP.$cljs$cst$5470$licenses$$.$cljs$core$IFn$_invoke$arity$1$($connectivity$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1103$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1678$manual$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$)):$and__5023__auto__$jscomp$1103$$}())?$app$main$data$nitrate$go_to_nitrate_billing$$:$open_cancel_contact_sales_modal$$,ctaText:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1104$$=
$APP.$cljs$cst$5470$licenses$$.$cljs$core$IFn$_invoke$arity$1$($connectivity$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1104$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1678$manual$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$)):$and__5023__auto__$jscomp$1104$$}())?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.subscription.settings.manual-cancel"),
benefitsTitle:"Loren ipsum",cancelAt:$APP.$cljs$core$truth_$$($APP.$cljs$cst$5466$cancel_at$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("nitrate.subscription.active-until",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5466$cancel_at$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$),"d MMMM, yyyy")])):null}):
function(){switch($subscription_type$jscomp$15$$){case "professional":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional"),benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.storage-benefit"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.selfhost.control-over-data"),$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.autosave-benefit"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.selfhost.unlimited-users"),$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.teams-editors-benefit"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.selfhost.community-support")],null)});case "unlimited":return $subscription_is_trial_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{ctaLinkTrial:$go_to_payments$$,cardTitleIcon:"character-u",cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited-trial"),editors:$APP.$cljs$cst$5232$quantity$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$))),
benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.storage-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.autosave-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.bill")],null),ctaTextTrial:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.add-payment-to-continue"),
ctaLink:$go_to_payments$$,ctaText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription"),benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-professional-benefits")}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited"),cardTitleIcon:"character-u",benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-unlimited-benefits"),
benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.storage-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.autosave-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.bill")],null),ctaText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription"),
ctaLink:$go_to_payments$$,editors:$APP.$cljs$cst$5232$quantity$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$115$$)))});case "enterprise":return $subscription_is_trial_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise-trial"),cardTitleIcon:"character-e",
benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-unlimited-benefits"),benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.unlimited-storage-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.autosave"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.capped-bill")],
null),ctaText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription"),ctaLink:$go_to_payments$$,ctaTextTrial:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.add-payment-to-continue"),ctaLinkTrial:$go_to_payments$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise"),cardTitleIcon:"character-e",
benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-unlimited-benefits"),benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.unlimited-storage-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.autosave"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.capped-bill")],
null),ctaText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription"),ctaLink:$go_to_payments$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$15$$)].join(""));}}(),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__membership-container",children:[$APP.$cljs$core$truth_$$($nitrate_QMARK_$jscomp$5$$?$nitrate_QMARK_$jscomp$5$$:$APP.$cljs$core$truth_$$($subscribed_since$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"professional"):$subscribed_since$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__membership",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_settings_subscription__subscription-member",iconId:"crown",size:"m"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__membership-date",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.support-us-since",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$subscribed_since$$]))})]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__membership",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_settings_subscription__penpot-member",iconId:"user",size:"m"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__membership-date",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.member-since",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$member_since_route$jscomp$28$$]))})]})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__other-subscriptions",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_settings_subscription__plan-section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.other-plans")}),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,
"professional")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional"),priceValue:"$0",pricePeriod:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.price-editor-month"),benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.storage-benefit"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.selfhost.control-over-data"),$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.autosave-benefit"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.selfhost.unlimited-users"),$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.teams-editors-benefit"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional.selfhost.community-support")],null),ctaText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.subscribe"),ctaLink:$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)&&$nitrate_QMARK_$jscomp$5$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"nitrate")?$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1106$$=
$APP.$cljs$cst$5470$licenses$$.$cljs$core$IFn$_invoke$arity$1$($connectivity$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1106$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1678$manual$$.$cljs$core$IFn$_invoke$arity$1$($nitrate_license$jscomp$3$$)):$and__5023__auto__$jscomp$1106$$}())?$app$main$data$nitrate$go_to_nitrate_billing$$:$open_cancel_contact_sales_modal$$:$go_to_payments$$,ctaTextWithIcon:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.more-information"),
ctaLinkWithIcon:$go_to_pricing_page$$}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1107$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"unlimited");return $and__5023__auto__$jscomp$1107$$?$APP.$app$config$saas_QMARK_$$:$and__5023__auto__$jscomp$1107$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{ctaLinkWithIcon:$go_to_pricing_page$$,showButtonCta:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,
"professional"),cardTitleIcon:"character-u",cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited"),benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.storage-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.autosave-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited.bill")],
null),priceValue:"$7",ctaTextWithIcon:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.more-information"),ctaLink:$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)&&$nitrate_QMARK_$jscomp$5$$?function(){return $open_contact_sales_modal$$.$cljs$core$IFn$_invoke$arity$2$?$open_contact_sales_modal$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"Unlimited"):$open_contact_sales_modal$$($subscription_type$jscomp$15$$,
"Unlimited")}:function(){return $open_subscription_modal$$.$cljs$core$IFn$_invoke$arity$2$?$open_subscription_modal$$.$cljs$core$IFn$_invoke$arity$2$("unlimited",$subscription$jscomp$11$$):$open_subscription_modal$$("unlimited",$subscription$jscomp$11$$)},ctaText:$APP.$cljs$core$truth_$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$11$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.subscribe"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.try-it-free"),
benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-professional-benefits"),recommended:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"professional"),pricePeriod:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.price-editor-month")}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1108$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,
"enterprise");return $and__5023__auto__$jscomp$1108$$?$APP.$cljs$core$truth_$$($APP.$app$config$saas_QMARK_$$)?!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$):$APP.$app$config$saas_QMARK_$$:$and__5023__auto__$jscomp$1108$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{ctaLinkWithIcon:$go_to_pricing_page$$,showButtonCta:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"professional"),
cardTitleIcon:"character-e",cardTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise"),benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.unlimited-storage-benefit"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.autosave"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise.capped-bill")],
null),priceValue:"$950",ctaTextWithIcon:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.more-information"),ctaLink:function(){return $open_subscription_modal$$.$cljs$core$IFn$_invoke$arity$2$?$open_subscription_modal$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$subscription$jscomp$11$$):$open_subscription_modal$$("enterprise",$subscription$jscomp$11$$)},ctaText:$APP.$cljs$core$truth_$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($subscription$jscomp$11$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.subscribe"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.try-it-free"),benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-unlimited-benefits"),pricePeriod:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.price-organization-month")}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)&&
!$nitrate_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$plan_card_STAR_$$,{ctaLinkWithIcon:$go_to_pricing_page$$,showButtonCta:$APP.$cljs$core$not$$($nitrate_license$jscomp$3$$),cardTitleIcon:"character-n",cardTitle:"Enterprise",benefits:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["Crea organizaciones y añade personas, que usarán Penpot con las reglas que configures.","Acceso exclusivo a la Admin Console","Lorem ipsum"],
null),codeAction:$cljs$cst$6755$activate$$,priceValue:"$25",ctaTextWithIcon:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.more-information"),ctaLink:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"unlimited")?function(){return $open_contact_sales_modal$$.$cljs$core$IFn$_invoke$arity$2$?$open_contact_sales_modal$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$15$$,"Nitrate"):$open_contact_sales_modal$$($subscription_type$jscomp$15$$,
"Nitrate")}:function(){return $open_subscription_modal$$.$cljs$core$IFn$_invoke$arity$2$?$open_subscription_modal$$.$cljs$core$IFn$_invoke$arity$2$("nitrate",$subscription$jscomp$11$$):$open_subscription_modal$$("nitrate",$subscription$jscomp$11$$)},ctaText:$APP.$cljs$core$truth_$$($nitrate_license$jscomp$3$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.subscribe"):"Try 14 days for free",inlineError:$nitrate_start_error_QMARK__nitrate_start_error_message_props_93521$$,
benefitsTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.benefits.all-unlimited-benefits"),pricePeriod:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.organization-member-month")}):null]})]})})};
$app$main$ui$settings$subscription$subscribe_nitrate_dialog$$=function($map__93527_nitrate_license$jscomp$4_props_93526$$){$map__93527_nitrate_license$jscomp$4_props_93526$$=$APP.$rumext$v2$util$wrap_props$$($map__93527_nitrate_license$jscomp$4_props_93526$$);var $map__93527__$1_online_QMARK_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__93527_nitrate_license$jscomp$4_props_93526$$);$map__93527_nitrate_license$jscomp$4_props_93526$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93527__$1_online_QMARK_$jscomp$1$$,
$APP.$cljs$cst$5227$nitrate_license$$);var $show_contact_sales_option$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93527__$1_online_QMARK_$jscomp$1$$,$APP.$cljs$cst$5228$show_contact_sales_option$$);$map__93527__$1_online_QMARK_$jscomp$1$$=$APP.$cljs$cst$5470$licenses$$.$cljs$core$IFn$_invoke$arity$1$($map__93527__$1_online_QMARK_$jscomp$1$$);var $handle_close_dialog$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),
$on_subscribe_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$nitrate$go_to_buy_nitrate_license$$($APP.$app$util$globals$location$$.href)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_close_dialog$jscomp$2$$,className:"main_ui_settings_subscription__close-btn",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",size:"m"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-title main_ui_settings_subscription__subscription-title main_ui_settings_subscription__nitrate-subscription",children:"Subscribe to the Enterprise plan"}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__93527__$1_online_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($show_contact_sales_option$$):$map__93527__$1_online_QMARK_$jscomp$1$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-content",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-text main_ui_settings_subscription__price-text",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__price-value",children:"25$"}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.form.enterprise.price")]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text",children:"You won’t be charged right now. Payment will be processed at the end of the trial. Cancel anytime."}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel"),
onClick:$handle_close_dialog$jscomp$2$$,className:"main_ui_settings_subscription__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$cljs$core$truth_$$($map__93527_nitrate_license$jscomp$4_props_93526$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.subscribe"):"TRY 14 DAYS FOR FREE",onClick:$on_subscribe_click$$,className:"main_ui_settings_subscription__primary-button"})]})})]})}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-content main_ui_settings_subscription__modal-contact-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text",children:"Lorem ipsum lorem ipsum Lorem ipsum lorem ipsum Lorem ipsum lorem ipsum"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text",children:$APP.$cljs$core$truth_$$($map__93527_nitrate_license$jscomp$4_props_93526$$)?"Contact us to upgrade to Nitrate:":"Contact us to try Nitrate for 14 days:"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text",
children:(0,$APP.$rumext$v2$jsx$$)("a",{href:"mailto:sales@penpot.app",className:"main_ui_settings_subscription__cta-button",children:"sales@penpot.app"})})]})]})})};
$app$main$ui$settings$subscription$nitrate_contact_sales_dialog$$=function($map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$){$map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$=$APP.$rumext$v2$util$wrap_props$$($map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$);$map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$);$map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$,$cljs$cst$6758$subscription_type$$);var $handle_close_dialog$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-dialog",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_close_dialog$jscomp$3$$,className:"main_ui_settings_subscription__close-btn",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",size:"m"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-title main_ui_settings_subscription__subscription-title",children:"Switch to "+($map__93529_map__93529__$1_props_93528_subscription_type$jscomp$16$$??"")+" plan?"}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text-medium",children:"When you downgrade:"}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_settings_subscription__downgrade-list",children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_settings_subscription__downgrade-item",children:"Your organization will be deleted."}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_settings_subscription__downgrade-item",
children:"The teams, projects and files will no longer be part of any organization but they will remain available."}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_settings_subscription__downgrade-item",children:"Your total storage, auto-version history, and file recovery period will be limited."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__downgrade-warning",children:"To switch to this plan, please contact our sales team.\nWe’ll help you update your subscription and ensure everything is set up correctly."}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__action-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$handle_close_dialog$jscomp$3$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:function(){return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("mailto:sales@penpot.app?subject\x3dSwitch%20to%20the%20Unlimited%20plan")},
children:"Contact sales"})]})]})]})})};
$app$main$ui$settings$subscription$nitrate_cancel_contact_sales_dialog$$=function($email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$){$email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$=$APP.$rumext$v2$util$wrap_props$$($email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$);$email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$=$APP.$cljs$core$__destructure_map$$($email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$);
$email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$,$APP.$cljs$cst$3207$email$$);var $mailto_url$$="mailto:sales@penpot.net?subject\x3dRequest%20to%20Cancel%20Nitrate%20Subscription\x26body\x3dHello%2C%0A%0AI%20would%20like%20to%20cancel%20my%20Enterprise%20subscription.%0AAccount%20email%3A%20"+(encodeURIComponent($email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$)??
"")+".%0A%0AThank%20you.";$email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$email$jscomp$22_handle_close_dialog$jscomp$4_map__93531_map__93531__$1_props_93530$$,
className:"main_ui_settings_subscription__close-btn",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",size:"m"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-title main_ui_settings_subscription__subscription-title",children:"Cancel subscription"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__modal-text-medium",
children:"To cancel your Nitrate subscription, please contact us at:"}),(0,$APP.$rumext$v2$jsx$$)("a",{href:"mailto:sales@penpot.net",className:"main_ui_settings_subscription__cta-link",children:"sales@penpot.net"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__action-buttons",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_settings_subscription__button-full-width",variant:"primary",type:"button",onClick:function(){return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($mailto_url$$)},
children:"Contact us"})})]})]})})};
$app$main$ui$settings$settings_STAR_$$=function($props_93533$$){var $error_report_id$jscomp$3$$=$props_93533$$.errorReportId,$type$jscomp$759$$=$props_93533$$.type,$error_href$jscomp$2$$=$props_93533$$.errorHref,$section$jscomp$61$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($props_93533$$.route,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null)),$profile$jscomp$116$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);
$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6768$app_DOT_main_DOT_ui_DOT_settings_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$116$$)],function(){return $profile$jscomp$116$$==null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3181$authentication$$],
null))):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,{}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_settings__dashboard-layout-refactor main_ui_settings__dashboard",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$sidebar$sidebar_STAR_$$,{profile:$profile$jscomp$116$$,section:$section$jscomp$61$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings__dashboard-content",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$header_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_settings__dashboard-container",children:function(){var $G__93535__$1$$=$section$jscomp$61$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$61$$.$fqn$:null;switch($G__93535__$1$$){case "settings-profile":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$profile$profile_page_STAR_$$,{});case "settings-feedback":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$feedback$feedback_page_STAR_$$,
{type:$type$jscomp$759$$,errorReportId:$error_report_id$jscomp$3$$,errorHref:$error_href$jscomp$2$$});case "settings-password":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$password$password_page_STAR_$$,{});case "settings-options":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$options$options_page_STAR_$$,{});case "settings-subscription":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$subscription$subscription_page_STAR_$$,{profile:$profile$jscomp$116$$});case "settings-integrations":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$integrations$integrations_page_STAR_$$,
{});case "settings-notifications":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$notifications$notifications_page_STAR_$$,{profile:$profile$jscomp$116$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__93535__$1$$)].join(""));}}()})]})]})]})};$APP.$app$main$ui$settings$settings_page_STAR_$$=function($props_93539$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$settings$settings_STAR_$$,$props_93539$$)};
$cljs$cst$6760$subscribe_to_trial$$=new $APP.$cljs$core$Keyword$$(null,"subscribe-to-trial","subscribe-to-trial",-1105082881);$cljs$cst$6747$error_report$$=new $APP.$cljs$core$Keyword$$(null,"error-report","error-report",-2013083107);$cljs$cst$6742$get_owned_organizations_summary$$=new $APP.$cljs$core$Keyword$$(null,"get-owned-organizations-summary","get-owned-organizations-summary",1832305258);$cljs$cst$6746$subject$$=new $APP.$cljs$core$Keyword$$(null,"subject","subject",-1411880451);
$cljs$cst$6741$owner_teams_with_people$$=new $APP.$cljs$core$Keyword$$(null,"owner-teams-with-people","owner-teams-with-people",-1234064148);$cljs$cst$6762$subscription_name$$=new $APP.$cljs$core$Keyword$$(null,"subscription-name","subscription-name",-649250617);$cljs$cst$6759$current_subscription$$=new $APP.$cljs$core$Keyword$$(null,"current-subscription","current-subscription",-770910774);
$cljs$cst$6748$feedback_disabled$$=new $APP.$cljs$core$Keyword$$(null,"feedback-disabled","feedback-disabled",232152321);$cljs$cst$6753$regenerate_mcp_token$$=new $APP.$cljs$core$Keyword$$(null,"regenerate-mcp-token","regenerate-mcp-token",757159680);$cljs$cst$6740$email_2$$=new $APP.$cljs$core$Keyword$$(null,"email-2","email-2",-1475431959);$cljs$cst$6738$email_1$$=new $APP.$cljs$core$Keyword$$(null,"email-1","email-1",1974791786);
$cljs$cst$6744$member_count$$=new $APP.$cljs$core$Keyword$$(null,"member-count","member-count",753583042);$cljs$cst$6752$generate_mcp_token$$=new $APP.$cljs$core$Keyword$$(null,"generate-mcp-token","generate-mcp-token",-1284794878);$cljs$cst$6751$expiration$$=new $APP.$cljs$core$Keyword$$(null,"expiration","expiration",238846697);$cljs$cst$6764$start_date$$=new $APP.$cljs$core$Keyword$$(null,"start-date","start-date",295168731);
$cljs$cst$6768$app_DOT_main_DOT_ui_DOT_settings_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.settings","dashboard","app.main.ui.settings/dashboard",-311373545);$cljs$cst$6766$nitrate_cancel_contact_sales_dialog$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-cancel-contact-sales-dialog","nitrate-cancel-contact-sales-dialog",1687041612);$cljs$cst$6749$send_user_feedback$$=new $APP.$cljs$core$Keyword$$(null,"send-user-feedback","send-user-feedback",-1832564578);
$cljs$cst$6745$delete_account$$=new $APP.$cljs$core$Keyword$$(null,"delete-account","delete-account",725157341);$cljs$cst$6765$nitrate_contact_sales_dialog$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-contact-sales-dialog","nitrate-contact-sales-dialog",-944375545);$cljs$cst$6757$redirect_to_payment_details$$=new $APP.$cljs$core$Keyword$$(null,"redirect-to-payment-details","redirect-to-payment-details",-1904019116);
$cljs$cst$6758$subscription_type$$=new $APP.$cljs$core$Keyword$$(null,"subscription-type","subscription-type",1621034091);$cljs$cst$6756$min_members$$=new $APP.$cljs$core$Keyword$$(null,"min-members","min-members",1244570149);$cljs$cst$6755$activate$$=new $APP.$cljs$core$Keyword$$(null,"activate","activate",441219614);$cljs$cst$6743$team_count$$=new $APP.$cljs$core$Keyword$$(null,"team-count","team-count",484422508);$cljs$cst$6739$changed$$=new $APP.$cljs$core$Keyword$$(null,"changed","changed",570724917);
$cljs$cst$6767$renovate$$=new $APP.$cljs$core$Keyword$$(null,"renovate","renovate",-818090812);$cljs$cst$6754$is_valid$$=new $APP.$cljs$core$Keyword$$(null,"is-valid","is-valid",-1195643145);$cljs$cst$6763$subscription_success$$=new $APP.$cljs$core$Keyword$$(null,"subscription-success","subscription-success",150990068);$cljs$cst$6761$management_dialog$$=new $APP.$cljs$core$Keyword$$(null,"management-dialog","management-dialog",-1692469763);
$cljs$cst$6750$perms$$=new $APP.$cljs$core$Keyword$$(null,"perms","perms",-1384176260);var $app$main$ui$settings$change_email$schema_COLON_email_change_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"EmailChangeForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$6738$email_1$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6740$email_2$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.invalid-email-confirmation")},
$APP.$cljs$cst$3441$error_SLASH_field$$,$cljs$cst$6740$email_2$$],null),function($data$jscomp$544_email_2$$){var $email_1$$=$cljs$cst$6738$email_1$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$544_email_2$$);$data$jscomp$544_email_2$$=$cljs$cst$6740$email_2$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$544_email_2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($email_1$$,$data$jscomp$544_email_2$$)}],null)],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$60$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$60$$,$APP.$cljs$cst$6404$change_email$$,$app$main$ui$settings$change_email$change_email_modal$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$61$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$61$$,$cljs$cst$6745$delete_account$$,$app$main$ui$settings$delete_account$delete_account_modal$$)});var $app$main$ui$settings$feedback$schema_COLON_feedback_form$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"FeedbackForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6746$subject$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1642$content$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,5E3],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6747$error_report$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],
null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5525$error_href$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,2048],null)],null)],null)],null);var $app$main$ui$settings$integrations$schema_COLON_form_access_token$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5223$expiration_date$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null)],null),$app$main$ui$settings$integrations$schema_COLON_form_mcp_token$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5223$expiration_date$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null)],
null),$app$main$ui$settings$integrations$form_initial_data_access_token$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,"",$APP.$cljs$cst$5223$expiration_date$$,"never"],null),$app$main$ui$settings$integrations$form_initial_data_mcp_token$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5223$expiration_date$$,"never"],null);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$62$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$62$$,$APP.$cljs$cst$3276$create_access_token$$,$app$main$ui$settings$integrations$create_access_token_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$63$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$63$$,$cljs$cst$6752$generate_mcp_token$$,$app$main$ui$settings$integrations$generate_mcp_token_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$64$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$64$$,$cljs$cst$6753$regenerate_mcp_token$$,$app$main$ui$settings$integrations$regenerate_mcp_token_modal$$)});
var $app$main$ui$settings$integrations$token_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($expires_txt_props_93486$$){var $expires_at$jscomp$1$$=$expires_txt_props_93486$$.expiresAt,$name$jscomp$532$$=$expires_txt_props_93486$$.name,$on_delete$jscomp$21$$=$expires_txt_props_93486$$.onDelete,$id$jscomp$1150$$=$expires_txt_props_93486$$.id;$expires_txt_props_93486$$=$expires_at$jscomp$1$$==null?null:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($expires_at$jscomp$1$$,
"PPP");var $expired_QMARK_$jscomp$2$$=$expires_at$jscomp$1$$!=null&&$APP.$app$common$time$now$$()>$expires_at$jscomp$1$$,$menu_open_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$menu_open_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($menu_open_STAR_$jscomp$3$$),$handle_menu_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$3$$,!1)}),$handle_menu_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$3$$,
$APP.$cljs$core$not$$($menu_open_QMARK_$jscomp$5$$))}),$handle_delete$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_delete$jscomp$21$$),$APP.$rumext$v2$adapt$$($id$jscomp$1150$$)],function(){return $on_delete$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete$jscomp$21$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1150$$):$on_delete$jscomp$21$$($id$jscomp$1150$$)}),$handle_open_confirm_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_delete$jscomp$3$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.delete-token.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.delete-token.message"),$APP.$cljs$cst$2487$accept_label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.delete-token.accept"),$APP.$cljs$cst$2490$on_accept$$,$handle_delete$jscomp$3$$],null)))}),$options$jscomp$654$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_delete$jscomp$3$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
$APP.$cljs$cst$266$id$$,"token-delete",$APP.$cljs$cst$2413$handler$$,$handle_open_confirm_modal$$],null)],null)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__item",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",title:$name$jscomp$532$$,className:"main_ui_settings_integrations__item-title",children:$name$jscomp$532$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"div",typography:"body-small",className:"main_ui_settings_integrations__item-subtitle "+($expired_QMARK_$jscomp$2$$?"main_ui_settings_integrations__warning":""),children:$expires_at$jscomp$1$$==null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("integrations.no-expiration"):$expired_QMARK_$jscomp$2$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("integrations.expired-on",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$expires_txt_props_93486$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("integrations.expires-on",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$expires_txt_props_93486$$]))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_integrations__item-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_settings_integrations__item-button","aria-pressed":$menu_open_QMARK_$jscomp$5$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),onClick:$handle_menu_click$jscomp$2$$,
icon:"menu"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,{onClose:$handle_menu_close$$,show:$menu_open_QMARK_$jscomp$5$$,minWidth:!0,top:-10,left:-138,options:$options$jscomp$654$$})]})]})});var $app$main$ui$settings$notifications$default_notification_settings$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3244$dashboard_comments$$,$APP.$cljs$cst$2132$all$$,$APP.$cljs$cst$3245$email_comments$$,$APP.$cljs$cst$2133$partial$$,$APP.$cljs$cst$3246$email_invites$$,$APP.$cljs$cst$2132$all$$],null),$app$main$ui$settings$notifications$schema_COLON_notifications_form$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"NotificationsForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3244$dashboard_comments$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2132$all$$,
null,$APP.$cljs$cst$2133$partial$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3245$email_comments$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2132$all$$,
null,$APP.$cljs$cst$2133$partial$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3246$email_invites$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$957$app_DOT_common_DOT_schema_SLASH_one_of$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2132$all$$,
null,$APP.$cljs$cst$2133$partial$$,null,$APP.$cljs$cst$226$none$$,null],null),null)],null)],null)],null);var $app$main$ui$settings$options$schema_COLON_options_form$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"OptionsForm"],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2839$lang$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,20],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3208$theme$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null)],null);var $app$main$ui$settings$password$schema_COLON_password_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"PasswordForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3239$password_1$$,
$APP.$cljs$cst$973$app_DOT_common_DOT_schema_SLASH_password$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3240$password_2$$,$APP.$cljs$cst$973$app_DOT_common_DOT_schema_SLASH_password$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3241$password_old$$,$APP.$cljs$cst$973$app_DOT_common_DOT_schema_SLASH_password$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$945$error_SLASH_code$$,"errors.password-invalid-confirmation",$APP.$cljs$cst$3441$error_SLASH_field$$,$APP.$cljs$cst$3240$password_2$$],null),function($p__93503_password_1$jscomp$1$$){var $map__93504__$1_password_2$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($p__93503_password_1$jscomp$1$$);$p__93503_password_1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93504__$1_password_2$jscomp$1$$,
$APP.$cljs$cst$3239$password_1$$);$map__93504__$1_password_2$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__93504__$1_password_2$jscomp$1$$,$APP.$cljs$cst$3240$password_2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__93503_password_1$jscomp$1$$,$map__93504__$1_password_2$jscomp$1$$)}],null)],null);var $app$main$ui$settings$profile$schema_COLON_profile_form$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"ProfileForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1365$fullname$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3207$email$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],null)],null);var $app$main$ui$settings$sidebar$arrow_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_settings_sidebar__arrow-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})}),$app$main$ui$settings$sidebar$feedback_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_settings_sidebar__feedback-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-feedback"})}),$app$main$ui$settings$sidebar$sidebar_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_93512$$){var $profile$jscomp$113$$=
$props_93512$$.profile;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_sidebar__dashboard-sidebar main_ui_settings_sidebar__settings",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings$sidebar$sidebar_content_STAR_$$,{profile:$profile$jscomp$113$$,section:$props_93512$$.section}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$sidebar$profile_section_STAR_$$,{profile:$profile$jscomp$113$$})]})});var $app$main$ui$settings$subscription$plan_card_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($inline_error_props_93513$$){var $recommended$$=$inline_error_props_93513$$.recommended,$card_title_icon$$=$inline_error_props_93513$$.cardTitleIcon,$editors$jscomp$4$$=$inline_error_props_93513$$.editors,$cta_text_with_icon$$=$inline_error_props_93513$$.ctaTextWithIcon,$code_action$$=$inline_error_props_93513$$.codeAction,$card_title$$=$inline_error_props_93513$$.cardTitle,
$cta_text_trial$$=$inline_error_props_93513$$.ctaTextTrial,$benefits_title$$=$inline_error_props_93513$$.benefitsTitle,$has_cta_link_show_button_cta$$=$inline_error_props_93513$$.showButtonCta,$cta_text$$=$inline_error_props_93513$$.ctaText,$cta_link_trial$$=$inline_error_props_93513$$.ctaLinkTrial,$cta_link_with_icon$$=$inline_error_props_93513$$.ctaLinkWithIcon,$price_value$$=$inline_error_props_93513$$.priceValue,$cta_link$$=$inline_error_props_93513$$.ctaLink,$cancel_at$jscomp$1$$=$inline_error_props_93513$$.cancelAt,
$price_period$$=$inline_error_props_93513$$.pricePeriod,$benefits$$=$inline_error_props_93513$$.benefits;$inline_error_props_93513$$=$inline_error_props_93513$$.inlineError;var $has_trial_QMARK_$$=$APP.$cljs$core$truth_$$($cta_link_trial$$)?$cta_text_trial$$:$cta_link_trial$$,$has_cta_with_icon_QMARK_$$=$APP.$cljs$core$truth_$$($cta_link_with_icon$$)?$cta_text_with_icon$$:$cta_link_with_icon$$,$has_cta_button$$=$APP.$cljs$core$truth_$$($cta_link$$)?$APP.$cljs$core$truth_$$($cta_text$$)?$has_cta_link_show_button_cta$$:
$cta_text$$:$cta_link$$;$has_cta_link_show_button_cta$$=$APP.$cljs$core$truth_$$($cta_link$$)?$APP.$cljs$core$truth_$$($cta_text$$)?$APP.$cljs$core$not$$($has_cta_link_show_button_cta$$):$cta_text$$:$cta_link$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__plan-card "+($APP.$cljs$core$truth_$$($recommended$$)?"main_ui_settings_subscription__plan-card-highlight":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__plan-card-header",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__plan-card-title-container",children:[$APP.$cljs$core$truth_$$($card_title_icon$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__plan-title-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$card_title_icon$$,size:"s"})}):null,(0,$APP.$rumext$v2$jsx$$)("h4",{className:"main_ui_settings_subscription__plan-card-title",children:$card_title$$}),
$APP.$cljs$core$truth_$$($recommended$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$badge$badge_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.recommended"),size:$APP.$cljs$cst$3945$small$$,"is-focus":!0}):null,$APP.$cljs$core$truth_$$($editors$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__plan-editors",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.settings.editors",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$editors$jscomp$4$$]))}):null]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($price_value$$)?$price_period$$:$price_value$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_settings_subscription__plan-price",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__plan-price-value",children:$price_value$$}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_settings_subscription__plan-price-period",
children:[" / ",$price_period$$]})]}):null,$APP.$cljs$core$truth_$$($cancel_at$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings_subscription__plan-cancel",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_settings_subscription__plan-cancel-date",children:$cancel_at$jscomp$1$$})}):null]}),$APP.$cljs$core$truth_$$($benefits_title$$)?(0,$APP.$rumext$v2$jsx$$)("h5",{className:"main_ui_settings_subscription__benefits-title",children:$benefits_title$$}):null,(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_settings_subscription__benefits-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$271$$,$benefit$$){$out_arr__44092__auto__$jscomp$271$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_settings_subscription__benefit",children:["- ",$benefit$$]},""+($benefit$$??"")));return $out_arr__44092__auto__$jscomp$271$$},[],$benefits$$)}),$APP.$cljs$core$truth_$$($has_cta_button$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"primary",type:"button",className:$APP.$cljs$core$not$$($has_trial_QMARK_$$)?"main_ui_settings_subscription__bottom-button":"",onClick:$cta_link$$,children:$cta_text$$}):null,$APP.$cljs$core$truth_$$($has_trial_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$cta_link_trial$$,className:"main_ui_settings_subscription__cta-button main_ui_settings_subscription__bottom-link",children:$cta_text_trial$$}):null,$APP.$cljs$core$truth_$$($has_cta_with_icon_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("button",
{onClick:$cta_link_with_icon$$,className:"main_ui_settings_subscription__cta-button main_ui_settings_subscription__more-info",children:[$cta_text_with_icon$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"open-link",size:"s"})]}):null,$APP.$cljs$core$truth_$$($has_cta_link_show_button_cta$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$cta_link$$,className:"main_ui_settings_subscription__cta-button "+($APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($has_trial_QMARK_$$)?
$has_trial_QMARK_$$:$code_action$$)?"main_ui_settings_subscription__bottom-link":""),children:$cta_text$$}):null,$APP.$cljs$core$truth_$$($code_action$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code_action$$,$cljs$cst$6755$activate$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$5230$nitrate_code_activation$$],null)))},className:"main_ui_settings_subscription__cta-button main_ui_settings_subscription__activate-by-code",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.activate-by-code")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_settings_subscription__renew-by-code main_ui_settings_subscription__bottom-link",onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5230$nitrate_code_activation$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5231$renew_QMARK_$$,!0],null)))},children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("nitrate.subscription.settings.renew-with-code")}):null,$APP.$cljs$core$truth_$$($inline_error_props_93513$$)?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_settings_subscription__inline-error",children:$inline_error_props_93513$$}):null]})});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$65$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$65$$,$cljs$cst$6761$management_dialog$$,$app$main$ui$settings$subscription$subscribe_management_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$66$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$66$$,$cljs$cst$6763$subscription_success$$,$app$main$ui$settings$subscription$subscription_success_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$67$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$67$$,$APP.$cljs$cst$5226$nitrate_dialog$$,$app$main$ui$settings$subscription$subscribe_nitrate_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$68$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$68$$,$cljs$cst$6765$nitrate_contact_sales_dialog$$,$app$main$ui$settings$subscription$nitrate_contact_sales_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$69$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$69$$,$cljs$cst$6766$nitrate_cancel_contact_sales_dialog$$,$app$main$ui$settings$subscription$nitrate_cancel_contact_sales_dialog$$)});var $app$main$ui$settings$header_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",className:"main_ui_settings__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_settings__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{"data-testid":"account-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-account-title")})})})});
//# sourceMappingURL=main-settings.js.map
