import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$main$ui$cursors$resize_ew$$=function($rot__74066__auto__$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__74066__auto__$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_nesw$$=function($rot__74066__auto__$jscomp$1$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(45+$rot__74066__auto__$jscomp$1$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_ns$$=function($rot__74066__auto__$jscomp$2$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__74066__auto__$jscomp$2$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_nwse$$=function($rot__74066__auto__$jscomp$3$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(135+$rot__74066__auto__$jscomp$3$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%32%2E%36%20%35%2E%36%4C%30%20%38%2E%33%20%32%2E%36%20%31%31%6C%31%2E%32%2D%31%2E%32%2D%2E%35%2D%2E%35%68%39%2E%34%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%4C%31%36%20%38%2E%33%6C%2D%32%2E%36%2D%32%2E%37%2D%31%2E%32%20%31%2E%32%2E%35%2E%35%48%33%2E%33%6C%2E%35%2D%2E%35%2D%31%2E%32%2D%31%2E%32%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%31%20%32%37%39%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%35%20%30%76%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%20%32%37%38%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%7A%6D%34%2E%35%2E%35%68%2D%34%76%31%68%35%76%2D%35%68%2D%31%7A%6D%34%2E%35%2D%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%7A%6D%2E%35%20%35%2E%35%68%2D%35%76%31%68%35%76%35%68%31%76%2D%35%68%35%76%2D%31%68%2D%35%76%2D%35%68%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%32%2E%36%20%36%2E%33%6C%2D%32%20%32%20%32%20%32%20%2E%36%2D%2E%35%2D%31%2D%31%48%31%34%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%48%32%2E%31%6C%31%2D%31%2D%2E%35%2D%2E%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$rotate$$=function($rot__74066__auto__$jscomp$4$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__74066__auto__$jscomp$4$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%31%20%33%2E%37%4C%33%2E%37%20%31%6C%32%2E%37%20%32%2E%37%2D%2E%36%2E%36%2D%31%2E%37%2D%31%2E%38%68%2D%2E%38%4C%31%2E%36%20%34%2E%33%20%31%20%33%2E%37%7A%4D%31%32%2E%33%20%31%35%6C%32%2E%37%2D%32%2E%37%2D%32%2E%38%2D%32%2E%38%2D%2E%36%2E%36%20%31%2E%39%20%31%2E%38%76%2E%38%6C%2D%31%2E%38%20%31%2E%37%2E%36%2E%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%33%2E%32%20%31%2E%39%76%2E%34%41%31%30%2E%35%20%31%30%2E%35%20%30%20%30%30%31%34%20%31%32%2E%38%76%2D%2E%39%68%2D%2E%34%41%39%2E%36%20%39%2E%36%20%30%20%30%31%34%2E%31%20%32%48%33%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%33%2E%37%2E%33%4C%37%20%33%2E%37%20%35%2E%38%20%35%20%34%2E%37%20%33%2E%38%61%39%2E%31%20%39%2E%31%20%30%20%30%30%37%2E%34%20%37%2E%35%4C%31%31%20%31%30%2E%31%6C%31%2E%33%2D%31%2E%33%20%33%2E%35%20%33%2E%35%2D%33%2E%34%20%33%2E%34%2D%31%2E%33%2D%31%2E%33%20%31%2E%32%2D%31%2E%32%61%31%31%20%31%31%20%30%20%30%31%2D%39%2E%34%2D%39%2E%34%4C%31%2E%36%20%35%20%2E%33%20%33%2E%37%20%33%2E%37%2E%33%7A%6D%2D%2E%35%20%32%2E%33%76%2E%37%61%31%30%2E%35%20%31%30%2E%35%20%30%20%30%30%31%30%2E%31%20%39%2E%35%6C%2D%31%2E%36%20%31%2E%36%2E%36%2E%36%20%32%2E%37%2D%32%2E%37%2D%32%2E%38%2D%32%2E%38%2D%2E%36%2E%36%20%31%2E%39%20%31%2E%38%61%31%33%33%2E%35%20%31%33%33%2E%35%20%30%20%30%30%2D%2E%37%20%30%41%39%2E%36%20%39%2E%36%20%30%20%30%31%34%20%32%2E%35%6C%31%2E%38%20%31%2E%38%2E%36%2D%2E%36%4C%33%2E%37%20%31%20%31%20%33%2E%37%6C%2E%36%2E%36%20%31%2E%36%2D%31%2E%37%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$text$$=function($rot__74066__auto__$jscomp$5$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__74066__auto__$jscomp$5$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%35%20%2E%35%76%32%63%31%2E%35%20%30%20%32%20%2E%39%20%32%20%32%76%37%63%30%20%31%2E%31%2D%2E%35%20%32%2D%32%20%32%76%32%63%31%2E%35%20%30%20%32%2E%34%2D%2E%34%20%33%2D%31%20%2E%36%2E%36%20%31%2E%35%20%31%20%33%20%31%76%2D%32%63%2D%31%2E%35%20%30%2D%32%2D%2E%39%2D%32%2D%32%76%2D%37%63%30%2D%31%2E%31%2E%35%2D%32%20%32%2D%32%76%2D%32%63%2D%31%2E%35%20%30%2D%32%2E%34%2E%34%2D%33%20%31%2D%2E%36%2D%2E%36%2D%31%2E%35%2D%31%2D%33%2D%31%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%64%3D%27%4D%35%2E%35%20%31%76%31%61%32%20%32%20%30%20%30%31%32%20%32%76%38%61%32%20%32%20%30%20%30%31%2D%32%20%32%76%31%63%31%20%30%20%32%2D%2E%35%20%32%2E%35%2D%31%2E%33%61%33%20%33%20%30%20%30%30%32%2E%35%20%31%2E%33%76%2D%31%61%32%20%32%20%30%20%30%31%2D%32%2D%32%56%34%63%30%2D%31%2E%31%2E%39%2D%32%20%32%2D%32%56%31%63%2D%31%20%30%2D%32%20%2E%35%2D%32%2E%35%20%31%2E%33%41%33%20%33%20%30%20%30%30%35%2E%35%20%31%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_ew$$=function($rot__74066__auto__$jscomp$6$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__74066__auto__$jscomp$6$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_nesw$$=function($rot__74066__auto__$jscomp$7$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(45+$rot__74066__auto__$jscomp$7$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_ns$$=function($rot__74066__auto__$jscomp$8$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__74066__auto__$jscomp$8$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$scale_nwse$$=function($rot__74066__auto__$jscomp$9$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(135+$rot__74066__auto__$jscomp$9$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%33%2E%37%38%35%20%34%2E%31%36%34%2D%2E%32%38%33%2E%32%39%4C%31%2E%39%31%34%20%36%2E%30%37%2E%30%32%34%20%38%6C%33%2E%37%36%31%20%33%2E%38%33%36%20%31%2E%30%32%36%2D%31%2E%30%34%35%2E%30%30%35%2E%30%30%36%20%31%2E%30%30%32%2D%31%2E%30%32%32%2D%31%2E%30%30%35%2D%31%2E%30%32%37%20%36%2E%33%38%32%2D%2E%30%30%36%2D%31%2E%30%30%36%20%31%2E%30%32%36%2E%38%39%31%2E%39%30%36%2E%31%31%31%2E%31%31%33%20%31%2E%30%32%36%20%31%2E%30%34%37%4C%31%35%2E%39%37%37%20%38%20%31%32%2E%32%32%20%34%2E%31%37%6C%2D%2E%32%38%34%2E%32%38%37%2D%2E%37%34%32%2E%37%35%38%2D%2E%31%31%31%2E%31%31%33%2D%2E%31%37%32%2E%31%37%36%2D%2E%37%31%39%2E%37%33%32%4C%31%31%2E%32%20%37%2E%32%36%34%6C%2D%36%2E%33%38%35%2E%30%30%37%4C%35%2E%38%32%20%36%2E%32%34%36%6C%2D%2E%39%30%32%2D%2E%39%32%32%2E%30%30%32%2D%2E%30%30%32%7A%6D%30%20%31%2E%31%33%33%2E%30%32%34%2E%30%32%35%2D%31%2E%33%31%35%20%31%2E%33%34%2D%31%2E%33%31%20%31%2E%33%33%36%20%32%2E%36%32%38%20%32%2E%36%38%2D%2E%30%32%35%2E%30%32%37%4C%31%2E%31%33%35%20%38%20%32%2E%34%38%20%36%2E%36%32%35%5A%6D%38%2E%34%33%36%2E%30%30%36%4C%31%34%2E%38%36%35%20%38%6C%2D%32%2E%36%34%38%20%32%2E%37%30%31%2D%2E%30%32%36%2D%2E%30%32%37%4C%31%34%2E%38%31%34%20%38%6C%2D%32%2E%36%31%39%2D%32%2E%36%37%32%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%6D%31%32%2E%32%32%31%20%34%2E%37%33%36%2D%2E%35%38%31%2E%35%39%33%20%32%2E%36%31%39%20%32%2E%36%37%2D%32%2E%36%32%34%20%32%2E%36%37%35%2E%35%38%32%2E%35%39%33%4C%31%35%2E%34%32%32%20%38%7A%4D%31%31%2E%31%39%36%20%35%2E%37%38%6C%2D%2E%34%34%37%2E%34%35%36%20%31%2E%33%39%34%20%31%2E%34%32%32%2D%38%2E%32%37%35%2E%30%31%20%31%2E%33%39%37%2D%31%2E%34%32%34%2D%2E%34%34%35%2D%2E%34%35%34%2D%32%2E%31%38%20%32%2E%32%32%32%20%32%2E%31%37%35%20%32%2E%32%31%38%2E%34%34%37%2D%2E%34%35%35%2D%31%2E%33%39%34%2D%31%2E%34%32%32%20%38%2E%32%37%35%2D%2E%30%31%31%2D%31%2E%33%39%37%20%31%2E%34%32%34%2E%34%34%35%2E%34%35%34%4C%31%33%2E%33%37%31%20%38%5A%4D%33%2E%37%38%34%20%34%2E%37%33%20%32%2E%31%39%38%20%36%2E%33%34%38%2E%35%37%38%20%37%2E%39%39%39%6C%33%2E%32%30%38%20%33%2E%32%37%31%2E%35%38%31%2D%2E%35%39%33%2D%32%2E%36%32%37%2D%32%2E%36%38%4C%32%2E%37%37%38%20%36%2E%39%34%6C%31%2E%35%38%37%2D%31%2E%36%31%37%5A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%70%61%69%6E%74%2D%6F%72%64%65%72%3D%27%73%74%72%6F%6B%65%20%66%69%6C%6C%20%6D%61%72%6B%65%72%73%27%20%73%74%79%6C%65%3D%27%2D%69%6E%6B%73%63%61%70%65%2D%73%74%72%6F%6B%65%3A%6E%6F%6E%65%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_ew_2$$=function($rot__74066__auto__$jscomp$10$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(0+$rot__74066__auto__$jscomp$10$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%39%2E%38%36%36%39%39%39%38%2C%38%2E%38%35%39%30%30%30%32%20%68%20%2D%33%2E%37%33%34%20%56%20%31%30%2E%37%33%32%20%4C%20%2D%30%2E%30%30%31%30%30%30%31%39%2C%38%2E%30%30%30%30%30%30%32%20%36%2E%31%33%32%39%39%39%38%2C%35%2E%32%36%38%30%30%30%31%20%76%20%31%2E%38%37%33%20%68%20%33%2E%37%33%34%20%76%20%2D%31%2E%38%37%33%20%4C%20%31%36%2E%30%30%31%2C%38%2E%30%30%30%30%30%30%32%20%39%2E%38%36%36%39%39%39%38%2C%31%30%2E%37%33%32%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%31%30%2E%34%2C%38%2E%33%39%30%30%30%30%32%20%48%20%35%2E%35%39%39%39%39%39%38%20%56%20%39%2E%39%35%30%39%39%39%39%20%4C%20%30%2E%37%39%39%39%39%39%38%31%2C%38%2E%30%30%30%30%30%30%32%20%35%2E%35%39%39%39%39%39%38%2C%36%2E%30%34%39%30%30%30%31%20%76%20%31%2E%35%36%20%48%20%31%30%2E%34%20%76%20%2D%31%2E%35%36%20%6C%20%34%2E%38%2C%31%2E%39%35%31%30%30%30%31%20%2D%34%2E%38%2C%31%2E%39%35%30%39%39%39%37%20%56%20%38%2E%33%39%31%30%30%30%32%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$ui$cursors$resize_ns_2$$=function($rot__74066__auto__$jscomp$11$$){return"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate("+(90+$rot__74066__auto__$jscomp$11$$??"")+" 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%39%2E%38%36%36%39%39%39%38%2C%38%2E%38%35%39%30%30%30%32%20%68%20%2D%33%2E%37%33%34%20%56%20%31%30%2E%37%33%32%20%4C%20%2D%30%2E%30%30%31%30%30%30%31%39%2C%38%2E%30%30%30%30%30%30%32%20%36%2E%31%33%32%39%39%39%38%2C%35%2E%32%36%38%30%30%30%31%20%76%20%31%2E%38%37%33%20%68%20%33%2E%37%33%34%20%76%20%2D%31%2E%38%37%33%20%4C%20%31%36%2E%30%30%31%2C%38%2E%30%30%30%30%30%30%32%20%39%2E%38%36%36%39%39%39%38%2C%31%30%2E%37%33%32%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%31%30%2E%34%2C%38%2E%33%39%30%30%30%30%32%20%48%20%35%2E%35%39%39%39%39%39%38%20%56%20%39%2E%39%35%30%39%39%39%39%20%4C%20%30%2E%37%39%39%39%39%39%38%31%2C%38%2E%30%30%30%30%30%30%32%20%35%2E%35%39%39%39%39%39%38%2C%36%2E%30%34%39%30%30%30%31%20%76%20%31%2E%35%36%20%48%20%31%30%2E%34%20%76%20%2D%31%2E%35%36%20%6C%20%34%2E%38%2C%31%2E%39%35%31%30%30%30%31%20%2D%34%2E%38%2C%31%2E%39%35%30%39%39%39%37%20%56%20%38%2E%33%39%31%30%30%30%32%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$common$uri$query_string__GT_map$$=function($s$jscomp$352$$){return $APP.$lambdaisland$uri$query_string__GT_map$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$352$$)},$app$common$schema$validate$$=function($s$jscomp$377$$,$value$jscomp$315$$){return $APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$377$$,$value$jscomp$315$$)},$rumext$v2$render_BANG_$$=function(){var $root$jscomp$27$$=$app$main$app_root$$,$element$jscomp$56$$=$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$01$$();
return $root$jscomp$27$$.render($element$jscomp$56$$)},$cljs$core$_methods$$=function(){var $JSCompiler_temp$jscomp$2056_mf$jscomp$11$$=$app$main$ui$releases$common$render_release_notes$$;if($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$!=null&&$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$.$cljs$core$IMultiFn$_methods$arity$1$!=null)$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$=$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$.$cljs$core$IMultiFn$_methods$arity$1$($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$);
else{var $m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$=$cljs$core$_methods$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$==null?null:$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$)];if($m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$!=null)$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$=$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$):
$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$);else if($m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$=$cljs$core$_methods$$._,$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$!=null)$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$=$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$):
$m__5372__auto__$jscomp$inline_9813_m__5374__auto__$jscomp$inline_9812$$($JSCompiler_temp$jscomp$2056_mf$jscomp$11$$);else throw $APP.$cljs$core$missing_protocol$$("IMultiFn.-methods",$JSCompiler_temp$jscomp$2056_mf$jscomp$11$$);}return $JSCompiler_temp$jscomp$2056_mf$jscomp$11$$},$app$util$object$without_empty$$=function($obj$jscomp$126$$){return $obj$jscomp$126$$!=null?Object.entries($obj$jscomp$126$$).reduce(($a$jscomp$300$$,[$k$jscomp$525$$,$v$jscomp$316$$])=>$v$jscomp$316$$==null?$a$jscomp$300$$:
($a$jscomp$300$$[$k$jscomp$525$$]=$v$jscomp$316$$,$a$jscomp$300$$),{}):null},$beicon$v2$core$first$$=function($ob$jscomp$37$$){return $APP.$beicon$v2$operators$pipe$$((0,$APP.$beicon$v2$operators$take$$)(1),$ob$jscomp$37$$)},$rumext$v2$element$cljs$0core$0IFn$0_invoke$0arity$01$$=function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$app$$,{},void 0)},$app$common$types$tokens_lib$enable_set$$=function($JSCompiler_temp$jscomp$2058__$jscomp$1301$$,$set_name$jscomp$2$$){if($JSCompiler_temp$jscomp$2058__$jscomp$1301$$!=
null&&$JSCompiler_temp$jscomp$2058__$jscomp$1301$$.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$!=null)$JSCompiler_temp$jscomp$2058__$jscomp$1301$$=$JSCompiler_temp$jscomp$2058__$jscomp$1301$$.$app$common$types$tokens_lib$ITokenTheme$enable_set$arity$2$($JSCompiler_temp$jscomp$2058__$jscomp$1301$$,$set_name$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$=$app$common$types$tokens_lib$enable_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2058__$jscomp$1301$$==
null?null:$JSCompiler_temp$jscomp$2058__$jscomp$1301$$)];if($m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$!=null)$JSCompiler_temp$jscomp$2058__$jscomp$1301$$=$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2058__$jscomp$1301$$,$set_name$jscomp$2$$):$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$($JSCompiler_temp$jscomp$2058__$jscomp$1301$$,
$set_name$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$=$app$common$types$tokens_lib$enable_set$$._,$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$!=null)$JSCompiler_temp$jscomp$2058__$jscomp$1301$$=$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2058__$jscomp$1301$$,
$set_name$jscomp$2$$):$m__5372__auto__$jscomp$inline_9818_m__5374__auto__$jscomp$inline_9817$$($JSCompiler_temp$jscomp$2058__$jscomp$1301$$,$set_name$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.enable-set",$JSCompiler_temp$jscomp$2058__$jscomp$1301$$);}return $JSCompiler_temp$jscomp$2058__$jscomp$1301$$},$app$common$types$tokens_lib$disable_set$$=function($JSCompiler_temp$jscomp$2059__$jscomp$1305$$,$set_name$jscomp$4$$){if($JSCompiler_temp$jscomp$2059__$jscomp$1305$$!=
null&&$JSCompiler_temp$jscomp$2059__$jscomp$1305$$.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$!=null)$JSCompiler_temp$jscomp$2059__$jscomp$1305$$=$JSCompiler_temp$jscomp$2059__$jscomp$1305$$.$app$common$types$tokens_lib$ITokenTheme$disable_set$arity$2$($JSCompiler_temp$jscomp$2059__$jscomp$1305$$,$set_name$jscomp$4$$);else{var $m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$=$app$common$types$tokens_lib$disable_set$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2059__$jscomp$1305$$==
null?null:$JSCompiler_temp$jscomp$2059__$jscomp$1305$$)];if($m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$!=null)$JSCompiler_temp$jscomp$2059__$jscomp$1305$$=$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2059__$jscomp$1305$$,$set_name$jscomp$4$$):$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$($JSCompiler_temp$jscomp$2059__$jscomp$1305$$,
$set_name$jscomp$4$$);else if($m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$=$app$common$types$tokens_lib$disable_set$$._,$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$!=null)$JSCompiler_temp$jscomp$2059__$jscomp$1305$$=$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2059__$jscomp$1305$$,
$set_name$jscomp$4$$):$m__5372__auto__$jscomp$inline_9823_m__5374__auto__$jscomp$inline_9822$$($JSCompiler_temp$jscomp$2059__$jscomp$1305$$,$set_name$jscomp$4$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.disable-set",$JSCompiler_temp$jscomp$2059__$jscomp$1305$$);}return $JSCompiler_temp$jscomp$2059__$jscomp$1305$$},$app$common$types$tokens_lib$theme_active_QMARK_$$=function($JSCompiler_temp$jscomp$2060__$jscomp$1346$$,$id$jscomp$197$$){if($JSCompiler_temp$jscomp$2060__$jscomp$1346$$!=
null&&$JSCompiler_temp$jscomp$2060__$jscomp$1346$$.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$2060__$jscomp$1346$$=$JSCompiler_temp$jscomp$2060__$jscomp$1346$$.$app$common$types$tokens_lib$ITokenThemes$theme_active_QMARK_$arity$2$($JSCompiler_temp$jscomp$2060__$jscomp$1346$$,$id$jscomp$197$$);else{var $m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$=$app$common$types$tokens_lib$theme_active_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2060__$jscomp$1346$$==
null?null:$JSCompiler_temp$jscomp$2060__$jscomp$1346$$)];if($m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$!=null)$JSCompiler_temp$jscomp$2060__$jscomp$1346$$=$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2060__$jscomp$1346$$,$id$jscomp$197$$):$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$($JSCompiler_temp$jscomp$2060__$jscomp$1346$$,
$id$jscomp$197$$);else if($m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$=$app$common$types$tokens_lib$theme_active_QMARK_$$._,$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$!=null)$JSCompiler_temp$jscomp$2060__$jscomp$1346$$=$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2060__$jscomp$1346$$,
$id$jscomp$197$$):$m__5372__auto__$jscomp$inline_9828_m__5374__auto__$jscomp$inline_9827$$($JSCompiler_temp$jscomp$2060__$jscomp$1346$$,$id$jscomp$197$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.theme-active?",$JSCompiler_temp$jscomp$2060__$jscomp$1346$$);}return $JSCompiler_temp$jscomp$2060__$jscomp$1346$$},$app$common$types$tokens_lib$deactivate_theme$$=function($JSCompiler_temp$jscomp$2061__$jscomp$1350$$,$id$jscomp$201$$){if($JSCompiler_temp$jscomp$2061__$jscomp$1350$$!=null&&
$JSCompiler_temp$jscomp$2061__$jscomp$1350$$.$app$common$types$tokens_lib$ITokenThemes$deactivate_theme$arity$2$!=null)$JSCompiler_temp$jscomp$2061__$jscomp$1350$$=$JSCompiler_temp$jscomp$2061__$jscomp$1350$$.$app$common$types$tokens_lib$ITokenThemes$deactivate_theme$arity$2$($JSCompiler_temp$jscomp$2061__$jscomp$1350$$,$id$jscomp$201$$);else{var $m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$=$app$common$types$tokens_lib$deactivate_theme$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2061__$jscomp$1350$$==
null?null:$JSCompiler_temp$jscomp$2061__$jscomp$1350$$)];if($m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$!=null)$JSCompiler_temp$jscomp$2061__$jscomp$1350$$=$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2061__$jscomp$1350$$,$id$jscomp$201$$):$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$($JSCompiler_temp$jscomp$2061__$jscomp$1350$$,
$id$jscomp$201$$);else if($m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$=$app$common$types$tokens_lib$deactivate_theme$$._,$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$!=null)$JSCompiler_temp$jscomp$2061__$jscomp$1350$$=$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2061__$jscomp$1350$$,
$id$jscomp$201$$):$m__5372__auto__$jscomp$inline_9833_m__5374__auto__$jscomp$inline_9832$$($JSCompiler_temp$jscomp$2061__$jscomp$1350$$,$id$jscomp$201$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenThemes.deactivate-theme",$JSCompiler_temp$jscomp$2061__$jscomp$1350$$);}return $JSCompiler_temp$jscomp$2061__$jscomp$1350$$},$app$main$data$event$Event$$=function(){},$app$main$data$event$_data$$=function($JSCompiler_temp$jscomp$2063__$jscomp$1418$$){if($JSCompiler_temp$jscomp$2063__$jscomp$1418$$!=
null&&$JSCompiler_temp$jscomp$2063__$jscomp$1418$$.$app$main$data$event$Event$_data$arity$1$!=null)$JSCompiler_temp$jscomp$2063__$jscomp$1418$$=$JSCompiler_temp$jscomp$2063__$jscomp$1418$$.$app$main$data$event$Event$_data$arity$1$($JSCompiler_temp$jscomp$2063__$jscomp$1418$$);else{var $m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$=$app$main$data$event$_data$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2063__$jscomp$1418$$==null?null:$JSCompiler_temp$jscomp$2063__$jscomp$1418$$)];
if($m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$!=null)$JSCompiler_temp$jscomp$2063__$jscomp$1418$$=$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2063__$jscomp$1418$$):$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$($JSCompiler_temp$jscomp$2063__$jscomp$1418$$);
else if($m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$=$app$main$data$event$_data$$._,$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$!=null)$JSCompiler_temp$jscomp$2063__$jscomp$1418$$=$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2063__$jscomp$1418$$):$m__5372__auto__$jscomp$inline_9837_m__5374__auto__$jscomp$inline_9836$$($JSCompiler_temp$jscomp$2063__$jscomp$1418$$);
else throw $APP.$cljs$core$missing_protocol$$("Event.-data",$JSCompiler_temp$jscomp$2063__$jscomp$1418$$);}return $JSCompiler_temp$jscomp$2063__$jscomp$1418$$},$app$main$data$event$PerformanceEvent$$=function(){},$goog$history$Event$$=function($token$jscomp$58$$){$APP.$goog$events$Event$$.call(this,"navigate");this.token=$token$jscomp$58$$},$goog$history$Html5History$$=function($opt_win$$,$opt_transformer$$){$APP.$goog$events$EventTarget$$.call(this);this.$window_$=$opt_win$$||window;this.$transformer_$=
$opt_transformer$$||null;this.$lastFragment_$=null;$APP.$goog$events$listen$$(this.$window_$,"popstate",this.$onHistoryEvent_$,!1,this);$APP.$goog$events$listen$$(this.$window_$,"hashchange",this.$onHistoryEvent_$,!1,this)},$JSCompiler_StaticMethods_setEnabled$$=function($JSCompiler_StaticMethods_setEnabled$self$$,$enable$jscomp$1$$){$enable$jscomp$1$$!=$JSCompiler_StaticMethods_setEnabled$self$$.$enabled_$&&($JSCompiler_StaticMethods_setEnabled$self$$.$enabled_$=$enable$jscomp$1$$)&&$JSCompiler_StaticMethods_setEnabled$self$$.dispatchEvent(new $goog$history$Event$$($JSCompiler_StaticMethods_setEnabled$self$$.getToken(),
!1))},$JSCompiler_StaticMethods_getFragment_$$=function($JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$){if($JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.$useFragment_$){$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$=$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.$window_$.location.href;const $index$jscomp$208$$=$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.indexOf("#");return $index$jscomp$208$$<0?"":$JSCompiler_StaticMethods_getFragment_$self_loc$jscomp$5$$.substring($index$jscomp$208$$+
1)}return null},$JSCompiler_StaticMethods_getUrl_$$=function($JSCompiler_StaticMethods_getUrl_$self$$,$token$jscomp$61$$){return $JSCompiler_StaticMethods_getUrl_$self$$.$useFragment_$?"#"+$token$jscomp$61$$:$JSCompiler_StaticMethods_getUrl_$self$$.$transformer_$?$JSCompiler_StaticMethods_getUrl_$self$$.$pathPrefix_$+$token$jscomp$61$$:$JSCompiler_StaticMethods_getUrl_$self$$.$pathPrefix_$+$token$jscomp$61$$+$JSCompiler_StaticMethods_getUrl_$self$$.$window_$.location.search},$meta_merge$core$meta_STAR_$$=
function($obj$jscomp$178$$){return($obj$jscomp$178$$!=null?$obj$jscomp$178$$.$cljs$lang$protocol_mask$partition0$$&131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$178$$.$cljs$core$IMeta$$||($obj$jscomp$178$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IMeta$$,$obj$jscomp$178$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IMeta$$,$obj$jscomp$178$$))?$APP.$cljs$core$meta$$($obj$jscomp$178$$):null},$reitit$trie$match$$=function($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$,
$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$){if($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$!=null&&$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$.$reitit$trie$Matcher$match$arity$4$!=null)$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$=$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$.$reitit$trie$Matcher$match$arity$4$($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$);else{var $m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$=
$reitit$trie$match$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$==null?null:$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$)];if($m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$!=null)$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$=$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$,
$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$):$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$);else if($m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$=$reitit$trie$match$$._,$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$!=null)$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$=$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$):$m__5372__auto__$jscomp$inline_9848_m__5374__auto__$jscomp$inline_9847$$($JSCompiler_temp$jscomp$2066_this$$jscomp$717$$,$i$jscomp$494$$,$max$jscomp$69$$,$path$jscomp$192$$);else throw $APP.$cljs$core$missing_protocol$$("Matcher.match",$JSCompiler_temp$jscomp$2066_this$$jscomp$717$$);}return $JSCompiler_temp$jscomp$2066_this$$jscomp$717$$},
$reitit$trie$depth$$=function($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$){if($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$!=null&&$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$.$reitit$trie$Matcher$depth$arity$1$!=null)$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$=$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$.$reitit$trie$Matcher$depth$arity$1$($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$);else{var $m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$=$reitit$trie$depth$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$==
null?null:$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$)];if($m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$!=null)$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$=$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$):$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$);
else if($m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$=$reitit$trie$depth$$._,$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$!=null)$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$=$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$):$m__5372__auto__$jscomp$inline_9852_m__5374__auto__$jscomp$inline_9851$$($JSCompiler_temp$jscomp$2067_this$$jscomp$721$$);
else throw $APP.$cljs$core$missing_protocol$$("Matcher.depth",$JSCompiler_temp$jscomp$2067_this$$jscomp$721$$);}return $JSCompiler_temp$jscomp$2067_this$$jscomp$721$$},$reitit$trie$length$$=function($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$){if($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$!=null&&$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$.$reitit$trie$Matcher$length$arity$1$!=null)$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$=$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$.$reitit$trie$Matcher$length$arity$1$($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$);
else{var $m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$=$reitit$trie$length$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$==null?null:$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$)];if($m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$!=null)$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$=$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$):
$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$);else if($m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$=$reitit$trie$length$$._,$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$!=null)$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$=$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$):
$m__5372__auto__$jscomp$inline_9856_m__5374__auto__$jscomp$inline_9855$$($JSCompiler_temp$jscomp$2068_this$$jscomp$723$$);else throw $APP.$cljs$core$missing_protocol$$("Matcher.length",$JSCompiler_temp$jscomp$2068_this$$jscomp$723$$);}return $JSCompiler_temp$jscomp$2068_this$$jscomp$723$$},$reitit$trie$data_matcher$$=function($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$){if($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$!=null&&$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$.$reitit$trie$TrieCompiler$data_matcher$arity$3$!=
null)$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$=$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$.$reitit$trie$TrieCompiler$data_matcher$arity$3$($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$);else{var $m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$=$reitit$trie$data_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$==null?null:$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$)];if($m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$!=
null)$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$=$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$):$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$);
else if($m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$=$reitit$trie$data_matcher$$._,$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$!=null)$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$=$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$,$params$jscomp$121$$,
$data$jscomp$162$$):$m__5372__auto__$jscomp$inline_9862_m__5374__auto__$jscomp$inline_9861$$($JSCompiler_temp$jscomp$2069_this$$jscomp$725$$,$params$jscomp$121$$,$data$jscomp$162$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.data-matcher",$JSCompiler_temp$jscomp$2069_this$$jscomp$725$$);}return $JSCompiler_temp$jscomp$2069_this$$jscomp$725$$},$reitit$trie$static_matcher$$=function($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$){if($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$!=
null&&$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$.$reitit$trie$TrieCompiler$static_matcher$arity$3$!=null)$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$=$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$.$reitit$trie$TrieCompiler$static_matcher$arity$3$($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$=$reitit$trie$static_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$==
null?null:$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$)];if($m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$!=null)$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$=$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$):$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$,
$path$jscomp$194$$,$matcher$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$=$reitit$trie$static_matcher$$._,$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$!=null)$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$=$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$,
$path$jscomp$194$$,$matcher$jscomp$2$$):$m__5372__auto__$jscomp$inline_9868_m__5374__auto__$jscomp$inline_9867$$($JSCompiler_temp$jscomp$2070_this$$jscomp$727$$,$path$jscomp$194$$,$matcher$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.static-matcher",$JSCompiler_temp$jscomp$2070_this$$jscomp$727$$);}return $JSCompiler_temp$jscomp$2070_this$$jscomp$727$$},$reitit$trie$wild_matcher$$=function($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$,$key$jscomp$319$$,$end$jscomp$76$$,
$matcher$jscomp$4$$){if($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$!=null&&$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$.$reitit$trie$TrieCompiler$wild_matcher$arity$4$!=null)$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$=$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$.$reitit$trie$TrieCompiler$wild_matcher$arity$4$($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$,$key$jscomp$319$$,$end$jscomp$76$$,$matcher$jscomp$4$$);else{var $m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$=
$reitit$trie$wild_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$==null?null:$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$)];if($m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$!=null)$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$=$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$,
$key$jscomp$319$$,$end$jscomp$76$$,$matcher$jscomp$4$$):$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$,$key$jscomp$319$$,$end$jscomp$76$$,$matcher$jscomp$4$$);else if($m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$=$reitit$trie$wild_matcher$$._,$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$!=null)$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$=$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$,$key$jscomp$319$$,$end$jscomp$76$$,$matcher$jscomp$4$$):$m__5372__auto__$jscomp$inline_9875_m__5374__auto__$jscomp$inline_9874$$($JSCompiler_temp$jscomp$2071_this$$jscomp$729$$,$key$jscomp$319$$,$end$jscomp$76$$,$matcher$jscomp$4$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.wild-matcher",$JSCompiler_temp$jscomp$2071_this$$jscomp$729$$);
}return $JSCompiler_temp$jscomp$2071_this$$jscomp$729$$},$reitit$trie$catch_all_matcher$$=function($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$,$key$jscomp$321$$,$params$jscomp$123$$,$data$jscomp$164$$){if($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$!=null&&$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$.$reitit$trie$TrieCompiler$catch_all_matcher$arity$4$!=null)$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$=$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$.$reitit$trie$TrieCompiler$catch_all_matcher$arity$4$($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$,
$key$jscomp$321$$,$params$jscomp$123$$,$data$jscomp$164$$);else{var $m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$=$reitit$trie$catch_all_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$==null?null:$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$)];if($m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$!=null)$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$=$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$.$cljs$core$IFn$_invoke$arity$4$?
$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$,$key$jscomp$321$$,$params$jscomp$123$$,$data$jscomp$164$$):$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$,$key$jscomp$321$$,$params$jscomp$123$$,$data$jscomp$164$$);else if($m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$=$reitit$trie$catch_all_matcher$$._,
$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$!=null)$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$=$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$.$cljs$core$IFn$_invoke$arity$4$?$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$,$key$jscomp$321$$,$params$jscomp$123$$,$data$jscomp$164$$):$m__5372__auto__$jscomp$inline_9882_m__5374__auto__$jscomp$inline_9881$$($JSCompiler_temp$jscomp$2072_this$$jscomp$731$$,
$key$jscomp$321$$,$params$jscomp$123$$,$data$jscomp$164$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.catch-all-matcher",$JSCompiler_temp$jscomp$2072_this$$jscomp$731$$);}return $JSCompiler_temp$jscomp$2072_this$$jscomp$731$$},$reitit$trie$linear_matcher$$=function($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$){if($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$!=null&&$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$.$reitit$trie$TrieCompiler$linear_matcher$arity$3$!=
null)$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$=$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$.$reitit$trie$TrieCompiler$linear_matcher$arity$3$($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$=$reitit$trie$linear_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$==null?null:$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$)];if($m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$!=
null)$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$=$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$):$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$,$matchers$jscomp$1$$,
$ordered_QMARK_$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$=$reitit$trie$linear_matcher$$._,$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$!=null)$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$=$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$.$cljs$core$IFn$_invoke$arity$3$?$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$,
$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$):$m__5372__auto__$jscomp$inline_9888_m__5374__auto__$jscomp$inline_9887$$($JSCompiler_temp$jscomp$2073_this$$jscomp$733$$,$matchers$jscomp$1$$,$ordered_QMARK_$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.linear-matcher",$JSCompiler_temp$jscomp$2073_this$$jscomp$733$$);}return $JSCompiler_temp$jscomp$2073_this$$jscomp$733$$},$reitit$trie$_path_matcher$$=function($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$,$matcher$jscomp$8$$){if($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$!=
null&&$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$.$reitit$trie$TrieCompiler$_path_matcher$arity$2$!=null)$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$=$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$.$reitit$trie$TrieCompiler$_path_matcher$arity$2$($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$,$matcher$jscomp$8$$);else{var $m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$=$reitit$trie$_path_matcher$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$==
null?null:$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$)];if($m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$!=null)$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$=$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$,$matcher$jscomp$8$$):$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$,
$matcher$jscomp$8$$);else if($m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$=$reitit$trie$_path_matcher$$._,$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$!=null)$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$=$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$,
$matcher$jscomp$8$$):$m__5372__auto__$jscomp$inline_9893_m__5374__auto__$jscomp$inline_9892$$($JSCompiler_temp$jscomp$2074_this$$jscomp$737$$,$matcher$jscomp$8$$);else throw $APP.$cljs$core$missing_protocol$$("TrieCompiler.-path-matcher",$JSCompiler_temp$jscomp$2074_this$$jscomp$737$$);}return $JSCompiler_temp$jscomp$2074_this$$jscomp$737$$},$reitit$impl$fast_get$$=function($m$jscomp$213$$,$k$jscomp$612$$){return $m$jscomp$213$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$213$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$612$$):
$m$jscomp$213$$($k$jscomp$612$$)},$reitit$impl$maybe_url_decode$$=function($s$jscomp$537$$){return $APP.$cljs$core$truth_$$($s$jscomp$537$$)?decodeURIComponent($s$jscomp$537$$):null},$reitit$core$match_by_path$$=function($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$,$path$jscomp$212$$){if($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$!=null&&$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$.$reitit$core$Router$match_by_path$arity$2$!=null)$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$=$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$.$reitit$core$Router$match_by_path$arity$2$($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$,
$path$jscomp$212$$);else{var $m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$=$reitit$core$match_by_path$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$==null?null:$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$)];if($m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$!=null)$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$=$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$,
$path$jscomp$212$$):$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$,$path$jscomp$212$$);else if($m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$=$reitit$core$match_by_path$$._,$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$!=null)$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$=$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$,$path$jscomp$212$$):$m__5372__auto__$jscomp$inline_9898_m__5374__auto__$jscomp$inline_9897$$($JSCompiler_temp$jscomp$2076_this$$jscomp$761$$,$path$jscomp$212$$);else throw $APP.$cljs$core$missing_protocol$$("Router.match-by-path",$JSCompiler_temp$jscomp$2076_this$$jscomp$761$$);}return $JSCompiler_temp$jscomp$2076_this$$jscomp$761$$},$app$plugins$utils$throw_not_valid$$=
function($code$jscomp$33$$,$value$jscomp$528$$){if($value$jscomp$528$$!=null)throw Error("[PENPOT PLUGIN] Value not valid: "+($value$jscomp$528$$??"")+". Code: "+($code$jscomp$33$$??""));throw Error("[PENPOT PLUGIN] Value not valid. Code: "+($code$jscomp$33$$??""));},$app$plugins$utils$reject_not_valid$$=function($reject$jscomp$20$$,$code$jscomp$35_msg$jscomp$29$$,$value$jscomp$530$$){$code$jscomp$35_msg$jscomp$29$$="[PENPOT PLUGIN] Value not valid: "+($value$jscomp$530$$??"")+". Code: "+($code$jscomp$35_msg$jscomp$29$$??
"");console.error($code$jscomp$35_msg$jscomp$29$$);return $reject$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($code$jscomp$35_msg$jscomp$29$$):$reject$jscomp$20$$($code$jscomp$35_msg$jscomp$29$$)},$app$util$text_editor$create_editor_state$cljs$0core$0IFn$0_invoke$0arity$01$$=function($content$jscomp$173$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createEditorState($content$jscomp$173$$,null)},$app$main$ui$css_cursors$init_static_cursor_style$$=
function($style$jscomp$56$$,$name$jscomp$418$$,$value$jscomp$755$$){$style$jscomp$56$$.add(".cursor-"+($name$jscomp$418$$??""),{cursor:""+($value$jscomp$755$$??"")+" !important"})},$app$util$theme$get_system_theme$$=function(){return $APP.$app$util$theme$color_scheme_media_query$$.matches?"dark":"light"},$meta_merge$core$with_meta_STAR_$$=function($obj$jscomp$179$$,$m$jscomp$204$$){return($obj$jscomp$179$$!=null?$obj$jscomp$179$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===
$obj$jscomp$179$$.$cljs$core$IWithMeta$$||($obj$jscomp$179$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$179$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$179$$))?$APP.$cljs$core$with_meta$$($obj$jscomp$179$$,$m$jscomp$204$$):$obj$jscomp$179$$},$reitit$trie$t_reitit$0trie50248$$=function($meta50241$$,$_$jscomp$1440$$,$params$jscomp$126$$,$data$jscomp$166$$,$match$jscomp$28$$,$meta50249$$){this.$meta50241$=
$meta50241$$;this.$_$=$_$jscomp$1440$$;this.params=$params$jscomp$126$$;this.data=$data$jscomp$166$$;this.match=$match$jscomp$28$$;this.$meta50249$=$meta50249$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$util$object$type_of_QMARK_$$=function($o$jscomp$203$$,$t$jscomp$53$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($o$jscomp$203$$,$APP.$app$util$object$type_symbol$$),
$t$jscomp$53$$)},$meta_merge$core$displace_QMARK_$$=function($obj$jscomp$180$$){return $APP.$cljs$cst$2378$displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($obj$jscomp$180$$))},$reitit$trie$assoc_param$$=function($match$jscomp$27$$,$k$jscomp$605$$,$v$jscomp$551$$){var $params$jscomp$124$$=$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($match$jscomp$27$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($match$jscomp$27$$,$APP.$cljs$cst$1435$params$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$124$$,$k$jscomp$605$$,$v$jscomp$551$$))},$meta_merge$core$replace_QMARK_$$=function($obj$jscomp$181$$){return $APP.$cljs$cst$2379$replace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($obj$jscomp$181$$))},$cljs$core$take_last$$=function($G__27428_coll$jscomp$284_lead$$){var $G__27427_s$jscomp$77$$=$APP.$cljs$core$seq$$($G__27428_coll$jscomp$284_lead$$);for($G__27428_coll$jscomp$284_lead$$=$APP.$cljs$core$seq$$($APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(1,
$G__27428_coll$jscomp$284_lead$$));;)if($G__27428_coll$jscomp$284_lead$$)$G__27427_s$jscomp$77$$=$APP.$cljs$core$next$$($G__27427_s$jscomp$77$$),$G__27428_coll$jscomp$284_lead$$=$APP.$cljs$core$next$$($G__27428_coll$jscomp$284_lead$$);else return $G__27427_s$jscomp$77$$},$app$main$data$event$append_to_buffer$$=function($buffer$jscomp$60$$,$item$jscomp$54$$){return $APP.$cljs$core$count$$($buffer$jscomp$60$$)>=1024?$buffer$jscomp$60$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($buffer$jscomp$60$$,
$item$jscomp$54$$)},$cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$03$$=function(){return function(){function $cljs$core$sp3__3$$($or__5025__auto____$6_x$jscomp$452$$,$or__5025__auto____$7_y$jscomp$222$$,$z$jscomp$74$$){var $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6_x$jscomp$452$$):
$or__5025__auto____$6_x$jscomp$452$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=
$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$7_y$jscomp$222$$):$or__5025__auto____$7_y$jscomp$222$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$74$$):$z$jscomp$74$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6_x$jscomp$452$$):$meta_merge$core$displace_QMARK_$$($or__5025__auto____$6_x$jscomp$452$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$7_y$jscomp$222$$):$meta_merge$core$displace_QMARK_$$($or__5025__auto____$7_y$jscomp$222$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$74$$):$meta_merge$core$displace_QMARK_$$($z$jscomp$74$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$))return $or__5025__auto__$jscomp$20_or__5025__auto____$1$jscomp$7_or__5025__auto____$2$jscomp$3_or__5025__auto____$3$jscomp$2_or__5025__auto____$4$jscomp$2_or__5025__auto____$5$$;
$or__5025__auto____$6_x$jscomp$452$$=$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$6_x$jscomp$452$$):$meta_merge$core$replace_QMARK_$$($or__5025__auto____$6_x$jscomp$452$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$6_x$jscomp$452$$))return $or__5025__auto____$6_x$jscomp$452$$;$or__5025__auto____$7_y$jscomp$222$$=$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$7_y$jscomp$222$$):
$meta_merge$core$replace_QMARK_$$($or__5025__auto____$7_y$jscomp$222$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$7_y$jscomp$222$$)?$or__5025__auto____$7_y$jscomp$222$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($z$jscomp$74$$):$meta_merge$core$replace_QMARK_$$($z$jscomp$74$$)}function $cljs$core$sp3__2$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$,$y$jscomp$221$$){var $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=
$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$):$or__5025__auto____$4$jscomp$1_x$jscomp$451$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;$or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=
$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$221$$):$y$jscomp$221$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;$or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=
$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$):$meta_merge$core$displace_QMARK_$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;
$or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$=$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$221$$):$meta_merge$core$displace_QMARK_$$($y$jscomp$221$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$))return $or__5025__auto__$jscomp$19_or__5025__auto____$1$jscomp$6_or__5025__auto____$2$jscomp$2_or__5025__auto____$3$jscomp$1$$;
$or__5025__auto____$4$jscomp$1_x$jscomp$451$$=$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$):$meta_merge$core$replace_QMARK_$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$4$jscomp$1_x$jscomp$451$$)?$or__5025__auto____$4$jscomp$1_x$jscomp$451$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$221$$):
$meta_merge$core$replace_QMARK_$$($y$jscomp$221$$)}function $cljs$core$sp3__1$$($x$jscomp$450$$){var $or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$450$$):$x$jscomp$450$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$))return $or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$;$or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$=
$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$450$$):$meta_merge$core$displace_QMARK_$$($x$jscomp$450$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$)?$or__5025__auto__$jscomp$18_or__5025__auto____$1$jscomp$5$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$450$$):
$meta_merge$core$replace_QMARK_$$($x$jscomp$450$$)}var $cljs$core$sp3$$=null,$cljs$core$sp3__4$$=function(){function $G__27338$$($x$jscomp$454$$,$y$jscomp$224$$,$z$jscomp$76$$,$var_args$jscomp$208$$){var $G__27342__i_args$jscomp$82$$=null;if(arguments.length>3){$G__27342__i_args$jscomp$82$$=0;for(var $G__27342__a$$=Array(arguments.length-3);$G__27342__i_args$jscomp$82$$<$G__27342__a$$.length;)$G__27342__a$$[$G__27342__i_args$jscomp$82$$]=arguments[$G__27342__i_args$jscomp$82$$+3],++$G__27342__i_args$jscomp$82$$;
$G__27342__i_args$jscomp$82$$=new $APP.$cljs$core$IndexedSeq$$($G__27342__a$$,0,null)}return $G__27338__delegate$$.call(this,$x$jscomp$454$$,$y$jscomp$224$$,$z$jscomp$76$$,$G__27342__i_args$jscomp$82$$)}function $G__27338__delegate$$($or__5025__auto__$jscomp$21_x$jscomp$453$$,$y$jscomp$223$$,$z$jscomp$75$$,$args$jscomp$81$$){$or__5025__auto__$jscomp$21_x$jscomp$453$$=$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$3$($or__5025__auto__$jscomp$21_x$jscomp$453$$,$y$jscomp$223$$,$z$jscomp$75$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$21_x$jscomp$453$$)?
$or__5025__auto__$jscomp$21_x$jscomp$453$$:$APP.$cljs$core$some$$(function($p1__23399_SHARP_$$){var $or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$=$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$nil_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__23399_SHARP_$$):$p1__23399_SHARP_$$==null;if($APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$))return $or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$;$or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$=
$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$displace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__23399_SHARP_$$):$meta_merge$core$displace_QMARK_$$($p1__23399_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$)?$or__5025__auto____$1$jscomp$8_or__5025__auto____$2$jscomp$4$$:$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$meta_merge$core$replace_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__23399_SHARP_$$):
$meta_merge$core$replace_QMARK_$$($p1__23399_SHARP_$$)},$args$jscomp$81$$)}$G__27338$$.$cljs$lang$maxFixedArity$=3;$G__27338$$.$cljs$lang$applyTo$=function($arglist__27343_args$jscomp$83$$){var $x$jscomp$455$$=$APP.$cljs$core$first$$($arglist__27343_args$jscomp$83$$);$arglist__27343_args$jscomp$83$$=$APP.$cljs$core$next$$($arglist__27343_args$jscomp$83$$);var $y$jscomp$225$$=$APP.$cljs$core$first$$($arglist__27343_args$jscomp$83$$);$arglist__27343_args$jscomp$83$$=$APP.$cljs$core$next$$($arglist__27343_args$jscomp$83$$);
var $z$jscomp$77$$=$APP.$cljs$core$first$$($arglist__27343_args$jscomp$83$$);$arglist__27343_args$jscomp$83$$=$APP.$cljs$core$rest$$($arglist__27343_args$jscomp$83$$);return $G__27338__delegate$$($x$jscomp$455$$,$y$jscomp$225$$,$z$jscomp$77$$,$arglist__27343_args$jscomp$83$$)};$G__27338$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__27338__delegate$$;return $G__27338$$}();$cljs$core$sp3$$=function($x$jscomp$456$$,$y$jscomp$226$$,$z$jscomp$78$$,$var_args$jscomp$209$$){switch(arguments.length){case 0:return null;
case 1:return $cljs$core$sp3__1$$.call(this,$x$jscomp$456$$);case 2:return $cljs$core$sp3__2$$.call(this,$x$jscomp$456$$,$y$jscomp$226$$);case 3:return $cljs$core$sp3__3$$.call(this,$x$jscomp$456$$,$y$jscomp$226$$,$z$jscomp$78$$);default:var $G__27349_G__27351__i$$=null;if(arguments.length>3){$G__27349_G__27351__i$$=0;for(var $G__27351__a$$=Array(arguments.length-3);$G__27349_G__27351__i$$<$G__27351__a$$.length;)$G__27351__a$$[$G__27349_G__27351__i$$]=arguments[$G__27349_G__27351__i$$+3],++$G__27349_G__27351__i$$;
$G__27349_G__27351__i$$=new $APP.$cljs$core$IndexedSeq$$($G__27351__a$$,0,null)}return $cljs$core$sp3__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$456$$,$y$jscomp$226$$,$z$jscomp$78$$,$G__27349_G__27351__i$$)}throw Error("Invalid arity: "+arguments.length);};$cljs$core$sp3$$.$cljs$lang$maxFixedArity$=3;$cljs$core$sp3$$.$cljs$lang$applyTo$=$cljs$core$sp3__4$$.$cljs$lang$applyTo$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$0$=function(){return null};$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$1$=
$cljs$core$sp3__1$$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$2$=$cljs$core$sp3__2$$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$3$=$cljs$core$sp3__3$$;$cljs$core$sp3$$.$cljs$core$IFn$_invoke$arity$variadic$=$cljs$core$sp3__4$$.$cljs$core$IFn$_invoke$arity$variadic$;return $cljs$core$sp3$$}()},$reitit$core$t_reitit$0core52163$$=function($non_conflicting$$,$names$jscomp$18$$,$conflicting_paths$$,$compiled_routes$jscomp$20$$,$conflicting$$,$routes$jscomp$24$$,$conflicting_QMARK_$$,$mixed_router$$,
$map__52162$$,$linear_router$$,$opts$jscomp$288$$,$meta52164$$){this.$non_conflicting$=$non_conflicting$$;this.names=$names$jscomp$18$$;this.$conflicting_paths$=$conflicting_paths$$;this.$compiled_routes$=$compiled_routes$jscomp$20$$;this.$conflicting$=$conflicting$$;this.$routes$=$routes$jscomp$24$$;this.$conflicting_QMARK_$=$conflicting_QMARK_$$;this.$mixed_router$=$mixed_router$$;this.$map__52162$=$map__52162$$;this.$linear_router$=$linear_router$$;this.$opts$=$opts$jscomp$288$$;this.$meta52164$=
$meta52164$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core52151$$=function($names$jscomp$15$$,$compiled_routes$jscomp$16$$,$map__52150$$,$routes$jscomp$21$$,$__GT_static_router$$,$lookup$jscomp$12$$,$wild$$,$static_router$$,$opts$jscomp$285$$,$wildcard_router$$,$meta52152$$){this.names=$names$jscomp$15$$;this.$compiled_routes$=$compiled_routes$jscomp$16$$;this.$map__52150$=$map__52150$$;this.$routes$=$routes$jscomp$21$$;
this.$__GT_static_router$=$__GT_static_router$$;this.$lookup$=$lookup$jscomp$12$$;this.$wild$=$wild$$;this.$static_router$=$static_router$$;this.$opts$=$opts$jscomp$285$$;this.$wildcard_router$=$wildcard_router$$;this.$meta52152$=$meta52152$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$decode$$=function($param$jscomp$11_path$jscomp$196$$,$start$jscomp$212$$,$end$jscomp$77$$,$percent_QMARK_$$){$param$jscomp$11_path$jscomp$196$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($param$jscomp$11_path$jscomp$196$$,
$start$jscomp$212$$,$end$jscomp$77$$);return $APP.$cljs$core$truth_$$($percent_QMARK_$$)?decodeURIComponent($param$jscomp$11_path$jscomp$196$$):$param$jscomp$11_path$jscomp$196$$},$reitit$trie$t_reitit$0trie50315$$=function($meta50241$jscomp$6$$,$_$jscomp$1446$$,$key$jscomp$324$$,$params$jscomp$128$$,$data$jscomp$168$$,$match$jscomp$31$$,$meta50316$$){this.$meta50241$=$meta50241$jscomp$6$$;this.$_$=$_$jscomp$1446$$;this.key=$key$jscomp$324$$;this.params=$params$jscomp$128$$;this.data=$data$jscomp$168$$;
this.match=$match$jscomp$31$$;this.$meta50316$=$meta50316$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$_slice_end$$=function($x$jscomp$1137$$,$xs$jscomp$32$$){var $i$jscomp$499$$=typeof $x$jscomp$1137$$==="string"?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($x$jscomp$1137$$,"/"):null;return typeof $i$jscomp$499$$==="number"&&$i$jscomp$499$$>0?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1137$$,$i$jscomp$499$$)],null),$xs$jscomp$32$$):$xs$jscomp$32$$},$app$plugins$utils$changes_component_copy_structure_QMARK_$$=function($objects$jscomp$265$$,$parent$jscomp$207$$,$child$jscomp$79$$){return $APP.$cljs$core$boolean$0$$($APP.$app$common$types$component$in_component_copy_QMARK_$$($parent$jscomp$207$$))||$APP.$cljs$core$boolean$0$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$265$$,
$child$jscomp$79$$))},$reitit$trie$t_reitit$0trie50263$$=function($meta50241$jscomp$2$$,$_$jscomp$1442$$,$path$jscomp$197$$,$matcher$jscomp$9$$,$size$jscomp$97$$,$meta50264$$){this.$meta50241$=$meta50241$jscomp$2$$;this.$_$=$_$jscomp$1442$$;this.path=$path$jscomp$197$$;this.$matcher$=$matcher$jscomp$9$$;this.size=$size$jscomp$97$$;this.$meta50264$=$meta50264$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$plugins$register$get_plugin_data$$=function($state$jscomp$193$$,
$plugin_id$jscomp$3$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$193$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3222$plugins$$,$APP.$cljs$cst$142$data$$,$plugin_id$jscomp$3$$],null))},$app$plugins$register$check_permission$$=function($map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,$permission$jscomp$1$$){var $or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$74$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,"00000000-0000-0000-0000-000000000000");if($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$74$$||($or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$74$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,"96dfa740-005d-8020-8007-55ede24a2bae")))return $or__5025__auto__$jscomp$627_or__5025__auto____$1$jscomp$74$$;
$map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$plugins$register$registry$$),$APP.$cljs$cst$142$data$$),$map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$);$map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$);
$map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,$APP.$cljs$cst$1728$permissions$$);return $APP.$cljs$core$contains_QMARK_$$($map__54130_map__54130__$1_permissions$jscomp$4_plugin_id$jscomp$2$$,$permission$jscomp$1$$)},$app$main$data$event$longtask_observer$$=function(){return typeof globalThis!=="undefined"&&globalThis.PerformanceObserver!=null?$APP.$beicon$v2$core$create$$(function($subs$jscomp$13$$){var $observer$jscomp$4$$=
new PerformanceObserver(function($list$jscomp$2$$){return $APP.$cljs$core$run_BANG_$$(function($entry$jscomp$40$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("longtask",$entry$jscomp$40$$.entryType)&&$entry$jscomp$40$$.duration>1E3?$subs$jscomp$13$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"long-task",$APP.$cljs$cst$1976$duration$$,$entry$jscomp$40$$.duration],null)):null},$list$jscomp$2$$.getEntries())});
$observer$jscomp$4$$.observe({entryTypes:["longtask"]});return function(){return $observer$jscomp$4$$.disconnect()}}):$APP.$beicon$v2$core$empty$$()},$app$main$data$event$user_input_observer$$=function(){return typeof globalThis!=="undefined"&&globalThis.PerformanceObserver!=null?$APP.$beicon$v2$core$create$$(function($subs$jscomp$12$$){var $observer$jscomp$3$$=new PerformanceObserver(function($list$jscomp$1$$){return $APP.$cljs$core$run_BANG_$$(function($entry$jscomp$39$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("event",
$entry$jscomp$39$$.entryType)&&$entry$jscomp$39$$.duration>1E3?$subs$jscomp$12$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"user-input",$APP.$cljs$cst$1976$duration$$,$entry$jscomp$39$$.duration,$APP.$cljs$cst$2325$event_name$$,$entry$jscomp$39$$.name],null)):null},$list$jscomp$1$$.getEntries())});$observer$jscomp$3$$.observe({entryTypes:["event"]});return function(){return $observer$jscomp$3$$.disconnect()}}):$APP.$beicon$v2$core$empty$$()},
$reitit$impl$maybe_map_values$$=function($f$jscomp$795$$,$coll$jscomp$1083$$){return $APP.$cljs$core$reduce_kv$$(function($coll__$1$jscomp$558$$,$k$jscomp$608$$,$temp__5827__auto__$jscomp$20_v$jscomp$554$$){$temp__5827__auto__$jscomp$20_v$jscomp$554$$=$f$jscomp$795$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$795$$.$cljs$core$IFn$_invoke$arity$1$($temp__5827__auto__$jscomp$20_v$jscomp$554$$):$f$jscomp$795$$($temp__5827__auto__$jscomp$20_v$jscomp$554$$);return $temp__5827__auto__$jscomp$20_v$jscomp$554$$==
null?$coll__$1$jscomp$558$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($coll__$1$jscomp$558$$,$k$jscomp$608$$,$temp__5827__auto__$jscomp$20_v$jscomp$554$$)},$coll$jscomp$1083$$,$coll$jscomp$1083$$)},$reitit$impl$path_params$$=function($params$jscomp$134$$){return $reitit$impl$maybe_map_values$$(function($p1__51735_SHARP__s$jscomp$inline_9902$$){$p1__51735_SHARP__s$jscomp$inline_9902$$=$APP.$reitit$impl$into_string$$($p1__51735_SHARP__s$jscomp$inline_9902$$);return $APP.$cljs$core$truth_$$($p1__51735_SHARP__s$jscomp$inline_9902$$)?
encodeURIComponent($p1__51735_SHARP__s$jscomp$inline_9902$$):null},$params$jscomp$134$$)},$reitit$core$t_reitit$0core52137$$=function($p$jscomp$233$$,$names$jscomp$12$$,$match$jscomp$48$$,$data$jscomp$186$$,$compiled_routes$jscomp$12$$,$routes$jscomp$18$$,$vec__52133$$,$vec__52130$$,$n$jscomp$281$$,$vec__52127$$,$result$jscomp$228$$,$opts$jscomp$282$$,$meta52138$$){this.p=$p$jscomp$233$$;this.names=$names$jscomp$12$$;this.match=$match$jscomp$48$$;this.data=$data$jscomp$186$$;this.$compiled_routes$=
$compiled_routes$jscomp$12$$;this.$routes$=$routes$jscomp$18$$;this.$vec__52133$=$vec__52133$$;this.$vec__52130$=$vec__52130$$;this.n=$n$jscomp$281$$;this.$vec__52127$=$vec__52127$$;this.result=$result$jscomp$228$$;this.$opts$=$opts$jscomp$282$$;this.$meta52138$=$meta52138$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core52101$$=function($matcher$jscomp$20$$,$names$jscomp$9$$,$compiled_routes$jscomp$8$$,$routes$jscomp$15$$,
$lookup$jscomp$9$$,$pl$jscomp$8$$,$nl$jscomp$12$$,$match_by_path$jscomp$3$$,$compiler$jscomp$7$$,$opts$jscomp$279$$,$vec__52069$$,$meta52102$$){this.$matcher$=$matcher$jscomp$20$$;this.names=$names$jscomp$9$$;this.$compiled_routes$=$compiled_routes$jscomp$8$$;this.$routes$=$routes$jscomp$15$$;this.$lookup$=$lookup$jscomp$9$$;this.pl=$pl$jscomp$8$$;this.nl=$nl$jscomp$12$$;this.$match_by_path$=$match_by_path$jscomp$3$$;this.$compiler$=$compiler$jscomp$7$$;this.$opts$=$opts$jscomp$279$$;this.$vec__52069$=
$vec__52069$$;this.$meta52102$=$meta52102$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core52015$$=function($names$jscomp$6$$,$data$jscomp$181$$,$compiled_routes$jscomp$4$$,$routes$jscomp$12$$,$vec__51994$$,$lookup$jscomp$6$$,$pl$jscomp$4$$,$nl$jscomp$8$$,$opts$jscomp$276$$,$meta52016$$){this.names=$names$jscomp$6$$;this.data=$data$jscomp$181$$;this.$compiled_routes$=$compiled_routes$jscomp$4$$;this.$routes$=$routes$jscomp$12$$;
this.$vec__51994$=$vec__51994$$;this.$lookup$=$lookup$jscomp$6$$;this.pl=$pl$jscomp$4$$;this.nl=$nl$jscomp$8$$;this.$opts$=$opts$jscomp$276$$;this.$meta52016$=$meta52016$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$core$t_reitit$0core51961$$=function($matcher$jscomp$17$$,$names$jscomp$3$$,$compiled_routes$$,$routes$jscomp$9$$,$lookup$jscomp$3$$,$pl$$,$nl$jscomp$4$$,$vec__51938$$,$match_by_path$$,$compiler$jscomp$4$$,$opts$jscomp$273$$,$meta51962$$){this.$matcher$=
$matcher$jscomp$17$$;this.names=$names$jscomp$3$$;this.$compiled_routes$=$compiled_routes$$;this.$routes$=$routes$jscomp$9$$;this.$lookup$=$lookup$jscomp$3$$;this.pl=$pl$$;this.nl=$nl$jscomp$4$$;this.$vec__51938$=$vec__51938$$;this.$match_by_path$=$match_by_path$$;this.$compiler$=$compiler$jscomp$4$$;this.$opts$=$opts$jscomp$273$$;this.$meta51962$=$meta51962$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$impl$_copy_meta$$=function($to$jscomp$21$$,
$from$jscomp$19$$){function $_with_meta$$($x$jscomp$1139$$,$m$jscomp$207$$){try{return $APP.$cljs$core$with_meta$$($x$jscomp$1139$$,$m$jscomp$207$$)}catch($e51557$$){if($e51557$$ instanceof Error)return $x$jscomp$1139$$;throw $e51557$$;}}return function $reitit$impl$_copy_meta_$__copy$$($l$jscomp$99$$,$p$jscomp$221$$,$m$jscomp$208$$){return $APP.$cljs$core$reduce_kv$$(function($l__$1$jscomp$2$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$,$v$jscomp$553$$){$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$221$$,
$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$);var $m_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$meta$$($v$jscomp$553$$))?$APP.$cljs$core$meta$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$19$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$)):null;return $APP.$cljs$core$truth_$$($m_SINGLEQUOTE_$jscomp$3$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($l__$1$jscomp$2$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$,$_with_meta$$,$m_SINGLEQUOTE_$jscomp$3$$):
$APP.$cljs$core$map_QMARK_$$($v$jscomp$553$$)&&!$APP.$cljs$core$record_QMARK_$$($v$jscomp$553$$)&&$APP.$cljs$core$seq$$($v$jscomp$553$$)?$reitit$impl$_copy_meta_$__copy$$($l__$1$jscomp$2$$,$k$jscomp$607_p_SINGLEQUOTE_$jscomp$3$$,$v$jscomp$553$$):$l__$1$jscomp$2$$},$l$jscomp$99$$,$m$jscomp$208$$)}($to$jscomp$21$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$to$jscomp$21$$)},$app$main$router$navigated$$=function($match$jscomp$53$$,$send_event_info_QMARK_$$){typeof $app$main$router$navigated_52290$$===
"undefined"&&($app$main$router$navigated_52290$$=function($match$jscomp$54$$,$send_event_info_QMARK_$jscomp$1$$,$meta52291$$){this.match=$match$jscomp$54$$;this.$send_event_info_QMARK_$=$send_event_info_QMARK_$jscomp$1$$;this.$meta52291$=$meta52291$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$navigated_52290$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigated_52290$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2465$app_DOT_main_DOT_router_SLASH_navigated$$},$app$main$router$navigated_52290$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52292$$,$meta52291__$1$$){return new $app$main$router$navigated_52290$$(this.match,this.$send_event_info_QMARK_$,$meta52291__$1$$)},$app$main$router$navigated_52290$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52291$},$app$main$router$navigated_52290$$.prototype.$cljs$core$IDeref$_deref$arity$1$=
function(){return this.match},$app$main$router$navigated_52290$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigated_52290$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){if($APP.$cljs$core$truth_$$(this.$send_event_info_QMARK_$)){var $route$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.match,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$725$name$$),$params$jscomp$138$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.match,$APP.$cljs$cst$2278$query_params$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($params$jscomp$138$$,$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"navigate",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2179$route$$,$APP.$cljs$core$name$$($route$jscomp$5$$)]))))}return null},$app$main$router$navigated_52290$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$navigated_52290$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1524$$,$state$jscomp$112$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$112$$,$APP.$cljs$cst$2179$route$$,this.match),$APP.$cljs$cst$727$exception$$)});return new $app$main$router$navigated_52290$$($match$jscomp$53$$,$send_event_info_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$event$simplify_props$$=function($data$jscomp$147$$){return $APP.$cljs$core$reduce_kv$$(function($data__$1$jscomp$5$$,$k$jscomp$604$$,$v$jscomp$550$$){return $APP.$cljs$core$map_QMARK_$$($v$jscomp$550$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$cst$2311$placeholder_SLASH_map$$):$APP.$cljs$core$vector_QMARK_$$($v$jscomp$550$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$app$main$data$event$xf_COLON_coerce_to_string$$,$v$jscomp$550$$)):$APP.$cljs$core$set_QMARK_$$($v$jscomp$550$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$event$xf_COLON_coerce_to_string$$,$v$jscomp$550$$)):$APP.$cljs$core$coll_QMARK_$$($v$jscomp$550$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,
$k$jscomp$604$$,$APP.$cljs$cst$2312$placeholder_SLASH_coll$$):$APP.$cljs$core$fn_QMARK_$$($v$jscomp$550$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data__$1$jscomp$5$$,$k$jscomp$604$$,$APP.$cljs$cst$2313$placeholder_SLASH_fn$$):$v$jscomp$550$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($data__$1$jscomp$5$$,$k$jscomp$604$$):$data__$1$jscomp$5$$},$data$jscomp$147$$,$data$jscomp$147$$)},$app$main$ui$static$0$request_dialog_STAR_$$=function($props_76128_title$jscomp$33$$){var $on_close$jscomp$13$$=
$props_76128_title$jscomp$33$$.onClose,$cancel_text$$=$props_76128_title$jscomp$33$$.cancelText,$content$jscomp$242$$=$props_76128_title$jscomp$33$$.content,$button_text$$=$props_76128_title$jscomp$33$$.buttonText,$on_button_click_on_click$jscomp$31$$=$props_76128_title$jscomp$33$$.onButtonClick;$props_76128_title$jscomp$33$$=$props_76128_title$jscomp$33$$.title;$on_button_click_on_click$jscomp$31$$=$APP.$cljs$core$truth_$$($on_button_click_on_click$jscomp$31$$)?$on_button_click_on_click$jscomp$31$$:
$on_close$jscomp$13$$;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__dialog",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__modal-close",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$13$$,className:"main_ui_static__modal-close-button",children:$APP.$app$main$ui$icons$close$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__dialog-title",children:$props_76128_title$jscomp$33$$}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$117$$,$content__$1$jscomp$45_p__76129$$){var $index$jscomp$409$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content__$1$jscomp$45_p__76129$$,0,null);$content__$1$jscomp$45_p__76129$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content__$1$jscomp$45_p__76129$$,1,null);$out_arr__44092__auto__$jscomp$117$$.push((0,$APP.$rumext$v2$jsx$$)("div",{children:$content__$1$jscomp$45_p__76129$$},
$index$jscomp$409$$));return $out_arr__44092__auto__$jscomp$117$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$242$$)),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__sign-info",children:[$APP.$cljs$core$truth_$$($cancel_text$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$13$$,className:"main_ui_static__cancel-button",children:$cancel_text$$}):null,(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_button_click_on_click$jscomp$31$$,
children:$button_text$$})]})]})})},$app$util$css$declarations__GT_str$$=function($declarations$$){return Array.from(Object.entries($declarations$$)).reduce(function($acc$jscomp$147$$,$p__74088_v$jscomp$629$$){var $k$jscomp$670$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74088_v$jscomp$629$$,0,null);$p__74088_v$jscomp$629$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74088_v$jscomp$629$$,1,null);return""+($acc$jscomp$147$$??"")+($k$jscomp$670$$??"")+": "+($p__74088_v$jscomp$629$$??
"")+";"},"")},$app$util$css$add_rule$$=function($styleSheet$jscomp$7$$,$rule$jscomp$4_selector$jscomp$18$$,$declarations$jscomp$1$$){$rule$jscomp$4_selector$jscomp$18$$=""+($rule$jscomp$4_selector$jscomp$18$$??"")+" { "+($app$util$css$declarations__GT_str$$($declarations$jscomp$1$$)??"")+" }";return $styleSheet$jscomp$7$$.insertRule($rule$jscomp$4_selector$jscomp$18$$,$styleSheet$jscomp$7$$.cssRules.length)},$reitit$impl$find_names$$=function($routes$jscomp$6$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__51700_SHARP_$$){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__51700_SHARP_$$))}),$routes$jscomp$6$$)},$app$plugins$flags$set_flag$$=function($id$jscomp$411$$,$key$jscomp$371$$,$value$jscomp$531$$){typeof $app$plugins$flags$set_flag_55299$$==="undefined"&&($app$plugins$flags$set_flag_55299$$=function($id$jscomp$412$$,$key$jscomp$372$$,$value$jscomp$532$$,$meta55300$$){this.id=$id$jscomp$412$$;
this.key=$key$jscomp$372$$;this.value=$value$jscomp$532$$;this.$meta55300$=$meta55300$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$plugins$flags$set_flag_55299$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$flags$set_flag_55299$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3446$app_DOT_plugins_DOT_flags_SLASH_set_flag$$},$app$plugins$flags$set_flag_55299$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55301$$,$meta55300__$1$$){return new $app$plugins$flags$set_flag_55299$$(this.id,this.key,this.value,$meta55300__$1$$)},$app$plugins$flags$set_flag_55299$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55300$},$app$plugins$flags$set_flag_55299$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$flags$set_flag_55299$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1797$$,$state$jscomp$248$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$248$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3222$plugins$$,$APP.$cljs$cst$1472$flags$$,this.id],null),$APP.$cljs$core$assoc$$,this.key,this.value)});return new $app$plugins$flags$set_flag_55299$$($id$jscomp$411$$,$key$jscomp$371$$,$value$jscomp$531$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$event$snapshot_performance_info$$=function($p__50549$$){var $map__50551__$1$$=$APP.$cljs$core$__destructure_map$$($p__50549$$),
$file_id$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50551__$1$$,$APP.$cljs$cst$1649$file_id$$);typeof $app$main$data$event$snapshot_performance_info_50569$$==="undefined"&&($app$main$data$event$snapshot_performance_info_50569$$=function($p__50549$jscomp$1$$,$map__50551$jscomp$1$$,$file_id$jscomp$16$$,$count_shapes$jscomp$1$$,$add_libraries_counters$jscomp$1$$,$meta50570$$){this.$p__50549$=$p__50549$jscomp$1$$;this.$map__50551$=$map__50551$jscomp$1$$;this.$file_id$=$file_id$jscomp$16$$;
this.$count_shapes$=$count_shapes$jscomp$1$$;this.$add_libraries_counters$=$add_libraries_counters$jscomp$1$$;this.$meta50570$=$meta50570$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$event$snapshot_performance_info_50569$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$snapshot_performance_info_50569$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2330$app_DOT_main_DOT_data_DOT_event_SLASH_snapshot_performance_info$$},
$app$main$data$event$snapshot_performance_info_50569$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50571$$,$meta50570__$1$$){return new $app$main$data$event$snapshot_performance_info_50569$$(this.$p__50549$,this.$map__50551$,this.$file_id$,this.$count_shapes$,this.$add_libraries_counters$,$meta50570__$1$$)},$app$main$data$event$snapshot_performance_info_50569$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50570$},$app$main$data$event$snapshot_performance_info_50569$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$snapshot_performance_info_50569$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1421$$,$state$jscomp$102$$){var $self__$jscomp$3002$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$102$$,$APP.$cljs$cst$2322$performance_info$$,function($info$jscomp$5$$){var $files$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$102$$,$APP.$cljs$cst$1933$files$$),$file$jscomp$14$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$6$$,$self__$jscomp$3002$$.$file_id$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($info$jscomp$5$$,$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$3002$$.$file_id$),$APP.$cljs$cst$2324$counters$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2331$total_shapes$$,$self__$jscomp$3002$$.$count_shapes$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$3002$$.$count_shapes$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$14$$):$self__$jscomp$3002$$.$count_shapes$($file$jscomp$14$$)),$APP.$cljs$cst$2324$counters$$,$self__$jscomp$3002$$.$add_libraries_counters$,$files$jscomp$6$$)})});return new $app$main$data$event$snapshot_performance_info_50569$$($p__50549$$,$map__50551__$1$$,$file_id$jscomp$15$$,function($file$jscomp$13$$){return $APP.$cljs$core$reduce_kv$$(function($sum$jscomp$1$$,$_$jscomp$1420$$,$page$jscomp$2$$){return $sum$jscomp$1$$+
$APP.$cljs$core$count$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$2$$))},0,$APP.$cljs$cst$1635$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$13$$)))},function($state$jscomp$101$$,$files$jscomp$5$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$8$$,$data$jscomp$150_library_id$jscomp$4$$){$data$jscomp$150_library_id$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$5$$,
$data$jscomp$150_library_id$jscomp$4$$),$APP.$cljs$cst$142$data$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$8$$,$APP.$cljs$cst$2327$total_components$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$150_library_id$jscomp$4$$))),$APP.$cljs$cst$2328$total_colors$$,$APP.$cljs$core$_PLUS_$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$150_library_id$jscomp$4$$))),$APP.$cljs$cst$2329$total_typographies$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$count$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$150_library_id$jscomp$4$$)))},$state$jscomp$101$$,$APP.$app$main$refs$select_libraries$$($files$jscomp$5$$,$file_id$jscomp$15$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$event$store_performace_info$$=
function(){typeof $app$main$data$event$store_performace_info_50594$$==="undefined"&&($app$main$data$event$store_performace_info_50594$$=function($meta50595$$){this.$meta50595$=$meta50595$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$event$store_performace_info_50594$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$store_performace_info_50594$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2332$app_DOT_main_DOT_data_DOT_event_SLASH_store_performace_info$$},$app$main$data$event$store_performace_info_50594$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50596$$,$meta50595__$1$$){return new $app$main$data$event$store_performace_info_50594$$($meta50595__$1$$)},$app$main$data$event$store_performace_info_50594$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50595$},$app$main$data$event$store_performace_info_50594$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$store_performace_info_50594$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1422_start$jscomp$211$$,$state$jscomp$103$$){$_$jscomp$1422_start$jscomp$211$$=performance.now();a:for(var $end$jscomp$74_i$jscomp$inline_9910$$=1E6;;){if($end$jscomp$74_i$jscomp$inline_9910$$===0)break a;Math.sin($end$jscomp$74_i$jscomp$inline_9910$$)*Math.sqrt($end$jscomp$74_i$jscomp$inline_9910$$);--$end$jscomp$74_i$jscomp$inline_9910$$}$end$jscomp$74_i$jscomp$inline_9910$$=
performance.now();return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$103$$,$APP.$cljs$cst$2322$performance_info$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2333$bench$$,$end$jscomp$74_i$jscomp$inline_9910$$-$_$jscomp$1422_start$jscomp$211$$)},$app$main$data$event$store_performace_info_50594$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$store_performace_info_50594$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1423$$,
$___$1$jscomp$809$$,$stream$jscomp$16$$){return $APP.$beicon$v2$core$map$$($app$main$data$event$snapshot_performance_info$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2334$app_DOT_main_DOT_data_DOT_workspace_SLASH_all_libraries_resolved$$),$stream$jscomp$16$$))))});return new $app$main$data$event$store_performace_info_50594$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$team$finalize_team$$=function($team_id$jscomp$46$$){typeof $app$main$data$team$finalize_team_55560$$==="undefined"&&($app$main$data$team$finalize_team_55560$$=function($team_id$jscomp$47$$,$meta55561$$){this.$team_id$=$team_id$jscomp$47$$;this.$meta55561$=$meta55561$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$finalize_team_55560$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$finalize_team_55560$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3330$app_DOT_main_DOT_data_DOT_team_SLASH_finalize_team$$},$app$main$data$team$finalize_team_55560$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55562$$,$meta55561__$1$$){return new $app$main$data$team$finalize_team_55560$$(this.$team_id$,$meta55561__$1$$)},$app$main$data$team$finalize_team_55560$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55561$},$app$main$data$team$finalize_team_55560$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$finalize_team_55560$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1718_team_id_SINGLEQUOTE_$$,$state$jscomp$220$$){$_$jscomp$1718_team_id_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$220$$,$APP.$cljs$cst$1943$current_team_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1718_team_id_SINGLEQUOTE_$$,this.$team_id$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$220$$,
$APP.$cljs$cst$1943$current_team_id$$),$APP.$cljs$cst$2187$shared_files$$),$APP.$cljs$cst$2980$fonts$$):$state$jscomp$220$$});return new $app$main$data$team$finalize_team_55560$$($team_id$jscomp$46$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$reitit$trie$t_reitit$0trie50277$$=function($meta50241$jscomp$4$$,$_$jscomp$1444$$,$key$jscomp$322$$,$end$jscomp$78$$,$matcher$jscomp$11$$,$meta50278$$){this.$meta50241$=$meta50241$jscomp$4$$;this.$_$=$_$jscomp$1444$$;this.key=$key$jscomp$322$$;this.end=$end$jscomp$78$$;
this.$matcher$=$matcher$jscomp$11$$;this.$meta50278$=$meta50278$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$common_prefix$$=function($s1$jscomp$17$$,$s2$jscomp$14$$){var $max$jscomp$70_x__5113__auto__$jscomp$inline_9914$$=$APP.$cljs$core$count$$($s1$jscomp$17$$);var $i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$=$APP.$cljs$core$count$$($s2$jscomp$14$$);$max$jscomp$70_x__5113__auto__$jscomp$inline_9914$$=$max$jscomp$70_x__5113__auto__$jscomp$inline_9914$$<
$i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$?$max$jscomp$70_x__5113__auto__$jscomp$inline_9914$$:$i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$;for($i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$=0;;){if($i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$>$max$jscomp$70_x__5113__auto__$jscomp$inline_9914$$)return $APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s1$jscomp$17$$,0,$max$jscomp$70_x__5113__auto__$jscomp$inline_9914$$);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s1$jscomp$17$$,
$i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s2$jscomp$14$$,$i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$)))return $i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$!==0?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s1$jscomp$17$$,0,$i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$):null;$i$jscomp$495_y__5114__auto__$jscomp$inline_9915$$+=1}},$reitit$trie$_slice_start$$=function($p__50145$$,$p__50146$$){function $_tailcut$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$,
$p__50165$$){var $JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50165$$,0,null),$JSCompiler_temp_const$jscomp$2083$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$;typeof $cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$!=="string"?$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$=new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$],null):typeof $cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$),$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$))?$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$=
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$,$APP.$cljs$core$count$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$))],null):typeof $JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$==="string"&&$APP.$cljs$core$not$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$)?
($cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$)?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$,"/"):$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$,$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$=
$APP.$cljs$core$truth_$$($cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$,0,$cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$,
$cp$jscomp$10_temp__5823__auto__$jscomp$inline_14148$$)],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$],null)):$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$=null;return $JSCompiler_temp_const$jscomp$2083$$.call($APP.$cljs$core$concat$$,$JSCompiler_temp$jscomp$11335_JSCompiler_temp$jscomp$11336_JSCompiler_temp$jscomp$11337_p$jscomp$210$$,
$APP.$cljs$core$rest$$($p__50165$$))}function $_postcut$$($p__50157$$){var $p$jscomp$209$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50157$$,0,null),$i$jscomp$498$$=$APP.$cljs$core$truth_$$($p$jscomp$209$$)?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($p$jscomp$209$$,"/"):$p$jscomp$209$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($i$jscomp$498$$)?$i$jscomp$498$$>0:$i$jscomp$498$$)?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($p$jscomp$209$$,0,$i$jscomp$498$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$209$$,$i$jscomp$498$$)],null),$APP.$cljs$core$rest$$($p__50157$$)):$p__50157$$}var $p1$jscomp$70$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50145$$,0,null),$p2$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50146$$,0,null);if($p1$jscomp$70$$==null||
$p2$jscomp$52$$==null)return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_postcut$$($p__50145$$),$_postcut$$($p__50146$$)],null);var $temp__5823__auto__$jscomp$126$$=function(){var $and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$=typeof $p1$jscomp$70$$==="string";return $and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$?($and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$=typeof $p2$jscomp$52$$==="string")?
$reitit$trie$common_prefix$$($p1$jscomp$70$$,$p2$jscomp$52$$):$and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$:$and__5023__auto__$jscomp$289_and__5023__auto____$1$jscomp$52$$}();return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$126$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_tailcut$$($temp__5823__auto__$jscomp$126$$,$p__50145$$),$_tailcut$$($temp__5823__auto__$jscomp$126$$,$p__50146$$)],null):new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__50145$$,$p__50146$$],null)},$reitit$trie$map_parameters$$=function($keys$jscomp$50$$){return $APP.$cljs$core$zipmap$$($keys$jscomp$50$$,$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$01$$(null))},$app$main$ui$css_cursors$init_dynamic_cursor_style$$=function($style$jscomp$57$$,$name$jscomp$419$$,$fn$jscomp$49$$){var $c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$=$APP.$cljs$core$seq$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,
360,10));$c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$);for(var $G__74179_chunk__74163_seq__74162__$1$$=null,$G__74178_count__74164$$=0,$i__74165$$=0;;)if($i__74165$$<$G__74178_count__74164$$){var $G__74180_rotation$jscomp$19$$=$G__74179_chunk__74163_seq__74162__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__74165$$);$style$jscomp$57$$.add(".cursor-"+($name$jscomp$419$$??
"")+"-"+($G__74180_rotation$jscomp$19$$??""),{cursor:""+(($fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__74180_rotation$jscomp$19$$):$fn$jscomp$49$$($G__74180_rotation$jscomp$19$$))??"")+" !important"});$i__74165$$+=1}else if($c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$))$G__74179_chunk__74163_seq__74162__$1$$=
$c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__74179_chunk__74163_seq__74162__$1$$)?($c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$=$APP.$cljs$core$_chunked_first$$($G__74179_chunk__74163_seq__74162__$1$$),$G__74178_count__74164$$=$APP.$cljs$core$_chunked_rest$$($G__74179_chunk__74163_seq__74162__$1$$),$G__74179_chunk__74163_seq__74162__$1$$=$c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$,
$G__74180_rotation$jscomp$19$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$),$c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$=$G__74178_count__74164$$,$G__74178_count__74164$$=$G__74180_rotation$jscomp$19$$):($G__74180_rotation$jscomp$19$$=$APP.$cljs$core$first$$($G__74179_chunk__74163_seq__74162__$1$$),$style$jscomp$57$$.add(".cursor-"+($name$jscomp$419$$??"")+"-"+($G__74180_rotation$jscomp$19$$??""),{cursor:""+
(($fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$fn$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__74180_rotation$jscomp$19$$):$fn$jscomp$49$$($G__74180_rotation$jscomp$19$$))??"")+" !important"}),$c__5548__auto__$jscomp$26_rotations_seq__74162_temp__5825__auto__$jscomp$288$$=$APP.$cljs$core$next$$($G__74179_chunk__74163_seq__74162__$1$$),$G__74179_chunk__74163_seq__74162__$1$$=null,$G__74178_count__74164$$=0),$i__74165$$=0;else break},$reitit$impl$path_for$$=function($route$jscomp$1_temp__5823__auto__$jscomp$132$$,
$path_params$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2406$path_params$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$1_temp__5823__auto__$jscomp$132$$))?($route$jscomp$1_temp__5823__auto__$jscomp$132$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$107$$,$part$jscomp$2_temp__5823__auto__$jscomp$133$$){if(typeof $part$jscomp$2_temp__5823__auto__$jscomp$133$$==="string")return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$107$$,
$part$jscomp$2_temp__5823__auto__$jscomp$133$$);$part$jscomp$2_temp__5823__auto__$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path_params$jscomp$1$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($part$jscomp$2_temp__5823__auto__$jscomp$133$$));return $APP.$cljs$core$truth_$$($part$jscomp$2_temp__5823__auto__$jscomp$133$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$107$$,$part$jscomp$2_temp__5823__auto__$jscomp$133$$):$APP.$cljs$core$reduced$$(null)},
$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$2407$path_parts$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$1_temp__5823__auto__$jscomp$132$$)),$APP.$cljs$core$truth_$$($route$jscomp$1_temp__5823__auto__$jscomp$132$$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$route$jscomp$1_temp__5823__auto__$jscomp$132$$):null):$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$1_temp__5823__auto__$jscomp$132$$)},$app$main$fonts$find_variant$$=
function($map__53033__$1_p__53032_variants$jscomp$4$$,$variant_data$$){$map__53033__$1_p__53032_variants$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__53033__$1_p__53032_variants$jscomp$4$$);$map__53033__$1_p__53032_variants$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__53033__$1_p__53032_variants$jscomp$4$$,$APP.$cljs$cst$2687$variants$$);var $props$jscomp$93$$=$APP.$cljs$core$keys$$($variant_data$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__53030_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($p1__53030_SHARP_$$,
$props$jscomp$93$$),$variant_data$$)},$map__53033__$1_p__53032_variants$jscomp$4$$)},$cljs$core$shuffle$$=function($a$jscomp$109_coll$jscomp$150$$){$a$jscomp$109_coll$jscomp$150$$=$APP.$cljs$core$to_array$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$to_array$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$109_coll$jscomp$150$$):$APP.$cljs$core$to_array$$($a$jscomp$109_coll$jscomp$150$$);const $randFn$jscomp$inline_9922$$=Math.random;for(let $i$jscomp$inline_9923$$=$a$jscomp$109_coll$jscomp$150$$.length-
1;$i$jscomp$inline_9923$$>0;$i$jscomp$inline_9923$$--){const $j$jscomp$inline_9924$$=Math.floor($randFn$jscomp$inline_9922$$()*($i$jscomp$inline_9923$$+1)),$tmp$jscomp$inline_9925$$=$a$jscomp$109_coll$jscomp$150$$[$i$jscomp$inline_9923$$];$a$jscomp$109_coll$jscomp$150$$[$i$jscomp$inline_9923$$]=$a$jscomp$109_coll$jscomp$150$$[$j$jscomp$inline_9924$$];$a$jscomp$109_coll$jscomp$150$$[$j$jscomp$inline_9924$$]=$tmp$jscomp$inline_9925$$}return $APP.$cljs$core$vec$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$vec$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$109_coll$jscomp$150$$):
$APP.$cljs$core$vec$$($a$jscomp$109_coll$jscomp$150$$)},$meta_merge$core$remove_top_displace$$=function($JSCompiler_temp$jscomp$11338_obj$jscomp$183$$){if(!$APP.$cljs$core$not$$($APP.$cljs$cst$2380$top_displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($JSCompiler_temp$jscomp$11338_obj$jscomp$183$$)))){var $G__23228$jscomp$inline_14152_JSCompiler_inline_result$jscomp$inline_14151$$=$APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$11338_obj$jscomp$183$$);$G__23228$jscomp$inline_14152_JSCompiler_inline_result$jscomp$inline_14151$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__23228$jscomp$inline_14152_JSCompiler_inline_result$jscomp$inline_14151$$,$APP.$cljs$cst$2380$top_displace$$):$APP.$cljs$core$dissoc$$($G__23228$jscomp$inline_14152_JSCompiler_inline_result$jscomp$inline_14151$$,$APP.$cljs$cst$2380$top_displace$$);$JSCompiler_temp$jscomp$11338_obj$jscomp$183$$=$APP.$cljs$core$with_meta$$($JSCompiler_temp$jscomp$11338_obj$jscomp$183$$,$G__23228$jscomp$inline_14152_JSCompiler_inline_result$jscomp$inline_14151$$)}return $JSCompiler_temp$jscomp$11338_obj$jscomp$183$$},
$meta_merge$core$pick_prioritized$$=function($left$jscomp$20$$,$right$jscomp$17$$){return $left$jscomp$20$$==null?$right$jscomp$17$$:$right$jscomp$17$$==null?$meta_merge$core$remove_top_displace$$($left$jscomp$20$$):$APP.$cljs$core$truth_$$($APP.$cljs$cst$2380$top_displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($left$jscomp$20$$)))?$right$jscomp$17$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$281$$=$meta_merge$core$displace_QMARK_$$($left$jscomp$20$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$281$$)?$meta_merge$core$displace_QMARK_$$($right$jscomp$17$$):$and__5023__auto__$jscomp$281$$}())?$meta_merge$core$with_meta_STAR_$$($right$jscomp$17$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$meta_merge$core$meta_STAR_$$($right$jscomp$17$$)]))):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$282$$=
$meta_merge$core$replace_QMARK_$$($left$jscomp$20$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$282$$)?$meta_merge$core$replace_QMARK_$$($right$jscomp$17$$):$and__5023__auto__$jscomp$282$$}())?$meta_merge$core$with_meta_STAR_$$($right$jscomp$17$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$meta_merge$core$meta_STAR_$$($right$jscomp$17$$)]))):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$423$$=
$meta_merge$core$displace_QMARK_$$($left$jscomp$20$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$423$$)?$or__5025__auto__$jscomp$423$$:$meta_merge$core$replace_QMARK_$$($right$jscomp$17$$)}())?$meta_merge$core$with_meta_STAR_$$($right$jscomp$17$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$APP.$cljs$cst$2378$displace$$),
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($right$jscomp$17$$),$APP.$cljs$cst$2379$replace$$)]))):$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$424$$=$meta_merge$core$replace_QMARK_$$($left$jscomp$20$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$424$$)?$or__5025__auto__$jscomp$424$$:$meta_merge$core$displace_QMARK_$$($right$jscomp$17$$)}())?$meta_merge$core$with_meta_STAR_$$($left$jscomp$20$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($right$jscomp$17$$),
$APP.$cljs$cst$2378$displace$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($meta_merge$core$meta_STAR_$$($left$jscomp$20$$),$APP.$cljs$cst$2379$replace$$)]))):null},$reitit$impl$compile_routes$$=function($routes$jscomp$7$$,$opts$jscomp$270$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51710_SHARP_$$){var $p$jscomp$inline_9931$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__51710_SHARP_$$,
0,null),$m$jscomp$inline_9932$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__51710_SHARP_$$,1,null),$map__51708__$1$jscomp$inline_9933$$=$APP.$cljs$core$__destructure_map$$($opts$jscomp$270$$),$compile$jscomp$inline_9934$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51708__$1$jscomp$inline_9933$$,$APP.$cljs$cst$411$compile$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p$jscomp$inline_9931$$,$m$jscomp$inline_9932$$,
$APP.$cljs$core$truth_$$($compile$jscomp$inline_9934$$)?$compile$jscomp$inline_9934$$.$cljs$core$IFn$_invoke$arity$2$?$compile$jscomp$inline_9934$$.$cljs$core$IFn$_invoke$arity$2$($p1__51710_SHARP_$$,$map__51708__$1$jscomp$inline_9933$$):$compile$jscomp$inline_9934$$($p1__51710_SHARP_$$,$map__51708__$1$jscomp$inline_9933$$):null],null)},$routes$jscomp$7$$))},$reitit$impl$_match$$=function($path$jscomp$206$$,$path_map$$){function $match$jscomp$36$$($x$jscomp$1138$$,$f$jscomp$792$$){return $APP.$cljs$core$fn_QMARK_$$($f$jscomp$792$$)?
$f$jscomp$792$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$792$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1138$$):$f$jscomp$792$$($x$jscomp$1138$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1138$$,$f$jscomp$792$$)}return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$1457_ps$jscomp$23$$,$f$jscomp$793_p__51527$$){$_$jscomp$1457_ps$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$793_p__51527$$,0,null);$f$jscomp$793_p__51527$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$793_p__51527$$,1,null);return $APP.$cljs$core$count$$($path$jscomp$206$$)>=$APP.$cljs$core$count$$($_$jscomp$1457_ps$jscomp$23$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$identity$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($match$jscomp$36$$,$path$jscomp$206$$,$_$jscomp$1457_ps$jscomp$23$$))?$APP.$cljs$core$reduced$$($f$jscomp$793_p__51527$$):null},null,$path_map$$)},$reitit$impl$_path_vals$$=function($m$jscomp$206$$,
$path_map$jscomp$1$$){return function $reitit$impl$_path_vals_$__path_vals$$($l$jscomp$98$$,$p$jscomp$220$$,$m__$1$jscomp$8$$){return $APP.$cljs$core$reduce_kv$$(function($l__$1$jscomp$1$$,$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$v$jscomp$552$$){$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$220$$,$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$);var $f$jscomp$794$$=$reitit$impl$_match$$($k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$path_map$jscomp$1$$);
return $APP.$cljs$core$truth_$$($f$jscomp$794$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l__$1$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$f$jscomp$794$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$794$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$552$$):$f$jscomp$794$$($v$jscomp$552$$)],null)):$APP.$cljs$core$map_QMARK_$$($v$jscomp$552$$)&&!$APP.$cljs$core$record_QMARK_$$($v$jscomp$552$$)&&
$APP.$cljs$core$seq$$($v$jscomp$552$$)?$reitit$impl$_path_vals_$__path_vals$$($l__$1$jscomp$1$$,$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$v$jscomp$552$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l__$1$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$606_p_SINGLEQUOTE_$jscomp$2$$,$v$jscomp$552$$],null))},$l$jscomp$98$$,$m__$1$jscomp$8$$)}($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$,
$m$jscomp$206$$)},$reitit$trie$t_reitit$0trie50328$$=function($meta50241$jscomp$8$$,$_$jscomp$1448$$,$matchers$jscomp$2$$,$ordered_QMARK_$jscomp$3$$,$size$jscomp$99$$,$meta50329$$){this.$meta50241$=$meta50241$jscomp$8$$;this.$_$=$_$jscomp$1448$$;this.$matchers$=$matchers$jscomp$2$$;this.$ordered_QMARK_$=$ordered_QMARK_$jscomp$3$$;this.size=$size$jscomp$99$$;this.$meta50329$=$meta50329$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$files$export_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=
function($files$jscomp$24_map__73556__$1_p__73555$$){$files$jscomp$24_map__73556__$1_p__73555$$=$APP.$cljs$core$__destructure_map$$($files$jscomp$24_map__73556__$1_p__73555$$);var $type$jscomp$590$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$24_map__73556__$1_p__73555$$,$APP.$cljs$cst$139$type$$);$files$jscomp$24_map__73556__$1_p__73555$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$24_map__73556__$1_p__73555$$,$APP.$cljs$cst$1933$files$$);return $APP.$beicon$v2$core$mapcat$$(function($file$jscomp$89$$){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$91_error$jscomp$83$$){$cause$jscomp$91_error$jscomp$83$$=
$APP.$cljs$core$ex_data$$($cause$jscomp$91_error$jscomp$83$$);return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$89$$),$APP.$cljs$cst$849$error$$,$cause$jscomp$91_error$jscomp$83$$],null))},$APP.$beicon$v2$core$map$$(function($uri$jscomp$103$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$89$$),
$APP.$cljs$cst$1584$uri$$,$uri$jscomp$103$$,$APP.$cljs$cst$4881$filename$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$89$$)],null)},$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2272$app_DOT_util_DOT_sse_SLASH_export_binfile$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$89$$),
$APP.$cljs$cst$1726$version$$,3,$APP.$cljs$cst$5130$include_libraries$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$590$$,$APP.$cljs$cst$2132$all$$),$APP.$cljs$cst$5131$embed_assets$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$590$$,$APP.$cljs$cst$735$merge$$)],null))))))},$APP.$beicon$v2$core$from$$($files$jscomp$24_map__73556__$1_p__73555$$))},$reitit$exception$exception$$=function($e$jscomp$293$$){var $data$jscomp$154$$=$APP.$cljs$core$ex_data$$($e$jscomp$293$$),
$message$jscomp$55$$=$APP.$reitit$exception$format_exception$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$154$$),$APP.$cljs$core$ex_message$$($e$jscomp$293$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$154$$));return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($message$jscomp$55$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$truth_$$($data$jscomp$154$$)?$data$jscomp$154$$:
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2373$reitit_DOT_exception_SLASH_cause$$,$e$jscomp$293$$))},$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$=function($type$jscomp$371$$,$data$jscomp$153$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$371$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$371$$,$APP.$cljs$cst$142$data$$,$data$jscomp$153$$],
null));},$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$=function($ob$jscomp$72$$){var $JSCompiler_inline_result$jscomp$2090$$=$APP.$shadow$js$shim$module$0rxjs$$.timeout(3E3);return $APP.$beicon$v2$operators$pipe$$($JSCompiler_inline_result$jscomp$2090$$,$ob$jscomp$72$$)},$app$main$ui$static$0$load_info$$=function($path_params$jscomp$19_stream$jscomp$106$$){var $default$$jscomp$91$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5138$loaded$$,!0],null);$path_params$jscomp$19_stream$jscomp$106$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$106$$))?$APP.$beicon$v2$core$map$$(function($info$jscomp$6$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5138$loaded$$,!0,$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$6$$)],null)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5526$get_file_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$106$$)],null))):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$106$$))?$APP.$beicon$v2$core$map$$(function($info$jscomp$7$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$5138$loaded$$,!0,$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$7$$),
$APP.$cljs$cst$5527$team_default$$,$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$7$$)],null)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5528$get_team_info$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($path_params$jscomp$19_stream$jscomp$106$$)],null))):(0,$APP.$beicon$v2$core$of$$)($default$$jscomp$91$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$106$$){return $cause$jscomp$106$$ instanceof
$APP.$app$main$ui$static$0$TimeoutError$$?(0,$APP.$beicon$v2$core$of$$)($default$$jscomp$91$$):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$106$$)},$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$02$$($path_params$jscomp$19_stream$jscomp$106$$))},$app$main$data$common$create_team_access_request$$=function($params$jscomp$149$$){typeof $app$main$data$common$create_team_access_request_52656$$==="undefined"&&($app$main$data$common$create_team_access_request_52656$$=function($params$jscomp$150$$,
$meta52657$$){this.params=$params$jscomp$150$$;this.$meta52657$=$meta52657$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$create_team_access_request_52656$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$create_team_access_request_52656$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2498$app_DOT_main_DOT_data_DOT_common_SLASH_create_team_access_request$$},
$app$main$data$common$create_team_access_request_52656$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52658$$,$meta52657__$1$$){return new $app$main$data$common$create_team_access_request_52656$$(this.params,$meta52657__$1$$)},$app$main$data$common$create_team_access_request_52656$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52657$},$app$main$data$common$create_team_access_request_52656$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$create_team_access_request_52656$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__52659_on_success$$=$APP.$cljs$core$meta$$(this.params),$map__52659__$1_on_error$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__52659_on_success$$);$map__52659_on_success$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52659__$1_on_error$jscomp$3$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__52659__$1_on_error$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52659__$1_on_error$jscomp$3$$,
$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__52659__$1_on_error$jscomp$3$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__52659_on_success$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2500$create_team_access_request$$,this.params)))});return new $app$main$data$common$create_team_access_request_52656$$($params$jscomp$149$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$workspace$media$valid_svg_string_QMARK_$$=function($text$jscomp$45$$){var $and__5023__auto__$jscomp$440_and__5023__auto____$1$jscomp$81$$=typeof $text$jscomp$45$$==="string";if($and__5023__auto__$jscomp$440_and__5023__auto____$1$jscomp$81$$)if($and__5023__auto__$jscomp$440_and__5023__auto____$1$jscomp$81$$=!$APP.$cuerdas$core$blank_QMARK_$$($text$jscomp$45$$))try{return $APP.$tubax$core$xml__GT_clj$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$45$$),!0}catch($e67806$$){return!1}else return $and__5023__auto__$jscomp$440_and__5023__auto____$1$jscomp$81$$;
else return $and__5023__auto__$jscomp$440_and__5023__auto____$1$jscomp$81$$},$reitit$impl$map_data$$=function($f$jscomp$796$$,$routes$jscomp$3$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($ds$jscomp$12_p__51631$$){var $p$jscomp$223$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ds$jscomp$12_p__51631$$,0,null);$ds$jscomp$12_p__51631$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($ds$jscomp$12_p__51631$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p$jscomp$223$$,$f$jscomp$796$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$796$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$223$$,$ds$jscomp$12_p__51631$$):$f$jscomp$796$$($p$jscomp$223$$,$ds$jscomp$12_p__51631$$)],null)},$routes$jscomp$3$$)},$reitit$impl$walk$$=function($raw_routes$$,$p__51609_path$jscomp$210$$){function $walk_one$$($pacc$$,$macc_macc__$1$$,$first__51623_routes__$1$$){if($APP.$cljs$core$vector_QMARK_$$($APP.$cljs$core$first$$($first__51623_routes__$1$$)))return $walk_many$$($pacc$$,
$macc_macc__$1$$,$first__51623_routes__$1$$);if(typeof $APP.$cljs$core$first$$($first__51623_routes__$1$$)==="string"){var $childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$=$APP.$cljs$core$seq$$($first__51623_routes__$1$$);$first__51623_routes__$1$$=$APP.$cljs$core$first$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$);$childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$=$APP.$cljs$core$next$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$);var $child_routes_data__$1$jscomp$6_maybe_arg$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$,0,null);$childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$=$APP.$cljs$core$vector_QMARK_$$($child_routes_data__$1$jscomp$6_maybe_arg$$)||$APP.$cljs$core$sequential_QMARK_$$($child_routes_data__$1$jscomp$6_maybe_arg$$)&&$APP.$cljs$core$sequential_QMARK_$$($APP.$cljs$core$first$$($child_routes_data__$1$jscomp$6_maybe_arg$$))||$child_routes_data__$1$jscomp$6_maybe_arg$$==null?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child_routes_data__$1$jscomp$6_maybe_arg$$,$APP.$cljs$core$rest$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$)],null);$child_routes_data__$1$jscomp$6_maybe_arg$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$,
0,null);$childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$,1,null);$macc_macc__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($macc_macc__$1$$,$expand$$.$cljs$core$IFn$_invoke$arity$2$?$expand$$.$cljs$core$IFn$_invoke$arity$2$($child_routes_data__$1$jscomp$6_maybe_arg$$,$map__51610__$1$$):$expand$$($child_routes_data__$1$jscomp$6_maybe_arg$$,$map__51610__$1$$));$child_routes_data__$1$jscomp$6_maybe_arg$$=
$walk_many$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pacc$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first__51623_routes__$1$$)].join(""),$macc_macc__$1$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$identity$$,$childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$));return $APP.$cljs$core$seq$$($childs$jscomp$5_seq__51622_seq__51622__$1_vec__51627$$)?$APP.$cljs$core$seq$$($child_routes_data__$1$jscomp$6_maybe_arg$$):new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pacc$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first__51623_routes__$1$$)].join(""),$macc_macc__$1$$],null)],null)}return null}function $walk_many$$($p$jscomp$222$$,$m$jscomp$210$$,$r$jscomp$106$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__51607_SHARP_$$,
$p2__51608_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($p1__51607_SHARP_$$,$walk_one$$($p$jscomp$222$$,$m$jscomp$210$$,$p2__51608_SHARP_$$))},$APP.$cljs$core$PersistentVector$EMPTY$$,$r$jscomp$106$$)}var $map__51610__$1$$=$APP.$cljs$core$__destructure_map$$($p__51609_path$jscomp$210$$);$p__51609_path$jscomp$210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51610__$1$$,$APP.$cljs$cst$296$path$$);var $data$jscomp$175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51610__$1$$,
$APP.$cljs$cst$142$data$$,$APP.$cljs$core$PersistentVector$EMPTY$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51610__$1$$,$APP.$cljs$cst$2408$routes$$,$APP.$cljs$core$PersistentVector$EMPTY$$);var $expand$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51610__$1$$,$APP.$cljs$cst$2409$expand$$);return $walk_one$$($p__51609_path$jscomp$210$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$identity$$,$data$jscomp$175$$),$raw_routes$$)},$app$main$ui$components$forms$image_radio_buttons$$=
function($props_73013$$){var $form$jscomp$164$$=function(){var $or__5025__auto__$jscomp$955$$=$props_73013$$.form;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$955$$)?$or__5025__auto__$jscomp$955$$:(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$components$forms$form_ctx$$)}(),$name$jscomp$383$$=$props_73013$$.name,$image$jscomp$29$$=$props_73013$$.image,$img_height$$=$props_73013$$["img-height"],$img_width$$=$props_73013$$["img-width"],$current_value$jscomp$3$$=function(){var $or__5025__auto__$jscomp$956$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$164$$),$APP.$cljs$cst$142$data$$),$name$jscomp$383$$,"");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$956$$)?$or__5025__auto__$jscomp$956$$:$props_73013$$.value}(),$on_change$jscomp$17$$=$props_73013$$["on-change"],$options$jscomp$591$$=$props_73013$$.options,$trim_QMARK_$jscomp$3$$=$props_73013$$.trim,$class$$jscomp$24$$=$props_73013$$["class"],
$encode_fn$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_73013$$["encode-fn"],$APP.$cljs$core$identity$$),$decode_fn$jscomp$6$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_73013$$["decode-fn"],$APP.$cljs$core$identity$$),$on_change_SINGLEQUOTE_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$17$$),$APP.$rumext$v2$adapt$$($form$jscomp$164$$),$APP.$rumext$v2$adapt$$($name$jscomp$383$$)],
function($G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$){$G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$));$G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$=$decode_fn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$decode_fn$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$):
$decode_fn$jscomp$6$$($G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$);$form$jscomp$164$$!=null&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$164$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$383$$],null),!0),$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$164$$,$name$jscomp$383$$,$G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$,
$trim_QMARK_$jscomp$3$$));return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$17$$)?$on_change$jscomp$17$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$17$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$383$$,$G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$):$on_change$jscomp$17$$($name$jscomp$383$$,$G__73014$jscomp$inline_9938_event$jscomp$136_value$jscomp$741$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:$APP.$cljs$core$truth_$$($image$jscomp$29$$)?$class$$jscomp$24$$:
""+($class$$jscomp$24$$??"")+" main_ui_components_forms__custom-radio",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$39$$,$JSCompiler_inline_result$jscomp$2093_image__$1$jscomp$1_p__73015$$){var $JSCompiler_temp_const$jscomp$2091_map__73016__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$2093_image__$1$jscomp$1_p__73015$$);$JSCompiler_inline_result$jscomp$2093_image__$1$jscomp$1_p__73015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2091_map__73016__$1$$,
$APP.$cljs$cst$1617$image$$);var $icon$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2091_map__73016__$1$$,$APP.$cljs$cst$1727$icon$$),$checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2091_map__73016__$1$$,$APP.$cljs$cst$260$value$$),$label$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2091_map__73016__$1$$,$APP.$cljs$cst$2296$label$$),
$area$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$2091_map__73016__$1$$,$APP.$cljs$cst$1679$area$$);$JSCompiler_temp_const$jscomp$2091_map__73016__$1$$=$out_arr__44092__auto__$jscomp$39$$.push;var $icon_QMARK_$jscomp$inline_9940$$=$icon$jscomp$12$$!=null,$value_SINGLEQUOTE_$jscomp$inline_9941$$=$encode_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$encode_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$):
$encode_fn$jscomp$3$$($checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$);$checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$,$current_value$jscomp$3$$);var $key$jscomp$inline_9943$$=""+($APP.$app$common$data$name$$($name$jscomp$383$$)??"")+"-"+($APP.$app$common$data$name$$($value_SINGLEQUOTE_$jscomp$inline_9941$$)??"");$JSCompiler_inline_result$jscomp$2093_image__$1$jscomp$1_p__73015$$=
(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$key$jscomp$inline_9943$$,style:{gridArea:$area$jscomp$5$$},className:"main_ui_components_forms__radio-label-image "+($checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$?"checked":""),children:[$icon_QMARK_$jscomp$inline_9940$$?(0,$APP.$rumext$v2$jsx$$)("span",{style:{height:$img_height$$,width:$img_width$$},className:"main_ui_components_forms__icon-inside",children:$icon$jscomp$12$$}):(0,$APP.$rumext$v2$jsx$$)("span",{style:{backgroundImage:"url("+($JSCompiler_inline_result$jscomp$2093_image__$1$jscomp$1_p__73015$$??
"")+")",height:$img_height$$,width:$img_width$$},className:"main_ui_components_forms__image-inside"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_forms__image-text",children:$label$jscomp$29$$}),(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$on_change_SINGLEQUOTE_$jscomp$2$$,type:"radio",id:$key$jscomp$inline_9943$$,name:$name$jscomp$383$$,value:$value_SINGLEQUOTE_$jscomp$inline_9941$$,checked:$checked_QMARK_$jscomp$inline_9942_value$jscomp$742$$,className:"main_ui_components_forms__radio-input"})]},
$key$jscomp$inline_9943$$);$JSCompiler_temp_const$jscomp$2091_map__73016__$1$$.call($out_arr__44092__auto__$jscomp$39$$,$JSCompiler_inline_result$jscomp$2093_image__$1$jscomp$1_p__73015$$);return $out_arr__44092__auto__$jscomp$39$$},[],$options$jscomp$591$$)})},$app$main$data$workspace$texts$decorate_range_info$$=function($content$jscomp$182$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$02$$(function($node$jscomp$317$$){return $APP.$app$common$data$update_when$$($node$jscomp$317$$,
$APP.$cljs$cst$342$children$$,function($children$jscomp$248$$){var $start$jscomp$221$$=$APP.$cljs$cst$1297$start$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$meta$$($node$jscomp$317$$),0);return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__70300_start__$1$jscomp$13$$,$node__$1$jscomp$71$$){var $result$jscomp$310$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70300_start__$1$jscomp$13$$,0,null);$p__70300_start__$1$jscomp$13$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70300_start__$1$jscomp$13$$,1,null);var $end$jscomp$87$$=$p__70300_start__$1$jscomp$13$$+$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$($node__$1$jscomp$71$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$310$$,$APP.$cljs$core$with_meta$$($node__$1$jscomp$71$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1297$start$$,$p__70300_start__$1$jscomp$13$$,$APP.$cljs$cst$1298$end$$,$end$jscomp$87$$],null))),$end$jscomp$87$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$start$jscomp$221$$],null),$children$jscomp$248$$))})},$APP.$cljs$core$with_meta$$($content$jscomp$182$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1297$start$$,0,$APP.$cljs$cst$1298$end$$,$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$182$$)],
null)))},$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$02$$=function($data$jscomp$293$$,$variant_id$jscomp$6$$){var $objects$jscomp$266_page_id$jscomp$88$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__55582_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55582_SHARP_$$),
$variant_id$jscomp$6$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$293$$)))));$objects$jscomp$266_page_id$jscomp$88$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$293$$,$APP.$cljs$cst$1635$pages_index$$),$objects$jscomp$266_page_id$jscomp$88$$),$APP.$cljs$cst$1636$objects$$);return $APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$293$$,
$objects$jscomp$266_page_id$jscomp$88$$,$variant_id$jscomp$6$$)},$reitit$impl$unresolved_conflicts$$=function($path_conflicting$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($conflicts$jscomp$2_p__51672$$){var $and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($conflicts$jscomp$2_p__51672$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$,0,null);$and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$,1,null);$conflicts$jscomp$2_p__51672$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($conflicts$jscomp$2_p__51672$$,1,null);$and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$=
$APP.$cljs$cst$2375$conflicting$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$)?$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2375$conflicting$$,$APP.$cljs$core$second$$),$conflicts$jscomp$2_p__51672$$):$and__5023__auto__$jscomp$290_route_data$jscomp$2_vec__51677$$}),$path_conflicting$$))},$app$main$data$workspace$texts$update_content_range$$=
function($content$jscomp$184$$,$start$jscomp$223$$,$end$jscomp$89$$,$attrs$jscomp$121$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$(function($node$jscomp$320$$){return $APP.$app$common$types$text$is_text_node_QMARK_$$($node$jscomp$320$$)&&$APP.$cljs$cst$1297$start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$320$$))>=$start$jscomp$223$$&&$APP.$cljs$cst$1298$end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$320$$))<=
$end$jscomp$89$$},function($p1__70313_SHARP_$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($p1__70313_SHARP_$$,$attrs$jscomp$121$$)},$content$jscomp$184$$)},$app$main$data$workspace$texts$split_content_at$$=function($content$jscomp$183$$,$position$jscomp$101$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$(function($node$jscomp$318$$){return $APP.$app$common$types$text$is_paragraph_node_QMARK_$$($node$jscomp$318$$)&&$APP.$cljs$cst$1297$start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$318$$))<
$position$jscomp$101$$&&$position$jscomp$101$$<$APP.$cljs$cst$1298$end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($node$jscomp$318$$))},function($node$jscomp$319$$){function $process_node$$($child$jscomp$120$$){var $start$jscomp$222$$=$APP.$cljs$cst$1297$start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($child$jscomp$120$$)),$end$jscomp$88$$=$APP.$cljs$cst$1298$end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($child$jscomp$120$$));return $start$jscomp$222$$<
$position$jscomp$101$$&&$position$jscomp$101$$<$end$jscomp$88$$?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($child$jscomp$120$$,$APP.$cljs$cst$1298$end$$,$position$jscomp$101$$),$APP.$cljs$cst$1593$text$$,$APP.$cljs$core$subs$$,0,$position$jscomp$101$$-$start$jscomp$222$$),$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($child$jscomp$120$$,
$APP.$cljs$cst$1297$start$$,$position$jscomp$101$$),$APP.$cljs$cst$1593$text$$,$APP.$cljs$core$subs$$,$position$jscomp$101$$-$start$jscomp$222$$)],null):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$child$jscomp$120$$],null)}return $APP.$app$common$data$update_when$$($node$jscomp$319$$,$APP.$cljs$cst$342$children$$,function($p1__70308_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($process_node$$),
$p1__70308_SHARP_$$)})},$content$jscomp$183$$)},$app$plugins$utils$flatten_error_map$cljs$0core$0IFn$0_invoke$0arity$02$$=function($prefix$jscomp$47$$,$m$jscomp$217$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p__55165_v$jscomp$579$$){var $k$jscomp$643_path$jscomp$233_segment$jscomp$42$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55165_v$jscomp$579$$,0,null);$p__55165_v$jscomp$579$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55165_v$jscomp$579$$,
1,null);$k$jscomp$643_path$jscomp$233_segment$jscomp$42$$=$k$jscomp$643_path$jscomp$233_segment$jscomp$42$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($k$jscomp$643_path$jscomp$233_segment$jscomp$42$$):typeof $k$jscomp$643_path$jscomp$233_segment$jscomp$42$$==="string"?$k$jscomp$643_path$jscomp$233_segment$jscomp$42$$:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$643_path$jscomp$233_segment$jscomp$42$$);$k$jscomp$643_path$jscomp$233_segment$jscomp$42$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$47$$,
$k$jscomp$643_path$jscomp$233_segment$jscomp$42$$);return $APP.$cljs$core$map_QMARK_$$($p__55165_v$jscomp$579$$)&&!$APP.$cljs$core$contains_QMARK_$$($p__55165_v$jscomp$579$$,$APP.$cljs$cst$141$message$$)?$app$plugins$utils$flatten_error_map$cljs$0core$0IFn$0_invoke$0arity$02$$($k$jscomp$643_path$jscomp$233_segment$jscomp$42$$,$p__55165_v$jscomp$579$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(".",$k$jscomp$643_path$jscomp$233_segment$jscomp$42$$),$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($p__55165_v$jscomp$579$$)],null)],null)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$m$jscomp$217$$]))},$app$plugins$utils$flatten_error_map$cljs$0core$0IFn$0_invoke$0arity$01$$=function($m$jscomp$216$$){return $app$plugins$utils$flatten_error_map$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentVector$EMPTY$$,
$m$jscomp$216$$)},$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$01$$=function($n$jscomp$91$$){return function($rf$jscomp$5$$){var $na$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$($n$jscomp$91$$);return function(){function $G__27417__2$$($result$jscomp$41$$,$input$jscomp$24$$){var $n__$1$jscomp$3$$=$APP.$cljs$core$_deref$$($na$jscomp$1$$);$na$jscomp$1$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$na$jscomp$1$$.$cljs$core$IDeref$_deref$arity$1$(null)-1);return $n__$1$jscomp$3$$>0?$result$jscomp$41$$:
$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$41$$,$input$jscomp$24$$):$rf$jscomp$5$$($result$jscomp$41$$,$input$jscomp$24$$)}function $G__27417__1$$($result$jscomp$40$$){return $rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$40$$):$rf$jscomp$5$$($result$jscomp$40$$)}function $G__27417__0$$(){return $rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():
$rf$jscomp$5$$()}var $G__27417$$=null;$G__27417$$=function($result$jscomp$42$$,$input$jscomp$25$$){switch(arguments.length){case 0:return $G__27417__0$$.call(this);case 1:return $G__27417__1$$.call(this,$result$jscomp$42$$);case 2:return $G__27417__2$$.call(this,$result$jscomp$42$$,$input$jscomp$25$$)}throw Error("Invalid arity: "+arguments.length);};$G__27417$$.$cljs$core$IFn$_invoke$arity$0$=$G__27417__0$$;$G__27417$$.$cljs$core$IFn$_invoke$arity$1$=$G__27417__1$$;$G__27417$$.$cljs$core$IFn$_invoke$arity$2$=
$G__27417__2$$;return $G__27417$$}()}},$app$main$data$event$remove_from_buffer$$=function($buffer$jscomp$61$$,$items$jscomp$25$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$01$$($items$jscomp$25$$),$buffer$jscomp$61$$)},$reitit$impl$uncompile_routes$$=function($routes$jscomp$8$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$,
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$take$$,2)),$routes$jscomp$8$$)},$app$plugins$utils$throw_validation_errors_QMARK_$$=function($plugin_id$jscomp$5$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$3222$plugins$$),
$APP.$cljs$cst$1472$flags$$),$plugin_id$jscomp$5$$),$APP.$cljs$cst$3444$throw_validation_errors$$))},$app$plugins$utils$not_valid$$=function($JSCompiler_temp$jscomp$2077_plugin_id$jscomp$6$$,$code$jscomp$34$$,$value$jscomp$529$$){$app$plugins$utils$throw_validation_errors_QMARK_$$($JSCompiler_temp$jscomp$2077_plugin_id$jscomp$6$$)?$JSCompiler_temp$jscomp$2077_plugin_id$jscomp$6$$=$app$plugins$utils$throw_not_valid$$($code$jscomp$34$$,$value$jscomp$529$$):($value$jscomp$529$$!=null?console.error("[PENPOT PLUGIN] Value not valid: "+
($value$jscomp$529$$??"")+". Code: "+($code$jscomp$34$$??"")):console.error("[PENPOT PLUGIN] Value not valid. Code: "+($code$jscomp$34$$??"")),$JSCompiler_temp$jscomp$2077_plugin_id$jscomp$6$$=null);return $JSCompiler_temp$jscomp$2077_plugin_id$jscomp$6$$},$app$plugins$utils$natural_child_ordering_QMARK_$$=function($plugin_id$jscomp$4$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$3222$plugins$$),$APP.$cljs$cst$1472$flags$$),$plugin_id$jscomp$4$$),$APP.$cljs$cst$3443$natural_child_ordering$$))},$app$plugins$utils$locate_component$$=function($objects$jscomp$262_root$jscomp$49$$,$shape$jscomp$376$$){var $libraries$jscomp$32_state$jscomp$245$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file$jscomp$44$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($libraries$jscomp$32_state$jscomp$245$$);$libraries$jscomp$32_state$jscomp$245$$=
$APP.$app$main$data$helpers$lookup_libraries$$($libraries$jscomp$32_state$jscomp$245$$);$objects$jscomp$262_root$jscomp$49$$=$APP.$app$common$types$container$get_instance_root$$($objects$jscomp$262_root$jscomp$49$$,$shape$jscomp$376$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$objects$jscomp$262_root$jscomp$49$$,$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($objects$jscomp$262_root$jscomp$49$$,
$file$jscomp$44$$,$libraries$jscomp$32_state$jscomp$245$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2551$include_deleted_QMARK_$$,!0],null)]))],null)},$app$plugins$utils$locate_presence$$=function($session_id$jscomp$1$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$2224$workspace_presence$$),
$session_id$jscomp$1$$)},$app$plugins$utils$locate_profile$$=function($map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$){$map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$=$app$plugins$utils$locate_presence$$($map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$);$map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$);$map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$,$APP.$cljs$cst$2321$profile_id$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1932$profiles$$),$map__55019_map__55019__$1_profile_id$jscomp$16_session_id$jscomp$2$$)},$app$plugins$utils$page_active_QMARK_$$=function($page_id$jscomp$78$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$78$$,
$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))},$app$plugins$utils$locate_page$$=function($file_id$jscomp$46$$,$id$jscomp$396$$){return $APP.$app$main$data$helpers$get_page$$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_id$jscomp$46$$),$id$jscomp$396$$)},$app$plugins$utils$locate_ruler_guide$$=function($file_id$jscomp$62_page$jscomp$46$$,
$page_id$jscomp$81$$,$ruler_id$$){$file_id$jscomp$62_page$jscomp$46$$=$app$plugins$utils$locate_page$$($file_id$jscomp$62_page$jscomp$46$$,$page_id$jscomp$81$$);return $file_id$jscomp$62_page$jscomp$46$$!=null?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55057_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55057_SHARP_$$),$ruler_id$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$2065$guides$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$62_page$jscomp$46$$))):
null},$app$plugins$utils$proxy__GT_ruler_guide$$=function($proxy$jscomp$10$$){return $app$plugins$utils$locate_ruler_guide$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$10$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$10$$,"$page"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$10$$,"$id"))},$app$plugins$utils$proxy__GT_flow$$=function($page$jscomp$45_proxy$jscomp$9$$){var $flow_id$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$45_proxy$jscomp$9$$,
"$id");$page$jscomp$45_proxy$jscomp$9$$=$app$plugins$utils$locate_page$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$45_proxy$jscomp$9$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$45_proxy$jscomp$9$$,"$page"));return $page$jscomp$45_proxy$jscomp$9$$!=null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2064$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$45_proxy$jscomp$9$$),$flow_id$$):null},$app$plugins$utils$proxy__GT_page$$=
function($id$jscomp$403_proxy$jscomp$4$$){var $file_id$jscomp$56$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$403_proxy$jscomp$4$$,"$file");$id$jscomp$403_proxy$jscomp$4$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$403_proxy$jscomp$4$$,"$id");return $file_id$jscomp$56$$!=null&&$id$jscomp$403_proxy$jscomp$4$$!=null?$app$plugins$utils$locate_page$$($file_id$jscomp$56$$,$id$jscomp$403_proxy$jscomp$4$$):null},$app$plugins$utils$locate_shape$$=
function($file_id$jscomp$48$$,$page_id$jscomp$77$$,$id$jscomp$397$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_page$$($file_id$jscomp$48$$,$page_id$jscomp$77$$),$APP.$cljs$cst$1636$objects$$),$id$jscomp$397$$)},$app$plugins$utils$proxy__GT_interaction$$=function($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$){var $index$jscomp$inline_9967$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$,
"$index");$proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$,"$page"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$,"$shape"));return $APP.$cljs$core$truth_$$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$)?
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($proxy$jscomp$11_temp__5825__auto__$jscomp$inline_9968$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2059$interactions$$,$index$jscomp$inline_9967$$],null)):null},$app$plugins$utils$proxy__GT_shape$$=function($id$jscomp$404_proxy$jscomp$5$$){var $file_id$jscomp$57$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$404_proxy$jscomp$5$$,"$file"),$page_id$jscomp$79$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$404_proxy$jscomp$5$$,"$page");$id$jscomp$404_proxy$jscomp$5$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$404_proxy$jscomp$5$$,"$id");return $file_id$jscomp$57$$!=null&&$page_id$jscomp$79$$!=null&&$id$jscomp$404_proxy$jscomp$5$$!=null?$app$plugins$utils$locate_shape$$($file_id$jscomp$57$$,$page_id$jscomp$79$$,$id$jscomp$404_proxy$jscomp$5$$):null},$app$plugins$utils$is_main_component_proxy_QMARK_$$=
function($p$jscomp$238_temp__5825__auto__$jscomp$191$$){$p$jscomp$238_temp__5825__auto__$jscomp$191$$=$app$plugins$utils$proxy__GT_shape$$($p$jscomp$238_temp__5825__auto__$jscomp$191$$);return $APP.$cljs$core$truth_$$($p$jscomp$238_temp__5825__auto__$jscomp$191$$)?$APP.$app$common$types$component$main_instance_QMARK_$$($p$jscomp$238_temp__5825__auto__$jscomp$191$$):null},$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_id$jscomp$47$$,$page_id$jscomp$76$$){return $APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_page$$($file_id$jscomp$47$$,
$page_id$jscomp$76$$))},$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return $app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))},$app$plugins$utils$locate_file$$=function($id$jscomp$395$$){return $APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$id$jscomp$395$$)},$app$plugins$utils$proxy__GT_file$$=function($id$jscomp$402_proxy$jscomp$3$$){$id$jscomp$402_proxy$jscomp$3$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$402_proxy$jscomp$3$$,"$id");return $id$jscomp$402_proxy$jscomp$3$$!=null?$app$plugins$utils$locate_file$$($id$jscomp$402_proxy$jscomp$3$$):null},$app$plugins$utils$locate_tokens_lib$$=function($file$jscomp$43_file_id$jscomp$52$$){$file$jscomp$43_file_id$jscomp$52$$=$app$plugins$utils$locate_file$$($file$jscomp$43_file_id$jscomp$52$$);
return $APP.$cljs$cst$2147$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$43_file_id$jscomp$52$$))},$app$plugins$utils$locate_token$$=function($file_id$jscomp$55_tokens_lib$jscomp$12$$,$set_id$jscomp$22$$,$token_id$jscomp$16$$){$file_id$jscomp$55_tokens_lib$jscomp$12$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$55_tokens_lib$jscomp$12$$);return $file_id$jscomp$55_tokens_lib$jscomp$12$$!=null?$APP.$app$common$types$tokens_lib$get_token$$($file_id$jscomp$55_tokens_lib$jscomp$12$$,
$set_id$jscomp$22$$,$token_id$jscomp$16$$):null},$app$plugins$utils$locate_token_set$$=function($file_id$jscomp$54_tokens_lib$jscomp$11$$,$set_id$jscomp$21$$){$file_id$jscomp$54_tokens_lib$jscomp$11$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$54_tokens_lib$jscomp$11$$);return $file_id$jscomp$54_tokens_lib$jscomp$11$$!=null?$APP.$app$common$types$tokens_lib$get_set$$($file_id$jscomp$54_tokens_lib$jscomp$11$$,$set_id$jscomp$21$$):null},$app$plugins$utils$locate_token_theme$$=function($file_id$jscomp$53_tokens_lib$jscomp$10$$,
$id$jscomp$401$$){$file_id$jscomp$53_tokens_lib$jscomp$10$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$53_tokens_lib$jscomp$10$$);return $file_id$jscomp$53_tokens_lib$jscomp$10$$!=null?$APP.$app$common$types$tokens_lib$get_theme$$($file_id$jscomp$53_tokens_lib$jscomp$10$$,$id$jscomp$401$$):null},$app$plugins$utils$locate_library_component$$=function($file_id$jscomp$51$$,$id$jscomp$400$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_file$$($file_id$jscomp$51$$),
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1643$components$$),$id$jscomp$400$$)},$app$plugins$utils$proxy__GT_library_component$$=function($id$jscomp$407_proxy$jscomp$8$$){var $file_id$jscomp$60$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$407_proxy$jscomp$8$$,"$file");$id$jscomp$407_proxy$jscomp$8$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$407_proxy$jscomp$8$$,"$id");return $file_id$jscomp$60$$!=null&&$id$jscomp$407_proxy$jscomp$8$$!=
null?$app$plugins$utils$locate_library_component$$($file_id$jscomp$60$$,$id$jscomp$407_proxy$jscomp$8$$):null},$app$plugins$utils$locate_library_typography$$=function($file_id$jscomp$50$$,$id$jscomp$399$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_file$$($file_id$jscomp$50$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2223$typographies$$),$id$jscomp$399$$)},
$app$plugins$utils$proxy__GT_library_typography$$=function($id$jscomp$406_proxy$jscomp$7$$){var $file_id$jscomp$59$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$406_proxy$jscomp$7$$,"$file");$id$jscomp$406_proxy$jscomp$7$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$406_proxy$jscomp$7$$,"$id");return $file_id$jscomp$59$$!=null&&$id$jscomp$406_proxy$jscomp$7$$!=null?$app$plugins$utils$locate_library_typography$$($file_id$jscomp$59$$,$id$jscomp$406_proxy$jscomp$7$$):
null},$app$plugins$utils$locate_library_color$$=function($file_id$jscomp$49$$,$id$jscomp$398$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_file$$($file_id$jscomp$49$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2220$colors$$),$id$jscomp$398$$)},$app$plugins$utils$proxy__GT_library_color$$=function($id$jscomp$405_proxy$jscomp$6$$){var $file_id$jscomp$58$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$405_proxy$jscomp$6$$,"$file");$id$jscomp$405_proxy$jscomp$6$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$405_proxy$jscomp$6$$,"$id");return $file_id$jscomp$58$$!=null&&$id$jscomp$405_proxy$jscomp$6$$!=null?$app$plugins$utils$locate_library_color$$($file_id$jscomp$58$$,$id$jscomp$405_proxy$jscomp$6$$):null},$app$main$data$event$process_performance_event$$=function($result$jscomp$220$$){var $event$jscomp$66$$=
$result$jscomp$220$$[0],$profile_id$jscomp$6$$=$result$jscomp$220$$[1];return($event$jscomp$66$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$event$jscomp$66$$.$app$main$data$event$PerformanceEvent$$||($event$jscomp$66$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$PerformanceEvent$$,$event$jscomp$66$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$PerformanceEvent$$,$event$jscomp$66$$))?$APP.$beicon$v2$core$create$$(function($subs$jscomp$11$$){var $start$jscomp$210$$=
performance.now();(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return scheduler.postTask(function(){var $time$jscomp$3$$=performance.now()-$start$jscomp$210$$;$time$jscomp$3$$>1E3&&$subs$jscomp$11$$.next($app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"blocking-event",$APP.$cljs$cst$2325$event_name$$,$APP.$app$common$data$name$$($APP.$potok$v2$core$type$$($event$jscomp$66$$)),
$APP.$cljs$cst$1976$duration$$,$time$jscomp$3$$],null)));return $subs$jscomp$11$$.complete()},{priority:"user-blocking"})});return null}):$APP.$beicon$v2$core$empty$$()},$app$main$data$workspace$versions$create_version_from_plugins$$=function($file_id$jscomp$334$$,$label$jscomp$36$$,$resolve$jscomp$37$$,$reject$jscomp$24$$){typeof $app$main$data$workspace$versions$create_version_from_plugins_73778$$==="undefined"&&($app$main$data$workspace$versions$create_version_from_plugins_73778$$=function($file_id$jscomp$335$$,
$label$jscomp$37$$,$resolve$jscomp$38$$,$reject$jscomp$25$$,$meta73779$$){this.$file_id$=$file_id$jscomp$335$$;this.label=$label$jscomp$37$$;this.resolve=$resolve$jscomp$38$$;this.reject=$reject$jscomp$25$$;this.$meta73779$=$meta73779$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$create_version_from_plugins_73778$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_from_plugins_73778$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5166$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_create_version_from_plugins$$},$app$main$data$workspace$versions$create_version_from_plugins_73778$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73780$$,$meta73779__$1$$){return new $app$main$data$workspace$versions$create_version_from_plugins_73778$$(this.$file_id$,this.label,this.resolve,this.reject,$meta73779__$1$$)},$app$main$data$workspace$versions$create_version_from_plugins_73778$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73779$},$app$main$data$workspace$versions$create_version_from_plugins_73778$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_from_plugins_73778$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2834_current_file_id$jscomp$14$$,$state$jscomp$1102$$){var $self__$jscomp$7107$$=this;$_$jscomp$2834_current_file_id$jscomp$14$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1102$$);
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$84$$){$self__$jscomp$7107$$.reject.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$7107$$.reject.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$84$$):$self__$jscomp$7107$$.reject($error$jscomp$84$$);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$concat$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$7107$$.$file_id$,$_$jscomp$2834_current_file_id$jscomp$14$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$):
null,$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7107$$.resolve,$APP.$beicon$v2$core$mapcat$$(function($map__73787__$1_p__73786$$){$map__73787__$1_p__73786$$=$APP.$cljs$core$__destructure_map$$($map__73787__$1_p__73786$$);var $id$jscomp$874$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73787__$1_p__73786$$,$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$map$$(function($versions$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73777_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$874$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73777_SHARP_$$))},$versions$$)},$APP.$beicon$v2$core$take$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5139$get_file_snapshots$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$7107$$.$file_id$],null))))},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5142$create_file_snapshot$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$7107$$.$file_id$,$APP.$cljs$cst$2296$label$$,$self__$jscomp$7107$$.label],null))},$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$7107$$.$file_id$,$_$jscomp$2834_current_file_id$jscomp$14$$)?$APP.$app$main$data$persistence$wait_persisted$cljs$0core$0IFn$0_invoke$0arity$01$$(null):(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$5167$nothing$$)))))))});return new $app$main$data$workspace$versions$create_version_from_plugins_73778$$($file_id$jscomp$334$$,
$label$jscomp$36$$,$resolve$jscomp$37$$,$reject$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$plugins$flags$flags_proxy$$=function($plugin_id$jscomp$8$$){var $obj_55324$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_55324$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FlagProxy"}});Object.defineProperty($obj_55324$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FlagProxy"}});Object.defineProperty($obj_55324$$,"naturalChildOrdering",
{enumerable:!0,get:function(){return $app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$8$$)},set:function($val_naturalchildordering_55367$$){return $APP.$cljs$core$boolean_QMARK_$$($val_naturalchildordering_55367$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$flags$set_flag$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3443$natural_child_ordering$$,$val_naturalchildordering_55367$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3447$naturalChildOrdering$$,
$val_naturalchildordering_55367$$)}});Object.defineProperty($obj_55324$$,"throwValidationErrors",{enumerable:!0,get:function(){return $app$plugins$utils$throw_validation_errors_QMARK_$$($plugin_id$jscomp$8$$)},set:function($val_throwvalidationerrors_55375$$){return $APP.$cljs$core$boolean_QMARK_$$($val_throwvalidationerrors_55375$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$flags$set_flag$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3444$throw_validation_errors$$,$val_throwvalidationerrors_55375$$)):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$8$$,$APP.$cljs$cst$3448$throwValidationErrors$$,$val_throwvalidationerrors_55375$$)}});return $obj_55324$$},$app$util$worker$Worker$$=function($instance$jscomp$6$$,$stream$jscomp$26$$,$__meta$jscomp$34$$,$__extmap$jscomp$34$$,$__hash$jscomp$93$$){this.instance=$instance$jscomp$6$$;this.stream=$stream$jscomp$26$$;this.$__meta$=$__meta$jscomp$34$$;this.$__extmap$=$__extmap$jscomp$34$$;this.$__hash$=$__hash$jscomp$93$$;this.$cljs$lang$protocol_mask$partition0$$=
2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$core$PartialMatch$$=function($template$jscomp$5$$,$data$jscomp$178$$,$result$jscomp$223$$,$path_params$jscomp$8$$,$required$jscomp$4$$,$__meta$jscomp$32$$,$__extmap$jscomp$32$$,$__hash$jscomp$91$$){this.template=$template$jscomp$5$$;this.data=$data$jscomp$178$$;this.result=$result$jscomp$223$$;this.$path_params$=$path_params$jscomp$8$$;this.required=$required$jscomp$4$$;this.$__meta$=$__meta$jscomp$32$$;this.$__extmap$=$__extmap$jscomp$32$$;
this.$__hash$=$__hash$jscomp$91$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$core$Match$$=function($template$jscomp$3$$,$data$jscomp$176$$,$result$jscomp$221$$,$path_params$jscomp$6$$,$path$jscomp$213$$,$__meta$jscomp$31$$,$__extmap$jscomp$31$$,$__hash$jscomp$90$$){this.template=$template$jscomp$3$$;this.data=$data$jscomp$176$$;this.result=$result$jscomp$221$$;this.$path_params$=$path_params$jscomp$6$$;this.path=$path$jscomp$213$$;
this.$__meta$=$__meta$jscomp$31$$;this.$__extmap$=$__extmap$jscomp$31$$;this.$__hash$=$__hash$jscomp$90$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$core$__GT_Match$$=function($template$jscomp$4$$,$data$jscomp$177$$,$result$jscomp$222$$,$path_params$jscomp$7$$,$path$jscomp$214$$){return new $reitit$core$Match$$($template$jscomp$4$$,$data$jscomp$177$$,$result$jscomp$222$$,$path_params$jscomp$7$$,$path$jscomp$214$$,null,null,null)},
$reitit$trie$Node$$=function($children$jscomp$170$$,$wilds$$,$catch_all$$,$params$jscomp$118$$,$data$jscomp$159$$,$__meta$jscomp$30$$,$__extmap$jscomp$30$$,$__hash$jscomp$89$$){this.children=$children$jscomp$170$$;this.$wilds$=$wilds$$;this.$catch_all$=$catch_all$$;this.params=$params$jscomp$118$$;this.data=$data$jscomp$159$$;this.$__meta$=$__meta$jscomp$30$$;this.$__extmap$=$__extmap$jscomp$30$$;this.$__hash$=$__hash$jscomp$89$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264},$reitit$trie$_node$$=function($G__50069$jscomp$inline_14154_m$jscomp$205$$){$G__50069$jscomp$inline_14154_m$jscomp$205$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$342$children$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2382$wilds$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$2383$catch_all$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$cst$1435$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$G__50069$jscomp$inline_14154_m$jscomp$205$$]));var $G__50090$jscomp$inline_14156_extmap__5365__auto__$jscomp$inline_14155$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50069$jscomp$inline_14154_m$jscomp$205$$,$APP.$cljs$cst$342$children$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2382$wilds$$,$APP.$cljs$cst$2383$catch_all$$,$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$142$data$$]));
$G__50090$jscomp$inline_14156_extmap__5365__auto__$jscomp$inline_14155$$=$APP.$cljs$core$record_QMARK_$$($G__50069$jscomp$inline_14154_m$jscomp$205$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__50090$jscomp$inline_14156_extmap__5365__auto__$jscomp$inline_14155$$):$G__50090$jscomp$inline_14156_extmap__5365__auto__$jscomp$inline_14155$$;return new $reitit$trie$Node$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($G__50069$jscomp$inline_14154_m$jscomp$205$$),
$APP.$cljs$cst$2382$wilds$$.$cljs$core$IFn$_invoke$arity$1$($G__50069$jscomp$inline_14154_m$jscomp$205$$),$APP.$cljs$cst$2383$catch_all$$.$cljs$core$IFn$_invoke$arity$1$($G__50069$jscomp$inline_14154_m$jscomp$205$$),$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($G__50069$jscomp$inline_14154_m$jscomp$205$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($G__50069$jscomp$inline_14154_m$jscomp$205$$),null,$APP.$cljs$core$not_empty$$($G__50090$jscomp$inline_14156_extmap__5365__auto__$jscomp$inline_14155$$),
null)},$reitit$trie$Match$$=function($params$jscomp$116$$,$data$jscomp$157$$,$__meta$jscomp$29$$,$__extmap$jscomp$29$$,$__hash$jscomp$88$$){this.params=$params$jscomp$116$$;this.data=$data$jscomp$157$$;this.$__meta$=$__meta$jscomp$29$$;this.$__extmap$=$__extmap$jscomp$29$$;this.$__hash$=$__hash$jscomp$88$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$trie$t_reitit$0trie50240$$=function($meta50241$jscomp$10$$){this.$meta50241$=$meta50241$jscomp$10$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$reitit$trie$CatchAll$$=function($value$jscomp$453$$,$__meta$jscomp$28$$,$__extmap$jscomp$28$$,$__hash$jscomp$87$$){this.value=$value$jscomp$453$$;this.$__meta$=$__meta$jscomp$28$$;this.$__extmap$=$__extmap$jscomp$28$$;this.$__hash$=$__hash$jscomp$87$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$trie$Wild$$=function($value$jscomp$451$$,
$__meta$jscomp$27$$,$__extmap$jscomp$27$$,$__hash$jscomp$86$$){this.value=$value$jscomp$451$$;this.$__meta$=$__meta$jscomp$27$$;this.$__extmap$=$__extmap$jscomp$27$$;this.$__hash$=$__hash$jscomp$86$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264},$reitit$trie$join_path$$=function($xs$jscomp$31$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($s$jscomp$533$$,$x$jscomp$1136$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$533$$),
typeof $x$jscomp$1136$$==="string"?$x$jscomp$1136$$:$x$jscomp$1136$$ instanceof $reitit$trie$Wild$$?["{",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1136$$.value),1),"}"].join(""):$x$jscomp$1136$$ instanceof $reitit$trie$CatchAll$$?["{*",$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1136$$.value),1),"}"].join(""):null].join("")},"",$xs$jscomp$31$$)},$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$=
function($map__50360__$1_matchers$jscomp$5_p__50359$$,$compiler$jscomp$1$$,$cp$jscomp$12$$){function $ends$$($children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$){$children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$=$APP.$cljs$core$__destructure_map$$($children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$);$children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$,
$APP.$cljs$cst$342$children$$);$children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$=$APP.$cljs$core$keys$$($children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$);return $APP.$cljs$core$truth_$$($children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$)?$children__$1$jscomp$22_map__50362__$1_or__5025__auto__$jscomp$432_p__50361$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/"],null)}
$map__50360__$1_matchers$jscomp$5_p__50359$$=$APP.$cljs$core$__destructure_map$$($map__50360__$1_matchers$jscomp$5_p__50359$$);var $data$jscomp$174$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50360__$1_matchers$jscomp$5_p__50359$$,$APP.$cljs$cst$142$data$$),$params$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50360__$1_matchers$jscomp$5_p__50359$$,$APP.$cljs$cst$1435$params$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),$children$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50360__$1_matchers$jscomp$5_p__50359$$,
$APP.$cljs$cst$342$children$$),$wilds$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50360__$1_matchers$jscomp$5_p__50359$$,$APP.$cljs$cst$2382$wilds$$),$catch_all$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__50360__$1_matchers$jscomp$5_p__50359$$,$APP.$cljs$cst$2383$catch_all$$);$map__50360__$1_matchers$jscomp$5_p__50359$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__50363$$=
$APP.$cljs$core$PersistentVector$EMPTY$$;return $APP.$cljs$core$truth_$$($data$jscomp$174$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__50363$$,$reitit$trie$data_matcher$$($compiler$jscomp$1$$,$params$jscomp$133$$,$data$jscomp$174$$)):$G__50363$$}(),function(){return function $reitit$trie$iter__50364$$($s__50365$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__50365__$2_temp__5825__auto__$jscomp$140$$=$APP.$cljs$core$seq$$($s__50365$$);if($s__50365__$2_temp__5825__auto__$jscomp$140$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__50365__$2_temp__5825__auto__$jscomp$140$$)){var $JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$=
$APP.$cljs$core$_chunked_first$$($s__50365__$2_temp__5825__auto__$jscomp$140$$),$size__5502__auto__$jscomp$19$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$),$b__50367_p$jscomp$214$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$19$$);a:{for(var $i__50366$jscomp$inline_9979$$=0;;)if($i__50366$jscomp$inline_9979$$<$size__5502__auto__$jscomp$19$$){var $b$jscomp$inline_14158_vec__50373$jscomp$inline_9980$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$,
$i__50366$jscomp$inline_9979$$),$p$jscomp$inline_9981_x$jscomp$inline_14159$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_14158_vec__50373$jscomp$inline_9980$$,0,null),$c$jscomp$inline_9982$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_14158_vec__50373$jscomp$inline_9980$$,1,null);$b$jscomp$inline_14158_vec__50373$jscomp$inline_9980$$=$b__50367_p$jscomp$214$$;$p$jscomp$inline_9981_x$jscomp$inline_14159$$=$reitit$trie$static_matcher$$($compiler$jscomp$1$$,
$p$jscomp$inline_9981_x$jscomp$inline_14159$$,$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$inline_9982$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$p$jscomp$inline_9981_x$jscomp$inline_14159$$)));$b$jscomp$inline_14158_vec__50373$jscomp$inline_9980$$.add($p$jscomp$inline_9981_x$jscomp$inline_14159$$);$i__50366$jscomp$inline_9979$$+=1}else{$JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$=
!0;break a}$JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$=void 0}return $JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50367_p$jscomp$214$$),$reitit$trie$iter__50364$$($APP.$cljs$core$_chunked_rest$$($s__50365__$2_temp__5825__auto__$jscomp$140$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50367_p$jscomp$214$$),null)}$JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$=
$APP.$cljs$core$first$$($s__50365__$2_temp__5825__auto__$jscomp$140$$);$b__50367_p$jscomp$214$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$,0,null);$JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$,1,null);return $APP.$cljs$core$cons$$($reitit$trie$static_matcher$$($compiler$jscomp$1$$,
$b__50367_p$jscomp$214$$,$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2105_c$jscomp$282_c__5501__auto__$jscomp$19_vec__50380$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$b__50367_p$jscomp$214$$))),$reitit$trie$iter__50364$$($APP.$cljs$core$rest$$($s__50365__$2_temp__5825__auto__$jscomp$140$$)))}return null}},null,null)}($children$jscomp$173$$)}()),function(){return function $reitit$trie$iter__50383$$($s__50384$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__50384__$2_temp__5825__auto__$jscomp$141$$=$APP.$cljs$core$seq$$($s__50384$$);if($s__50384__$2_temp__5825__auto__$jscomp$141$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__50384__$2_temp__5825__auto__$jscomp$141$$)){var $c__5501__auto__$jscomp$20$$=$APP.$cljs$core$_chunked_first$$($s__50384__$2_temp__5825__auto__$jscomp$141$$),$size__5502__auto__$jscomp$20$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$20$$),$b__50386$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$20$$);
return function(){for(var $i__50385$$=0;;)if($i__50385$$<$size__5502__auto__$jscomp$20$$){var $JSCompiler_temp_const$jscomp$2106_vec__50389$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$20$$,$i__50385$$),$JSCompiler_inline_result$jscomp$2107_p$jscomp$217$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2106_vec__50389$$,0,null),$c$jscomp$285$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2106_vec__50389$$,1,null);
$JSCompiler_temp_const$jscomp$2106_vec__50389$$=$b__50386$$;var $pv$jscomp$inline_9984$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2107_p$jscomp$217$$),$ends__$1$jscomp$inline_9985$$=$ends$$($c$jscomp$285$$);$JSCompiler_inline_result$jscomp$2107_p$jscomp$217$$=$APP.$cljs$core$next$$($ends__$1$jscomp$inline_9985$$)?$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2403$reitit_DOT_trie_SLASH_multiple_terminators$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2404$terminators$$,$ends__$1$jscomp$inline_9985$$,$APP.$cljs$cst$296$path$$,$reitit$trie$join_path$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$JSCompiler_inline_result$jscomp$2107_p$jscomp$217$$))],null)):$reitit$trie$wild_matcher$$($compiler$jscomp$1$$,$pv$jscomp$inline_9984$$,$APP.$cljs$core$ffirst$$($ends__$1$jscomp$inline_9985$$),$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$285$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,
$pv$jscomp$inline_9984$$)));$JSCompiler_temp_const$jscomp$2106_vec__50389$$.add($JSCompiler_inline_result$jscomp$2107_p$jscomp$217$$);$i__50385$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50386$$),$reitit$trie$iter__50383$$($APP.$cljs$core$_chunked_rest$$($s__50384__$2_temp__5825__auto__$jscomp$141$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50386$$),null)}var $vec__50397$$=$APP.$cljs$core$first$$($s__50384__$2_temp__5825__auto__$jscomp$141$$),
$p$jscomp$216$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__50397$$,0,null),$c$jscomp$284$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__50397$$,1,null);return $APP.$cljs$core$cons$$(function(){var $pv$jscomp$12$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$216$$),$ends__$1$jscomp$1$$=$ends$$($c$jscomp$284$$);return $APP.$cljs$core$next$$($ends__$1$jscomp$1$$)?$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2403$reitit_DOT_trie_SLASH_multiple_terminators$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2404$terminators$$,$ends__$1$jscomp$1$$,$APP.$cljs$cst$296$path$$,$reitit$trie$join_path$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,$p$jscomp$216$$))],null)):$reitit$trie$wild_matcher$$($compiler$jscomp$1$$,$pv$jscomp$12$$,$APP.$cljs$core$ffirst$$($ends__$1$jscomp$1$$),$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($c$jscomp$284$$,$compiler$jscomp$1$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cp$jscomp$12$$,
$pv$jscomp$12$$)))}(),$reitit$trie$iter__50383$$($APP.$cljs$core$rest$$($s__50384__$2_temp__5825__auto__$jscomp$141$$)))}return null}},null,null)}($wilds$jscomp$2$$)}()),function(){return function $reitit$trie$iter__50404$$($s__50405$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__50405__$2_temp__5825__auto__$jscomp$142$$=$APP.$cljs$core$seq$$($s__50405$$);if($s__50405__$2_temp__5825__auto__$jscomp$142$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__50405__$2_temp__5825__auto__$jscomp$142$$)){var $JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$=
$APP.$cljs$core$_chunked_first$$($s__50405__$2_temp__5825__auto__$jscomp$142$$),$size__5502__auto__$jscomp$21$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$),$b__50407_p$jscomp$218$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$21$$);a:{for(var $i__50406$jscomp$inline_9987$$=0;;)if($i__50406$jscomp$inline_9987$$<$size__5502__auto__$jscomp$21$$){var $b$jscomp$inline_14164_vec__50412$jscomp$inline_9988$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$,
$i__50406$jscomp$inline_9987$$),$p$jscomp$inline_9989_x$jscomp$inline_14165$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_14164_vec__50412$jscomp$inline_9988$$,0,null),$c$jscomp$inline_9990$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_14164_vec__50412$jscomp$inline_9988$$,1,null);$b$jscomp$inline_14164_vec__50412$jscomp$inline_9988$$=$b__50407_p$jscomp$218$$;$p$jscomp$inline_9989_x$jscomp$inline_14165$$=$reitit$trie$catch_all_matcher$$($compiler$jscomp$1$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$inline_9989_x$jscomp$inline_14165$$),$params$jscomp$133$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$inline_9990$$));$b$jscomp$inline_14164_vec__50412$jscomp$inline_9988$$.add($p$jscomp$inline_9989_x$jscomp$inline_14165$$);$i__50406$jscomp$inline_9987$$+=1}else{$JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$=!0;break a}$JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$=
void 0}return $JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50407_p$jscomp$218$$),$reitit$trie$iter__50404$$($APP.$cljs$core$_chunked_rest$$($s__50405__$2_temp__5825__auto__$jscomp$142$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__50407_p$jscomp$218$$),null)}$JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$=$APP.$cljs$core$first$$($s__50405__$2_temp__5825__auto__$jscomp$142$$);
$b__50407_p$jscomp$218$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$,0,null);$JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$,1,null);return $APP.$cljs$core$cons$$($reitit$trie$catch_all_matcher$$($compiler$jscomp$1$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($b__50407_p$jscomp$218$$),$params$jscomp$133$$,$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2108_c$jscomp$286_c__5501__auto__$jscomp$21_vec__50419$$)),$reitit$trie$iter__50404$$($APP.$cljs$core$rest$$($s__50405__$2_temp__5825__auto__$jscomp$142$$)))}return null}},null,null)}($catch_all$jscomp$2$$)}());return $APP.$cljs$core$count$$($map__50360__$1_matchers$jscomp$5_p__50359$$)>1?$reitit$trie$linear_matcher$$($compiler$jscomp$1$$,
$map__50360__$1_matchers$jscomp$5_p__50359$$,!1):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($map__50360__$1_matchers$jscomp$5_p__50359$$),1)?$APP.$cljs$core$first$$($map__50360__$1_matchers$jscomp$5_p__50359$$):null},$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$01$$=function($options$jscomp$450$$){return $reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($options$jscomp$450$$,new $reitit$trie$t_reitit$0trie50240$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$APP.$cljs$core$PersistentVector$EMPTY$$)},$reitit$trie$conflicting_parts_QMARK_$$=function($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$,$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$){for(;;){var $G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$=$reitit$trie$_slice_start$$($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$,$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$);$G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$,
0,null);$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$=$APP.$cljs$core$seq$$($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$);$G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$=$APP.$cljs$core$first$$($G__50649_parts2_seq__50176_seq__50176__$1_ss1$$);$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$=$APP.$cljs$core$next$$($G__50649_parts2_seq__50176_seq__50176__$1_ss1$$);$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$,
1,null);var $seq__50179_seq__50179__$1_ss2$$=$APP.$cljs$core$seq$$($G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$);$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$=$APP.$cljs$core$first$$($seq__50179_seq__50179__$1_ss2$$);$seq__50179_seq__50179__$1_ss2$$=$APP.$cljs$core$next$$($seq__50179_seq__50179__$1_ss2$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$,$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([null])))return!0;if($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$==null||$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$==null)return!1;if($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$ instanceof $reitit$trie$CatchAll$$||$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$ instanceof $reitit$trie$CatchAll$$)return!0;if($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$ instanceof $reitit$trie$Wild$$||
$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$ instanceof $reitit$trie$Wild$$)$G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$=$reitit$trie$_slice_end$$($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$,$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$),$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$=$reitit$trie$_slice_end$$($G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$,$seq__50179_seq__50179__$1_ss2$$);else{if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$,
$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$))return!1;$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$=$seq__50179_seq__50179__$1_ss2$$;$G__50648_first__50177_parts1_s1$jscomp$18_vec__50175$$=$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$;$G__50649_parts2_seq__50176_seq__50176__$1_ss1$$=$G__50652_first__50180_s2$jscomp$15_vec__50172_vec__50178$$}}},$app$main$features$toggle_feature$$=function(){typeof $app$main$features$toggle_feature_54893$$==="undefined"&&($app$main$features$toggle_feature_54893$$=
function($feature$jscomp$10$$,$meta54894$$){this.$feature$=$feature$jscomp$10$$;this.$meta54894$=$meta54894$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$features$toggle_feature_54893$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$toggle_feature_54893$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3130$app_DOT_main_DOT_features_SLASH_toggle_feature$$},$app$main$features$toggle_feature_54893$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_54895$$,$meta54894__$1$$){return new $app$main$features$toggle_feature_54893$$(this.$feature$,$meta54894__$1$$)},$app$main$features$toggle_feature_54893$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54894$},$app$main$features$toggle_feature_54893$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$toggle_feature_54893$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1640$$,$state$jscomp$172$$){var $self__$jscomp$3450$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$172$$,$APP.$cljs$cst$3102$features_runtime$$,function($features__$1$jscomp$5$$){if($APP.$cljs$core$contains_QMARK_$$($features__$1$jscomp$5$$,$self__$jscomp$3450$$.$feature$))return $APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"feature disabled"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2574$feature$$,$self__$jscomp$3450$$.$feature$],null)],null)}),null,"app.main.features",$APP.$cljs$cst$144$trace$$,!1),$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$5$$,
$self__$jscomp$3450$$.$feature$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"feature enabled"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2574$feature$$,$self__$jscomp$3450$$.$feature$],null)],null)}),null,"app.main.features",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$5$$,$self__$jscomp$3450$$.$feature$)}),$APP.$cljs$cst$3102$features_runtime$$,$APP.$clojure$set$intersection$$,$APP.$app$common$features$no_migration_features$$)});return new $app$main$features$toggle_feature_54893$$("layout/grid",$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$util$theme$use_initialize$$=
function($map__74145__$1_p__74144$$){$map__74145__$1_p__74144$$=$APP.$cljs$core$__destructure_map$$($map__74145__$1_p__74144$$);var $profile_theme$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74145__$1_p__74144$$,$APP.$cljs$cst$3208$theme$$),$system_theme_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$util$theme$get_system_theme$$),$system_theme$$=$APP.$cljs$core$_deref$$($system_theme_STAR_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $s$jscomp$557$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__74143_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($system_theme_STAR_$$,$p1__74143_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__74142_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__74142_SHARP_$$.matches)?"dark":"light"},$APP.$shadow$js$shim$module$0rxjs$$.fromEvent($APP.$app$util$theme$color_scheme_media_query$$,"change")));return function(){return $APP.$beicon$v2$core$_dispose$$($s$jscomp$557$$)}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($system_theme$$),$APP.$rumext$v2$adapt$$($profile_theme$$)],function(){var $G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_theme$$,"system")?$system_theme$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_theme$$,"default")?"dark":
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($profile_theme$$,"dark"),$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=document.querySelector("body");$G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$,
"dark")?"default":"light";$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$.removeAttribute("class");$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$.classList.add($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$);
a:{$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($APP.$app$util$theme$color_scheme_listeners_STAR_$$));$G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$=null;for(var $G__74150$jscomp$inline_10004_count__74140$jscomp$inline_9998$$=0,
$i__74141$jscomp$inline_9999$$=0;;)if($i__74141$jscomp$inline_9999$$<$G__74150$jscomp$inline_10004_count__74140$jscomp$inline_9998$$){var $G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$=$G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__74141$jscomp$inline_9999$$);$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$.$cljs$core$IFn$_invoke$arity$0$?$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$.$cljs$core$IFn$_invoke$arity$0$():
$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$();$i__74141$jscomp$inline_9999$$+=1}else if($JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$))$G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$=
$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$)?($JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=
$APP.$cljs$core$_chunked_first$$($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$),$G__74150$jscomp$inline_10004_count__74140$jscomp$inline_9998$$=$APP.$cljs$core$_chunked_rest$$($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$),$G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$=
$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$,$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$),$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=
$G__74150$jscomp$inline_10004_count__74140$jscomp$inline_9998$$,$G__74150$jscomp$inline_10004_count__74140$jscomp$inline_9998$$=$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$):($G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$=$APP.$cljs$core$first$$($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$),$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$.$cljs$core$IFn$_invoke$arity$0$?$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$.$cljs$core$IFn$_invoke$arity$0$():
$G__74152$jscomp$inline_10006_f$jscomp$inline_10000$$(),$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=$APP.$cljs$core$next$$($G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$),$G__74151$jscomp$inline_10005_chunk__74139$jscomp$inline_9997_class$$jscomp$inline_9994_color$jscomp$inline_9992_seq__74138__$1$jscomp$inline_10002$$=
null,$G__74150$jscomp$inline_10004_count__74140$jscomp$inline_9998$$=0),$i__74141$jscomp$inline_9999$$=0;else{$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=null;break a}$JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$=void 0}return $JSCompiler_inline_result$jscomp$2110_c__5548__auto__$jscomp$inline_10003_node$jscomp$inline_9993_seq__74138$jscomp$inline_9996_temp__5825__auto__$jscomp$inline_10001$$})},
$app$main$features$enable_feature$$=function(){typeof $app$main$features$enable_feature_54904$$==="undefined"&&($app$main$features$enable_feature_54904$$=function($feature$jscomp$12$$,$meta54905$$){this.$feature$=$feature$jscomp$12$$;this.$meta54905$=$meta54905$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$features$enable_feature_54904$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$enable_feature_54904$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3131$app_DOT_main_DOT_features_SLASH_enable_feature$$},$app$main$features$enable_feature_54904$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_54906$$,$meta54905__$1$$){return new $app$main$features$enable_feature_54904$$(this.$feature$,$meta54905__$1$$)},$app$main$features$enable_feature_54904$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta54905$},$app$main$features$enable_feature_54904$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$features$enable_feature_54904$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1641$$,$state$jscomp$173$$){var $self__$jscomp$3454$$=this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$173$$,$self__$jscomp$3454$$.$feature$))return $state$jscomp$173$$;$APP.$app$common$logging$enabled_QMARK_$$("app.main.features",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"feature enabled"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2574$feature$$,$self__$jscomp$3454$$.$feature$],null)],null)}),null,"app.main.features",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$173$$,
$APP.$cljs$cst$3102$features_runtime$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$self__$jscomp$3454$$.$feature$),$APP.$cljs$cst$3102$features_runtime$$,$APP.$clojure$set$intersection$$,$APP.$app$common$features$no_migration_features$$)});return new $app$main$features$enable_feature_54904$$("plugins/runtime",$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$team$create_team_with_invitations$$=function($p__55625$$){var $map__55626__$1$$=
$APP.$cljs$core$__destructure_map$$($p__55625$$),$name$jscomp$274$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55626__$1$$,$APP.$cljs$cst$725$name$$),$emails$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55626__$1$$,$APP.$cljs$cst$3346$emails$$),$role$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55626__$1$$,$APP.$cljs$cst$2501$role$$);typeof $app$main$data$team$create_team_with_invitations_55627$$==="undefined"&&($app$main$data$team$create_team_with_invitations_55627$$=
function($p__55625$jscomp$1$$,$map__55626$jscomp$1$$,$params$jscomp$200$$,$name$jscomp$275$$,$emails$jscomp$1$$,$role$jscomp$6$$,$meta55628$$){this.$p__55625$=$p__55625$jscomp$1$$;this.$map__55626$=$map__55626$jscomp$1$$;this.params=$params$jscomp$200$$;this.name=$name$jscomp$275$$;this.$emails$=$emails$jscomp$1$$;this.role=$role$jscomp$6$$;this.$meta55628$=$meta55628$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$create_team_with_invitations_55627$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_team_with_invitations_55627$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3347$app_DOT_main_DOT_data_DOT_team_SLASH_create_team_with_invitations$$},$app$main$data$team$create_team_with_invitations_55627$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55629$$,$meta55628__$1$$){return new $app$main$data$team$create_team_with_invitations_55627$$(this.$p__55625$,this.$map__55626$,this.params,
this.name,this.$emails$,this.role,$meta55628__$1$$)},$app$main$data$team$create_team_with_invitations_55627$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55628$},$app$main$data$team$create_team_with_invitations_55627$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$create_team_with_invitations_55627$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55630_on_success$jscomp$12$$=$APP.$cljs$core$meta$$(this.params),
$map__55630__$1_on_error$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($map__55630_on_success$jscomp$12$$);$map__55630_on_success$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55630__$1_on_error$jscomp$16$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__55630__$1_on_error$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55630__$1_on_error$jscomp$16$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55630__$1_on_error$jscomp$16$$,
$APP.$beicon$v2$core$map$$($APP.$app$main$data$team$team_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55630_on_success$jscomp$12$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3348$create_team_with_invitations$$,$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,this.name,$APP.$cljs$cst$3346$emails$$,this.$emails$,$APP.$cljs$cst$2501$role$$,this.role,$APP.$cljs$cst$227$features$$,
$APP.$app$main$features$global_enabled_features$$],null),$APP.$cljs$core$meta$$(this))))))});return new $app$main$data$team$create_team_with_invitations_55627$$($p__55625$$,$map__55626__$1$$,$map__55626__$1$$,$name$jscomp$274$$,$emails$$,$role$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$reitit$impl$meta_merge$$=function($G__51639_left$jscomp$24$$,$G__51640_right$jscomp$20$$,$map__51637__$1_p__51636_update$$){$map__51637__$1_p__51636_update$$=$APP.$cljs$core$__destructure_map$$($map__51637__$1_p__51636_update$$);
var $merge$jscomp$1_meta_merge__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51637__$1_p__51636_update$$,$APP.$cljs$cst$2410$meta_merge$$),$update_paths$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51637__$1_p__51636_update$$,$APP.$cljs$cst$2411$update_paths$$);$map__51637__$1_p__51636_update$$=$APP.$cljs$core$truth_$$($update_paths$$)?function($p1__51635_SHARP_$$){var $JSCompiler_inline_result$jscomp$11334_c$jscomp$inline_14172$$=$reitit$impl$_path_vals$$($p1__51635_SHARP_$$,
$update_paths$$);$JSCompiler_inline_result$jscomp$11334_c$jscomp$inline_14172$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$apply$$,$APP.$cljs$core$assoc_in$$),$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$JSCompiler_inline_result$jscomp$11334_c$jscomp$inline_14172$$);return $reitit$impl$_copy_meta$$($JSCompiler_inline_result$jscomp$11334_c$jscomp$inline_14172$$,$p1__51635_SHARP_$$)}:$APP.$cljs$core$identity$$;
$merge$jscomp$1_meta_merge__$1$$=$APP.$cljs$core$truth_$$($merge$jscomp$1_meta_merge__$1$$)?$merge$jscomp$1_meta_merge__$1$$:$meta_merge$core$meta_merge$$;$G__51639_left$jscomp$24$$=$map__51637__$1_p__51636_update$$.$cljs$core$IFn$_invoke$arity$1$?$map__51637__$1_p__51636_update$$.$cljs$core$IFn$_invoke$arity$1$($G__51639_left$jscomp$24$$):$map__51637__$1_p__51636_update$$($G__51639_left$jscomp$24$$);$G__51640_right$jscomp$20$$=$map__51637__$1_p__51636_update$$.$cljs$core$IFn$_invoke$arity$1$?$map__51637__$1_p__51636_update$$.$cljs$core$IFn$_invoke$arity$1$($G__51640_right$jscomp$20$$):
$map__51637__$1_p__51636_update$$($G__51640_right$jscomp$20$$);return $merge$jscomp$1_meta_merge__$1$$.$cljs$core$IFn$_invoke$arity$2$?$merge$jscomp$1_meta_merge__$1$$.$cljs$core$IFn$_invoke$arity$2$($G__51639_left$jscomp$24$$,$G__51640_right$jscomp$20$$):$merge$jscomp$1_meta_merge__$1$$($G__51639_left$jscomp$24$$,$G__51640_right$jscomp$20$$)},$reitit$impl$merge_data$$=function($opts$jscomp$266$$,$p$jscomp$224$$,$x$jscomp$1143$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$105$$,
$p__51642_v$jscomp$555$$){var $k$jscomp$609$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51642_v$jscomp$555$$,0,null);$p__51642_v$jscomp$555$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51642_v$jscomp$555$$,1,null);try{return $reitit$impl$meta_merge$$($acc$jscomp$105$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$609$$,$p__51642_v$jscomp$555$$]),$opts$jscomp$266$$)}catch($e51646$$){if($e51646$$ instanceof Error){var $e$jscomp$294$$=$e51646$$;
return $reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2377$reitit_DOT_impl_SLASH_merge_data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$296$path$$,$p$jscomp$224$$,$APP.$cljs$cst$257$left$$,$acc$jscomp$105$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$609$$,$p__51642_v$jscomp$555$$]),$APP.$cljs$cst$727$exception$$,$e$jscomp$294$$],null))}throw $e51646$$;}},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$x$jscomp$1143$$)},$reitit$impl$resolve_routes$$=function($G__51655_raw_routes$jscomp$1$$,$p__51651$$){var $map__51653__$1$$=$APP.$cljs$core$__destructure_map$$($p__51651$$),$coerce$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51653__$1$$,$APP.$cljs$cst$2412$coerce$$);$G__51655_raw_routes$jscomp$1$$=$reitit$impl$map_data$$(function($p1__51648_SHARP_$$,$p2__51649_SHARP_$$){return $reitit$impl$merge_data$$($map__51653__$1$$,$p1__51648_SHARP_$$,$p2__51649_SHARP_$$)},$reitit$impl$walk$$($G__51655_raw_routes$jscomp$1$$,
$map__51653__$1$$));return $APP.$cljs$core$truth_$$($coerce$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__51650_SHARP_$$){return $coerce$$.$cljs$core$IFn$_invoke$arity$2$?$coerce$$.$cljs$core$IFn$_invoke$arity$2$($p1__51650_SHARP_$$,$map__51653__$1$$):$coerce$$($p1__51650_SHARP_$$,$map__51653__$1$$)}),$G__51655_raw_routes$jscomp$1$$):$G__51655_raw_routes$jscomp$1$$},$app$main$ui$forms$conj_dedup$$=
function($coll$jscomp$1098$$,$item$jscomp$112$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($coll$jscomp$1098$$,$item$jscomp$112$$))},$reitit$core$default_router_options$$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2461$lookup$$,function($map__52181_map__52181__$1_name$jscomp$250_p__52177$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52181_map__52181__$1_name$jscomp$250_p__52177$$,
0,null);$map__52181_map__52181__$1_name$jscomp$250_p__52177$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52181_map__52181__$1_name$jscomp$250_p__52177$$,1,null);$map__52181_map__52181__$1_name$jscomp$250_p__52177$$=$APP.$cljs$core$__destructure_map$$($map__52181_map__52181__$1_name$jscomp$250_p__52177$$);$map__52181_map__52181__$1_name$jscomp$250_p__52177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52181_map__52181__$1_name$jscomp$250_p__52177$$,$APP.$cljs$cst$725$name$$);
return $APP.$cljs$core$truth_$$($map__52181_map__52181__$1_name$jscomp$250_p__52177$$)?$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$map__52181_map__52181__$1_name$jscomp$250_p__52177$$]):null},$APP.$cljs$cst$2409$expand$$,$APP.$reitit$core$expand$$,$APP.$cljs$cst$2412$coerce$$,function($route$jscomp$4$$){return $route$jscomp$4$$},$APP.$cljs$cst$411$compile$$,function($map__52191_map__52191__$1_p__52186$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52191_map__52191__$1_p__52186$$,
0,null);$map__52191_map__52191__$1_p__52186$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52191_map__52191__$1_p__52186$$,1,null);$map__52191_map__52191__$1_p__52186$$=$APP.$cljs$core$__destructure_map$$($map__52191_map__52191__$1_p__52186$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52191_map__52191__$1_p__52186$$,$APP.$cljs$cst$2413$handler$$)},$APP.$cljs$cst$727$exception$$,$reitit$exception$exception$$,$APP.$cljs$cst$2411$update_paths$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2390$parameters$$,$APP.$cljs$core$any_QMARK_$$],null),$reitit$impl$accumulate$$],null)],null),$APP.$cljs$cst$2462$conflicts$$,function($conflicts$jscomp$4$$){return $reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2374$path_conflicts$$,
$conflicts$jscomp$4$$)}],null)},$app$plugins$utils$mixed_value$$=function($s$jscomp$547_values$jscomp$72$$){$s$jscomp$547_values$jscomp$72$$=$APP.$cljs$core$set$$($s$jscomp$547_values$jscomp$72$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($s$jscomp$547_values$jscomp$72$$),1)?$APP.$cljs$core$first$$($s$jscomp$547_values$jscomp$72$$):"mixed"},$reitit$impl$name_conflicting_routes$$=function($G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$){$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$=
$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$group_by$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$second$$),$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$);$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$=$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,
$APP.$cljs$core$first$$),$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$);$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$=$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$pos_QMARK_$$,$APP.$cljs$core$count$$,$APP.$cljs$core$butlast$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$second$$])),
$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$);$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$=$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$seq$$($G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$);$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$=$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$==
null?null:$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__51696_v$jscomp$556$$){var $k$jscomp$610$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51696_v$jscomp$556$$,0,null);$p__51696_v$jscomp$556$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51696_v$jscomp$556$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$610$$,$APP.$cljs$core$set$$($p__51696_v$jscomp$556$$)],null)},$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$);
return $G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$==null?null:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__51695__$1_G__51695__$2_G__51695__$3_G__51695__$4_G__51695__$5_routes$jscomp$5$$)},$reitit$impl$conflicting_paths$$=function($conflicts$jscomp$3$$){return $APP.$cljs$core$set$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,function(){return function $reitit$impl$conflicting_paths_$_iter__51683$$($s__51684$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__51684__$2_temp__5825__auto__$jscomp$143$$=$APP.$cljs$core$seq$$($s__51684$$);if($s__51684__$2_temp__5825__auto__$jscomp$143$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__51684__$2_temp__5825__auto__$jscomp$143$$)){var $JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$=$APP.$cljs$core$_chunked_first$$($s__51684__$2_temp__5825__auto__$jscomp$143$$),$size__5502__auto__$jscomp$22$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$),
$b__51686_p$jscomp$226$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$22$$);a:{for(var $i__51685$jscomp$inline_10013$$=0;;)if($i__51685$jscomp$inline_10013$$<$size__5502__auto__$jscomp$22$$){var $b$jscomp$inline_14174_vec__51687$jscomp$inline_10014$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$,$i__51685$jscomp$inline_10013$$),$p$jscomp$inline_10015_x$jscomp$inline_14175$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_14174_vec__51687$jscomp$inline_10014$$,
0,null),$pc$jscomp$inline_10016$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_14174_vec__51687$jscomp$inline_10014$$,1,null);$b$jscomp$inline_14174_vec__51687$jscomp$inline_10014$$=$b__51686_p$jscomp$226$$;$p$jscomp$inline_10015_x$jscomp$inline_14175$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$pc$jscomp$inline_10016$$),$APP.$cljs$core$first$$($p$jscomp$inline_10015_x$jscomp$inline_14175$$));
$b$jscomp$inline_14174_vec__51687$jscomp$inline_10014$$.add($p$jscomp$inline_10015_x$jscomp$inline_14175$$);$i__51685$jscomp$inline_10013$$+=1}else{$JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$=!0;break a}$JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$=void 0}return $JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__51686_p$jscomp$226$$),
$reitit$impl$conflicting_paths_$_iter__51683$$($APP.$cljs$core$_chunked_rest$$($s__51684__$2_temp__5825__auto__$jscomp$143$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__51686_p$jscomp$226$$),null)}$JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$=$APP.$cljs$core$first$$($s__51684__$2_temp__5825__auto__$jscomp$143$$);$b__51686_p$jscomp$226$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$,
0,null);$JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$,1,null);return $APP.$cljs$core$cons$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$JSCompiler_inline_result$jscomp$2116_c__5501__auto__$jscomp$22_pc$jscomp$2_vec__51691$$),
$APP.$cljs$core$first$$($b__51686_p$jscomp$226$$)),$reitit$impl$conflicting_paths_$_iter__51683$$($APP.$cljs$core$rest$$($s__51684__$2_temp__5825__auto__$jscomp$143$$)))}return null}},null,null)}($conflicts$jscomp$3$$)}()))},$reitit$trie$into_set$$=function($x$jscomp$1133$$){return $APP.$cljs$core$set_QMARK_$$($x$jscomp$1133$$)||$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$1133$$)?$APP.$cljs$core$set$$($x$jscomp$1133$$):$x$jscomp$1133$$==null?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$x$jscomp$1133$$)},$reitit$trie$split_path$$=function($s$jscomp$532$$,$bracket_QMARK__map__50132__$1_p__50131$$){function $_catch_all$$($from$jscomp$18_value$jscomp$inline_10023$$,$to$jscomp$20$$){var $JSCompiler_temp_const$jscomp$2103$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$from$jscomp$18_value$jscomp$inline_10023$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$532$$,$from$jscomp$18_value$jscomp$inline_10023$$+
1,$to$jscomp$20$$));return new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$2103$$,[new $reitit$trie$CatchAll$$($from$jscomp$18_value$jscomp$inline_10023$$,null,null,null)],null)}function $_wild$$($JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$,$temp__5823__auto__$jscomp$inline_10019_to$jscomp$19$$){var $JSCompiler_temp_const$jscomp$2086$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$=
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$532$$,$JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$+1,$temp__5823__auto__$jscomp$inline_10019_to$jscomp$19$$);$temp__5823__auto__$jscomp$inline_10019_to$jscomp$19$$=$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$,"/");$JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$=$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_10019_to$jscomp$19$$)?
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$,0,$temp__5823__auto__$jscomp$inline_10019_to$jscomp$19$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$,$temp__5823__auto__$jscomp$inline_10019_to$jscomp$19$$+1)):$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$);
return new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$2086$$,[new $reitit$trie$Wild$$($JSCompiler_inline_result$jscomp$2087_from$jscomp$17_s$jscomp$inline_10018$$,null,null,null)],null)}function $_static$$($from$jscomp$16$$,$to$jscomp$18$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from$jscomp$16$$,$to$jscomp$18$$)?null:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($s$jscomp$532$$,
$from$jscomp$16$$,$to$jscomp$18$$)],null)}$bracket_QMARK__map__50132__$1_p__50131$$=$APP.$cljs$core$__destructure_map$$($bracket_QMARK__map__50132__$1_p__50131$$);var $colon_QMARK__syntax$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($bracket_QMARK__map__50132__$1_p__50131$$,$APP.$cljs$cst$2386$syntax$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1437$colon$$,null,$APP.$cljs$cst$2387$bracket$$,null],null),null));$bracket_QMARK__map__50132__$1_p__50131$$=
$APP.$cljs$cst$2387$bracket$$.$cljs$core$IFn$_invoke$arity$1$($reitit$trie$into_set$$($colon_QMARK__syntax$$));$colon_QMARK__syntax$$=$APP.$cljs$cst$1437$colon$$.$cljs$core$IFn$_invoke$arity$1$($reitit$trie$into_set$$($colon_QMARK__syntax$$));for(var $G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$=null,$G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$=0,$to$jscomp$17$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($to$jscomp$17$$,$APP.$cljs$core$count$$($s$jscomp$532$$)))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$,
$_static$$($G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$,$to$jscomp$17$$));var $G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$532$$,$to$jscomp$17$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($bracket_QMARK__map__50132__$1_p__50131$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("{",$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$):$bracket_QMARK__map__50132__$1_p__50131$$)?
($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=function(){var $or__5025__auto__$jscomp$426$$=$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$532$$,"}",$to$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$426$$)?$or__5025__auto__$jscomp$426$$:$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2388$reitit_DOT_trie_SLASH_unclosed_brackets$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$296$path$$,
$s$jscomp$532$$],null))}(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("*",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$532$$,$to$jscomp$17$$+1))?($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$,$_static$$($G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_catch_all$$($to$jscomp$17$$+
1,$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$+1),$to$jscomp$17$$=$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$+1)):($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$,
$_static$$($G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_wild$$($to$jscomp$17$$,$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$+1),$to$jscomp$17$$=$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$+
1))):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($colon_QMARK__syntax$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(":",$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$):$colon_QMARK__syntax$$)?($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=function(){var $or__5025__auto__$jscomp$427$$=$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$532$$,"/",$to$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$427$$)?
$or__5025__auto__$jscomp$427$$:$APP.$cljs$core$count$$($s$jscomp$532$$)}(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$-$to$jscomp$17$$)?$to$jscomp$17$$+=1:($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$,$_static$$($G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_wild$$($to$jscomp$17$$,
$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$),$to$jscomp$17$$=$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$))):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($colon_QMARK__syntax$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("*",
$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$):$colon_QMARK__syntax$$)?($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$count$$($s$jscomp$532$$),$G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($G__50610_G__50613_G__50621_G__50625_ss$jscomp$7$$,$_static$$($G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$,$to$jscomp$17$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_catch_all$$($to$jscomp$17$$,
$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$)])),$G__50611_G__50614_G__50622_G__50626_from$jscomp$15$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$),$to$jscomp$17$$=$G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$=$APP.$cljs$core$fix$$($G__50612_G__50615_G__50623_G__50627_c$jscomp$280_to_SINGLEQUOTE_$$)):$to$jscomp$17$$+=1}},$reitit$impl$path_conflicting_routes$$=function($routes$jscomp$4$$,$opts$jscomp$268$$){var $parts_and_routes$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__51660$$){var $s$jscomp$535$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51660$$,0,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$reitit$trie$split_path$$($s$jscomp$535$$,$opts$jscomp$268$$),$p__51660$$],null)},$routes$jscomp$4$$);return $APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$209$$,$p__51664_r$jscomp$108$$){var $p$jscomp$225$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51664_r$jscomp$108$$,0,null);$p__51664_r$jscomp$108$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51664_r$jscomp$108$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p__51664_r$jscomp$108$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$106$$,$p__51668_r_SINGLEQUOTE_$$){var $p_SINGLEQUOTE_$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51668_r_SINGLEQUOTE_$$,0,null);$p__51668_r_SINGLEQUOTE_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51668_r_SINGLEQUOTE_$$,1,null);return $reitit$trie$conflicting_parts_QMARK_$$($p$jscomp$225$$,$p_SINGLEQUOTE_$jscomp$4$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$106$$,
$p__51668_r_SINGLEQUOTE_$$):$acc$jscomp$106$$},$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($parts_and_routes$$,$index$jscomp$209$$+1))],null)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$core$second$$))),$parts_and_routes$$))},$reitit$trie$insert$cljs$0core$0IFn$0_invoke$0arity$04$$=function($node$jscomp$259$$,$path$jscomp$205$$,$data$jscomp$173$$,
$map__50355__$1_p__50354$$){$map__50355__$1_p__50354$$=$APP.$cljs$core$__destructure_map$$($map__50355__$1_p__50354$$);var $parameters$jscomp$1_params$jscomp$132$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50355__$1_p__50354$$,$APP.$cljs$cst$2402$reitit_DOT_trie_SLASH_parameters$$,$reitit$trie$map_parameters$$),$G__50356$jscomp$inline_14177_parts$jscomp$20$$=$reitit$trie$split_path$$($path$jscomp$205$$,$map__50355__$1_p__50354$$);$G__50356$jscomp$inline_14177_parts$jscomp$20$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$string_QMARK_$$,$G__50356$jscomp$inline_14177_parts$jscomp$20$$));$parameters$jscomp$1_params$jscomp$132$$=$parameters$jscomp$1_params$jscomp$132$$.$cljs$core$IFn$_invoke$arity$1$?$parameters$jscomp$1_params$jscomp$132$$.$cljs$core$IFn$_invoke$arity$1$($G__50356$jscomp$inline_14177_parts$jscomp$20$$):$parameters$jscomp$1_params$jscomp$132$$($G__50356$jscomp$inline_14177_parts$jscomp$20$$);return $reitit$trie$_insert$$($APP.$cljs$core$truth_$$($node$jscomp$259$$)?
$node$jscomp$259$$:$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$reitit$trie$split_path$$($path$jscomp$205$$,$map__50355__$1_p__50354$$),$path$jscomp$205$$,$parameters$jscomp$1_params$jscomp$132$$,$data$jscomp$173$$)},$reitit$impl$parse$$=function($path$jscomp$207_path__$1$jscomp$6$$,$opts$jscomp$262_path_parts$$){$path$jscomp$207_path__$1$jscomp$6$$=$reitit$trie$join_path$$($reitit$trie$split_path$$($path$jscomp$207_path__$1$jscomp$6$$,$opts$jscomp$262_path_parts$$));$opts$jscomp$262_path_parts$$=
$reitit$trie$split_path$$($path$jscomp$207_path__$1$jscomp$6$$,$opts$jscomp$262_path_parts$$);var $path_params$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$string_QMARK_$$,$opts$jscomp$262_path_parts$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2406$path_params$$,$path_params$$,$APP.$cljs$cst$2407$path_parts$$,$opts$jscomp$262_path_parts$$,
$APP.$cljs$cst$296$path$$,$path$jscomp$207_path__$1$jscomp$6$$],null)},$reitit$core$linear_router$cljs$0core$0IFn$0_invoke$0arity$02$$=function($compiled_routes$jscomp$3$$,$opts$jscomp$275$$){var $compiler$jscomp$6$$=$APP.$cljs$cst$2429$reitit_DOT_trie_SLASH_trie_compiler$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$275$$,new $reitit$trie$t_reitit$0trie50240$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)),$names$jscomp$5$$=$reitit$impl$find_names$$($compiled_routes$jscomp$3$$),$vec__51938$jscomp$2$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($nl$jscomp$7_p__51941$$,$map__51954_p__51942$$){function $f$jscomp$797$$($JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$){var $temp__5823__auto__$jscomp$138$$=$reitit$impl$path_for$$($map__51954__$1$$,$JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$);$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$138$$)?$JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$=
$reitit$core$__GT_Match$$($p$jscomp$230$$,$map__51949__$1$$,$result$jscomp$225$$,$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$),$temp__5823__auto__$jscomp$138$$):($JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$=$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$),$JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$=
new $reitit$core$PartialMatch$$($p$jscomp$230$$,$map__51949__$1$$,$result$jscomp$225$$,$JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$,$path_params$jscomp$12$$,null,null,null));return $JSCompiler_temp$jscomp$2101_p1__51930_SHARP__path_params$jscomp$inline_10034$$}var $pl$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$7_p__51941$$,0,null);$nl$jscomp$7_p__51941$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$7_p__51941$$,
1,null);var $p$jscomp$230$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__51954_p__51942$$,0,null),$map__51949_name$jscomp$237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__51954_p__51942$$,1,null),$map__51949__$1$$=$APP.$cljs$core$__destructure_map$$($map__51949_name$jscomp$237$$);$map__51949_name$jscomp$237$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51949__$1$$,$APP.$cljs$cst$725$name$$);var $result$jscomp$225$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__51954_p__51942$$,
2,null);$map__51954_p__51942$$=$reitit$impl$parse$$($p$jscomp$230$$,$opts$jscomp$275$$);var $map__51954__$1$$=$APP.$cljs$core$__destructure_map$$($map__51954_p__51942$$),$path_params$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__51954__$1$$,$APP.$cljs$cst$2406$path_params$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($pl$jscomp$3$$,$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$01$$($reitit$trie$insert$cljs$0core$0IFn$0_invoke$0arity$04$$(null,
$p$jscomp$230$$,$reitit$core$__GT_Match$$($p$jscomp$230$$,$map__51949__$1$$,$result$jscomp$225$$,null,null),$opts$jscomp$275$$))),$APP.$cljs$core$truth_$$($map__51949_name$jscomp$237$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nl$jscomp$7_p__51941$$,$map__51949_name$jscomp$237$$,$f$jscomp$797$$):$nl$jscomp$7_p__51941$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],
null),$compiled_routes$jscomp$3$$),$pl$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51938$jscomp$2$$,0,null),$nl$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51938$jscomp$2$$,1,null),$matcher$jscomp$19$$=$reitit$trie$linear_matcher$$($compiler$jscomp$6$$,$pl$jscomp$2$$,!0),$match_by_path$jscomp$2$$=$reitit$trie$_path_matcher$$($compiler$jscomp$6$$,$matcher$jscomp$19$$),$routes$jscomp$11$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$3$$);
return new $reitit$core$t_reitit$0core51961$$($matcher$jscomp$19$$,$names$jscomp$5$$,$compiled_routes$jscomp$3$$,$routes$jscomp$11$$,$nl$jscomp$6$$,$pl$jscomp$2$$,$nl$jscomp$6$$,$vec__51938$jscomp$2$$,$match_by_path$jscomp$2$$,$compiler$jscomp$6$$,$opts$jscomp$275$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2430$reitit_DOT_core_SLASH_router$$],null))},$reitit$impl$__GT_wild_route_QMARK_$$=function($opts$jscomp$264$$){return function($p__51600_path$jscomp$209$$){$p__51600_path$jscomp$209$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51600_path$jscomp$209$$,0,null);return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$cst$2406$path_params$$.$cljs$core$IFn$_invoke$arity$1$($reitit$impl$parse$$($p__51600_path$jscomp$209$$,$opts$jscomp$264$$))))}},$app$main$router$initialize_router$$=function(){var $routes$jscomp$29$$=$app$main$ui$routes$routes$$;typeof $app$main$router$initialize_router_52256$$==="undefined"&&($app$main$router$initialize_router_52256$$=function($routes$jscomp$30$$,
$meta52257$$){this.$routes$=$routes$jscomp$30$$;this.$meta52257$=$meta52257$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$initialize_router_52256$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_router_52256$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2464$app_DOT_main_DOT_router_SLASH_initialize_router$$},$app$main$router$initialize_router_52256$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_52258$$,$meta52257__$1$$){return new $app$main$router$initialize_router_52256$$(this.$routes$,$meta52257__$1$$)},$app$main$router$initialize_router_52256$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52257$},$app$main$router$initialize_router_52256$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_router_52256$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($JSCompiler_temp_const$jscomp$14360__$jscomp$1521$$,
$e$jscomp$inline_14993_state$jscomp$111$$){$JSCompiler_temp_const$jscomp$14360__$jscomp$1521$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;a:{var $raw_routes$jscomp$inline_14978$$=this.$routes$,$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$reitit$core$default_router_options$$(),$APP.$cljs$core$PersistentArrayMap$EMPTY$$]));$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$=
$APP.$cljs$core$__destructure_map$$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$);var $router$jscomp$inline_14981$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$,$APP.$cljs$cst$2180$router$$),$conflicts$jscomp$inline_14982$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$,$APP.$cljs$cst$2462$conflicts$$);try{var $routes$jscomp$inline_14983$$=
$reitit$impl$resolve_routes$$($raw_routes$jscomp$inline_14978$$,$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$),$path_conflicting$jscomp$inline_14984$$=$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($router$jscomp$inline_14981$$)?$APP.$cljs$core$not$$($conflicts$jscomp$inline_14982$$):$router$jscomp$inline_14981$$)?$reitit$impl$path_conflicting_routes$$($routes$jscomp$inline_14983$$,$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$):null,$name_conflicting$jscomp$inline_14985$$=
$reitit$impl$name_conflicting_routes$$($routes$jscomp$inline_14983$$),$compiled_routes$jscomp$inline_14986$$=$reitit$impl$compile_routes$$($routes$jscomp$inline_14983$$,$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$),$wilds_QMARK_$jscomp$inline_14987$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$($reitit$impl$__GT_wild_route_QMARK_$$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$),$compiled_routes$jscomp$inline_14986$$)),$all_wilds_QMARK_$jscomp$inline_14988$$=
$APP.$cljs$core$every_QMARK_$$($reitit$impl$__GT_wild_route_QMARK_$$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$),$compiled_routes$jscomp$inline_14986$$),$router__$1$jscomp$inline_14989$$=$APP.$cljs$core$truth_$$($router$jscomp$inline_14981$$)?$router$jscomp$inline_14981$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($compiled_routes$jscomp$inline_14986$$))&&!$wilds_QMARK_$jscomp$inline_14987$$?$reitit$core$single_static_path_router$$:$APP.$cljs$core$truth_$$($path_conflicting$jscomp$inline_14984$$)?
$reitit$core$quarantine_router$$:$wilds_QMARK_$jscomp$inline_14987$$?$all_wilds_QMARK_$jscomp$inline_14988$$?$reitit$core$trie_router$$:$reitit$core$mixed_router$$:$reitit$core$lookup_router$$,$temp__5825__auto___52458$jscomp$inline_14990$$=$APP.$cljs$core$truth_$$($conflicts$jscomp$inline_14982$$)?$reitit$impl$unresolved_conflicts$$($path_conflicting$jscomp$inline_14984$$):$conflicts$jscomp$inline_14982$$;$APP.$cljs$core$truth_$$($temp__5825__auto___52458$jscomp$inline_14990$$)&&($conflicts$jscomp$inline_14982$$.$cljs$core$IFn$_invoke$arity$1$?
$conflicts$jscomp$inline_14982$$.$cljs$core$IFn$_invoke$arity$1$($temp__5825__auto___52458$jscomp$inline_14990$$):$conflicts$jscomp$inline_14982$$($temp__5825__auto___52458$jscomp$inline_14990$$));$APP.$cljs$core$truth_$$($name_conflicting$jscomp$inline_14985$$)&&$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2376$name_conflicts$$,$name_conflicting$jscomp$inline_14985$$);var $temp__5825__auto___52463$jscomp$inline_14991$$=$APP.$cljs$cst$2463$validate$$.$cljs$core$IFn$_invoke$arity$1$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$);
$APP.$cljs$core$truth_$$($temp__5825__auto___52463$jscomp$inline_14991$$)&&($temp__5825__auto___52463$jscomp$inline_14991$$.$cljs$core$IFn$_invoke$arity$2$?$temp__5825__auto___52463$jscomp$inline_14991$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$inline_14986$$,$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$):$temp__5825__auto___52463$jscomp$inline_14991$$($compiled_routes$jscomp$inline_14986$$,$map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$));
var $G__52217$jscomp$inline_14992$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$,$APP.$cljs$cst$2460$reitit_DOT_core_SLASH_path_conflicting$$,$path_conflicting$jscomp$inline_14984$$);var $JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$=$router__$1$jscomp$inline_14989$$.$cljs$core$IFn$_invoke$arity$2$?$router__$1$jscomp$inline_14989$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$inline_14986$$,
$G__52217$jscomp$inline_14992$$):$router__$1$jscomp$inline_14989$$($compiled_routes$jscomp$inline_14986$$,$G__52217$jscomp$inline_14992$$);break a}catch($e52204$jscomp$inline_14996$$){if($e52204$jscomp$inline_14996$$ instanceof Error)throw $e$jscomp$inline_14993_state$jscomp$111$$=$e52204$jscomp$inline_14996$$,$JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__52202$jscomp$inline_14979_map__52202__$1$jscomp$inline_14980$$,
$APP.$cljs$cst$727$exception$$,$APP.$cljs$core$identity$$),$JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$inline_14993_state$jscomp$111$$):$JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$($e$jscomp$inline_14993_state$jscomp$111$$);throw $e52204$jscomp$inline_14996$$;}$JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$=
void 0}return $JSCompiler_temp_const$jscomp$14360__$jscomp$1521$$.call($APP.$cljs$core$assoc$$,$e$jscomp$inline_14993_state$jscomp$111$$,$APP.$cljs$cst$2180$router$$,$JSCompiler_inline_result$jscomp$14362_fexpr__52206$jscomp$inline_14995$$)});return new $app$main$router$initialize_router_52256$$($routes$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$router$initialize_history$$=function(){var $on_change$jscomp$3$$=$app$main$ui$routes$on_navigate$$;typeof $app$main$router$initialize_history_52459$$===
"undefined"&&($app$main$router$initialize_history_52459$$=function($on_change$jscomp$4$$,$meta52460$$){this.$on_change$=$on_change$jscomp$4$$;this.$meta52460$=$meta52460$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$router$initialize_history_52459$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_history_52459$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2475$app_DOT_main_DOT_router_SLASH_initialize_history$$},
$app$main$router$initialize_history_52459$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52461$$,$meta52460__$1$$){return new $app$main$router$initialize_history_52459$$(this.$on_change$,$meta52460__$1$$)},$app$main$router$initialize_history_52459$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52460$},$app$main$router$initialize_history_52459$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_history_52459$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1532_instance$jscomp$inline_10039$$,$state$jscomp$117$$){$_$jscomp$1532_instance$jscomp$inline_10039$$=new $goog$history$Html5History$$(null,new $$jscomp$scope$m1810428007$0$TokenTransformer$$);$_$jscomp$1532_instance$jscomp$inline_10039$$.$useFragment_$!=1&&($APP.$goog$events$listen$$($_$jscomp$1532_instance$jscomp$inline_10039$$.$window_$,"hashchange",$_$jscomp$1532_instance$jscomp$inline_10039$$.$onHistoryEvent_$,!1,$_$jscomp$1532_instance$jscomp$inline_10039$$),$_$jscomp$1532_instance$jscomp$inline_10039$$.$useFragment_$=
!0);$JSCompiler_StaticMethods_setEnabled$$($_$jscomp$1532_instance$jscomp$inline_10039$$,!0);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$117$$,$APP.$cljs$cst$2468$history$$,$_$jscomp$1532_instance$jscomp$inline_10039$$)},$app$main$router$initialize_history_52459$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$router$initialize_history_52459$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1533_stopper$jscomp$3$$,
$state$jscomp$118$$,$stream$jscomp$19$$){var $self__$jscomp$3273$$=this;$_$jscomp$1533_stopper$jscomp$3$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2475$app_DOT_main_DOT_router_SLASH_initialize_history$$),$stream$jscomp$19$$);var $history__$1$jscomp$2$$=$APP.$cljs$cst$2468$history$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$118$$),$router$jscomp$5$$=$APP.$cljs$cst$2180$router$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$118$$);
$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $G__52468$$=$history__$1$jscomp$2$$.getToken();return $self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$($router$jscomp$5$$,$G__52468$$,!0):$self__$jscomp$3273$$.$on_change$($router$jscomp$5$$,$G__52468$$,!0)});return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($new_url$jscomp$1_p__52471$$){var $old_path$jscomp$inline_10050_old_url$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_url$jscomp$1_p__52471$$,0,null);$new_url$jscomp$1_p__52471$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_url$jscomp$1_p__52471$$,1,null);if($new_url$jscomp$1_p__52471$$!=null){var $JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$;if(!($JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$=$old_path$jscomp$inline_10050_old_url$jscomp$1$$==null)){var $old_params$jscomp$inline_10051_params$jscomp$inline_10045$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$1944$team_id$$],null),$new_params$jscomp$inline_10048_new_uri$jscomp$inline_10046$$=$APP.$app$common$uri$uri$$($new_url$jscomp$1_p__52471$$);$JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_params$jscomp$inline_10048_new_uri$jscomp$inline_10046$$);
$new_params$jscomp$inline_10048_new_uri$jscomp$inline_10046$$=$APP.$cljs$core$select_keys$$($app$common$uri$query_string__GT_map$$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($new_params$jscomp$inline_10048_new_uri$jscomp$inline_10046$$)),$old_params$jscomp$inline_10051_params$jscomp$inline_10045$$);var $old_uri$jscomp$inline_10049$$=$APP.$app$common$uri$uri$$($old_path$jscomp$inline_10050_old_url$jscomp$1$$);$old_path$jscomp$inline_10050_old_url$jscomp$1$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($old_uri$jscomp$inline_10049$$);
$old_params$jscomp$inline_10051_params$jscomp$inline_10045$$=$APP.$cljs$core$select_keys$$($app$common$uri$query_string__GT_map$$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($old_uri$jscomp$inline_10049$$)),$old_params$jscomp$inline_10051_params$jscomp$inline_10045$$);$JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_path$jscomp$inline_10050_old_url$jscomp$1$$,$JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$)||
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_params$jscomp$inline_10048_new_uri$jscomp$inline_10046$$,$old_params$jscomp$inline_10051_params$jscomp$inline_10045$$)}return $self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$?$self__$jscomp$3273$$.$on_change$.$cljs$core$IFn$_invoke$arity$3$($router$jscomp$5$$,$new_url$jscomp$1_p__52471$$,$JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$):$self__$jscomp$3273$$.$on_change$($router$jscomp$5$$,$new_url$jscomp$1_p__52471$$,
$JSCompiler_temp$jscomp$2118_new_path$jscomp$inline_10047_send_QMARK_$$)}return null},$APP.$beicon$v2$core$take_until$$($_$jscomp$1533_stopper$jscomp$3$$,$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(null,null),$APP.$beicon$v2$core$create$$(function($subs$jscomp$14$$){var $key$jscomp$328$$=$APP.$goog$events$listen$$($history__$1$jscomp$2$$,"navigate",function($o$jscomp$261$$){return $subs$jscomp$14$$.next($o$jscomp$261$$.token)});
return function(){$JSCompiler_StaticMethods_setEnabled$$($history__$1$jscomp$2$$,!1);return $APP.$goog$events$unlistenByKey$$($key$jscomp$328$$)}})))))});return new $app$main$router$initialize_history_52459$$($on_change$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$router$match$$=function($router$jscomp$3_temp__5825__auto__$jscomp$145$$,$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$){$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$=$APP.$app$common$uri$uri$$($path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$);
$router$jscomp$3_temp__5825__auto__$jscomp$145$$=$reitit$core$match_by_path$$($router$jscomp$3_temp__5825__auto__$jscomp$145$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$));if($APP.$cljs$core$truth_$$($router$jscomp$3_temp__5825__auto__$jscomp$145$$)){$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$=$app$common$uri$query_string__GT_map$$($APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$));
var $params$jscomp$137$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$2406$path_params$$.$cljs$core$IFn$_invoke$arity$1$($router$jscomp$3_temp__5825__auto__$jscomp$145$$),$APP.$cljs$cst$747$query$$,$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$],null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($router$jscomp$3_temp__5825__auto__$jscomp$145$$,$APP.$cljs$cst$1435$params$$,
$params$jscomp$137$$),$APP.$cljs$cst$2278$query_params$$,$path$jscomp$223_query_params$jscomp$2_uri$jscomp$69$$)}return null},$app$main$rasterizer$on_message$$=function($evdata_event$jscomp$91$$){var $evorigin_message$jscomp$inline_10055_type$jscomp$478$$=$evdata_event$jscomp$91$$.origin;$evdata_event$jscomp$91$$=$evdata_event$jscomp$91$$.data;if($APP.$cljs$core$object_QMARK_$$($evdata_event$jscomp$91$$)&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$app$main$rasterizer$origin$$,$evorigin_message$jscomp$inline_10055_type$jscomp$478$$)&&
($evorigin_message$jscomp$inline_10055_type$jscomp$478$$=$evdata_event$jscomp$91$$.type,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("penpot/rasterizer",$evdata_event$jscomp$91$$.scope))){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($evorigin_message$jscomp$inline_10055_type$jscomp$478$$,"ready"))a:for($APP.$app$main$rasterizer$ready_QMARK_$$=!0,$evorigin_message$jscomp$inline_10055_type$jscomp$478$$=$APP.$app$main$rasterizer$queue$$.shift();;)if($evorigin_message$jscomp$inline_10055_type$jscomp$478$$!=
null)$APP.$app$main$rasterizer$send_message_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$rasterizer$send_message_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($evorigin_message$jscomp$inline_10055_type$jscomp$478$$):$APP.$app$main$rasterizer$send_message_BANG_$$($evorigin_message$jscomp$inline_10055_type$jscomp$478$$),$evorigin_message$jscomp$inline_10055_type$jscomp$478$$=$APP.$app$main$rasterizer$queue$$.shift();else break a;return $APP.$app$main$rasterizer$msgbus$$.next($evdata_event$jscomp$91$$)}return null},
$app$main$data$workspace$zoom$fit_to_shapes$$=function($ids$jscomp$65$$){typeof $app$main$data$workspace$zoom$fit_to_shapes_66414$$==="undefined"&&($app$main$data$workspace$zoom$fit_to_shapes_66414$$=function($ids$jscomp$66$$,$meta66415$$){this.ids=$ids$jscomp$66$$;this.$meta66415$=$meta66415$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3638$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_fit_to_shapes$$},$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66416$$,$meta66415__$1$$){return new $app$main$data$workspace$zoom$fit_to_shapes_66414$$(this.ids,$meta66415__$1$$)},$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66415$},$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1922_page_id$jscomp$108$$,$state$jscomp$358$$){if($APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$358$$)||$APP.$cljs$core$empty_QMARK_$$(this.ids))return $state$jscomp$358$$;$_$jscomp$1922_page_id$jscomp$108$$=
$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$358$$);var $objects$jscomp$315$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$358$$,$_$jscomp$1922_page_id$jscomp$108$$),$srect$jscomp$5$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66409_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$315$$,$p1__66409_SHARP_$$)},
this.ids));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$358$$,$APP.$cljs$cst$1937$workspace_local$$,function($map__66428__$1_p__66427$$){$map__66428__$1_p__66427$$=$APP.$cljs$core$__destructure_map$$($map__66428__$1_p__66427$$);var $vport$jscomp$2_zoom$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66428__$1_p__66427$$,$APP.$cljs$cst$2211$vport$$),$srect__$1$jscomp$2$$=$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$($vport$jscomp$2_zoom$jscomp$10$$,
$srect$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$256$padding$$,40,$APP.$cljs$cst$3474$min_zoom$$,.01],null));$vport$jscomp$2_zoom$jscomp$10$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$2_zoom$jscomp$10$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect__$1$jscomp$2$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__66428__$1_p__66427$$,
$APP.$cljs$cst$2204$zoom$$,$vport$jscomp$2_zoom$jscomp$10$$),$APP.$cljs$cst$3630$zoom_inverse$$,1/$vport$jscomp$2_zoom$jscomp$10$$),$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$core$merge$$,$srect__$1$jscomp$2$$)})},$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$fit_to_shapes_66414$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1923$$,$state$jscomp$359$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$359$$)});
return new $app$main$data$workspace$zoom$fit_to_shapes_66414$$($ids$jscomp$65$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$util$worker$init$$=function(){var $on_error$jscomp$4$$=$app$main$worker$on_error$$,$instance$jscomp$9$$=new Worker($APP.$app$config$worker_uri$$),$bus$$=$APP.$beicon$v2$core$subject$$(),$worker$jscomp$10$$=new $app$util$worker$Worker$$($instance$jscomp$9$$,$bus$$.asObservable(),null,null,null);$instance$jscomp$9$$.addEventListener("message",function($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$){$G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$=
$G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$.data;var $sender_id$jscomp$inline_10058$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$,"senderId"),$reply_to$jscomp$inline_10059$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$,"replyTo"),$payload$jscomp$inline_10060$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$,
"payload"),$buffer$jscomp$inline_10061$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$,"buffer");$G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3135$sender_id$$,$APP.$cljs$core$truth_$$($sender_id$jscomp$inline_10058$$)?$APP.$cljs$core$uuid$$($sender_id$jscomp$inline_10058$$):
null,$APP.$cljs$cst$3136$reply_to$$,$APP.$cljs$core$truth_$$($reply_to$jscomp$inline_10059$$)?$APP.$cljs$core$uuid$$($reply_to$jscomp$inline_10059$$):null,$APP.$cljs$cst$3137$payload$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$,"cmd"),"initialize-indices")?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$3140$initialize_indices$$,
$APP.$cljs$cst$3141$file_raw$$,$payload$jscomp$inline_10060$$],null):$payload$jscomp$inline_10060$$!=null?$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($payload$jscomp$inline_10060$$):null,$APP.$cljs$cst$3138$buffer_QMARK_$$,$buffer$jscomp$inline_10061$$],null));return $APP.$cljs$core$truth_$$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$))?($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$=
$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$),$on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$):$on_error$jscomp$4$$($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$)):$bus$$.next($G__53864_data$jscomp$inline_10057_event$jscomp$79_message$jscomp$71$$)});$instance$jscomp$9$$.addEventListener("error",
function($G__53866_event$jscomp$80$$){$G__53866_event$jscomp$80$$=$G__53866_event$jscomp$80$$.data;return $on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_error$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($worker$jscomp$10$$,$G__53866_event$jscomp$80$$):$on_error$jscomp$4$$($worker$jscomp$10$$,$G__53866_event$jscomp$80$$)});return $worker$jscomp$10$$},$app$main$data$profile$mark_questions_as_answered$$=function($onboarding_questions$$){typeof $app$main$data$profile$mark_questions_as_answered_55208$$===
"undefined"&&($app$main$data$profile$mark_questions_as_answered_55208$$=function($onboarding_questions$jscomp$1$$,$meta55209$$){this.$onboarding_questions$=$onboarding_questions$jscomp$1$$;this.$meta55209$=$meta55209$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3254$app_DOT_main_DOT_data_DOT_profile_SLASH_mark_questions_as_answered$$},$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55210$$,$meta55209__$1$$){return new $app$main$data$profile$mark_questions_as_answered_55208$$(this.$onboarding_questions$,$meta55209__$1$$)},$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55209$},
$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1685$$,$state$jscomp$203$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$203$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,
$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3255$onboarding_questions_answered$$,!0)},$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_questions_as_answered_55208$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $props$jscomp$130$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3255$onboarding_questions_answered$$,!0,$APP.$cljs$cst$3256$onboarding_questions$$,
this.$onboarding_questions$],null);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3221$update_profile_props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,$props$jscomp$130$$],null)))});return new $app$main$data$profile$mark_questions_as_answered_55208$$($onboarding_questions$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$ui$static$0$nitrate_unavailable_STAR_$$=
function(){return(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_static__nitrate-unavailable-layout",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__nitrate-unavailable-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:"logo-nitrate-unavailable",className:"main_ui_static__nitrate-unavailable-logo"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_static__nitrate-unavailable-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.nitrate-unavailable.main-message")})]}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_static__nitrate-unavailable-footer",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.copyright-period")})]})},$app$main$ui$static$0$request_access_STAR_$$=function($on_close$jscomp$14_props_76133$$){var $is_default$$=$on_close$jscomp$14_props_76133$$.isDefault,$profile$jscomp$73$$=$on_close$jscomp$14_props_76133$$.profile,$team_id$jscomp$160$$=$on_close$jscomp$14_props_76133$$.teamId,$file_id$jscomp$368$$=$on_close$jscomp$14_props_76133$$.fileId,
$is_workspace$$=$on_close$jscomp$14_props_76133$$.isWorkspace,$requested_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5521$sent$$,!1,$APP.$cljs$cst$5522$already_requested$$,!1],null)),$requested$$=$APP.$cljs$core$_deref$$($requested_STAR_$$);$on_close$jscomp$14_props_76133$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$73$$)],function(){var $team_id__$1$jscomp$13$$=
$APP.$cljs$cst$2507$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$73$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,$team_id__$1$jscomp$13$$])))});var $on_success$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($requested_STAR_$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5521$sent$$,!0,$APP.$cljs$cst$5522$already_requested$$,!1],null))}),$on_error$jscomp$72$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($requested_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5521$sent$$,!0,$APP.$cljs$cst$5522$already_requested$$,!0],null))}),$on_request_access$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$368$$),
$APP.$rumext$v2$adapt$$($team_id$jscomp$160$$),$APP.$rumext$v2$adapt$$($is_workspace$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$create_team_access_request$$($APP.$cljs$core$with_meta$$($file_id$jscomp$368$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$368$$,$APP.$cljs$cst$5523$is_viewer$$,$APP.$cljs$core$not$$($is_workspace$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$160$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$on_success$jscomp$56$$,$APP.$cljs$cst$1300$on_error$$,$on_error$jscomp$72$$],null))))});return $APP.$cljs$core$truth_$$($is_default$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project"),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),
onClose:$on_close$jscomp$14_props_76133$$}):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$719$$=$file_id$jscomp$368$$!=null;return $and__5023__auto__$jscomp$719$$?$APP.$cljs$cst$5522$already_requested$$.$cljs$core$IFn$_invoke$arity$1$($requested$$):$and__5023__auto__$jscomp$719$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.file"),content:new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.or-others.file")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_76133$$}):$APP.$cljs$core$truth_$$($APP.$cljs$cst$5522$already_requested$$.$cljs$core$IFn$_invoke$arity$1$($requested$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.project"),content:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.already-requested.or-others.project")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_76133$$}):$APP.$cljs$core$truth_$$($APP.$cljs$cst$5521$sent$$.$cljs$core$IFn$_invoke$arity$1$($requested$$))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.done.success"),content:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.done.remember")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_76133$$}):
$file_id$jscomp$368$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.file"),content:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.you-can-ask.file"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.if-approves")],null),
buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.ask"),onButtonClick:$on_request_access$$,cancelText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_76133$$}):$team_id$jscomp$160$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_dialog_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project"),content:new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.you-can-ask.project"),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.if-approves")],null),buttonText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.ask"),onButtonClick:$on_request_access$$,cancelText:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.go-dashboard"),onClose:$on_close$jscomp$14_props_76133$$}):
null},$app$main$ui$static$0$internal_error_STAR_$$=function($props_76145_support_contact_click$$){var $report$jscomp$3$$=$props_76145_support_contact_click$$.report,$on_reset$$=$props_76145_support_contact_click$$.onReset,$report_uri$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_reset__$1$$=function(){return $APP.$cljs$core$truth_$$($on_reset$$)?$on_reset$$:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(null))}}();$props_76145_support_contact_click$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reset__$1$$),$APP.$rumext$v2$adapt$$($report$jscomp$3$$)],function(){$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$($on_reset__$1$$);var $error_report_id$$=$APP.$app$common$uuid$next$$(),$error_href$$=$APP.$app$util$globals$location$$.href;$APP.$app$main$errors$last_report$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$error_report_id$$,$APP.$cljs$cst$1642$content$$,
$report$jscomp$3$$],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2520$settings_feedback$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,"issue",$APP.$cljs$cst$5524$error_report_id$$,$error_report_id$$,$APP.$cljs$cst$5525$error_href$$,$error_href$$],null)))});var $on_download$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$292_temp__5825__auto__$jscomp$335$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$292_temp__5825__auto__$jscomp$335$$);
$event$jscomp$292_temp__5825__auto__$jscomp$335$$=$APP.$rumext$v2$ref_val$$($report_uri$$);return $APP.$cljs$core$truth_$$($event$jscomp$292_temp__5825__auto__$jscomp$335$$)?$APP.$app$util$dom$trigger_download_uri$$("report","text/plain",$event$jscomp$292_temp__5825__auto__$jscomp$335$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($report$jscomp$3$$)],function(){if($report$jscomp$3$$!=null){$APP.$app$main$errors$last_report$$=$report$jscomp$3$$;
var $uri$jscomp$107$$=$APP.$app$util$webapi$create_uri$$($APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($report$jscomp$3$$,"text/plain"));$APP.$rumext$v2$set_ref_val_BANG_$$($report_uri$$,$uri$jscomp$107$$);return function(){return $APP.$app$util$webapi$revoke_uri$$($uri$jscomp$107$$)}}return null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.internal-error.main-message")}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__desc-message",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_static__desc-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.internal-error.desc-message-first")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_static__desc-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.internal-error.desc-message-second")})]}),$report$jscomp$3$$!=null?(0,$APP.$rumext$v2$jsx$$)("a",
{onClick:$on_download$jscomp$1$$,className:"main_ui_static__download-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.download",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["report.txt"]))}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__buttons-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",className:"main_ui_static__support-btn",onClick:$props_76145_support_contact_click$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.contact-support")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_static__retry-btn",onClick:$on_reset__$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")})]})]})},$app$main$ui$static$0$service_unavailable_STAR_$$=function(){var $on_click$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(null))});
return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.service-unavailable.main-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.service-unavailable.desc-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__sign-info",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_click$jscomp$32$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")})})]})},$app$main$ui$static$0$bad_gateway_STAR_$$=function(){var $handle_retry$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(null))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,
{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.bad-gateway.main-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.bad-gateway.desc-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__sign-info",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_retry$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")})})]})},$app$main$ui$static$0$not_found_STAR_$$=function(){return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$static$0$error_container_STAR_$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__main-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.not-found.main-message")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.desc-message.error")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__desc-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.desc-message.doesnt-exist")})]})},$app$main$ui$auth$recovery_request$recovery_sent_page$$=function($email$jscomp$17_props_75616$$){$email$jscomp$17_props_75616$$=$email$jscomp$17_props_75616$$.email;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_auth_recovery_request__auth-form-wrapper main_ui_auth_recovery_request__register-success",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_auth_recovery_request__auth-title-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_auth_recovery_request__auth-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.check-email")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__notification-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.sent-recovery")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__notification-text-email",
children:$email$jscomp$17_props_75616$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_auth_recovery_request__notification-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.sent-recovery-check")})]})},$app$main$ui$forms$form_multi_input_STAR_$$=function($on_focus$jscomp$4_props_75485$$){var $name$jscomp$436$$=void 0,$valid_item_fn$jscomp$1$$=void 0,$caution_item_fn$jscomp$1$$=void 0,$trim$jscomp$5$$=void 0,$props$jscomp$268_props__$1$jscomp$62$$=void 0;
({name:$name$jscomp$436$$,trim:$trim$jscomp$5$$,validItemFn:$valid_item_fn$jscomp$1$$,cautionItemFn:$caution_item_fn$jscomp$1$$,...$props$jscomp$268_props__$1$jscomp$62$$}=$on_focus$jscomp$4_props_75485$$);var $form$jscomp$180$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$touched_QMARK_$jscomp$7$$=function(){var $and__5023__auto__$jscomp$692$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$180$$)),
$name$jscomp$436$$);return $and__5023__auto__$jscomp$692$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$180$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null)):$and__5023__auto__$jscomp$692$$}(),$value$jscomp$782$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$focus_QMARK_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$items$jscomp$55$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $initial$jscomp$33$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$180$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$name$jscomp$436$$],null));return $APP.$cljs$core$vector_QMARK_$$($initial$jscomp$33$$)||$APP.$cljs$core$set_QMARK_$$($initial$jscomp$33$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($val$jscomp$195$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1593$text$$,$val$jscomp$195$$,$APP.$cljs$cst$4839$valid$$,$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$195$$):$valid_item_fn$jscomp$1$$($val$jscomp$195$$),$APP.$cljs$cst$4863$caution$$,$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$195$$):$caution_item_fn$jscomp$1$$($val$jscomp$195$$)],null)},$initial$jscomp$33$$):
$APP.$cljs$core$PersistentVector$EMPTY$$});$on_focus$jscomp$4_props_75485$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($focus_QMARK_$jscomp$3$$,!0)});var $on_change$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($content$jscomp$240_event$jscomp$227$$){$content$jscomp$240_event$jscomp$227$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($content$jscomp$240_event$jscomp$227$$));return $APP.$cljs$core$reset_BANG_$$($value$jscomp$782$$,
$content$jscomp$240_event$jscomp$227$$)}),$on_key_down$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($value$jscomp$782$$)),$APP.$rumext$v2$adapt$$($form$jscomp$180$$),$APP.$rumext$v2$adapt$$($name$jscomp$436$$),$APP.$rumext$v2$adapt$$($valid_item_fn$jscomp$1$$),$APP.$rumext$v2$adapt$$($caution_item_fn$jscomp$1$$),$APP.$rumext$v2$adapt$$($trim$jscomp$5$$)],function($event$jscomp$228$$){var $val$jscomp$196$$=function(){var $G__75486$$=
$APP.$cljs$core$_deref$$($value$jscomp$782$$);return $APP.$cljs$core$truth_$$($trim$jscomp$5$$)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__75486$$):$G__75486$$}();if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1064_or__5025__auto____$1$jscomp$115$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$228$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1064_or__5025__auto____$1$jscomp$115$$))return $or__5025__auto__$jscomp$1064_or__5025__auto____$1$jscomp$115$$;
$or__5025__auto__$jscomp$1064_or__5025__auto____$1$jscomp$115$$=(0,$APP.$app$util$keyboard$comma_QMARK_$$)($event$jscomp$228$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1064_or__5025__auto____$1$jscomp$115$$)?$or__5025__auto__$jscomp$1064_or__5025__auto____$1$jscomp$115$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$228$$)}()))if($APP.$app$util$dom$prevent_default$$($event$jscomp$228$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$228$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$180$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null),!0),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$693$$=$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$196$$):$valid_item_fn$jscomp$1$$($val$jscomp$196$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$693$$)?!$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$782$$)):
$and__5023__auto__$jscomp$693$$}())){$APP.$cljs$core$reset_BANG_$$($value$jscomp$782$$,"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$180$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null),!1);for(var $G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$=$APP.$cljs$core$seq$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($val$jscomp$196$$,
/,|\s+/)),$G__75515_chunk__75488_v_75518__$1$$=null,$G__75516_c__5548__auto__$jscomp$34_count__75489$$=0,$i__75490$$=0;;)if($i__75490$$<$G__75516_c__5548__auto__$jscomp$34_count__75489$$){var $v$jscomp$636_v_75509__$1$$=$G__75515_chunk__75488_v_75518__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__75490$$);$v$jscomp$636_v_75509__$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$636_v_75509__$1$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$55$$,
$app$main$ui$forms$conj_dedup$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1593$text$$,$v$jscomp$636_v_75509__$1$$,$APP.$cljs$cst$4839$valid$$,$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$636_v_75509__$1$$):$valid_item_fn$jscomp$1$$($v$jscomp$636_v_75509__$1$$),$APP.$cljs$cst$4863$caution$$,$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$636_v_75509__$1$$):
$caution_item_fn$jscomp$1$$($v$jscomp$636_v_75509__$1$$)],null));$i__75490$$+=1}else if($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$=$APP.$cljs$core$seq$$($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$)?($G__75516_c__5548__auto__$jscomp$34_count__75489$$=$APP.$cljs$core$_chunked_first$$($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$),
$G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$=$APP.$cljs$core$_chunked_rest$$($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$),$G__75515_chunk__75488_v_75518__$1$$=$G__75516_c__5548__auto__$jscomp$34_count__75489$$,$G__75516_c__5548__auto__$jscomp$34_count__75489$$=$APP.$cljs$core$count$$($G__75516_c__5548__auto__$jscomp$34_count__75489$$)):($v$jscomp$636_v_75509__$1$$=$APP.$cljs$core$first$$($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$),
$G__75515_chunk__75488_v_75518__$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$636_v_75509__$1$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$55$$,$app$main$ui$forms$conj_dedup$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1593$text$$,$G__75515_chunk__75488_v_75518__$1$$,$APP.$cljs$cst$4839$valid$$,$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__75515_chunk__75488_v_75518__$1$$):
$valid_item_fn$jscomp$1$$($G__75515_chunk__75488_v_75518__$1$$),$APP.$cljs$cst$4863$caution$$,$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__75515_chunk__75488_v_75518__$1$$):$caution_item_fn$jscomp$1$$($G__75515_chunk__75488_v_75518__$1$$)],null)),$G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$=$APP.$cljs$core$next$$($G__75514_seq__75487_seq__75487__$1_temp__5825__auto__$jscomp$319$$),$G__75515_chunk__75488_v_75518__$1$$=
null,$G__75516_c__5548__auto__$jscomp$34_count__75489$$=0),$i__75490$$=0;else return null}else return null;else return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$694$$=(0,$APP.$app$util$keyboard$backspace_QMARK_$$)($event$jscomp$228$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$694$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$782$$)):$and__5023__auto__$jscomp$694$$}())?($APP.$app$util$dom$prevent_default$$($event$jscomp$228$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$228$$),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$55$$,function($items__$1$jscomp$10$$){return $APP.$cljs$core$empty_QMARK_$$($items__$1$jscomp$10$$)?$items__$1$jscomp$10$$:$APP.$cljs$core$pop$$($items__$1$jscomp$10$$)})):null}),$on_paste$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$){var $G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$=
$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$.clipboardData.getData("text");var $G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$=($G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$=typeof $G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$==="string")?$APP.$cljs$core$re_find$$(/[,\s]/,$G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$):
$G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$;if($APP.$cljs$core$truth_$$($G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$)){$APP.$app$util$dom$prevent_default$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$);$APP.$app$util$dom$stop_propagation$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$180$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null),!0);$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$empty_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$trim$$,
$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$,/,|\s+/)));$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$APP.$cljs$core$seq$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$);$G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$=null;for(var $G__75539_i__75494_75526$$=
$G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$=0;;)if($G__75539_i__75494_75526$$<$G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$){var $part_75528$$=$G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__75539_i__75494_75526$$);$APP.$cljs$core$truth_$$($valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($part_75528$$):
$valid_item_fn$jscomp$1$$($part_75528$$))&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$55$$,$app$main$ui$forms$conj_dedup$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1593$text$$,$part_75528$$,$APP.$cljs$cst$4839$valid$$,!0,$APP.$cljs$cst$4863$caution$$,$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($part_75528$$):$caution_item_fn$jscomp$1$$($part_75528$$)],null));$G__75539_i__75494_75526$$+=
1}else if($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$APP.$cljs$core$seq$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$))$G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$=$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$)?
($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$APP.$cljs$core$_chunked_first$$($G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$),$G__75539_i__75494_75526$$=$APP.$cljs$core$_chunked_rest$$($G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$),$G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$=$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$,
$G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$=$APP.$cljs$core$count$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$),$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$G__75539_i__75494_75526$$):($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$APP.$cljs$core$first$$($G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$),
$APP.$cljs$core$truth_$$($valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$):$valid_item_fn$jscomp$1$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$))&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($items$jscomp$55$$,$app$main$ui$forms$conj_dedup$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1593$text$$,$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$,$APP.$cljs$cst$4839$valid$$,!0,$APP.$cljs$cst$4863$caution$$,$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$caution_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$):$caution_item_fn$jscomp$1$$($c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$)],
null)),$c__5548__auto___75538_event$jscomp$229_part_75543_parts$jscomp$24_seq__75491_75523_temp__5825__auto___75536$$=$APP.$cljs$core$next$$($G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$),$G__75540_chunk__75492_75524_paste_data$jscomp$1_seq__75491_75537__$1$$=null,$G__75541_JSCompiler_inline_result$jscomp$2119_and__5023__auto__$jscomp$inline_10063_count__75493_75525$$=0),$G__75539_i__75494_75526$$=0;else break;$APP.$cljs$core$reset_BANG_$$($value$jscomp$782$$,"");return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$180$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null),!1)}return null}),$on_blur$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($focus_QMARK_$jscomp$3$$,!1);return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$180$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null)))?null:$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$180$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$436$$],null),!0)}),$on_remove_item$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($item$jscomp$113$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$55$$,
function($p1__75484_SHARP_$$){return $APP.$cljs$core$filterv$$(function($x$jscomp$1243$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1243$$,$item$jscomp$113$$)},$p1__75484_SHARP_$$)})});$props$jscomp$268_props__$1$jscomp$62$$={...$props$jscomp$268_props__$1$jscomp$62$$,value:$APP.$cljs$core$_deref$$($value$jscomp$782$$),onChange:$on_change$jscomp$32$$,onFocus:$on_focus$jscomp$4_props_75485$$,onBlur:$on_blur$jscomp$6$$,onKeyDown:$on_key_down$jscomp$8$$,onPaste:$on_paste$jscomp$1$$,
hintType:$APP.$cljs$core$truth_$$(function(){var $G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$;if($APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$7$$)){if($G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$=!$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($value$jscomp$782$$)))$G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$=
$APP.$cljs$core$_deref$$($value$jscomp$782$$),$G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$=$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$):$valid_item_fn$jscomp$1$$($G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$),
$G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$=$APP.$cljs$core$not$$($G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$)}else $G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$=$touched_QMARK_$jscomp$7$$;return $G__75496$jscomp$inline_10065_JSCompiler_inline_result$jscomp$2122_JSCompiler_temp$jscomp$2120_JSCompiler_temp$jscomp$2121$$}())?
"error":null};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($items$jscomp$55$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($value$jscomp$782$$))],function(){var $combined$jscomp$2_data$jscomp$453_items_text$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$core$_deref$$($items$jscomp$55$$)),$val$jscomp$197$$=function(){var $G__75497$$=$APP.$cljs$core$_deref$$($value$jscomp$782$$);
return $APP.$cljs$core$truth_$$($trim$jscomp$5$$)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__75497$$):$G__75497$$}();$combined$jscomp$2_data$jscomp$453_items_text$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$697$$=$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$valid_item_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$197$$):$valid_item_fn$jscomp$1$$($val$jscomp$197$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$697$$)?
!$APP.$cuerdas$core$empty_QMARK_$$($val$jscomp$197$$):$and__5023__auto__$jscomp$697$$}())?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($combined$jscomp$2_data$jscomp$453_items_text$$,$val$jscomp$197$$):$combined$jscomp$2_data$jscomp$453_items_text$$;$combined$jscomp$2_data$jscomp$453_items_text$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$combined$jscomp$2_data$jscomp$453_items_text$$);return $APP.$app$util$forms$update_input_value_BANG_$$($form$jscomp$180$$,$name$jscomp$436$$,
$combined$jscomp$2_data$jscomp$453_items_text$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_forms__multi-input",children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$268_props__$1$jscomp$62$$),function(){var $temp__5825__auto__$jscomp$320$$=$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($items$jscomp$55$$));return $temp__5825__auto__$jscomp$320$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_forms__multi-input-chips",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$102$$,$item$jscomp$114$$){$out_arr__44092__auto__$jscomp$102$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_forms__multi-input-chip",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_forms__multi-input-chip-text",children:$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$114$$)}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",className:"main_ui_forms__multi-input-chip-icon",icon:"close",iconSize:"s","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.remove"),onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_remove_item$$,$item$jscomp$114$$)})]},$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$114$$)));return $out_arr__44092__auto__$jscomp$102$$},[],$temp__5825__auto__$jscomp$320$$)}):null}()]})},$app$main$data$profile$mark_onboarding_as_viewed$cljs$0core$0IFn$0_invoke$0arity$01$$=
function($p__55189$$){var $map__55190__$1$$=$APP.$cljs$core$__destructure_map$$($p__55189$$),$version$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55190__$1$$,$APP.$cljs$cst$1726$version$$);typeof $app$main$data$profile$mark_onboarding_as_viewed_55191$$==="undefined"&&($app$main$data$profile$mark_onboarding_as_viewed_55191$$=function($p__55189$jscomp$1$$,$map__55190$jscomp$1$$,$version$jscomp$14$$,$meta55192$$){this.$p__55189$=$p__55189$jscomp$1$$;this.$map__55190$=$map__55190$jscomp$1$$;
this.version=$version$jscomp$14$$;this.$meta55192$=$meta55192$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$profile$mark_onboarding_as_viewed_55191$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_onboarding_as_viewed_55191$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3251$app_DOT_main_DOT_data_DOT_profile_SLASH_mark_onboarding_as_viewed$$},$app$main$data$profile$mark_onboarding_as_viewed_55191$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55193$$,$meta55192__$1$$){return new $app$main$data$profile$mark_onboarding_as_viewed_55191$$(this.$p__55189$,this.$map__55190$,this.version,$meta55192__$1$$)},$app$main$data$profile$mark_onboarding_as_viewed_55191$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55192$},$app$main$data$profile$mark_onboarding_as_viewed_55191$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$profile$mark_onboarding_as_viewed_55191$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$=this.version;$or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$)?$or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$:$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$);$or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3252$onboarding_viewed$$,!0,$APP.$cljs$cst$3253$release_notes_viewed$$,$or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$],null);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($APP.$app$main$data$profile$refresh_profile$$()),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3221$update_profile_props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,$or__5025__auto__$jscomp$inline_10067_props$jscomp$129_version__$1$$],
null)))});return new $app$main$data$profile$mark_onboarding_as_viewed_55191$$($p__55189$$,$map__55190__$1$$,$version$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$rasterizer$init_BANG_$$=function(){var $iframe$jscomp$3$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("iframe");$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"id","rasterizer");$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"src",$APP.$app$main$rasterizer$origin$$);
$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"hidden",!0);window.addEventListener("message",$app$main$rasterizer$on_message$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($allowed_QMARK_$$){if($APP.$cljs$core$truth_$$($allowed_QMARK_$$))$APP.$app$util$dom$append_child_BANG_$$(document.body,$iframe$jscomp$3$$);else{var $new_origin$jscomp$1$$=""+($APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"rasterizer.html"]))??"");$APP.$app$common$logging$enabled_QMARK_$$("app.main.rasterizer",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"fallback to main domain"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1792$origin$$,$new_origin$jscomp$1$$],null)],null)}),null,"app.main.rasterizer",$APP.$cljs$cst$1162$warn$$,!1);$APP.$app$util$dom$set_attribute_BANG_$$($iframe$jscomp$3$$,"src",$new_origin$jscomp$1$$);$APP.$app$util$dom$append_child_BANG_$$(document.body,$iframe$jscomp$3$$);$APP.$app$main$rasterizer$origin$$=$new_origin$jscomp$1$$;$APP.$app$config$rasterizer_uri$$=$APP.$app$config$public_uri$$}return $APP.$app$main$rasterizer$instance$$=$iframe$jscomp$3$$},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$81$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.rasterizer",
$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"rasterizer iframe blocked by adblocker"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1792$origin$$,$APP.$app$main$rasterizer$origin$$],
null)],null)}),$cause$jscomp$81$$,"app.main.rasterizer",$APP.$cljs$cst$849$error$$,!1);return(0,$APP.$beicon$v2$core$of$$)(!1)},$APP.$beicon$v2$core$map$$(function($allowed_QMARK_$jscomp$1_response$jscomp$12$$){($allowed_QMARK_$jscomp$1_response$jscomp$12$$=$APP.$cljs$core$not$$($allowed_QMARK_$jscomp$1_response$jscomp$12$$.redirected))||$APP.$app$common$logging$enabled_QMARK_$$("app.main.rasterizer",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"rasterizer iframe blocked by adblocker"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1792$origin$$,$APP.$app$main$rasterizer$origin$$],null)],null)}),null,"app.main.rasterizer",$APP.$cljs$cst$849$error$$,!1);return $allowed_QMARK_$jscomp$1_response$jscomp$12$$},
$APP.$app$util$http$fetch$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$3818$head$$,$APP.$cljs$cst$1584$uri$$,$APP.$app$config$rasterizer_uri$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$3747$no_cors$$],null)))))},$app$main$data$event$persist_events$$=function($events$jscomp$2$$){if($APP.$cljs$core$seq$$($events$jscomp$2$$)){var $uri$jscomp$68$$=$APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"api/main/methods/push-audit-events"]));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)(null)},$APP.$beicon$v2$core$mapcat$$($APP.$app$main$repo$handle_response$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1584$uri$$,$uri$jscomp$68$$,$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$2285$post$$,$APP.$cljs$cst$1588$credentials$$,"include",$APP.$cljs$cst$1586$body$$,new $APP.$app$util$http$t_app$0util$0http45186$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2326$events$$,$events$jscomp$2$$],null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)],null))))}return(0,$APP.$beicon$v2$core$of$$)(null)},$app$main$data$event$initialize$$=function(){typeof $app$main$data$event$initialize_50633$$==="undefined"&&($app$main$data$event$initialize_50633$$=function($meta50634$$){this.$meta50634$=$meta50634$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$event$initialize_50633$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$initialize_50633$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2335$app_DOT_main_DOT_data_DOT_event_SLASH_initialize$$},$app$main$data$event$initialize_50633$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50635$$,$meta50634__$1$$){return new $app$main$data$event$initialize_50633$$($meta50634__$1$$)},$app$main$data$event$initialize_50633$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50634$},
$app$main$data$event$initialize_50633$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$initialize_50633$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$event$store_performace_info$$())},$app$main$data$event$initialize_50633$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$event$initialize_50633$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function($_$jscomp$1425$$,$___$1$jscomp$811$$,$stream$jscomp$17$$){var $session$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$stopper$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2335$app_DOT_main_DOT_data_DOT_event_SLASH_initialize$$),$stream$jscomp$17$$),$buffer$jscomp$62$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,
$APP.$cljs$core$PersistentVector$EMPTY$$)),$profile$jscomp$1$$=$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$($APP.$cljs$cst$266$id$$,$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1931$profile$$,$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$storage$user$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1331$emit_current_value_QMARK_$$,!0],null)))));$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event instrumentation initialized"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function($chunk$jscomp$18$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2336$app_DOT_main_DOT_data_DOT_event_SLASH_chunk_persisted$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2337$chunk$$,$chunk$jscomp$18$$],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($buffer$jscomp$62$$,$app$main$data$event$remove_from_buffer$$,$APP.$cljs$core$count$$($chunk$jscomp$18$$))},function($cause$jscomp$37$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unexpected error on audit persistence"],null)],null)}),$cause$jscomp$37$$,"app.main.data.event",$APP.$cljs$cst$849$error$$,!1);return null},function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"audit persistence terminated"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$take_until$$($stopper$$,$APP.$beicon$v2$core$mapcat$$(function($events$jscomp$3_p__50661$$){var $chunk$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($events$jscomp$3_p__50661$$,
0,null),$profile_id$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($events$jscomp$3_p__50661$$,1,null);$events$jscomp$3_p__50661$$=$APP.$cljs$core$filterv$$(function($p1__50617_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$7$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__50617_SHARP_$$))},$chunk$jscomp$19$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($chunk$jscomp$19$$),$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"events chunk persisted"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2338$total$$,$APP.$cljs$core$count$$($chunk$jscomp$19$$)],
null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return null},$app$main$data$event$persist_events$$($events$jscomp$3_p__50661$$)))},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$APP.$beicon$v2$core$map$$(function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(100),$APP.$cljs$core$_deref$$($buffer$jscomp$62$$))},
$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2339$app_DOT_main_DOT_data_DOT_event_SLASH_force_persist$$),$stream$jscomp$17$$),$APP.$beicon$v2$core$debounce$$(2E3,$APP.$beicon$v2$core$filter$$(function($p1__50616_SHARP_$$){return $APP.$cljs$core$count$$($p1__50616_SHARP_$$)>0},$APP.$beicon$v2$core$from_atom$cljs$0core$0IFn$0_invoke$0arity$02$$($buffer$jscomp$62$$,null))),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2340$async$$,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2341$app_DOT_main_DOT_data_DOT_profile_SLASH_logout$$),$stream$jscomp$17$$))))))));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"session reinitialized"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$reset_BANG_$$($session$$,null)},function($cause$jscomp$38$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"error on event batching stream"],null)],null)}),$cause$jscomp$38$$,"app.main.data.event",$APP.$cljs$cst$849$error$$,!1);return null},function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"events batching stream terminated"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$take_until$$($stopper$$,$APP.$beicon$v2$core$switch_map$$(function(){return(0,$APP.$beicon$v2$core$timer$$)(18E5)},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($event$jscomp$67$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event enqueued"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($buffer$jscomp$62$$,
$app$main$data$event$append_to_buffer$$,$event$jscomp$67$$)},$APP.$beicon$v2$core$map$$(function($event$jscomp$68$$){var $or__5025__auto__$jscomp$inline_10069_session_STAR_$$=$APP.$cljs$core$_deref$$($session$$);$or__5025__auto__$jscomp$inline_10069_session_STAR_$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_10069_session_STAR_$$)?$or__5025__auto__$jscomp$inline_10069_session_STAR_$$:$APP.$app$common$time$now$$();var $JSCompiler_temp_const$jscomp$11344_context$jscomp$27$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;
var $JSCompiler_inline_result$jscomp$11346_context$jscomp$inline_14183$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_deref$$($APP.$app$main$data$event$context$$),$APP.$cljs$cst$2320$context$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$68$$)])),
$APP.$cljs$cst$2342$session$$,$or__5025__auto__$jscomp$inline_10069_session_STAR_$$),$APP.$cljs$cst$2343$session_id$$,$APP.$app$config$session_id$$),$APP.$cljs$cst$2344$external_session_id$$,$APP.$app$config$external_session_id$$());var $JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$global$$,"externalContextInfo");$JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$=
$APP.$cljs$core$fn_QMARK_$$($JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$)?$JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$.$cljs$core$IFn$_invoke$arity$0$?$JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$.$cljs$core$IFn$_invoke$arity$0$():$JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$():
null;$JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$=$APP.$app$common$json$__GT_clj$$($JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$);$JSCompiler_inline_result$jscomp$11346_context$jscomp$inline_14183$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$11346_context$jscomp$inline_14183$$,
$JSCompiler_inline_result$jscomp$inline_14184_external_context_info$jscomp$inline_14186_f$jscomp$inline_14185$$]));$JSCompiler_temp_const$jscomp$11344_context$jscomp$27$$=$JSCompiler_temp_const$jscomp$11344_context$jscomp$27$$.call($APP.$app$common$data$without_nils$$,$JSCompiler_inline_result$jscomp$11346_context$jscomp$inline_14183$$);$APP.$cljs$core$reset_BANG_$$($session$$,$or__5025__auto__$jscomp$inline_10069_session_STAR_$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$68$$,
$APP.$cljs$cst$2345$timestamp$$,$APP.$app$common$time$now$$()),$APP.$cljs$cst$2320$context$$,$JSCompiler_temp_const$jscomp$11344_context$jscomp$27$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$cst$2321$profile_id$$,$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$event$make_event$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$stream$jscomp$17$$)),$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$map$$($app$main$data$event$make_performance_event$$,
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$app$main$data$event$user_input_observer$$()))),$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$map$$($app$main$data$event$make_performance_event$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$app$main$data$event$longtask_observer$$()))),typeof globalThis!=="undefined"&&globalThis.requestAnimationFrame!=null&&globalThis.scheduler!=null&&globalThis.scheduler.postTask!=
null?$APP.$beicon$v2$core$debounce$$(1E3,$APP.$beicon$v2$core$merge_map$$($app$main$data$event$process_performance_event$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($profile$jscomp$1$$,$stream$jscomp$17$$))):$APP.$beicon$v2$core$empty$$())))))))},function($cause$jscomp$39$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unexpected error during event collection initialization"],null)],null)}),$cause$jscomp$39$$,"app.main.data.event",$APP.$cljs$cst$1162$warn$$,!1);return null},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($flags$jscomp$16$$){if($APP.$cljs$core$contains_QMARK_$$($flags$jscomp$16$$,$APP.$cljs$cst$1199$audit_log$$)||
$APP.$cljs$core$contains_QMARK_$$($flags$jscomp$16$$,$APP.$cljs$cst$1231$telemetry$$))return $APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event collection enabled"],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$flags$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$flags$jscomp$16$$))],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1),(0,$APP.$beicon$v2$core$of$$)(!0);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"event collection disabled (no audit-log or telemetry flag)"],null)],null)}),null,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$40$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.event",
$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unable to fetch backend flags, proceeding with event collection"],null)],null)}),$cause$jscomp$40$$,"app.main.data.event",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1231$telemetry$$,null],null),null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2346$get_enabled_flags$$)))))});return new $app$main$data$event$initialize_50633$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$team$team_initialized$$=function($team_id$jscomp$42$$){typeof $app$main$data$team$team_initialized_55552$$==="undefined"&&($app$main$data$team$team_initialized_55552$$=function($team_id$jscomp$43$$,
$meta55553$$){this.$team_id$=$team_id$jscomp$43$$;this.$meta55553$=$meta55553$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$team_initialized_55552$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_initialized_55552$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3328$app_DOT_main_DOT_data_DOT_team_SLASH_team_initialized$$},$app$main$data$team$team_initialized_55552$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55554$$,$meta55553__$1$$){return new $app$main$data$team$team_initialized_55552$$(this.$team_id$,$meta55553__$1$$)},$app$main$data$team$team_initialized_55552$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55553$},$app$main$data$team$team_initialized_55552$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_initialized_55552$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$,
$state$jscomp$218$$){$_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$218$$,$APP.$cljs$cst$2181$teams$$);$_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$,this.$team_id$);if($APP.$cljs$core$not$$($_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$))return $APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("authentication",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3181$authentication$$],null),null])),null));var $permissions$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$,$APP.$cljs$cst$1728$permissions$$);$_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$,$APP.$cljs$cst$227$features$$);return(0,$APP.$beicon$v2$core$of$$)(function($p1__55551_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55551_SHARP_$$,$APP.$cljs$cst$1728$permissions$$,$permissions$jscomp$6$$)},$APP.$app$main$features$initialize$$($_$jscomp$1714_features__$1$jscomp$12_team$jscomp$10_teams$jscomp$4$$),$APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(this.$team_id$))},
$app$main$data$team$team_initialized_55552$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$team_initialized_55552$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3299$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$,this.$team_id$)});return new $app$main$data$team$team_initialized_55552$$($team_id$jscomp$42$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$team$initialize_team$$=function($team_id$jscomp$44$$){typeof $app$main$data$team$initialize_team_55555$$==="undefined"&&($app$main$data$team$initialize_team_55555$$=function($team_id$jscomp$45$$,$meta55556$$){this.$team_id$=$team_id$jscomp$45$$;this.$meta55556$=$meta55556$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$initialize_team_55555$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$initialize_team_55555$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3329$app_DOT_main_DOT_data_DOT_team_SLASH_initialize_team$$},$app$main$data$team$initialize_team_55555$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55557$$,$meta55556__$1$$){return new $app$main$data$team$initialize_team_55555$$(this.$team_id$,$meta55556__$1$$)},$app$main$data$team$initialize_team_55555$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55556$},$app$main$data$team$initialize_team_55555$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$initialize_team_55555$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1716$$,$state$jscomp$219$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$219$$,$APP.$cljs$cst$1943$current_team_id$$,this.$team_id$)},$app$main$data$team$initialize_team_55555$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$initialize_team_55555$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1717_stopper$jscomp$4$$,$___$1$jscomp$1049$$,$stream$jscomp$31$$){$_$jscomp$1717_stopper$jscomp$4$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3330$app_DOT_main_DOT_data_DOT_team_SLASH_finalize_team$$),$stream$jscomp$31$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$1717_stopper$jscomp$4$$,
$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$()),$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$team_initialized$$,this.$team_id$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3300$app_DOT_main_DOT_data_DOT_team_SLASH_teams_fetched$$),$stream$jscomp$31$$))))});return new $app$main$data$team$initialize_team_55555$$($team_id$jscomp$44$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$plugins$utils$error_messages$$=function($explain$jscomp$3_msg$jscomp$30$$){$explain$jscomp$3_msg$jscomp$30$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(". ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($message$jscomp$94_p__55178$$){var $field$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$94_p__55178$$,0,null);$message$jscomp$94_p__55178$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$94_p__55178$$,
1,null);return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("plugins.validation.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$field$jscomp$1$$,$message$jscomp$94_p__55178$$]))},$app$plugins$utils$flatten_error_map$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$schema$messages$interpret_schema_problem$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($explain$jscomp$3_msg$jscomp$30$$)))));
return $APP.$cuerdas$core$blank_QMARK_$$($explain$jscomp$3_msg$jscomp$30$$)?null:$explain$jscomp$3_msg$jscomp$30$$},$app$plugins$utils$handle_error$$=function($plugin_id$jscomp$7$$){return function($cause$jscomp$71$$){var $explain$jscomp$4$$=$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$71$$)),$message$jscomp$95_throw_QMARK_$$=$app$plugins$utils$throw_validation_errors_QMARK_$$($plugin_id$jscomp$7$$);if($APP.$cljs$core$truth_$$($message$jscomp$95_throw_QMARK_$$?
$explain$jscomp$4$$:$message$jscomp$95_throw_QMARK_$$))return $app$plugins$utils$throw_not_valid$$($APP.$cljs$cst$849$error$$,$app$plugins$utils$error_messages$$($explain$jscomp$4$$));if($message$jscomp$95_throw_QMARK_$$)throw $cause$jscomp$71$$;$message$jscomp$95_throw_QMARK_$$=$APP.$cljs$core$truth_$$($explain$jscomp$4$$)?function(){console.error($APP.$app$common$schema$humanize_explain$$($explain$jscomp$4$$));var $or__5025__auto__$jscomp$650$$=$app$plugins$utils$error_messages$$($explain$jscomp$4$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$650$$)?$or__5025__auto__$jscomp$650$$:$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$explain$jscomp$4$$]))}():function(){var $or__5025__auto__$jscomp$651_or__5025__auto____$1$jscomp$81$$=$APP.$cljs$core$ex_data$$($cause$jscomp$71$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$651_or__5025__auto____$1$jscomp$81$$))return $or__5025__auto__$jscomp$651_or__5025__auto____$1$jscomp$81$$;
$or__5025__auto__$jscomp$651_or__5025__auto____$1$jscomp$81$$=$APP.$cljs$core$ex_message$$($cause$jscomp$71$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$651_or__5025__auto____$1$jscomp$81$$)?$or__5025__auto__$jscomp$651_or__5025__auto____$1$jscomp$81$$:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$71$$)}();console.log($cause$jscomp$71$$.stack);return $app$plugins$utils$not_valid$$($plugin_id$jscomp$7$$,$APP.$cljs$cst$849$error$$,$message$jscomp$95_throw_QMARK_$$)}},
$app$common$files$tokens$convert_dtcg_token$$=function($description$jscomp$15_token_attrs$jscomp$3$$){var $name$jscomp$370$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"name"),$type$jscomp$551_value__$1$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"type"),$value$jscomp$628$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"value");
$description$jscomp$15_token_attrs$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($description$jscomp$15_token_attrs$jscomp$3$$,"description");var $type__$1$jscomp$11$$=$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$551_value__$1$jscomp$21$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($type$jscomp$551_value__$1$jscomp$21$$);
$type$jscomp$551_value__$1$jscomp$21$$=function(){switch($type__$1$jscomp$11$$ instanceof $APP.$cljs$core$Keyword$$?$type__$1$jscomp$11$$.$fqn$:null){case "font-family":return $APP.$app$common$types$tokens_lib$convert_dtcg_font_family$$($value$jscomp$628$$);case "typography":return $APP.$app$common$types$tokens_lib$convert_dtcg_typography_composite$$($value$jscomp$628$$);case "shadow":return $APP.$app$common$types$tokens_lib$convert_dtcg_shadow_composite$$($value$jscomp$628$$);default:return $value$jscomp$628$$}}();
return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,$name$jscomp$370$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$11$$,$APP.$cljs$cst$260$value$$,typeof $type$jscomp$551_value__$1$jscomp$21$$==="number"?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$551_value__$1$jscomp$21$$):$type$jscomp$551_value__$1$jscomp$21$$,$APP.$cljs$cst$936$description$$,$description$jscomp$15_token_attrs$jscomp$3$$],
null))},$app$main$ui$static$0$login_modal_STAR_$$=function(){var $current_section$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1172$login$$),$user_email$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$register_token$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$set_section$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$291_section$jscomp$25$$){$event$jscomp$291_section$jscomp$25$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$291_section$jscomp$25$$),"section"));return $APP.$cljs$core$reset_BANG_$$($current_section$$,$event$jscomp$291_section$jscomp$25$$)}),$set_section_recovery$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$5516$recovery_request$$)}),$set_section_login$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($current_section$$,
$APP.$cljs$cst$1172$login$$)}),$success_login$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$reload$$())}),$success_register$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$460$$){$APP.$cljs$core$reset_BANG_$$($register_token$$,$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$460$$));return $APP.$cljs$core$reset_BANG_$$($current_section$$,
$APP.$cljs$cst$5517$register_validate$$)}),$register_email_sent$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($email$jscomp$19$$){$APP.$cljs$core$reset_BANG_$$($user_email$$,$email$jscomp$19$$);return $APP.$cljs$core$reset_BANG_$$($current_section$$,$APP.$cljs$cst$5518$register_email_sent$$)}),$recovery_email_sent$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($email$jscomp$20$$){$APP.$cljs$core$reset_BANG_$$($user_email$$,$email$jscomp$20$$);return $APP.$cljs$core$reset_BANG_$$($current_section$$,
$APP.$cljs$cst$5519$recovery_email_sent$$)}),$on_nav_root$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$navigate$$($APP.$cljs$cst$3410$auth_login$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__dialog-login",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_static__modal-close",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_nav_root$jscomp$1$$,className:"main_ui_static__modal-close-button",children:$APP.$app$main$ui$icons$close$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__login",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo",children:$APP.$app$main$ui$icons$logo$$}),function(){var $G__76127_G__76127__$1$$=$APP.$cljs$core$_deref$$($current_section$$);$G__76127_G__76127__$1$$=
$G__76127_G__76127__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76127_G__76127__$1$$.$fqn$:null;switch($G__76127_G__76127__$1$$){case "login":return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.login")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.free")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$login$login_dialog_STAR_$$,{onRecoveryRequest:$set_section_recovery$$,onSuccessCallback:$success_login$$,handleRedirect:!0}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_static__separator"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__change-section",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register")," ",(0,$APP.$rumext$v2$jsx$$)("a",{"data-section":"register",onClick:$set_section$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register-submit")})]})]});
case "register":return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.signup-free")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__logo-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.login.start-using")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_methods_STAR_$$,
{onSuccessCallback:$success_register$$,hideSeparator:!0}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__separator"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__change-section",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.already-have-account")," ",(0,$APP.$rumext$v2$jsx$$)("a",{"data-section":"login",onClick:$set_section$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-here")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_static__links",children:[(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_static__separator"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$terms_register_STAR_$$,{})]})]});case "register-validate":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_form_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$_deref$$($register_token$$)],
null),onSuccessCallback:$register_email_sent$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__links",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__register",children:(0,$APP.$rumext$v2$jsx$$)("a",{"data-section":"register",onClick:$set_section$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.go-back")})})})]});case "register-email-sent":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__form-container",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_success_page_STAR_$$,
{params:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3207$email$$,$APP.$cljs$core$_deref$$($user_email$$),$APP.$cljs$cst$5520$hide_logo$$,!0],null)})});case "recovery-request":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$recovery_request$recovery_request_page$$,{"go-back-callback":$set_section_login$$,"on-success-callback":$recovery_email_sent$$});case "recovery-email-sent":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__form-container",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth$recovery_request$recovery_sent_page$$,
{email:$APP.$cljs$core$_deref$$($user_email$$)})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76127_G__76127__$1$$)].join(""));}}()]})]})})},$app$common$files$tokens$make_token_theme_schema$$=function($tokens_lib$jscomp$17$$,$group$jscomp$42$$,$name$jscomp$374$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$schema_COLON_token_theme_attrs$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1613$group$$,$APP.$app$common$files$tokens$make_token_theme_group_schema$$($tokens_lib$jscomp$17$$,$name$jscomp$374$$,null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$app$common$files$tokens$make_token_theme_name_schema$$($tokens_lib$jscomp$17$$,
$group$jscomp$42$$,null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_theme_description$$],null)],null)])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$3441$error_SLASH_field$$,$APP.$cljs$cst$2116$sets$$,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__72086_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.token-theme-not-existing-sets",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$cst$2116$sets$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__72086_SHARP_$$)))]))}],
null),function($map__72094__$1_p__72093_sets$jscomp$13$$){$map__72094__$1_p__72093_sets$jscomp$13$$=$APP.$cljs$core$__destructure_map$$($map__72094__$1_p__72093_sets$jscomp$13$$);$map__72094__$1_p__72093_sets$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72094__$1_p__72093_sets$jscomp$13$$,$APP.$cljs$cst$2116$sets$$);return $tokens_lib$jscomp$17$$==null||$APP.$cljs$core$every_QMARK_$$(function($p1__72089_SHARP_$$){return $APP.$app$common$types$tokens_lib$get_set_by_name$$($tokens_lib$jscomp$17$$,
$p1__72089_SHARP_$$)},$map__72094__$1_p__72093_sets$jscomp$13$$)}],null)],null)},$app$common$files$tokens$make_token_set_schema$$=function($tokens_lib$jscomp$14$$){return $APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$schema_COLON_token_set_attrs$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$app$common$files$tokens$make_token_set_name_schema$$($tokens_lib$jscomp$14$$,null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,function($p1__72074_SHARP_$$){return $APP.$app$common$types$tokens_lib$normalized_set_name_QMARK_$$($p1__72074_SHARP_$$)}],
null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$app$common$files$tokens$schema_COLON_token_set_description$$],null)],null)]))},$app$common$logic$tokens$generate_set_active_token_theme$$=function($changes$jscomp$290$$,$tokens_lib$jscomp$22$$,$id$jscomp$777$$,$active_QMARK_$$){return $APP.$cljs$core$truth_$$($active_QMARK_$$)?
$APP.$app$common$logic$tokens$generate_update_active_token_theme$$($changes$jscomp$290$$,$tokens_lib$jscomp$22$$,function($p1__72452_SHARP_$$){return $APP.$app$common$types$tokens_lib$activate_theme$$($p1__72452_SHARP_$$,$id$jscomp$777$$)}):$APP.$app$common$logic$tokens$generate_update_active_token_theme$$($changes$jscomp$290$$,$tokens_lib$jscomp$22$$,function($p1__72453_SHARP_$$){return $app$common$types$tokens_lib$deactivate_theme$$($p1__72453_SHARP_$$,$id$jscomp$777$$)})},$app$common$logic$tokens$generate_set_enabled_token_set$$=
function($changes$jscomp$287$$,$tokens_lib$jscomp$19$$,$set_name$jscomp$27$$,$enabled_QMARK_$jscomp$3$$){return $APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$3$$)?$APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$287$$,$tokens_lib$jscomp$19$$,function($p1__72436_SHARP_$$){return $app$common$types$tokens_lib$enable_set$$($p1__72436_SHARP_$$,$set_name$jscomp$27$$)}):$APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$287$$,$tokens_lib$jscomp$19$$,
function($p1__72437_SHARP_$$){return $app$common$types$tokens_lib$disable_set$$($p1__72437_SHARP_$$,$set_name$jscomp$27$$)})},$app$common$files$changes_builder$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$=function($changes$jscomp$33$$,$type$jscomp$428$$,$id$jscomp$355$$,$page_id$jscomp$60$$,$namespace$jscomp$13$$,$key$jscomp$368$$,$value$jscomp$524$$){var $data$jscomp$265$$=$APP.$cljs$cst$3193$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$33$$)),
$old_val$jscomp$1$$=function(){var $G__54024__$1$$=$type$jscomp$428$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$428$$.$fqn$:null;switch($G__54024__$1$$){case "file":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$1744$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$368$$);case "page":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,
$APP.$cljs$cst$1635$pages_index$$),$id$jscomp$355$$),$APP.$cljs$cst$873$options$$),$APP.$cljs$cst$1744$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$368$$);case "shape":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,
$APP.$cljs$cst$1635$pages_index$$),$page_id$jscomp$60$$),$APP.$cljs$cst$1636$objects$$),$id$jscomp$355$$),$APP.$cljs$cst$1744$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$368$$);case "color":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$2220$colors$$),
$id$jscomp$355$$),$APP.$cljs$cst$1744$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$368$$);case "typography":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$2223$typographies$$),$id$jscomp$355$$),$APP.$cljs$cst$1744$plugin_data$$),$namespace$jscomp$13$$),
$key$jscomp$368$$);case "component":return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$265$$,$APP.$cljs$cst$1643$components$$),$id$jscomp$355$$),$APP.$cljs$cst$1744$plugin_data$$),$namespace$jscomp$13$$),$key$jscomp$368$$);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__54024__$1$$)].join(""));}}(),$redo_change$$=function(){var $G__54031_G__54031__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2617$set_plugin_data$$,$APP.$cljs$cst$2618$object_type$$,$type$jscomp$428$$,$APP.$cljs$cst$394$namespace$$,$namespace$jscomp$13$$,$APP.$cljs$cst$302$key$$,$key$jscomp$368$$,$APP.$cljs$cst$260$value$$,$value$jscomp$524$$],null);$G__54031_G__54031__$1$$=$APP.$cljs$core$uuid_QMARK_$$($id$jscomp$355$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54031_G__54031__$1$$,$APP.$cljs$cst$2281$object_id$$,$id$jscomp$355$$):$G__54031_G__54031__$1$$;return $APP.$cljs$core$uuid_QMARK_$$($page_id$jscomp$60$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54031_G__54031__$1$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$60$$):$G__54031_G__54031__$1$$}(),$undo_change$$=function(){var $G__54034_G__54034__$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2617$set_plugin_data$$,$APP.$cljs$cst$2618$object_type$$,$type$jscomp$428$$,$APP.$cljs$cst$394$namespace$$,$namespace$jscomp$13$$,$APP.$cljs$cst$302$key$$,$key$jscomp$368$$,$APP.$cljs$cst$260$value$$,$old_val$jscomp$1$$],null);$G__54034_G__54034__$1$$=$APP.$cljs$core$uuid_QMARK_$$($id$jscomp$355$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54034_G__54034__$1$$,$APP.$cljs$cst$2281$object_id$$,$id$jscomp$355$$):$G__54034_G__54034__$1$$;return $APP.$cljs$core$uuid_QMARK_$$($page_id$jscomp$60$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__54034_G__54034__$1$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$60$$):$G__54034_G__54034__$1$$}();return $APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$33$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,$redo_change$$),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,$undo_change$$))},
$app$main$data$workspace$reorder_children$$=function($file_id$jscomp$281$$,$page_id$jscomp$278$$,$parent_id$jscomp$96$$,$children$jscomp$253$$){typeof $app$main$data$workspace$reorder_children_71983$$==="undefined"&&($app$main$data$workspace$reorder_children_71983$$=function($file_id$jscomp$282$$,$page_id$jscomp$279$$,$parent_id$jscomp$97$$,$children$jscomp$254$$,$meta71984$$){this.$file_id$=$file_id$jscomp$282$$;this.$page_id$=$page_id$jscomp$279$$;this.$parent_id$=$parent_id$jscomp$97$$;this.children=
$children$jscomp$254$$;this.$meta71984$=$meta71984$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$reorder_children_71983$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$reorder_children_71983$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4551$app_DOT_main_DOT_data_DOT_workspace_SLASH_reorder_children$$},$app$main$data$workspace$reorder_children_71983$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71985$$,$meta71984__$1$$){return new $app$main$data$workspace$reorder_children_71983$$(this.$file_id$,this.$page_id$,this.$parent_id$,this.children,$meta71984__$1$$)},$app$main$data$workspace$reorder_children_71983$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71984$},$app$main$data$workspace$reorder_children_71983$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$reorder_children_71983$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$281_it$jscomp$248_page_id__$1$jscomp$17$$,$state$jscomp$910$$){var $self__$jscomp$6313$$=this,$file_id__$1$jscomp$8_undo_id$jscomp$83$$=function(){var $or__5025__auto__$jscomp$886$$=$self__$jscomp$6313$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$886$$)?$or__5025__auto__$jscomp$886$$:$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$910$$)}();$changes$jscomp$281_it$jscomp$248_page_id__$1$jscomp$17$$=function(){var $or__5025__auto__$jscomp$887$$=
$self__$jscomp$6313$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$887$$)?$or__5025__auto__$jscomp$887$$:$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$910$$)}();var $objects$jscomp$669$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$910$$,$file_id__$1$jscomp$8_undo_id$jscomp$83$$,$changes$jscomp$281_it$jscomp$248_page_id__$1$jscomp$17$$);$file_id__$1$jscomp$8_undo_id$jscomp$83$$=Symbol();
$changes$jscomp$281_it$jscomp$248_page_id__$1$jscomp$17$$=$APP.$app$common$files$changes_builder$reorder_children$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,$changes$jscomp$281_it$jscomp$248_page_id__$1$jscomp$17$$),$objects$jscomp$669$$),$self__$jscomp$6313$$.$parent_id$,$self__$jscomp$6313$$.children);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($file_id__$1$jscomp$8_undo_id$jscomp$83$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$281_it$jscomp$248_page_id__$1$jscomp$17$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6313$$.$parent_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($file_id__$1$jscomp$8_undo_id$jscomp$83$$))});
return new $app$main$data$workspace$reorder_children_71983$$($file_id$jscomp$281$$,$page_id$jscomp$278$$,$parent_id$jscomp$96$$,$children$jscomp$253$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$set_shape_index$$=function($file_id$jscomp$279$$,$page_id$jscomp$276$$,$id$jscomp$752$$,$new_index$jscomp$4$$){typeof $app$main$data$workspace$set_shape_index_71980$$==="undefined"&&($app$main$data$workspace$set_shape_index_71980$$=function($file_id$jscomp$280$$,$page_id$jscomp$277$$,
$id$jscomp$753$$,$new_index$jscomp$5$$,$meta71981$$){this.$file_id$=$file_id$jscomp$280$$;this.$page_id$=$page_id$jscomp$277$$;this.id=$id$jscomp$753$$;this.$new_index$=$new_index$jscomp$5$$;this.$meta71981$=$meta71981$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_shape_index_71980$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_index_71980$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4550$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_shape_index$$},$app$main$data$workspace$set_shape_index_71980$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71982$$,$meta71981__$1$$){return new $app$main$data$workspace$set_shape_index_71980$$(this.$file_id$,this.$page_id$,this.id,this.$new_index$,$meta71981__$1$$)},$app$main$data$workspace$set_shape_index_71980$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71981$},$app$main$data$workspace$set_shape_index_71980$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_index_71980$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$280_it$jscomp$247_page_id__$1$jscomp$16$$,$state$jscomp$909$$){var $self__$jscomp$6309$$=this,$file_id__$1$jscomp$7_undo_id$jscomp$82$$=function(){var $or__5025__auto__$jscomp$884$$=$self__$jscomp$6309$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$884$$)?$or__5025__auto__$jscomp$884$$:$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$909$$)}();
$changes$jscomp$280_it$jscomp$247_page_id__$1$jscomp$16$$=function(){var $or__5025__auto__$jscomp$885$$=$self__$jscomp$6309$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$885$$)?$or__5025__auto__$jscomp$885$$:$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$909$$)}();var $objects$jscomp$668$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$909$$,$file_id__$1$jscomp$7_undo_id$jscomp$82$$,$changes$jscomp$280_it$jscomp$247_page_id__$1$jscomp$16$$);
$file_id__$1$jscomp$7_undo_id$jscomp$82$$=Symbol();var $shape$jscomp$759$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$668$$,$self__$jscomp$6309$$.id),$parent$jscomp$284$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$668$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$759$$)),$current_index$jscomp$4_new_index__$1$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$284$$),
$self__$jscomp$6309$$.id);$current_index$jscomp$4_new_index__$1$$=$self__$jscomp$6309$$.$new_index$>$current_index$jscomp$4_new_index__$1$$?$self__$jscomp$6309$$.$new_index$+1:$self__$jscomp$6309$$.$new_index$;$changes$jscomp$280_it$jscomp$247_page_id__$1$jscomp$16$$=$APP.$app$common$files$changes_builder$change_parent$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$280_it$jscomp$247_page_id__$1$jscomp$16$$),$objects$jscomp$668$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$284$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$759$$],null),$current_index$jscomp$4_new_index__$1$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($file_id__$1$jscomp$7_undo_id$jscomp$82$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$280_it$jscomp$247_page_id__$1$jscomp$16$$),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6309$$.id],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($file_id__$1$jscomp$7_undo_id$jscomp$82$$))});return new $app$main$data$workspace$set_shape_index_71980$$($file_id$jscomp$279$$,
$page_id$jscomp$276$$,$id$jscomp$752$$,$new_index$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$libraries$update_color_data$$=function($color$jscomp$64_color__$1$jscomp$6$$,$file_id$jscomp$135$$){$color$jscomp$64_color__$1$jscomp$6$$=(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$64_color__$1$jscomp$6$$));typeof $app$main$data$workspace$libraries$update_color_data_69655$$===
"undefined"&&($app$main$data$workspace$libraries$update_color_data_69655$$=function($color$jscomp$65$$,$file_id$jscomp$136$$,$meta69656$$){this.color=$color$jscomp$65$$;this.$file_id$=$file_id$jscomp$136$$;this.$meta69656$=$meta69656$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_color_data_69655$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_color_data_69655$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3975$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_color_data$$},$app$main$data$workspace$libraries$update_color_data_69655$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69657$$,$meta69656__$1$$){return new $app$main$data$workspace$libraries$update_color_data_69655$$(this.color,this.$file_id$,$meta69656__$1$$)},$app$main$data$workspace$libraries$update_color_data_69655$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69656$},
$app$main$data$workspace$libraries$update_color_data_69655$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_color_data_69655$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($color__$1$jscomp$7_it$jscomp$177$$,$state$jscomp$498$$){$color__$1$jscomp$7_it$jscomp$177$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.color,$APP.$cljs$cst$725$name$$,""+($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$(this.color)??
"")+"/"+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.color)??""));return $APP.$app$main$data$workspace$libraries$update_color_STAR_$$(this,$state$jscomp$498$$,$color__$1$jscomp$7_it$jscomp$177$$,this.$file_id$)});return new $app$main$data$workspace$libraries$update_color_data_69655$$($color$jscomp$64_color__$1$jscomp$6$$,$file_id$jscomp$135$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$groups$ungroup_shapes$$=function($var_args$jscomp$1233$$){for(var $args__5755__auto__$jscomp$225$$=
[],$len__5749__auto___67771$$=arguments.length,$i__5750__auto___67772$$=0;;)if($i__5750__auto___67772$$<$len__5749__auto___67771$$)$args__5755__auto__$jscomp$225$$.push(arguments[$i__5750__auto___67772$$]),$i__5750__auto___67772$$+=1;else break;return $APP.$app$main$data$workspace$groups$ungroup_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$225$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$225$$.slice(1),0,null):null)},$app$main$data$workspace$interactions$add_interaction$$=
function($page_id$jscomp$218$$,$shape_id$jscomp$118$$,$interaction$jscomp$38$$){typeof $app$main$data$workspace$interactions$add_interaction_70658$$==="undefined"&&($app$main$data$workspace$interactions$add_interaction_70658$$=function($page_id$jscomp$219$$,$shape_id$jscomp$119$$,$interaction$jscomp$39$$,$meta70659$$){this.$page_id$=$page_id$jscomp$219$$;this.$shape_id$=$shape_id$jscomp$119$$;this.interaction=$interaction$jscomp$39$$;this.$meta70659$=$meta70659$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_interaction_70658$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_interaction_70658$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4376$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_interaction$$},$app$main$data$workspace$interactions$add_interaction_70658$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70660$$,$meta70659__$1$$){return new $app$main$data$workspace$interactions$add_interaction_70658$$(this.$page_id$,this.$shape_id$,this.interaction,$meta70659__$1$$)},$app$main$data$workspace$interactions$add_interaction_70658$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70659$},$app$main$data$workspace$interactions$add_interaction_70658$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_interaction_70658$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2417_page_id__$1$jscomp$11$$,$state$jscomp$783$$){var $self__$jscomp$5768$$=this;$_$jscomp$2417_page_id__$1$jscomp$11$$=function(){var $or__5025__auto__$jscomp$862$$=$self__$jscomp$5768$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$862$$)?$or__5025__auto__$jscomp$862$$:$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$783$$)}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5768$$.$shape_id$],null),function($shape$jscomp$710$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$710$$,$APP.$cljs$cst$2059$interactions$$,$APP.$app$common$types$shape$interactions$add_interaction$$,$self__$jscomp$5768$$.interaction)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2051$page_id$$,$_$jscomp$2417_page_id__$1$jscomp$11$$],null)),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5768$$.interaction))?
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5768$$.interaction)],null),$APP.$app$common$logic$shapes$show_in_viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2051$page_id$$,$_$jscomp$2417_page_id__$1$jscomp$11$$],null)):null,$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$interactions$flow_origin_QMARK_$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5768$$.interaction],null)))?$APP.$app$main$data$workspace$interactions$new_flow_event$$($state$jscomp$783$$,$_$jscomp$2417_page_id__$1$jscomp$11$$,$self__$jscomp$5768$$.$shape_id$):null)});return new $app$main$data$workspace$interactions$add_interaction_70658$$($page_id$jscomp$218$$,$shape_id$jscomp$118$$,$interaction$jscomp$38$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set$$=
function($name$jscomp$375$$,$enabled_QMARK_$jscomp$4$$){typeof $app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$=function($name$jscomp$376$$,$enabled_QMARK_$jscomp$5$$,$meta73101$$){this.name=$name$jscomp$376$$;this.$enabled_QMARK_$=$enabled_QMARK_$jscomp$5$$;this.$meta73101$=$meta73101$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4787$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_enabled_token_set$$},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73102$$,$meta73101__$1$$){return new $app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$(this.name,this.$enabled_QMARK_$,$meta73101__$1$$)},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73101$},$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2691_data$jscomp$414$$,$changes$jscomp$305_state$jscomp$995_tlib$$){$_$jscomp$2691_data$jscomp$414$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$305_state$jscomp$995_tlib$$);$changes$jscomp$305_state$jscomp$995_tlib$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$305_state$jscomp$995_tlib$$);$changes$jscomp$305_state$jscomp$995_tlib$$=$app$common$logic$tokens$generate_set_enabled_token_set$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$_$jscomp$2691_data$jscomp$414$$),$changes$jscomp$305_state$jscomp$995_tlib$$,this.name,this.$enabled_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$305_state$jscomp$995_tlib$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$($name$jscomp$375$$,$enabled_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$tokens$library_edit$set_token_theme_active$$=
function($id$jscomp$789$$,$active_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$=function($id$jscomp$790$$,$active_QMARK_$jscomp$2$$,$meta73011$$){this.id=$id$jscomp$790$$;this.$active_QMARK_$=$active_QMARK_$jscomp$2$$;this.$meta73011$=$meta73011$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4780$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_set_token_theme_active$$},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73012$$,$meta73011__$1$$){return new $app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$(this.id,
this.$active_QMARK_$,$meta73011__$1$$)},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73011$},$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2684_data$jscomp$408$$,
$changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$){$_$jscomp$2684_data$jscomp$408$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$);$changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$);$changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$=$app$common$logic$tokens$generate_set_active_token_theme$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$_$jscomp$2684_data$jscomp$408$$),$changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$,this.id,this.$active_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$298_state$jscomp$989_tokens_lib$jscomp$32$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$($id$jscomp$789$$,$active_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$workspace$texts$update_text_range$$=function($id$jscomp$618$$,$start$jscomp$225$$,$end$jscomp$91$$,$attrs$jscomp$123$$){typeof $app$main$data$workspace$texts$update_text_range_70318$$==="undefined"&&($app$main$data$workspace$texts$update_text_range_70318$$=function($id$jscomp$619$$,$start$jscomp$226$$,$end$jscomp$92$$,$attrs$jscomp$124$$,$meta70319$$){this.id=$id$jscomp$619$$;this.start=$start$jscomp$226$$;this.end=$end$jscomp$92$$;this.$attrs$=$attrs$jscomp$124$$;this.$meta70319$=
$meta70319$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_text_range_70318$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_range_70318$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4079$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_range$$},$app$main$data$workspace$texts$update_text_range_70318$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70320$$,$meta70319__$1$$){return new $app$main$data$workspace$texts$update_text_range_70318$$(this.id,this.start,this.end,this.$attrs$,$meta70319__$1$$)},$app$main$data$workspace$texts$update_text_range_70318$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70319$},$app$main$data$workspace$texts$update_text_range_70318$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_range_70318$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2185_objects$jscomp$518_shape_ids$jscomp$6$$,$state$jscomp$576$$){var $self__$jscomp$5003$$=this;$_$jscomp$2185_objects$jscomp$518_shape_ids$jscomp$6$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$576$$);var $shape$jscomp$582$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2185_objects$jscomp$518_shape_ids$jscomp$6$$,$self__$jscomp$5003$$.id);$_$jscomp$2185_objects$jscomp$518_shape_ids$jscomp$6$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$582$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5003$$.id],null):$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$582$$)?$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2185_objects$jscomp$518_shape_ids$jscomp$6$$,$self__$jscomp$5003$$.id):null;return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2185_objects$jscomp$518_shape_ids$jscomp$6$$,
function($JSCompiler_temp$jscomp$2096_shape__$1$jscomp$42$$){if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2096_shape__$1$jscomp$42$$)){var $new_content$jscomp$inline_10075_start$jscomp$inline_10072$$=$self__$jscomp$5003$$.start,$end$jscomp$inline_10073$$=$self__$jscomp$5003$$.end,$attrs$jscomp$inline_10074$$=$self__$jscomp$5003$$.$attrs$;$new_content$jscomp$inline_10075_start$jscomp$inline_10072$$=$app$main$data$workspace$texts$update_content_range$$($app$main$data$workspace$texts$split_content_at$$($app$main$data$workspace$texts$split_content_at$$($app$main$data$workspace$texts$decorate_range_info$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2096_shape__$1$jscomp$42$$)),
$new_content$jscomp$inline_10075_start$jscomp$inline_10072$$),$end$jscomp$inline_10073$$),$new_content$jscomp$inline_10075_start$jscomp$inline_10072$$,$end$jscomp$inline_10073$$,$attrs$jscomp$inline_10074$$);$JSCompiler_temp$jscomp$2096_shape__$1$jscomp$42$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2096_shape__$1$jscomp$42$$,$APP.$cljs$cst$1642$content$$,$new_content$jscomp$inline_10075_start$jscomp$inline_10072$$)}return $JSCompiler_temp$jscomp$2096_shape__$1$jscomp$42$$})),
$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$576$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5003$$.id)):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$texts$update_text_range_70318$$($id$jscomp$618$$,$start$jscomp$225$$,$end$jscomp$91$$,$attrs$jscomp$123$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$=
function($file_id$jscomp$68$$,$type$jscomp$442$$,$id$jscomp$421$$,$page_id$jscomp$86$$,$namespace$jscomp$16$$,$key$jscomp$375$$,$value$jscomp$537$$){typeof $app$main$data$plugins$set_file_plugin_data_66437$$==="undefined"&&($app$main$data$plugins$set_file_plugin_data_66437$$=function($file_id$jscomp$69$$,$type$jscomp$443$$,$id$jscomp$422$$,$page_id$jscomp$87$$,$namespace$jscomp$17$$,$key$jscomp$376$$,$value$jscomp$538$$,$meta66438$$){this.$file_id$=$file_id$jscomp$69$$;this.type=$type$jscomp$443$$;
this.id=$id$jscomp$422$$;this.$page_id$=$page_id$jscomp$87$$;this.$namespace$=$namespace$jscomp$17$$;this.key=$key$jscomp$376$$;this.value=$value$jscomp$538$$;this.$meta66438$=$meta66438$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$set_file_plugin_data_66437$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$set_file_plugin_data_66437$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3464$app_DOT_main_DOT_data_DOT_plugins_SLASH_set_file_plugin_data$$},$app$main$data$plugins$set_file_plugin_data_66437$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66439$$,$meta66438__$1$$){return new $app$main$data$plugins$set_file_plugin_data_66437$$(this.$file_id$,this.type,this.id,this.$page_id$,this.$namespace$,this.key,this.value,$meta66438__$1$$)},$app$main$data$plugins$set_file_plugin_data_66437$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66438$},$app$main$data$plugins$set_file_plugin_data_66437$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$set_file_plugin_data_66437$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$,$state$jscomp$256$$){$changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$256$$,
$APP.$cljs$cst$1933$files$$),this.$file_id$),$APP.$cljs$cst$142$data$$);$changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$=$app$common$files$changes_builder$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$),$APP.$cljs$cst$1649$file_id$$,
this.$file_id$),this.type,this.id,this.$page_id$,this.$namespace$,this.key,this.value);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$84_file_data$jscomp$69_it$jscomp$143$$))});return new $app$main$data$plugins$set_file_plugin_data_66437$$($file_id$jscomp$68$$,$type$jscomp$442$$,$id$jscomp$421$$,$page_id$jscomp$86$$,$namespace$jscomp$16$$,$key$jscomp$375$$,$value$jscomp$537$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$=
function($file_id$jscomp$67$$,$type$jscomp$441$$,$id$jscomp$420$$,$namespace$jscomp$15$$,$key$jscomp$374$$,$value$jscomp$536$$){return $app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$67$$,$type$jscomp$441$$,$id$jscomp$420$$,null,$namespace$jscomp$15$$,$key$jscomp$374$$,$value$jscomp$536$$)},$app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$=function($file_id$jscomp$66$$,$type$jscomp$440$$,$namespace$jscomp$14$$,$key$jscomp$373$$,
$value$jscomp$535$$){return $app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$66$$,$type$jscomp$440$$,null,null,$namespace$jscomp$14$$,$key$jscomp$373$$,$value$jscomp$535$$)},$app$main$data$workspace$groups$group_shapes$$=function($var_args$jscomp$1232$$){for(var $args__5755__auto__$jscomp$224$$=[],$len__5749__auto___67762$$=arguments.length,$i__5750__auto___67763$$=0;;)if($i__5750__auto___67763$$<$len__5749__auto___67762$$)$args__5755__auto__$jscomp$224$$.push(arguments[$i__5750__auto___67763$$]),
$i__5750__auto___67763$$+=1;else break;return $APP.$app$main$data$workspace$groups$group_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$224$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$224$$.slice(2),0,null):null)},$app$main$data$workspace$media$create_svg_shape_with_images$$=function($file_id$jscomp$113$$,$id$jscomp$522$$,$svg_string$jscomp$2$$,$position$jscomp$83$$,$on_success$jscomp$29$$,$on_error$jscomp$31$$){typeof $app$main$data$workspace$media$create_svg_shape_with_images_67964$$===
"undefined"&&($app$main$data$workspace$media$create_svg_shape_with_images_67964$$=function($file_id$jscomp$114$$,$id$jscomp$523$$,$name$jscomp$321$$,$svg_string$jscomp$3$$,$position$jscomp$84$$,$on_success$jscomp$30$$,$on_error$jscomp$32$$,$meta67965$$){this.$file_id$=$file_id$jscomp$114$$;this.id=$id$jscomp$523$$;this.name=$name$jscomp$321$$;this.$svg_string$=$svg_string$jscomp$3$$;this.position=$position$jscomp$84$$;this.$on_success$=$on_success$jscomp$30$$;this.$on_error$=$on_error$jscomp$32$$;
this.$meta67965$=$meta67965$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$create_svg_shape_with_images_67964$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_with_images_67964$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3762$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_create_svg_shape_with_images$$},$app$main$data$workspace$media$create_svg_shape_with_images_67964$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67966$$,$meta67965__$1$$){return new $app$main$data$workspace$media$create_svg_shape_with_images_67964$$(this.$file_id$,this.id,this.name,this.$svg_string$,this.position,this.$on_success$,this.$on_error$,$meta67965__$1$$)},$app$main$data$workspace$media$create_svg_shape_with_images_67964$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67965$},$app$main$data$workspace$media$create_svg_shape_with_images_67964$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$media$create_svg_shape_with_images_67964$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4450$$=this;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4450$$.$on_error$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4450$$.$on_success$,$APP.$beicon$v2$core$map$$(function($svg_data$jscomp$23$$){return $APP.$app$main$data$workspace$svg_upload$add_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4450$$.id,
$svg_data$jscomp$23$$,$self__$jscomp$4450$$.position,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3733$ignore_selection_QMARK_$$,!0,$APP.$cljs$cst$3669$change_selection_QMARK_$$,!1],null))},$APP.$beicon$v2$core$mapcat$$(function($svg_data$jscomp$24$$){return $APP.$beicon$v2$core$map$$(function($p1__67963_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($svg_data$jscomp$24$$,$APP.$cljs$cst$3726$image_data$$,$p1__67963_SHARP_$$)},$APP.$app$main$data$workspace$svg_upload$upload_images$$($svg_data$jscomp$24$$,
$self__$jscomp$4450$$.$file_id$))},$APP.$beicon$v2$core$take$$($APP.$app$main$data$workspace$media$svg__GT_clj$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4450$$.name,$self__$jscomp$4450$$.$svg_string$],null)))))))});return new $app$main$data$workspace$media$create_svg_shape_with_images_67964$$($file_id$jscomp$113$$,$id$jscomp$522$$,"svg",$svg_string$jscomp$2$$,$position$jscomp$83$$,$on_success$jscomp$29$$,$on_error$jscomp$31$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$workspace$media$create_svg_shape$$=function($id$jscomp$520$$,$svg_string$$){var $position$jscomp$81$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);typeof $app$main$data$workspace$media$create_svg_shape_67936$$==="undefined"&&($app$main$data$workspace$media$create_svg_shape_67936$$=function($id$jscomp$521$$,$name$jscomp$319$$,$svg_string$jscomp$1$$,$position$jscomp$82$$,$meta67937$$){this.id=$id$jscomp$521$$;this.name=$name$jscomp$319$$;this.$svg_string$=
$svg_string$jscomp$1$$;this.position=$position$jscomp$82$$;this.$meta67937$=$meta67937$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$create_svg_shape_67936$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_67936$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3761$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_create_svg_shape$$},
$app$main$data$workspace$media$create_svg_shape_67936$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67938$$,$meta67937__$1$$){return new $app$main$data$workspace$media$create_svg_shape_67936$$(this.id,this.name,this.$svg_string$,this.position,$meta67937__$1$$)},$app$main$data$workspace$media$create_svg_shape_67936$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67937$},$app$main$data$workspace$media$create_svg_shape_67936$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$create_svg_shape_67936$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4446$$=this;return $APP.$beicon$v2$core$map$$(function($p1__67935_SHARP_$$){return $APP.$app$main$data$workspace$svg_upload$add_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$4446$$.id,$p1__67935_SHARP_$$,$self__$jscomp$4446$$.position,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3733$ignore_selection_QMARK_$$,
!0,$APP.$cljs$cst$3669$change_selection_QMARK_$$,!1],null))},$APP.$beicon$v2$core$take$$($APP.$app$main$data$workspace$media$svg__GT_clj$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4446$$.name,$self__$jscomp$4446$$.$svg_string$],null))))});return new $app$main$data$workspace$media$create_svg_shape_67936$$($id$jscomp$520$$,"svg",$svg_string$$,$position$jscomp$81$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$data$workspace$versions$restore_version_from_plugin$$=
function($file_id$jscomp$336$$,$id$jscomp$875$$,$resolve$jscomp$39$$,$reject$jscomp$26$$){typeof $app$main$data$workspace$versions$restore_version_from_plugins_73809$$==="undefined"&&($app$main$data$workspace$versions$restore_version_from_plugins_73809$$=function($file_id$jscomp$337$$,$id$jscomp$876$$,$resolve$jscomp$40$$,$reject$jscomp$27$$,$meta73810$$){this.$file_id$=$file_id$jscomp$337$$;this.id=$id$jscomp$876$$;this.resolve=$resolve$jscomp$40$$;this.reject=$reject$jscomp$27$$;this.$meta73810$=
$meta73810$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$restore_version_from_plugins_73809$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_from_plugins_73809$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5168$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_restore_version_from_plugins$$},$app$main$data$workspace$versions$restore_version_from_plugins_73809$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73811$$,$meta73810__$1$$){return new $app$main$data$workspace$versions$restore_version_from_plugins_73809$$(this.$file_id$,this.id,this.resolve,this.reject,$meta73810__$1$$)},$app$main$data$workspace$versions$restore_version_from_plugins_73809$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73810$},$app$main$data$workspace$versions$restore_version_from_plugins_73809$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_from_plugins_73809$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$7111$$=this;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$85$$){$self__$jscomp$7111$$.reject.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$7111$$.reject.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$85$$):$self__$jscomp$7111$$.reject($error$jscomp$85$$);return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-version",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugins"],null)),$APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$versions$initialize_version$$()},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5158$restore_file_snapshot$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$7111$$.$file_id$,$APP.$cljs$cst$266$id$$,$self__$jscomp$7111$$.id],null))},$APP.$app$main$data$persistence$wait_persisted$cljs$0core$0IFn$0_invoke$0arity$01$$(null))),$APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7111$$.resolve,(0,$APP.$beicon$v2$core$of$$)(1)))))});return new $app$main$data$workspace$versions$restore_version_from_plugins_73809$$($file_id$jscomp$336$$,
$id$jscomp$875$$,$resolve$jscomp$39$$,$reject$jscomp$26$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$ui$static$0$context_wrapper_STAR_$$=function($props_76183$$){var $profile$jscomp$74$$=$props_76183$$.profile,$children$jscomp$292$$=$props_76183$$.children,$is_dashboard$$=$props_76183$$.isDashboard,$is_viewer$$=$props_76183$$.isViewer;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($props_76183$$.isWorkspace)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_static__workspace",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_static__workspace-left",children:[$APP.$app$main$ui$icons$logo_icon$$,(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__project-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project-name")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__file-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.penpot-file")})]})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__workspace-right"})]}):$APP.$cljs$core$truth_$$($is_viewer$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__viewer",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$viewer$header$header$$,{zoom:1,permissions:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5511$is_logged$$,!0],null),frame:null,index:0,section:$APP.$cljs$cst$2059$interactions$$,file:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.penpot-file")],null),"shown-thumbnails":!1,page:null,"interactions-mode":null,project:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("not-found.no-permission.project-name")],null)})}):$APP.$cljs$core$truth_$$($is_dashboard$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_static__dashboard",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_static__dashboard-sidebar",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$sidebar$sidebar_STAR_$$,{team:null,projects:$APP.$cljs$core$PersistentVector$EMPTY$$,project:$APP.$cljs$cst$2522$default_project_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$74$$),profile:$profile$jscomp$74$$,section:$APP.$cljs$cst$4865$dashboard_projects$$,searchTerm:""})})}):null,$children$jscomp$292$$]})},$app$main$ui$static$0$exception_section_STAR_$$=function($props_76169_props__$1$jscomp$69$$){var $data$jscomp$462$$=
$props_76169_props__$1$jscomp$69$$.data,$type$jscomp$606$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$462$$,$APP.$cljs$cst$139$type$$),$cause$jscomp$107$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$462$$,$APP.$cljs$cst$3418$app_DOT_main_DOT_errors_SLASH_instance$$),$report$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cause$jscomp$107$$)],function(){return $APP.$app$common$exceptions$exception_QMARK_$$($cause$jscomp$107$$)?
$APP.$app$main$errors$generate_report$$($cause$jscomp$107$$):null});$props_76169_props__$1$jscomp$69$$={...$props_76169_props__$1$jscomp$69$$,report:$report$jscomp$4$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($report$jscomp$4$$),$APP.$rumext$v2$adapt$$($type$jscomp$606$$),$APP.$rumext$v2$adapt$$($cause$jscomp$107$$)],function(){return $APP.$app$common$exceptions$exception_QMARK_$$($cause$jscomp$107$$)&&!$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3181$authentication$$,null,$APP.$cljs$cst$2676$not_found$$,null],null),null),$type$jscomp$606$$)?$APP.$app$main$errors$submit_report$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2325$event_name$$,"exception-page",$APP.$cljs$cst$572$report$$,$report$jscomp$4$$,$APP.$cljs$cst$275$hint$$,$APP.$app$common$exceptions$get_hint$$($cause$jscomp$107$$)])):null});switch($type$jscomp$606$$ instanceof
$APP.$cljs$core$Keyword$$?$type$jscomp$606$$.$fqn$:null){case "not-found":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$not_found_STAR_$$,{});case "authentication":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$not_found_STAR_$$,{});case "bad-gateway":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$bad_gateway_STAR_$$,$props_76169_props__$1$jscomp$69$$);case "service-unavailable":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$service_unavailable_STAR_$$,{});
case "nitrate-unavailable":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$nitrate_unavailable_STAR_$$,{});default:return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$internal_error_STAR_$$,$props_76169_props__$1$jscomp$69$$)}},$app$main$ui$static$0$exception_page_STAR_$$=function($props_76217$$){var $profile$jscomp$75_route$jscomp$20$$=$props_76217$$.route,$not_found_QMARK__type$jscomp$607$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($props_76217$$.data),$auth_error_QMARK__path$jscomp$258$$=
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$75_route$jscomp$20$$),$params$jscomp$417$$=$APP.$cljs$cst$2278$query_params$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$75_route$jscomp$20$$),$workspace_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($auth_error_QMARK__path$jscomp$258$$,"workspace"),$dashboard_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($auth_error_QMARK__path$jscomp$258$$,"dashboard"),$view_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($auth_error_QMARK__path$jscomp$258$$,
"view"),$info_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$info$jscomp$8$$=$APP.$cljs$core$_deref$$($info_STAR_$$);$profile$jscomp$75_route$jscomp$20$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$auth_error_QMARK__path$jscomp$258$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($not_found_QMARK__type$jscomp$607$$,$APP.$cljs$cst$3181$authentication$$);$not_found_QMARK__type$jscomp$607$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($not_found_QMARK__type$jscomp$607$$,
$APP.$cljs$cst$2676$not_found$$);var $authenticated_QMARK_$$=$APP.$app$main$data$auth$is_authenticated_QMARK_$$($profile$jscomp$75_route$jscomp$20$$),$initial_authenticated_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $authenticated_QMARK_$$}),$request_access_QMARK_$$=function(){var $and__5023__auto__$jscomp$720$$=$APP.$cljs$core$truth_$$($workspace_QMARK_$$)?$workspace_QMARK_$$:$APP.$cljs$core$truth_$$($dashboard_QMARK_$$)?$dashboard_QMARK_$$:$view_QMARK_$$;
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$720$$)?$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$)!=null||$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$)!=null:$and__5023__auto__$jscomp$720$$}();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($params$jscomp$417$$),$APP.$rumext$v2$adapt$$($info$jscomp$8$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5138$loaded$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$))?
null:$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$info_STAR_$$),$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$reset_BANG_$$,$info_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5138$loaded$$,!0],null)),$app$main$ui$static$0$load_info$$($params$jscomp$417$$))});return $auth_error_QMARK__path$jscomp$258$$||$not_found_QMARK__type$jscomp$607$$?
$authenticated_QMARK_$$?$APP.$cljs$core$not$$($initial_authenticated_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0}):$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($info$jscomp$8$$,$APP.$cljs$cst$5138$loaded$$,!1))?$APP.$cljs$core$truth_$$($request_access_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$context_wrapper_STAR_$$,{isWorkspace:$workspace_QMARK_$$,
isDashboard:$dashboard_QMARK_$$,isViewer:$view_QMARK_$$,profile:$profile$jscomp$75_route$jscomp$20$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$request_access_STAR_$$,{fileId:$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$),teamId:$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$),isDefault:$APP.$cljs$cst$5527$team_default$$.$cljs$core$IFn$_invoke$arity$1$($info$jscomp$8$$),profile:$profile$jscomp$75_route$jscomp$20$$,isWorkspace:$workspace_QMARK_$$})}):
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$exception_section_STAR_$$,$props_76217$$):null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$context_wrapper_STAR_$$,{isWorkspace:$workspace_QMARK_$$,isDashboard:$dashboard_QMARK_$$,isViewer:$view_QMARK_$$,profile:$profile$jscomp$75_route$jscomp$20$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$login_modal_STAR_$$,{})}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$static$0$exception_section_STAR_$$,$props_76217$$)},$app$common$types$objects_map$get_data$$=
function($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$){if($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$!=null&&$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$.$app$common$types$objects_map$IObjectsMap$get_data$arity$1$!=null)$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$=$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$.$app$common$types$objects_map$IObjectsMap$get_data$arity$1$($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$);else{var $m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$=
$app$common$types$objects_map$get_data$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$==null?null:$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$)];if($m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$!=null)$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$=$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$):
$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$);else if($m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$=$app$common$types$objects_map$get_data$$._,$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$!=null)$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$=$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$):
$m__5372__auto__$jscomp$inline_10079_m__5374__auto__$jscomp$inline_10078$$($JSCompiler_temp$jscomp$2124_this$$jscomp$888$$);else throw $APP.$cljs$core$missing_protocol$$("IObjectsMap.get-data",$JSCompiler_temp$jscomp$2124_this$$jscomp$888$$);}return $JSCompiler_temp$jscomp$2124_this$$jscomp$888$$},$app$common$types$objects_map$_hash_for_key$$=function($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$,$key$jscomp$434$$){if($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$!=null&&$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$.$app$common$types$objects_map$IObjectsMap$_hash_for_key$arity$2$!=
null)$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$=$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$.$app$common$types$objects_map$IObjectsMap$_hash_for_key$arity$2$($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$,$key$jscomp$434$$);else{var $m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$=$app$common$types$objects_map$_hash_for_key$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$==null?null:$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$)];if($m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$!=
null)$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$=$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$,$key$jscomp$434$$):$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$,$key$jscomp$434$$);else if($m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$=
$app$common$types$objects_map$_hash_for_key$$._,$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$!=null)$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$=$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$,$key$jscomp$434$$):$m__5372__auto__$jscomp$inline_10084_m__5374__auto__$jscomp$inline_10083$$($JSCompiler_temp$jscomp$2125_this$$jscomp$890$$,
$key$jscomp$434$$);else throw $APP.$cljs$core$missing_protocol$$("IObjectsMap.-hash-for-key",$JSCompiler_temp$jscomp$2125_this$$jscomp$890$$);}return $JSCompiler_temp$jscomp$2125_this$$jscomp$890$$},$app$common$types$objects_map$ObjectsMapEntry$$=function($key$jscomp$435$$,$omap$$){this.key=$key$jscomp$435$$;this.$omap$=$omap$$;this.$cljs$lang$protocol_mask$partition0$$=2178943251;this.$cljs$lang$protocol_mask$partition1$$=0},$app$common$types$objects_map$ObjectsMap$$=function($metadata$jscomp$9$$,
$cache$jscomp$107$$,$data$jscomp$520$$,$modified$$,$hash$jscomp$35$$){this.metadata=$metadata$jscomp$9$$;this.cache=$cache$jscomp$107$$;this.data=$data$jscomp$520$$;this.$modified$=$modified$$;this.hash=$hash$jscomp$35$$;this.$cljs$lang$protocol_mask$partition0$$=2163607311;this.$cljs$lang$protocol_mask$partition1$$=139264},$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$$=function($JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$){if($APP.$cljs$core$truth_$$($JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.$modified$)){var $G__83518_83534$$=
$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.data,$G__83519_83535$$=$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.cache,$G__83520_83536$$=function($data_SINGLEQUOTE_$$){$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.$modified$=!1;return $JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$self$$.data=$data_SINGLEQUOTE_$$};$app$common$types$objects_map$do_compact$$.$cljs$core$IFn$_invoke$arity$3$?
$app$common$types$objects_map$do_compact$$.$cljs$core$IFn$_invoke$arity$3$($G__83518_83534$$,$G__83519_83535$$,$G__83520_83536$$):$app$common$types$objects_map$do_compact$$($G__83518_83534$$,$G__83519_83535$$,$G__83520_83536$$)}},$app$common$types$objects_map$do_compact$$=function($data$jscomp$522_new_data$jscomp$4$$,$cache$jscomp$109$$,$update_fn$jscomp$56$$){$data$jscomp$522_new_data$jscomp$4$$=$APP.$cljs$core$persistent_BANG_$$($APP.$cljs$core$reduce_kv$$(function($JSCompiler_temp$jscomp$11004_data__$1$jscomp$18$$,
$id$jscomp$1087$$,$JSCompiler_temp_const$jscomp$11005_obj$jscomp$225$$){if($JSCompiler_temp_const$jscomp$11005_obj$jscomp$225$$==null){$JSCompiler_temp_const$jscomp$11005_obj$jscomp$225$$=$APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$;var $JSCompiler_inline_result$jscomp$11007_data$jscomp$inline_14188$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cache$jscomp$109$$,$id$jscomp$1087$$);$JSCompiler_inline_result$jscomp$11007_data$jscomp$inline_14188$$=$APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11007_data$jscomp$inline_14188$$,
null);$JSCompiler_temp$jscomp$11004_data__$1$jscomp$18$$=$JSCompiler_temp_const$jscomp$11005_obj$jscomp$225$$.call($APP.$cljs$core$assoc_BANG_$$,$JSCompiler_temp$jscomp$11004_data__$1$jscomp$18$$,$id$jscomp$1087$$,$JSCompiler_inline_result$jscomp$11007_data$jscomp$inline_14188$$)}return $JSCompiler_temp$jscomp$11004_data__$1$jscomp$18$$},$APP.$cljs$core$_as_transient$$($data$jscomp$522_new_data$jscomp$4$$),$data$jscomp$522_new_data$jscomp$4$$));$update_fn$jscomp$56$$.$cljs$core$IFn$_invoke$arity$1$?
$update_fn$jscomp$56$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$522_new_data$jscomp$4$$):$update_fn$jscomp$56$$($data$jscomp$522_new_data$jscomp$4$$);return null},$app$common$types$objects_map$from_data$$=function($data$jscomp$523$$){return new $app$common$types$objects_map$ObjectsMap$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$data$jscomp$523$$,!1,null)},$app$common$types$objects_map$create$$=function($var_args$jscomp$1522$$){switch(arguments.length){case 0:return $app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$();
case 1:var $JSCompiler_inline_result$jscomp$2126_other$jscomp$inline_10086$$=arguments[0];if($JSCompiler_inline_result$jscomp$2126_other$jscomp$inline_10086$$ instanceof $app$common$types$objects_map$ObjectsMap$$)$JSCompiler_inline_result$jscomp$2126_other$jscomp$inline_10086$$=$app$common$types$objects_map$from_data$$($app$common$types$objects_map$get_data$$($JSCompiler_inline_result$jscomp$2126_other$jscomp$inline_10086$$));else throw Error("invalid arguments");return $JSCompiler_inline_result$jscomp$2126_other$jscomp$inline_10086$$;
default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}},$app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return $app$common$types$objects_map$from_data$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$ui$debug$icons_preview$icons_gallery_STAR_$$=function(){var $entries$jscomp$47$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$seq$$(Object.entries($APP.$app$main$ui$icons$default$0$$)));
return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_debug_icons_preview__gallery",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$261$$,$p__83498_val$jscomp$236$$){var $key$jscomp$438$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83498_val$jscomp$236$$,0,null);$p__83498_val$jscomp$236$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83498_val$jscomp$236$$,1,null);$out_arr__44092__auto__$jscomp$261$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{title:$key$jscomp$438$$,className:"main_ui_debug_icons_preview__gallery-item",children:[$p__83498_val$jscomp$236$$,(0,$APP.$rumext$v2$jsx$$)("span",{children:$key$jscomp$438$$})]},$key$jscomp$438$$));return $out_arr__44092__auto__$jscomp$261$$},[],$entries$jscomp$47$$)})},$app$main$ui$debug$icons_preview$cursors_gallery_STAR_$$=function(){var $rotation$jscomp$28$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$entries$jscomp$48$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,
$APP.$cljs$core$seq$$(Object.entries($app$main$ui$cursors$default$0$$)));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$timers$interval$$(100,function(){return $APP.$cljs$core$reset_BANG_$$($rotation$jscomp$28$$,$APP.$cljs$core$inc$$)})});return(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_debug_icons_preview__gallery",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$262$$,$JSCompiler_temp_const$jscomp$11349_p__83507$$){var $JSCompiler_inline_result$jscomp$11351_key$jscomp$439$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11349_p__83507$$,0,null),$JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11349_p__83507$$,1,null);$JSCompiler_temp_const$jscomp$11349_p__83507$$=$out_arr__44092__auto__$jscomp$262$$.push;if($APP.$cljs$core$fn_QMARK_$$($JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$)){var $G__83511$jscomp$inline_14191$$=
$APP.$cljs$core$_deref$$($rotation$jscomp$28$$);$JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$=$JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$.$cljs$core$IFn$_invoke$arity$1$($G__83511$jscomp$inline_14191$$):$JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$($G__83511$jscomp$inline_14191$$)}$JSCompiler_inline_result$jscomp$11351_key$jscomp$439$$=
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_debug_icons_preview__gallery-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundImage:$APP.$cuerdas$core$replace$$($JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$,/(url\(.*\)).*/,"$1"),cursor:$JSCompiler_temp$jscomp$inline_14190_value$jscomp$1025_value__$1$jscomp$inline_14192$$},className:"main_ui_debug_icons_preview__cursor"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$11351_key$jscomp$439$$]))})]},
$JSCompiler_inline_result$jscomp$11351_key$jscomp$439$$);$JSCompiler_temp_const$jscomp$11349_p__83507$$.call($out_arr__44092__auto__$jscomp$262$$,$JSCompiler_inline_result$jscomp$11351_key$jscomp$439$$);return $out_arr__44092__auto__$jscomp$262$$},[],$entries$jscomp$48$$)})},$app$main$ui$debug$icons_preview$icons_preview_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_debug_icons_preview__container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_debug_icons_preview__title",
children:"Cursors"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$icons_preview$cursors_gallery_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_debug_icons_preview__title",children:"Icons"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$icons_preview$icons_gallery_STAR_$$,{})]})},$app$main$ui$debug$playground$playground_clipboard_STAR_$$=function(){var $on_paste$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$419_stream$jscomp$110$$){$e$jscomp$419_stream$jscomp$110$$=
$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$419_stream$jscomp$110$$.clipboardData,$APP.$app$util$clipboard$default_options$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$419_stream$jscomp$110$$,function($data$jscomp$524$$){return console.log("data",$data$jscomp$524$$)})}),$on_dragover$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$420$$){return $e$jscomp$420$$.preventDefault()}),
$on_drop$jscomp$23$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$421_stream$jscomp$111$$){$e$jscomp$421_stream$jscomp$111$$.preventDefault();$e$jscomp$421_stream$jscomp$111$$=$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$421_stream$jscomp$111$$.dataTransfer,$APP.$app$util$clipboard$default_options$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$421_stream$jscomp$111$$,function($data$jscomp$525$$){return console.log("data",
$data$jscomp$525$$)})}),$on_click$jscomp$77$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$422_stream$jscomp$112$$){console.log("event",$e$jscomp$422_stream$jscomp$112$$);$e$jscomp$422_stream$jscomp$112$$=$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$clipboard$default_options$$);return $APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($e$jscomp$422_stream$jscomp$112$$,function($data$jscomp$526$$){return console.log("data",
$data$jscomp$526$$)})});window.addEventListener("paste",$on_paste$jscomp$4$$);window.addEventListener("drop",$on_drop$jscomp$23$$);window.addEventListener("dragover",$on_dragover$$);return(0,$APP.$rumext$v2$jsx$$)("button",{id:"paste",onClick:$on_click$jscomp$77$$,children:"Paste"})},$app$main$ui$debug$playground$playground_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$playground$playground_clipboard_STAR_$$,{})},$app$main$ui$error_boundary$error_boundary_STAR_$$=function($fallback_wrapper_props_83577$$){var $children$jscomp$319$$=
$fallback_wrapper_props_83577$$.children,$fallback$jscomp$1$$=$fallback_wrapper_props_83577$$.fallback;$fallback_wrapper_props_83577$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fallback$jscomp$1$$)],function(){return function($props_83578_route$jscomp$25$$){var $reset_error_boundary$$=$props_83578_route$jscomp$25$$.resetErrorBoundary,$data$jscomp$527_error$jscomp$157$$=$props_83578_route$jscomp$25$$.error;$props_83578_route$jscomp$25$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);
$data$jscomp$527_error$jscomp$157$$=$APP.$app$main$errors$exception__GT_error_data$$($data$jscomp$527_error$jscomp$157$$);return(0,$APP.$rumext$v2$jsx$$)($fallback$jscomp$1$$,{data:$data$jscomp$527_error$jscomp$157$$,route:$props_83578_route$jscomp$25$$,onReset:$reset_error_boundary$$})}});var $on_error$jscomp$75$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$goog$functions$debounce$$(function($error$jscomp$158$$,$info$jscomp$9$$){if($APP.$cljs$core$truth_$$($APP.$app$main$errors$stale_asset_error_QMARK_$$($error$jscomp$158$$)))return $APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$984$reason$$,
$APP.$cljs$core$ex_message$$($error$jscomp$158$$)]));if($APP.$cljs$core$truth_$$($APP.$app$main$errors$is_ignorable_exception_QMARK_$$($error$jscomp$158$$)))return null;$APP.$app$common$exceptions$print_throwable$$($error$jscomp$158$$);return console.error("Component trace: \n",$info$jscomp$9$$.componentStack,"\n",$error$jscomp$158$$)},100)});return(0,$APP.$rumext$v2$jsx$$)($shadow$js$shim$module$0react_error_boundary$$.ErrorBoundary,{FallbackComponent:$fallback_wrapper_props_83577$$,onError:$on_error$jscomp$75$$,
children:$children$jscomp$319$$})},$app$main$ui$exports$files$mark_file_error$$=function($files$jscomp$50$$,$file_id$jscomp$458$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83676_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$458$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83676_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__83676_SHARP_$$,$APP.$cljs$cst$2199$export_error_QMARK_$$,
!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5133$loading$$,!1])):$p1__83676_SHARP_$$},$files$jscomp$50$$)},$app$main$ui$exports$files$mark_file_success$$=function($files$jscomp$51$$,$file_id$jscomp$459$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83678_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$459$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83678_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__83678_SHARP_$$,
$cljs$cst$6438$export_success_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5133$loading$$,!1])):$p1__83678_SHARP_$$},$files$jscomp$51$$)},$app$main$ui$exports$files$initialize_state$$=function($files$jscomp$52_files__$1$jscomp$8$$){$files$jscomp$52_files__$1$jscomp$8$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$209$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$209$$,$APP.$cljs$cst$5133$loading$$,
!0)},$files$jscomp$52_files__$1$jscomp$8$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$109$status$$,$cljs$cst$6439$prepare$$,$APP.$cljs$cst$1938$selected$$,$APP.$cljs$cst$2132$all$$,$APP.$cljs$cst$1933$files$$,$files$jscomp$52_files__$1$jscomp$8$$],null)},$app$main$ui$exports$files$export_entry_STAR_$$=function($file$jscomp$210_props_83680$$){$file$jscomp$210_props_83680$$=$file$jscomp$210_props_83680$$.file;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__file-entry "+
($APP.$cljs$core$truth_$$($APP.$cljs$cst$5133$loading$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$))?"main_ui_exports_files__loading":"")+" "+($APP.$cljs$core$truth_$$($cljs$cst$6438$export_success_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$))?"main_ui_exports_files__success":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$2199$export_error_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$))?"main_ui_exports_files__error":""),
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__file-name",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$5133$loading$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$))?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{width:16,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_exports_files__file-icon",children:$APP.$cljs$core$truth_$$($cljs$cst$6438$export_success_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$))?
$APP.$app$main$ui$icons$tick$$:$APP.$cljs$core$truth_$$($APP.$cljs$cst$2199$export_error_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$))?$APP.$app$main$ui$icons$close$$:null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__file-name-label",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$210_props_83680$$)})]})})},$app$main$ui$exports$files$export_dialog$$=function($props_83681_status$jscomp$27$$){var $on_accept$jscomp$19_team_id$jscomp$187$$=
$props_83681_status$jscomp$27$$["team-id"],$files$jscomp$53$$=$props_83681_status$jscomp$27$$.files,$state_STAR_$jscomp$27$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$exports$files$initialize_state$$,$files$jscomp$53$$)),$has_libs_QMARK_$$=$APP.$cljs$core$some$$($APP.$cljs$cst$2496$has_libraries$$,$files$jscomp$53$$),$state$jscomp$1258$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$27$$),$selected$jscomp$224$$=
$APP.$cljs$cst$1938$selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1258$$);$props_83681_status$jscomp$27$$=$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1258$$);var $start_export$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$19_team_id$jscomp$187$$),$APP.$rumext$v2$adapt$$($selected$jscomp$224$$),$APP.$rumext$v2$adapt$$($files$jscomp$53$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$27$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$109$status$$,$cljs$cst$6440$exporting$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file_id$jscomp$460_p__83682$$){var $map__83683__$1_uri$jscomp$115$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$460_p__83682$$);$file_id$jscomp$460_p__83682$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83683__$1_uri$jscomp$115$$,$APP.$cljs$cst$1649$file_id$$);var $error$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83683__$1_uri$jscomp$115$$,
$APP.$cljs$cst$849$error$$),$filename$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83683__$1_uri$jscomp$115$$,$APP.$cljs$cst$4881$filename$$);$map__83683__$1_uri$jscomp$115$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83683__$1_uri$jscomp$115$$,$APP.$cljs$cst$1584$uri$$);if($APP.$cljs$core$truth_$$($error$jscomp$159$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$27$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1933$files$$,
$app$main$ui$exports$files$mark_file_error$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_id$jscomp$460_p__83682$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$27$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1933$files$$,$app$main$ui$exports$files$mark_file_success$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_id$jscomp$460_p__83682$$]));return $APP.$app$util$dom$trigger_download_uri$$($filename$jscomp$16$$,
"application/penpot",$map__83683__$1_uri$jscomp$115$$)},$app$main$data$exports$files$export_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1933$files$$,$files$jscomp$53$$,$APP.$cljs$cst$139$type$$,$selected$jscomp$224$$])))}),$on_cancel$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$795$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$795$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())});
$on_accept$jscomp$19_team_id$jscomp$187$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($start_export$$)],function($event$jscomp$796$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$796$$);return $start_export$$.$cljs$core$IFn$_invoke$arity$0$?$start_export$$.$cljs$core$IFn$_invoke$arity$0$():$start_export$$()});var $on_change$jscomp$105$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$797_type$jscomp$729$$){$event$jscomp$797_type$jscomp$729$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($event$jscomp$797_type$jscomp$729$$),"type"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$27$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1938$selected$$,$event$jscomp$797_type$jscomp$729$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($has_libs_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($has_libs_QMARK_$$)?
null:$start_export$$.$cljs$core$IFn$_invoke$arity$0$?$start_export$$.$cljs$core$IFn$_invoke$arity$0$():$start_export$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_exports_files__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.title")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_cancel$jscomp$11$$,className:"main_ui_exports_files__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83681_status$jscomp$27$$,$cljs$cst$6439$prepare$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_files__modal-msg",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.description-1")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_files__modal-scd-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.description-2")}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$263$$,$type$jscomp$730$$){$out_arr__44092__auto__$jscomp$263$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__export-option",
children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:["export-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$730$$)].join(""),className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$224$$,$type$jscomp$730$$)?"checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$224$$,$type$jscomp$730$$)?"checked":"",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$224$$,
$type$jscomp$730$$)?$APP.$app$main$ui$icons$status_tick$$:null}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__option-content",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_exports_files__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.options."+($APP.$app$common$data$name$$($type$jscomp$730$$)??"")+".title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_exports_files__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("files-download-modal.options."+
($APP.$app$common$data$name$$($type$jscomp$730$$)??"")+".message")})]}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"radio",id:["export-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$730$$)].join(""),checked:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$224$$,$type$jscomp$730$$),name:"export-option","data-type":$APP.$cljs$core$name$$($type$jscomp$730$$),onChange:$on_change$jscomp$105$$,className:"main_ui_exports_files__option-input"})]})},$APP.$cljs$core$name$$($type$jscomp$730$$)));
return $out_arr__44092__auto__$jscomp$263$$},[],$APP.$app$main$data$exports$files$valid_types$$)]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),onClick:$on_cancel$jscomp$11$$,className:"main_ui_exports_files__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",
{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),onClick:$on_accept$jscomp$19_team_id$jscomp$187$$,className:"main_ui_exports_files__accept-btn"})]})})]}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83681_status$jscomp$27$$,$cljs$cst$6440$exporting$$)?function(){var $in_progress_QMARK_$jscomp$3$$=$APP.$cljs$core$some$$($APP.$cljs$cst$5133$loading$$,$APP.$cljs$cst$1933$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1258$$));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_exports_files__modal-content",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$264$$,$file$jscomp$211$$){$out_arr__44092__auto__$jscomp$264$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$exports$files$export_entry_STAR_$$,{file:$file$jscomp$211$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$211$$)??"")));return $out_arr__44092__auto__$jscomp$264$$},
[],$APP.$cljs$cst$1933$files$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1258$$)),$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{role:"status","aria-live":"polite",className:"main_ui_exports_files__status-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.downloading-file")}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__modal-footer",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_exports_files__action-buttons",
children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),disabled:$in_progress_QMARK_$jscomp$3$$,onClick:$on_cancel$jscomp$11$$,className:"main_ui_exports_files__accept-btn"})})})]})}():null]})})},$app$main$ui$nitrate$entry$nitrate_entry_STAR_$$=function($props_83685$$){var $profile$jscomp$95$$=$props_83685$$.profile;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$95$$)],
function(){var $_STAR_sync_STAR__orig_val__73692$jscomp$inline_10090$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$util$storage$storage$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5170$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5171$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$,
!0]))}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__73692$jscomp$inline_10090$$}return $APP.$app$main$data$auth$is_authenticated_QMARK_$$($profile$jscomp$95$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2533$dashboard_recent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$2507$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$95$$)],
null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5486$auth_register$$))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$nitrate$entry$nitrate_entry_page_STAR_$$=function($props_83686$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$nitrate$entry$nitrate_entry_STAR_$$,
$props_83686$$)},$app$main$ui$ds$notifications$toast$toast_STAR_$$=function($detail$jscomp$10_props_83687$$){var $children$jscomp$320$$,$on_close$jscomp$53$$,$is_html$jscomp$3_or__5025__auto__$jscomp$inline_10092$$,$props$jscomp$419$$;({className:$class$$jscomp$86_class$__$1$jscomp$14$$,level:$level$jscomp$66_level__$1$jscomp$3$$,appearance:$appearance$jscomp$2_appearance__$1$jscomp$1$$,type:$type$jscomp$731_type__$1$jscomp$19$$,isHtml:$is_html$jscomp$3_or__5025__auto__$jscomp$inline_10092$$,children:$children$jscomp$320$$,
detail:$detail$jscomp$10_props_83687$$,onClose:$on_close$jscomp$53$$,...$props$jscomp$419$$}=$detail$jscomp$10_props_83687$$);var $class$$jscomp$86_class$__$1$jscomp$14$$=""+($class$$jscomp$86_class$__$1$jscomp$14$$??"")+" main_ui_ds_notifications_toast__toast";var $level$jscomp$66_level__$1$jscomp$3$$=typeof $level$jscomp$66_level__$1$jscomp$3$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($level$jscomp$66_level__$1$jscomp$3$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$3$$,
$APP.$cljs$cst$205$default$$);var $type$jscomp$731_type__$1$jscomp$19$$=typeof $type$jscomp$731_type__$1$jscomp$19$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$731_type__$1$jscomp$19$$):$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$731_type__$1$jscomp$19$$,$APP.$cljs$cst$2320$context$$);var $appearance$jscomp$2_appearance__$1$jscomp$1$$=typeof $appearance$jscomp$2_appearance__$1$jscomp$1$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($appearance$jscomp$2_appearance__$1$jscomp$1$$):
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($appearance$jscomp$2_appearance__$1$jscomp$1$$,$APP.$cljs$cst$5102$neutral$$);return(0,$APP.$rumext$v2$create_element$$)("aside",{...$props$jscomp$419$$,className:$class$$jscomp$86_class$__$1$jscomp$14$$,role:"alert","aria-live":"polite"},$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$shared$notification_pill$notification_pill_STAR_$$,{level:$level$jscomp$66_level__$1$jscomp$3$$,type:$type$jscomp$731_type__$1$jscomp$19$$,isHtml:$APP.$cljs$core$truth_$$($is_html$jscomp$3_or__5025__auto__$jscomp$inline_10092$$)?
$is_html$jscomp$3_or__5025__auto__$jscomp$inline_10092$$:!1,appearance:$appearance$jscomp$2_appearance__$1$jscomp$1$$,detail:$detail$jscomp$10_props_83687$$,children:$children$jscomp$320$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$53$$,"aria-label":"Close",className:"main_ui_ds_notifications_toast__close-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$3$$,$APP.$cljs$cst$205$default$$)?"main_ui_ds_notifications_toast__level-default":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$3$$,$APP.$cljs$cst$2354$warning$$)?"main_ui_ds_notifications_toast__level-warning":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$3$$,$APP.$cljs$cst$849$error$$)?"main_ui_ds_notifications_toast__level-error":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$3$$,$APP.$cljs$cst$2355$success$$)?"main_ui_ds_notifications_toast__level-success":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($level$jscomp$66_level__$1$jscomp$3$$,$APP.$cljs$cst$1161$info$$)?"main_ui_ds_notifications_toast__level-info":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close"})}))},$app$main$ui$ds$notifications$actionable$actionable_STAR_$$=function($props_83688_variant__$1$jscomp$9$$){var $on_cancel$jscomp$12$$=void 0,$children$jscomp$321$$=void 0,$on_cancel__$1_variant$jscomp$31$$=void 0,
$accept_label$jscomp$1$$=void 0,$cancel_label$$=void 0,$on_accept$jscomp$20$$=void 0,$class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$=void 0,$props$jscomp$420_props__$1$jscomp$112$$=void 0;({className:$class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$,variant:$on_cancel__$1_variant$jscomp$31$$,acceptLabel:$accept_label$jscomp$1$$,cancelLabel:$cancel_label$$,children:$children$jscomp$321$$,onAccept:$on_accept$jscomp$20$$,onCancel:$on_cancel$jscomp$12$$,...$props$jscomp$420_props__$1$jscomp$112$$}=
$props_83688_variant__$1$jscomp$9$$);$props_83688_variant__$1$jscomp$9$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($on_cancel__$1_variant$jscomp$31$$,"default");$class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$=$APP.$app$common$data$append_class$$($class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$,"main_ui_ds_notifications_actionable__notification");$props$jscomp$420_props__$1$jscomp$112$$={...$props$jscomp$420_props__$1$jscomp$112$$,className:$class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$,
"data-testid":"actionable"};$class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept$jscomp$20$$)],function($e$jscomp$423$$){return $APP.$cljs$core$fn_QMARK_$$($on_accept$jscomp$20$$)?$on_accept$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$423$$):$on_accept$jscomp$20$$($e$jscomp$423$$):null});$on_cancel__$1_variant$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$jscomp$12$$)],
function($e$jscomp$424$$){return $APP.$cljs$core$truth_$$($on_cancel$jscomp$12$$)?$on_cancel$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_cancel$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$424$$):$on_cancel$jscomp$12$$($e$jscomp$424$$):null});return(0,$APP.$rumext$v2$create_element$$)("aside",$props$jscomp$420_props__$1$jscomp$112$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_notifications_actionable__notification-message",children:$children$jscomp$321$$}),$APP.$cljs$core$truth_$$($cancel_label$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$on_cancel__$1_variant$jscomp$31$$,children:$cancel_label$$}):null,$APP.$cljs$core$truth_$$($accept_label$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83688_variant__$1$jscomp$9$$,"default")?"primary":"destructive",type:"button",onClick:$class$$jscomp$87_class$__$1$jscomp$15_on_accept__$1$jscomp$1$$,
children:$accept_label$jscomp$1$$}):null)},$app$main$ui$notifications$inline_notification$inline_notification$$=function($cancel$jscomp$4_props_83689$$){var $links$jscomp$4$$=$cancel$jscomp$4_props_83689$$.links,$accept$jscomp$12$$=$cancel$jscomp$4_props_83689$$.accept,$content$jscomp$275$$=$cancel$jscomp$4_props_83689$$.content;$cancel$jscomp$4_props_83689$$=$cancel$jscomp$4_props_83689$$.cancel;return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$ds$notifications$actionable$actionable_STAR_$$,{className:"main_ui_notifications_inline_notification__new-inline",
cancelLabel:$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($cancel$jscomp$4_props_83689$$),onCancel:$APP.$cljs$cst$2365$callback$$.$cljs$core$IFn$_invoke$arity$1$($cancel$jscomp$4_props_83689$$),acceptLabel:$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($accept$jscomp$12$$),onAccept:$APP.$cljs$cst$2365$callback$$.$cljs$core$IFn$_invoke$arity$1$($accept$jscomp$12$$),children:[$content$jscomp$275$$,$links$jscomp$4$$!=null?(0,$APP.$rumext$v2$jsx$$)("nav",{className:"main_ui_notifications_inline_notification__link-nav",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$265$$,$link$jscomp$10_p__83690$$){var $index$jscomp$601$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($link$jscomp$10_p__83690$$,0,null);$link$jscomp$10_p__83690$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($link$jscomp$10_p__83690$$,1,null);$out_arr__44092__auto__$jscomp$265$$.push($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link_button$link_button_STAR_$$,
{className:"main_ui_notifications_inline_notification__link",onClick:$APP.$cljs$cst$2365$callback$$.$cljs$core$IFn$_invoke$arity$1$($link$jscomp$10_p__83690$$),value:$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($link$jscomp$10_p__83690$$)},"link-"+($index$jscomp$601$$??"")));return $out_arr__44092__auto__$jscomp$265$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($links$jscomp$4$$))}):null]})},$app$main$ui$notifications$current_notification_STAR_$$=function(){var $notification$jscomp$6$$=
$APP.$rumext$v2$deref$$($app$main$ui$notifications$ref_COLON_notification$$),$on_close$jscomp$54$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$hide$$())}),$actionable_QMARK_$$=$APP.$cljs$cst$2364$timeout$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)==null&&$APP.$cljs$cst$2367$actions$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)==null,$inline_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2359$inline$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2358$floating$$,$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)),$toast_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$))||
$APP.$cljs$cst$2364$timeout$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)!=null,$content$jscomp$276$$=function(){var $or__5025__auto__$jscomp$1484$$=$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1484$$)?$or__5025__auto__$jscomp$1484$$:""}();return $APP.$cljs$core$truth_$$($notification$jscomp$6$$)?$toast_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$notifications$toast$toast_STAR_$$,
{level:function(){var $or__5025__auto__$jscomp$1485$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1485$$)?$or__5025__auto__$jscomp$1485$$:$APP.$cljs$cst$1161$info$$}(),type:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),detail:$APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),onClose:$on_close$jscomp$54$$,children:$content$jscomp$276$$}):
$inline_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$notifications$inline_notification$inline_notification$$,{accept:$APP.$cljs$cst$924$accept$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),cancel:$APP.$cljs$cst$2366$cancel$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),links:$APP.$cljs$cst$2368$links$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),content:$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)}):$actionable_QMARK_$$?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{level:function(){var $or__5025__auto__$jscomp$1486$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1486$$)?$or__5025__auto__$jscomp$1486$$:$APP.$cljs$cst$1161$info$$}(),links:$APP.$cljs$cst$2368$links$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),content:$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$)}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$notifications$toast$toast_STAR_$$,{level:function(){var $or__5025__auto__$jscomp$1487$$=$APP.$cljs$cst$284$level$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1487$$)?$or__5025__auto__$jscomp$1487$$:$APP.$cljs$cst$1161$info$$}(),type:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),detail:$APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($notification$jscomp$6$$),
onClose:$on_close$jscomp$54$$,children:$content$jscomp$276$$}):null},$app$main$ui$onboarding$questions$step_container_STAR_$$=function($class$$jscomp$88_props_83694$$){var $form$jscomp$212$$=$class$$jscomp$88_props_83694$$.form,$on_next$$=$class$$jscomp$88_props_83694$$.onNext,$step$jscomp$38$$=$class$$jscomp$88_props_83694$$.step,$children$jscomp$322$$=$class$$jscomp$88_props_83694$$.children,$on_prev$$=$class$$jscomp$88_props_83694$$.onPrev,$label$jscomp$61$$=$class$$jscomp$88_props_83694$$.label;
$class$$jscomp$88_props_83694$$=$class$$jscomp$88_props_83694$$.className;var $on_next_STAR_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_next$$),$APP.$rumext$v2$adapt$$($step$jscomp$38$$),$APP.$rumext$v2$adapt$$($label$jscomp$61$$)],function($form__$1$jscomp$21$$,$event$jscomp$798$$){var $params$jscomp$455$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$21$$)),
$APP.$cljs$cst$2296$label$$,$label$jscomp$61$$),$APP.$cljs$cst$5773$step$$,$step$jscomp$38$$),$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$($params$jscomp$455$$));return $on_next$$.$cljs$core$IFn$_invoke$arity$2$?$on_next$$.$cljs$core$IFn$_invoke$arity$2$($form__$1$jscomp$21$$,$event$jscomp$798$$):$on_next$$($form__$1$jscomp$21$$,$event$jscomp$798$$)});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$forms$form$$,
{form:$form$jscomp$212$$,"on-submit":$on_next_STAR_$$,"class":""+($class$$jscomp$88_props_83694$$??"")+" main_ui_onboarding_questions__form-wrapper",children:[$children$jscomp$322$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__action-buttons",children:[$on_prev$$!=null?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_prev$$,className:"main_ui_onboarding_questions__prev-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.previous")}):null,
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$submit_button_STAR_$$,{label:$step$jscomp$38$$<4?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.start"),className:"main_ui_onboarding_questions__next-button"})]})]})},$app$main$ui$onboarding$questions$step_1_STAR_$$=function($props_83698_show_step_3$$){var $form$jscomp$213$$=$props_83698_show_step_3$$.form,$on_next$jscomp$1$$=$props_83698_show_step_3$$.onNext;
$props_83698_show_step_3$$=$props_83698_show_step_3$$.showStep3;var $use_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.use.work"),$APP.$cljs$cst$260$value$$,"work"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.use.education"),$APP.$cljs$cst$260$value$$,"education"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.use.personal"),$APP.$cljs$cst$260$value$$,"personal"],null)],null))}),$role_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.select-option"),$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$302$key$$,"role",$APP.$cljs$cst$2959$disabled$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.product-design"),$APP.$cljs$cst$260$value$$,"ux",
$APP.$cljs$cst$302$key$$,"ux"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.developer"),$APP.$cljs$cst$260$value$$,"developer",$APP.$cljs$cst$302$key$$,"developer"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.student-teacher"),$APP.$cljs$cst$260$value$$,"student-teacher",$APP.$cljs$cst$302$key$$,
"student"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.graphic-design"),$APP.$cljs$cst$260$value$$,"designer",$APP.$cljs$cst$302$key$$,"design"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.marketing"),$APP.$cljs$cst$260$value$$,"marketing",$APP.$cljs$cst$302$key$$,"marketing"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.product-management"),$APP.$cljs$cst$260$value$$,"manager",$APP.$cljs$cst$302$key$$,"manager"],null)],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other-short"),$APP.$cljs$cst$260$value$$,"other"],null))}),$current_role$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$213$$),
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2501$role$$);return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container_STAR_$$,{form:$form$jscomp$213$$,step:1,label:"questions:about-you",onNext:$on_next$jscomp$1$$,className:"main_ui_onboarding_questions__step",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:"1/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($props_83698_show_step_3$$))?4:3)}),(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/form/slide-1-help-us-know-you.svg",alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.lets-get-started"),className:"main_ui_onboarding_questions__header-image"}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step1.title")}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_onboarding_questions__modal-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step1.subtitle")}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__modal-question",children:[(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_onboarding_questions__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step1.question1")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$radio_buttons$$,{options:$use_options$$,name:$cljs$cst$6441$expected_use$$,"class":"main_ui_onboarding_questions__radio"}),(0,$APP.$rumext$v2$jsx$$)("h3",
{className:"main_ui_onboarding_questions__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step3.question1")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{options:$role_options$$,"select-class":"main_ui_onboarding_questions__select","default":"",name:$APP.$cljs$cst$2501$role$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_role$$,"other")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,
{name:$cljs$cst$6442$role_other$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other"),"show-error":!1,label:""}):null]})]})},$app$main$ui$onboarding$questions$step_2_STAR_$$=function($on_prev$jscomp$1_props_83704$$){var $form$jscomp$214$$=$on_prev$jscomp$1_props_83704$$.form,$on_next$jscomp$2$$=$on_prev$jscomp$1_props_83704$$.onNext,$show_step_3$jscomp$1$$=$on_prev$jscomp$1_props_83704$$.showStep3;$on_prev$jscomp$1_props_83704$$=$on_prev$jscomp$1_props_83704$$.onPrev;
var $design_tool_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.figma"),$cljs$cst$6445$img_width$$,"48px",$cljs$cst$6446$img_height$$,"60px",$APP.$cljs$cst$260$value$$,
"figma",$APP.$cljs$cst$1617$image$$,"images/form/slide-2-figma.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.sketch"),$cljs$cst$6445$img_width$$,"48px",$cljs$cst$6446$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"sketch",$APP.$cljs$cst$1617$image$$,"images/form/slide-2-sketch.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.adobe-xd"),
$cljs$cst$6445$img_width$$,"48px",$cljs$cst$6446$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"adobe-xd",$APP.$cljs$cst$1617$image$$,"images/form/slide-2-adobe-xd.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.canva"),$cljs$cst$6445$img_width$$,"48px",$cljs$cst$6446$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"canva",$APP.$cljs$cst$1617$image$$,"images/form/slide-2-canva.png"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invision"),$cljs$cst$6445$img_width$$,"48px",$cljs$cst$6446$img_height$$,"60px",$APP.$cljs$cst$260$value$$,"invision",$APP.$cljs$cst$1617$image$$,"images/form/slide-2-invision.png"],null)],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other-short"),$APP.$cljs$cst$260$value$$,"other",$APP.$cljs$cst$1727$icon$$,
$APP.$app$main$ui$icons$curve$$],null))}),$current_experience$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$214$$),$APP.$cljs$cst$142$data$$),$cljs$cst$6443$experience_design_tool$$),$on_design_tool_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_experience$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_experience$$,
"other")?($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$214$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$6444$experience_design_tool_other$$],null)),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$214$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$cljs$cst$6444$experience_design_tool_other$$],null))):null});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container_STAR_$$,{form:$form$jscomp$214$$,step:2,label:"questions:experience-design-tool",onNext:$on_next$jscomp$2$$,onPrev:$on_prev$jscomp$1_props_83704$$,className:"main_ui_onboarding_questions__step",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:"2/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$1$$))?
4:3)}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step2.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__radio-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$forms$image_radio_buttons$$,{options:$design_tool_options$$,"img-width":"48px","img-height":"60px",name:$cljs$cst$6443$experience_design_tool$$,image:!0,"class":"main_ui_onboarding_questions__radio-image",
"on-change":$on_design_tool_change$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_experience$$,"other")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$cljs$cst$6444$experience_design_tool_other$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other"),"show-error":!1,label:""}):null]})]})},$app$main$ui$onboarding$questions$step_3_STAR_$$=function($on_prev$jscomp$2_props_83706$$){var $form$jscomp$215$$=$on_prev$jscomp$2_props_83706$$.form,
$on_next$jscomp$3$$=$on_prev$jscomp$2_props_83706$$.onNext,$show_step_3$jscomp$2$$=$on_prev$jscomp$2_props_83706$$.showStep3;$on_prev$jscomp$2_props_83706$$=$on_prev$jscomp$2_props_83706$$.onPrev;var $team_size_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.select-option"),
$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$302$key$$,"team-size",$APP.$cljs$cst$2959$disabled$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.just-me"),$APP.$cljs$cst$260$value$$,"1",$APP.$cljs$cst$302$key$$,"1"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.2-100"),
$APP.$cljs$cst$260$value$$,"2-100",$APP.$cljs$cst$302$key$$,"2-100"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.101-500"),$APP.$cljs$cst$260$value$$,"101-500",$APP.$cljs$cst$302$key$$,"101-500"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.501-1000"),
$APP.$cljs$cst$260$value$$,"501-1000",$APP.$cljs$cst$302$key$$,"501-1000"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.1001-5000"),$APP.$cljs$cst$260$value$$,"1001-5000",$APP.$cljs$cst$302$key$$,"1001-5000"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.team-size.more-than-5001"),
$APP.$cljs$cst$260$value$$,"5001+",$APP.$cljs$cst$302$key$$,"5001+"],null)],null)});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container_STAR_$$,{form:$form$jscomp$215$$,step:3,label:"questions:about-your-job",onNext:$on_next$jscomp$3$$,onPrev:$on_prev$jscomp$2_props_83706$$,className:"main_ui_onboarding_questions__step",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:"3/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$2$$))?
4:3)}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step3.title")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__modal-question",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$select$$,{options:$team_size_options$$,"default":"","select-class":"main_ui_onboarding_questions__select",name:$cljs$cst$6447$team_size$$})})]})},$app$main$ui$onboarding$questions$step_4_STAR_$$=
function($on_prev$jscomp$3_props_83713$$){var $form$jscomp$216$$=$on_prev$jscomp$3_props_83713$$.form,$on_next$jscomp$4$$=$on_prev$jscomp$3_props_83713$$.onNext,$show_step_3$jscomp$3$$=$on_prev$jscomp$3_props_83713$$.showStep3;$on_prev$jscomp$3_props_83713$$=$on_prev$jscomp$3_props_83713$$.onPrev;var $start_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$shuffle$$(new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.ui"),$APP.$cljs$cst$260$value$$,"ui",$APP.$cljs$cst$1617$image$$,"images/form/slide-3-design-app-ui-ux.svg"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.wireframing"),
$APP.$cljs$cst$260$value$$,"wireframing",$APP.$cljs$cst$1617$image$$,"images/form/slide-3-wireframing.svg"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.prototyping"),$APP.$cljs$cst$260$value$$,"prototyping",$APP.$cljs$cst$1617$image$$,"images/form/slide-3-prototyping.svg"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.ds"),
$APP.$cljs$cst$260$value$$,"ds",$APP.$cljs$cst$1617$image$$,"images/form/slide-3-design-systems.svg"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.start-with.code"),$APP.$cljs$cst$260$value$$,"code",$APP.$cljs$cst$1617$image$$,"images/form/slide-3-code-from-design.svg"],null)],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other-short"),
$APP.$cljs$cst$260$value$$,"other",$APP.$cljs$cst$1727$icon$$,$APP.$app$main$ui$icons$curve$$],null))}),$current_start$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$216$$),$APP.$cljs$cst$142$data$$),$cljs$cst$6448$start_with$$),$on_start_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_start$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_start$$,
"other")?($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$216$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$6449$start_with_other$$],null)),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($form$jscomp$216$$,$APP.$app$common$data$dissoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,
$cljs$cst$6449$start_with_other$$],null))):null});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$onboarding$questions$step_container_STAR_$$,{form:$form$jscomp$216$$,step:4,label:"questions:how-start",onNext:$on_next$jscomp$4$$,onPrev:$on_prev$jscomp$3_props_83713$$,className:"main_ui_onboarding_questions__step",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__paginator",children:""+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$3$$))?4:3)+
"/"+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$3$$))?4:3)}),(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_onboarding_questions__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.questions.step4.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_questions__radio-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$forms$image_radio_buttons$$,{options:$start_options$$,"img-width":"100px",
"img-height":"110px",name:$cljs$cst$6448$start_with$$,"on-change":$on_start_change$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_start$$,"other")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$cljs$cst$6449$start_with_other$$,label:"","show-error":!1,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other")}):null]})]})},$app$main$ui$onboarding$questions$questions_modal$$=function(){var $container$jscomp$102$$=(0,$APP.$rumext$v2$use_ref$$)(),
$step$jscomp$39$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(1),$clean_data$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$show_step_3$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$step_1_form$$=function(){var $G__83717$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$4840$initial$$,
$G__83717$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_1$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$4840$initial$$,$G__83717$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_1$$)}(),$step_2_form$$=function(){var $G__83721$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$4840$initial$$,
$G__83721$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_2$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$4840$initial$$,$G__83721$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_2$$)}(),$step_3_form$$=function(){var $G__83725$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$4840$initial$$,
$G__83725$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_3$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$4840$initial$$,$G__83725$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_3$$)}(),$step_4_form$$=function(){var $G__83729$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$4840$initial$$,
$G__83729$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_4$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$4840$initial$$,$G__83729$$,$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$questions$schema_COLON_questions_form_4$$)}(),$on_next$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form$jscomp$217$$){$APP.$cljs$core$truth_$$($cljs$cst$6441$expected_use$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$217$$))))&&
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6441$expected_use$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$217$$))),"work")?$APP.$cljs$core$reset_BANG_$$($show_step_3$jscomp$4$$,!0):$APP.$cljs$core$reset_BANG_$$($show_step_3$jscomp$4$$,!1));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($step$jscomp$39$$,$APP.$cljs$core$inc$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($clean_data$$,
$APP.$cljs$core$merge$$,$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$217$$)))}),$on_prev$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($step$jscomp$39$$,$APP.$cljs$core$dec$$)}),$on_submit$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($clean_data$$))],function($data$jscomp$530_form$jscomp$218$$){$data$jscomp$530_form$jscomp$218$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_deref$$($clean_data$$),$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data$jscomp$530_form$jscomp$218$$))]));$APP.$cljs$core$reset_BANG_$$($clean_data$$,$data$jscomp$530_form$jscomp$218$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$mark_questions_as_answered$$($data$jscomp$530_form$jscomp$218$$))});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_questions__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{ref:$container$jscomp$102$$,className:"main_ui_onboarding_questions__modal-container",children:function(){switch($APP.$cljs$core$_deref$$($step$jscomp$39$$)){case 1:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_1_STAR_$$,{onNext:$on_next$jscomp$5$$,onPrev:$on_prev$jscomp$4$$,form:$step_1_form$$,showStep3:$show_step_3$jscomp$4$$});case 2:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_2_STAR_$$,
{onNext:$on_next$jscomp$5$$,onPrev:$on_prev$jscomp$4$$,form:$step_2_form$$,showStep3:$show_step_3$jscomp$4$$});case 3:return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_3_STAR_$$,{onNext:$on_next$jscomp$5$$,onPrev:$on_prev$jscomp$4$$,form:$step_3_form$$,showStep3:$show_step_3$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_4_STAR_$$,{onNext:$on_submit$jscomp$20$$,onPrev:$on_prev$jscomp$4$$,
form:$step_4_form$$,showStep3:$show_step_3$jscomp$4$$});default:return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_step_3$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$step_4_STAR_$$,{onNext:$on_submit$jscomp$20$$,onPrev:$on_prev$jscomp$4$$,form:$step_4_form$$,showStep3:$show_step_3$jscomp$4$$}):null}}()})})},$app$main$ui$onboarding$team_choice$team_info_feature_STAR_$$=function($props_83699$$){var $text$jscomp$154$$=$props_83699$$.text;return(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_onboarding_team_choice__modal-info-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__modal-info-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$props_83699$$.iconId,size:"m"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",className:"main_ui_onboarding_team_choice__color-light",children:$text$jscomp$154$$})]})},
$app$main$ui$onboarding$team_choice$team_info_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-info",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/form/slide-final-team.svg"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-info-desc",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"title-medium",className:"main_ui_onboarding_team_choice__color-light",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.team-definition")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-large",className:"main_ui_onboarding_team_choice__color-dimmed",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-desc")})]}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_onboarding_team_choice__modal-info-features",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_info_feature_STAR_$$,
{iconId:"document",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-1")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_info_feature_STAR_$$,{iconId:"move",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-2")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_info_feature_STAR_$$,{iconId:"tree",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-3")}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_info_feature_STAR_$$,{iconId:"user",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-4")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_info_feature_STAR_$$,{iconId:"tick",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team-feature-5")})]})]})},$app$main$ui$onboarding$team_choice$get_available_roles$$=function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"viewer",$APP.$cljs$cst$260$value$$,"viewer",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.viewer")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"editor",$APP.$cljs$cst$260$value$$,"editor",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.editor")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"admin",$APP.$cljs$cst$260$value$$,"admin",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.admin")],null)],null)},$app$main$ui$onboarding$team_choice$team_form_STAR_$$=function($initial$jscomp$42_props_83702_roles$jscomp$1$$){var $go_to_team$$=$initial$jscomp$42_props_83702_roles$jscomp$1$$.goToTeam;$initial$jscomp$42_props_83702_roles$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2501$role$$,"editor"],null)});var $form$jscomp$219$$=$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$298$schema$$,$app$main$ui$onboarding$team_choice$schema_COLON_team_form$$,$APP.$cljs$cst$4840$initial$$,$initial$jscomp$42_props_83702_roles$jscomp$1$$]));$initial$jscomp$42_props_83702_roles$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$onboarding$team_choice$get_available_roles$$);
var $error_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_success$jscomp$58$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($response$jscomp$17_team_id$jscomp$188$$){$response$jscomp$17_team_id$jscomp$188$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($response$jscomp$17_team_id$jscomp$188$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$6450$onboarding_team_id$$,$response$jscomp$17_team_id$jscomp$188$$,$APP.$cljs$cst$3252$onboarding_viewed$$,!0],null)));return $APP.$cljs$core$truth_$$($go_to_team$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,$response$jscomp$17_team_id$jscomp$188$$]))):null}),$on_error$jscomp$76$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause$jscomp$117_map__83705__$1$$){$cause$jscomp$117_map__83705__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($cause$jscomp$117_map__83705__$1$$));var $type$jscomp$732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$117_map__83705__$1$$,$APP.$cljs$cst$139$type$$),$code$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause$jscomp$117_map__83705__$1$$,$APP.$cljs$cst$273$code$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2261$validation$$,$type$jscomp$732$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5245$profile_is_muted$$,$code$jscomp$65$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2261$validation$$,$type$jscomp$732$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5246$max_invitations_by_request$$,$code$jscomp$65$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.maximum-invitations-by-request-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2512$threshold$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$117_map__83705__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2572$restriction$$,
$type$jscomp$732$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3435$max_quote_reached$$,$code$jscomp$65$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.max-quota-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2883$target$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$117_map__83705__$1$$)]))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5247$member_is_muted$$,
$code$jscomp$65$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5248$email_has_permanent_bounces$$,$code$jscomp$65$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5249$email_has_complaints$$,$code$jscomp$65$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-spam-or-permanent-bounces",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$117_map__83705__$1$$)]))):
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($error_STAR_$jscomp$1$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic"))}),$on_create_without_invitations$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__83708__$1_name$jscomp$513_p__83707$$){$map__83708__$1_name$jscomp$513_p__83707$$=$APP.$cljs$core$__destructure_map$$($map__83708__$1_name$jscomp$513_p__83707$$);$map__83708__$1_name$jscomp$513_p__83707$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83708__$1_name$jscomp$513_p__83707$$,
$APP.$cljs$cst$725$name$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$with_meta$$($APP.$app$main$data$team$create_team$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$map__83708__$1_name$jscomp$513_p__83707$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$on_success$jscomp$58$$,$APP.$cljs$cst$1300$on_error$$,$on_error$jscomp$76$$],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$cljs$cst$6451$onboarding_without_invitations$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step",$APP.$cljs$cst$2296$label$$,"team:create-team-and-invite-later",$APP.$cljs$cst$2504$team_name$$,$map__83708__$1_name$jscomp$513_p__83707$$,$APP.$cljs$cst$5773$step$$,
8],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-finish"],null))]))}),$on_create_with_invitations$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__83710__$1_p__83709$$){$map__83710__$1_p__83709$$=$APP.$cljs$core$__destructure_map$$($map__83710__$1_p__83709$$);var $name$jscomp$514$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83710__$1_p__83709$$,
$APP.$cljs$cst$725$name$$),$emails$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83710__$1_p__83709$$,$APP.$cljs$cst$3346$emails$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$with_meta$$($app$main$data$team$create_team_with_invitations$$($APP.$cljs$core$with_meta$$($map__83710__$1_p__83709$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$on_success$jscomp$58$$,$APP.$cljs$cst$1300$on_error$$,
$on_error$jscomp$76$$],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$cljs$cst$6452$onboarding_with_invitations$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step",$APP.$cljs$cst$2296$label$$,"team:create-team-and-invite",$cljs$cst$6453$invites$$,
$APP.$cljs$core$count$$($emails$jscomp$4$$),$APP.$cljs$cst$2504$team_name$$,$name$jscomp$514$$,$APP.$cljs$cst$2501$role$$,$APP.$cljs$cst$2501$role$$.$cljs$core$IFn$_invoke$arity$1$($map__83710__$1_p__83709$$),$APP.$cljs$cst$5773$step$$,8],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-finish"],null))]))}),$on_submit$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($form__$1$jscomp$22_params$jscomp$458$$){$form__$1$jscomp$22_params$jscomp$458$$=
$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form__$1$jscomp$22_params$jscomp$458$$));var $emails$jscomp$5$$=$APP.$cljs$cst$3346$emails$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$22_params$jscomp$458$$);return $APP.$cljs$core$count$$($emails$jscomp$5$$)>0?$on_create_with_invitations$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_with_invitations$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$22_params$jscomp$458$$):$on_create_with_invitations$$($form__$1$jscomp$22_params$jscomp$458$$):
$on_create_without_invitations$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_without_invitations$$.$cljs$core$IFn$_invoke$arity$1$($form__$1$jscomp$22_params$jscomp$458$$):$on_create_without_invitations$$($form__$1$jscomp$22_params$jscomp$458$$)}),$on_skip$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3252$onboarding_viewed$$,!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"onboarding-step",$APP.$cljs$cst$2296$label$$,"team:skip-team-creation",$APP.$cljs$cst$5773$step$$,7],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"onboarding-finish"],null))]))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__modal-team",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$forms$form_STAR_$$,{form:$form$jscomp$219$$,className:"main_ui_onboarding_team_choice__modal-team-form",onSubmit:$on_submit$jscomp$21$$,children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-team-block",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,
{level:2,typography:"title-medium",className:"main_ui_onboarding_team_choice__color-light",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.team-modal.create-team")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-team-sub-block",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"headline-small",className:"main_ui_onboarding_team_choice__color-light",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-enter")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,{type:"text",icon:"effects",name:$APP.$cljs$cst$725$name$$,autoFocus:!0,autoComplete:"off",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-name")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-small",className:"main_ui_onboarding_team_choice__color-dimmed",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-desc")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-team-block",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"title-medium",className:"main_ui_onboarding_team_choice__color-light",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.invite-members")}),function(){var $temp__5825__auto__$jscomp$484$$=$APP.$cljs$core$_deref$$($error_STAR_$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$484$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$849$error$$,children:$temp__5825__auto__$jscomp$484$$}):null}(),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-team-sub-block",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_select_STAR_$$,{name:$APP.$cljs$cst$2501$role$$,options:$initial$jscomp$42_props_83702_roles$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$forms$form_multi_input_STAR_$$,
{type:"email",name:$APP.$cljs$cst$3346$emails$$,trim:!0,validItemFn:$APP.$app$common$schema$parse_email$$,cautionItemFn:$APP.$cljs$core$PersistentHashSet$EMPTY$$,autoComplete:"off",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.invite-member.emails")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-small",className:"main_ui_onboarding_team_choice__color-dimmed",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.invite-members-desc")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-team-block",children:[function(){var $emails$jscomp$6_num_emails_params$jscomp$459$$=$APP.$cljs$cst$4838$clean_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$219$$));$emails$jscomp$6_num_emails_params$jscomp$459$$=$APP.$cljs$cst$3346$emails$$.$cljs$core$IFn$_invoke$arity$1$($emails$jscomp$6_num_emails_params$jscomp$459$$);$emails$jscomp$6_num_emails_params$jscomp$459$$=$APP.$cljs$core$count$$($emails$jscomp$6_num_emails_params$jscomp$459$$);
return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_submit_STAR_$$,{variant:"primary",className:"main_ui_onboarding_team_choice__align-center",children:$emails$jscomp$6_num_emails_params$jscomp$459$$>0?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-and-invite"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.create-team-without-invite")})})}(),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_onboarding_team_choice__link-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link$link_STAR_$$,{className:"main_ui_onboarding_team_choice__link",action:$on_skip$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.continue-without-a-team")})})]})]})})},$app$main$ui$onboarding$team_choice$onboarding_team_modal_STAR_$$=function($go_to_team$jscomp$1_props_83714$$){$go_to_team$jscomp$1_props_83714$$=$go_to_team$jscomp$1_props_83714$$.goToTeam;
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"animated fade-in main_ui_onboarding_team_choice__modal-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:1,typography:"title-large",className:"main_ui_onboarding_team_choice__color-light",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding-v2.welcome.title")}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_onboarding_team_choice__modal-sections",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_info_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__modal-separator",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_onboarding_team_choice__modal-separator-line"})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$team_form_STAR_$$,{goToTeam:$go_to_team$jscomp$1_props_83714$$})]})]})})},
$app$main$ui$releases$common$navigation_bullets_STAR_$$=function($props_83703$$){var $navigate$jscomp$5$$=$props_83703$$.navigate,$slide$$=$props_83703$$.slide;return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_releases_common__step-dots",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$266$$,$i$jscomp$546$$){$out_arr__44092__auto__$jscomp$266$$.push((0,$APP.$rumext$v2$jsx$$)("li",{onClick:function(){return $navigate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?
$navigate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($i$jscomp$546$$):$navigate$jscomp$5$$($i$jscomp$546$$)},className:"main_ui_releases_common__dot "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($slide$$,$i$jscomp$546$$)?"main_ui_releases_common__current":"")}));return $out_arr__44092__auto__$jscomp$266$$},[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($props_83703$$.total))})},$app$main$ui$releases$release_notes_STAR_$$=function($klass$jscomp$39_props_83925$$){var $version$jscomp$61$$=
$klass$jscomp$39_props_83925$$.version,$slide_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1297$start$$),$slide$jscomp$34$$=$APP.$cljs$core$_deref$$($slide_STAR_$$),$klass_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("fade-in-down");$klass$jscomp$39_props_83925$$=$APP.$cljs$core$_deref$$($klass_STAR_$$);var $navigate$jscomp$37$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__83904_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($slide_STAR_$$,
$p1__83904_SHARP_$$)}),$next$jscomp$44$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($slide$jscomp$34$$)],function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($slide$jscomp$34$$,$APP.$cljs$cst$1297$start$$))return $navigate$jscomp$37$$.$cljs$core$IFn$_invoke$arity$1$?$navigate$jscomp$37$$.$cljs$core$IFn$_invoke$arity$1$(0):$navigate$jscomp$37$$(0);var $G__83926$$=$slide$jscomp$34$$+1;return $navigate$jscomp$37$$.$cljs$core$IFn$_invoke$arity$1$?
$navigate$jscomp$37$$.$cljs$core$IFn$_invoke$arity$1$($G__83926$$):$navigate$jscomp$37$$($G__83926$$)}),$finish$jscomp$38$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($version$jscomp$61$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$profile$mark_onboarding_as_viewed$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1726$version$$,$version$jscomp$61$$],null))]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$profile$mark_onboarding_as_viewed$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1726$version$$,$version$jscomp$61$$],null)))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($slide$jscomp$34$$)],
function(){$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$slide$jscomp$34$$)&&$APP.$cljs$core$reset_BANG_$$($klass_STAR_$$,"fade-in");var $sem$jscomp$11$$=$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(300,function(){return $APP.$cljs$core$reset_BANG_$$($klass_STAR_$$,null)});return function(){$APP.$cljs$core$reset_BANG_$$($klass_STAR_$$,null);return $APP.$beicon$v2$core$_dispose$$($sem$jscomp$11$$)}});return $app$main$ui$releases$common$render_release_notes$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1333$next$$,$next$jscomp$44$$,$APP.$cljs$cst$1957$navigate$$,$navigate$jscomp$37$$,$cljs$cst$6455$finish$$,$finish$jscomp$38$$,$cljs$cst$6454$klass$$,$klass$jscomp$39_props_83925$$,$APP.$cljs$cst$1974$slide$$,$slide$jscomp$34$$,$APP.$cljs$cst$1726$version$$,$version$jscomp$61$$],null))},$app$main$ui$releases$release_notes_modal$$=function($props_83936$$){var $versions$jscomp$1$$=$cljs$core$_methods$$();return $APP.$cljs$core$contains_QMARK_$$($versions$jscomp$1$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_83936$$,
"version"))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"relnotes",children:(0,$APP.$rumext$v2$create_element$$)($app$main$ui$releases$release_notes_STAR_$$,$props_83936$$)}):null},$app$main$ui$workspace_legacy_redirect_STAR_$$=function($props_83993$$){var $project_id$jscomp$54$$=$props_83993$$.projectId,$file_id$jscomp$461$$=$props_83993$$.fileId,$layout$jscomp$42$$=$props_83993$$.layout,$page_id$jscomp$484$$=$props_83993$$.pageId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($map__83996__$1_p__83995_team_id$jscomp$189$$){$map__83996__$1_p__83995_team_id$jscomp$189$$=$APP.$cljs$core$__destructure_map$$($map__83996__$1_p__83995_team_id$jscomp$189$$);$map__83996__$1_p__83995_team_id$jscomp$189$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83996__$1_p__83995_team_id$jscomp$189$$,$APP.$cljs$cst$1944$team_id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,
$map__83996__$1_p__83995_team_id$jscomp$189$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$461$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$484$$,$APP.$cljs$cst$1620$layout$$,$layout$jscomp$42$$])))},$APP.$app$main$errors$on_error$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3564$get_project$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$project_id$jscomp$54$$],null)))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$dashboard_legacy_redirect_STAR_$$=function($props_83999$$){var $project_id$jscomp$55$$=$props_83999$$.projectId,$team_id$jscomp$190$$=$props_83999$$.teamId,$search_term$jscomp$9$$=$props_83999$$.searchTerm,$plugin_url$jscomp$6$$=$props_83999$$.pluginUrl,$section$jscomp$56$$=$props_83999$$.section,$template$jscomp$13$$=$props_83999$$.template,$section__$1$jscomp$4$$=function(){var $G__84000__$1$$=
$section$jscomp$56$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$56$$.$fqn$:null;switch($G__84000__$1$$){case "dashboard-legacy-search":return $APP.$cljs$cst$2526$dashboard_search$$;case "dashboard-legacy-projects":return $APP.$cljs$cst$2533$dashboard_recent$$;case "dashboard-legacy-files":return $APP.$cljs$cst$2523$dashboard_files$$;case "dashboard-legacy-libraries":return $APP.$cljs$cst$2529$dashboard_libraries$$;case "dashboard-legacy-fonts":return $APP.$cljs$cst$2531$dashboard_fonts$$;
case "dashboard-legacy-font-providers":return $cljs$cst$6462$dashboard_font_providers$$;case "dashboard-legacy-team-members":return $APP.$cljs$cst$2535$dashboard_members$$;case "dashboard-legacy-team-invitations":return $APP.$cljs$cst$2537$dashboard_invitations$$;case "dashboard-legacy-team-webhooks":return $APP.$cljs$cst$2539$dashboard_webhooks$$;case "dashboard-legacy-team-settings":return $APP.$cljs$cst$2541$dashboard_settings$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__84000__$1$$)].join(""));
}}();$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($section__$1$jscomp$4$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$190$$,$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$55$$,$APP.$cljs$cst$2527$search_term$$,
$search_term$jscomp$9$$,$APP.$cljs$cst$3455$plugin$$,$plugin_url$jscomp$6$$,$APP.$cljs$cst$2414$template$$,$template$jscomp$13$$],null))))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$viewer_legacy_redirect_STAR_$$=function($props_84005$$){var $file_id$jscomp$462$$=$props_84005$$.fileId,$index$jscomp$602$$=$props_84005$$.index,$section$jscomp$57$$=$props_84005$$.section,
$interactions_mode$jscomp$11$$=$props_84005$$.interactionsMode,$page_id$jscomp$485$$=$props_84005$$.pageId,$share$jscomp$7$$=$props_84005$$.share,$share_id$jscomp$36$$=$props_84005$$.shareId,$frame_id$jscomp$171$$=$props_84005$$.frameId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1597$viewer$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
8,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$485$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$462$$,$APP.$cljs$cst$1371$section$$,$section$jscomp$57$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$602$$,$APP.$cljs$cst$3262$share_id$$,$share_id$jscomp$36$$,$APP.$cljs$cst$5339$interactions_mode$$,$interactions_mode$jscomp$11$$,$APP.$cljs$cst$1612$frame_id$$,$frame_id$jscomp$171$$,$APP.$cljs$cst$5508$share$$,$share$jscomp$7$$],null))))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})},$app$main$ui$team_container_STAR_$$=function($map__84011_map__84011__$1_props_84006$$){var $children$jscomp$323$$=$map__84011_map__84011__$1_props_84006$$.children,$team_id$jscomp$191$$=$map__84011_map__84011__$1_props_84006$$.teamId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$191$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$initialize_team$$($team_id$jscomp$191$$));
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$finalize_team$$($team_id$jscomp$191$$))}});$map__84011_map__84011__$1_props_84006$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$);$map__84011_map__84011__$1_props_84006$$=$APP.$cljs$core$__destructure_map$$($map__84011_map__84011__$1_props_84006$$);var $permissions$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84011_map__84011__$1_props_84006$$,$APP.$cljs$cst$1728$permissions$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$191$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__84011_map__84011__$1_props_84006$$))?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_team_id$$),{value:$team_id$jscomp$191$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$permissions$$),{value:$permissions$jscomp$50$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$can_edit_QMARK_$$),
{value:$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$50$$),children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$children$jscomp$323$$},$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($team_id$jscomp$191$$))})})}):null},$app$main$ui$page_STAR_$$=function($map__84018__$1_props_84013$$){var $profile$jscomp$96$$=$map__84018__$1_props_84013$$.profile,$route$jscomp$26$$=$map__84018__$1_props_84013$$.route;$map__84018__$1_props_84013$$=$APP.$cljs$core$__destructure_map$$($route$jscomp$26$$);
var $data$jscomp$531$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84018__$1_props_84013$$,$APP.$cljs$cst$142$data$$),$params$jscomp$463$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84018__$1_props_84013$$,$APP.$cljs$cst$1435$params$$),$props$jscomp$423$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$96$$,$APP.$cljs$cst$575$props$$),$section$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$531$$,$APP.$cljs$cst$725$name$$),
$team$jscomp$97$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$nitrate_entry_active_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$storage$$,$APP.$cljs$cst$5170$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$)===!0,$show_question_modal_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$onboarding$$)&&!$nitrate_entry_active_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$cst$3252$onboarding_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$423$$))&&
!$APP.$cljs$core$contains_QMARK_$$($props$jscomp$423$$,$APP.$cljs$cst$3256$onboarding_questions$$),$show_team_modal_QMARK_$$=function(){var $and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$onboarding$$);return $and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$?($and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$=
!$nitrate_entry_active_QMARK_$$)?($and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$=$APP.$cljs$core$not$$($APP.$cljs$cst$3252$onboarding_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$423$$)))?($and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$=!$APP.$cljs$core$contains_QMARK_$$($props$jscomp$423$$,$cljs$cst$6450$onboarding_team_id$$))?
$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$97$$):$and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$:$and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$:$and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$:$and__5023__auto__$jscomp$1087_and__5023__auto____$1$jscomp$177_and__5023__auto____$2$jscomp$58_and__5023__auto____$3$jscomp$11$$}(),
$show_release_modal_QMARK_$$=function(){var $and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1223$onboarding$$);return $and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$?($and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$=
!$nitrate_entry_active_QMARK_$$)?($and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$=!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1246$hide_release_modal$$))?($and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$=$APP.$cljs$cst$3252$onboarding_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$423$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3253$release_notes_viewed$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$423$$),$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("0.0",$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)):$and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$):
$and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$:$and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$:$and__5023__auto__$jscomp$1088_and__5023__auto____$1$jscomp$178_and__5023__auto____$2$jscomp$59_and__5023__auto____$3$jscomp$12$$}();return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_route$$),{value:$route$jscomp$26$$,
children:function(){switch($section$jscomp$58$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$58$$.$fqn$:null){case "auth-login":case "auth-register":case "auth-register-validate":case "auth-register-success":case "auth-recovery-request":case "auth-recovery":return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$auth_page$$,{route:$route$jscomp$26$$})});case "auth-verify-token":return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$verify_token_page_STAR_$$,
{route:$route$jscomp$26$$})});case "nitrate-entry":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$nitrate$entry$nitrate_entry_page_STAR_$$,{profile:$profile$jscomp$96$$});case "settings-profile":case "settings-password":case "settings-options":case "settings-feedback":case "settings-subscription":case "settings-integrations":case "settings-notifications":var $params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$463$$,$APP.$cljs$cst$747$query$$),$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=
function(){var $G__84024_G__84024__$1$$=$params__$1$jscomp$64$$;$G__84024_G__84024__$1$$=$G__84024_G__84024__$1$$==null?null:$APP.$cljs$cst$5524$error_report_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84024_G__84024__$1$$);return $G__84024_G__84024__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84024_G__84024__$1$$)}();return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$settings_page_STAR_$$,{route:$route$jscomp$26$$,type:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$64$$,
$APP.$cljs$cst$139$type$$),errorReportId:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,errorHref:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$64$$,$APP.$cljs$cst$5525$error_href$$)})});case "debug-icons-preview":return $APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$icons_preview$icons_preview_STAR_$$,{}):null;case "debug-playground":return $APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$debug$playground$playground_STAR_$$,{}):null;case "dashboard-search":case "dashboard-recent":case "dashboard-files":case "dashboard-libraries":case "dashboard-fonts":case "dashboard-font-providers":case "dashboard-members":case "dashboard-invitations":case "dashboard-webhooks":case "dashboard-settings":case "dashboard-deleted":$params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$463$$,$APP.$cljs$cst$747$query$$);var $index$jscomp$603_team_id$jscomp$192$$=
function(){var $G__84025_G__84025__$1$$=$params__$1$jscomp$64$$;$G__84025_G__84025__$1$$=$G__84025_G__84025__$1$$==null?null:$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84025_G__84025__$1$$);return $G__84025_G__84025__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84025_G__84025__$1$$)}(),$project_id$jscomp$56_share_id$jscomp$37$$=function(){var $G__84026_G__84026__$1$$=$params__$1$jscomp$64$$;$G__84026_G__84026__$1$$=$G__84026_G__84026__$1$$==null?null:$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84026_G__84026__$1$$);
return $G__84026_G__84026__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84026_G__84026__$1$$)}();$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__84027$$=$params__$1$jscomp$64$$;return $G__84027$$==null?null:$APP.$cljs$cst$2527$search_term$$.$cljs$core$IFn$_invoke$arity$1$($G__84027$$)}();var $file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=function(){var $G__84028$$=$params__$1$jscomp$64$$;
return $G__84028$$==null?null:$APP.$cljs$cst$3455$plugin$$.$cljs$core$IFn$_invoke$arity$1$($G__84028$$)}(),$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__84030$$=$params__$1$jscomp$64$$;return $G__84030$$==null?null:$APP.$cljs$cst$2414$template$$.$cljs$core$IFn$_invoke$arity$1$($G__84030$$)}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Suspense$$,{children:[$show_question_modal_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$questions_modal$$,
{}):$APP.$cljs$core$truth_$$($show_team_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$onboarding_team_modal_STAR_$$,{goToTeam:!0}):$APP.$cljs$core$truth_$$($show_release_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$release_notes_modal$$,{version:$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$team_container_STAR_$$,{teamId:$index$jscomp$603_team_id$jscomp$192$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard_page_STAR_$$,
{profile:$profile$jscomp$96$$,section:$section$jscomp$58$$,teamId:$index$jscomp$603_team_id$jscomp$192$$,searchTerm:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,pluginUrl:$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,projectId:$project_id$jscomp$56_share_id$jscomp$37$$,template:$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$})})]});case "workspace":return $params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$463$$,
$APP.$cljs$cst$747$query$$),$index$jscomp$603_team_id$jscomp$192$$=function(){var $G__84032_G__84032__$1$$=$params__$1$jscomp$64$$;$G__84032_G__84032__$1$$=$G__84032_G__84032__$1$$==null?null:$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84032_G__84032__$1$$);return $G__84032_G__84032__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84032_G__84032__$1$$)}(),$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=function(){var $G__84033_G__84033__$1$$=
$params__$1$jscomp$64$$;$G__84033_G__84033__$1$$=$G__84033_G__84033__$1$$==null?null:$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84033_G__84033__$1$$);return $G__84033_G__84033__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84033_G__84033__$1$$)}(),$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__84034_G__84034__$1$$=$params__$1$jscomp$64$$;$G__84034_G__84034__$1$$=$G__84034_G__84034__$1$$==null?null:$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84034_G__84034__$1$$);
return $G__84034_G__84034__$1$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84034_G__84034__$1$$)}(),$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__84035_G__84035__$1$$=$params__$1$jscomp$64$$;$G__84035_G__84035__$1$$=$G__84035_G__84035__$1$$==null?null:$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($G__84035_G__84035__$1$$);return $G__84035_G__84035__$1$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__84035_G__84035__$1$$)}(),
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Suspense$$,{children:[$APP.$cljs$core$truth_$$($APP.$app$config$external_feature_flag$$())?$show_question_modal_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$questions$questions_modal$$,{}):$APP.$cljs$core$truth_$$($show_team_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$onboarding$team_choice$onboarding_team_modal_STAR_$$,{goToTeam:!1}):$APP.$cljs$core$truth_$$($show_release_modal_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$release_notes_modal$$,
{version:$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)}):null:null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$team_container_STAR_$$,{teamId:$index$jscomp$603_team_id$jscomp$192$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace_page_STAR_$$,{teamId:$index$jscomp$603_team_id$jscomp$192$$,fileId:$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,pageId:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,
layoutName:$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$},$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$)})]});case "viewer":$params__$1$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$463$$,$APP.$cljs$cst$747$query$$);$index$jscomp$603_team_id$jscomp$192$$=function(){var $G__84038$$=$APP.$app$main$router$get_query_param$$($params__$1$jscomp$64$$,$APP.$cljs$cst$1801$index$$);return $G__84038$$==null?null:
$APP.$cljs$core$parse_long$$($G__84038$$)}();$project_id$jscomp$56_share_id$jscomp$37$$=function(){var $G__84039$$=$APP.$cljs$cst$3262$share_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__84039$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84039$$)}();$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__84042$jscomp$inline_10096_or__5025__auto__$jscomp$1488$$=$APP.$cljs$cst$1371$section$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);
$G__84042$jscomp$inline_10096_or__5025__auto__$jscomp$1488$$=$G__84042$jscomp$inline_10096_or__5025__auto__$jscomp$1488$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__84042$jscomp$inline_10096_or__5025__auto__$jscomp$1488$$);return $APP.$cljs$core$truth_$$($G__84042$jscomp$inline_10096_or__5025__auto__$jscomp$1488$$)?$G__84042$jscomp$inline_10096_or__5025__auto__$jscomp$1488$$:$APP.$cljs$cst$2059$interactions$$}();$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=
function(){var $G__84043$$=$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__84043$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84043$$)}();$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__84044$$=$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__84044$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84044$$)}();var $imode_interactions_mode$jscomp$12$$=
function(){var $G__84045$jscomp$inline_10098_or__5025__auto__$jscomp$1489$$=$APP.$cljs$cst$5339$interactions_mode$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);$G__84045$jscomp$inline_10098_or__5025__auto__$jscomp$1489$$=$G__84045$jscomp$inline_10098_or__5025__auto__$jscomp$1489$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__84045$jscomp$inline_10098_or__5025__auto__$jscomp$1489$$);return $APP.$cljs$core$truth_$$($G__84045$jscomp$inline_10098_or__5025__auto__$jscomp$1489$$)?
$G__84045$jscomp$inline_10098_or__5025__auto__$jscomp$1489$$:$APP.$cljs$cst$5342$show_on_click$$}(),$frame_id$jscomp$172$$=function(){var $G__84046$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return $G__84046$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84046$$)}(),$map__84063__$1_share$jscomp$8$$=$APP.$cljs$cst$5508$share$$.$cljs$core$IFn$_invoke$arity$1$($params__$1$jscomp$64$$);return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Suspense$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer_page_STAR_$$,
{pageId:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,fileId:$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,frameId:$frame_id$jscomp$172$$,section:$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$,index:$index$jscomp$603_team_id$jscomp$192$$,shareId:$project_id$jscomp$56_share_id$jscomp$37$$,interactionsMode:$imode_interactions_mode$jscomp$12$$,share:$map__84063__$1_share$jscomp$8$$})});case "workspace-legacy":return $project_id$jscomp$56_share_id$jscomp$37$$=
function(){var $G__84047__$1_G__84047__$2$$=$params$jscomp$463$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);$G__84047__$1_G__84047__$2$$=$G__84047__$1_G__84047__$2$$==null?null:$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84047__$1_G__84047__$2$$);return $G__84047__$1_G__84047__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84047__$1_G__84047__$2$$)}(),$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=
function(){var $G__84050__$1_G__84050__$2$$=$params$jscomp$463$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);$G__84050__$1_G__84050__$2$$=$G__84050__$1_G__84050__$2$$==null?null:$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84050__$1_G__84050__$2$$);return $G__84050__$1_G__84050__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84050__$1_G__84050__$2$$)}(),$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=
function(){var $G__84051__$1_G__84051__$2$$=$params$jscomp$463$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);$G__84051__$1_G__84051__$2$$=$G__84051__$1_G__84051__$2$$==null?null:$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84051__$1_G__84051__$2$$);return $G__84051__$1_G__84051__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84051__$1_G__84051__$2$$)}(),$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$=function(){var $G__84052__$1_G__84052__$2$$=
$params$jscomp$463$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);$G__84052__$1_G__84052__$2$$=$G__84052__$1_G__84052__$2$$==null?null:$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($G__84052__$1_G__84052__$2$$);return $G__84052__$1_G__84052__$2$$==null?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__84052__$1_G__84052__$2$$)}(),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace_legacy_redirect_STAR_$$,{projectId:$project_id$jscomp$56_share_id$jscomp$37$$,
fileId:$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,pageId:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,layout:$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$});case "dashboard-legacy-search":case "dashboard-legacy-projects":case "dashboard-legacy-files":case "dashboard-legacy-libraries":case "dashboard-legacy-fonts":case "dashboard-legacy-font-providers":case "dashboard-legacy-team-members":case "dashboard-legacy-team-invitations":case "dashboard-legacy-team-webhooks":case "dashboard-legacy-team-settings":return $index$jscomp$603_team_id$jscomp$192$$=
function(){var $G__84055__$1_G__84055__$2$$=$params$jscomp$463$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);$G__84055__$1_G__84055__$2$$=$G__84055__$1_G__84055__$2$$==null?null:$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84055__$1_G__84055__$2$$);return $G__84055__$1_G__84055__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84055__$1_G__84055__$2$$)}(),$project_id$jscomp$56_share_id$jscomp$37$$=function(){var $G__84056__$1_G__84056__$2$$=
$params$jscomp$463$$==null?null:$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);$G__84056__$1_G__84056__$2$$=$G__84056__$1_G__84056__$2$$==null?null:$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($G__84056__$1_G__84056__$2$$);return $G__84056__$1_G__84056__$2$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($G__84056__$1_G__84056__$2$$)}(),$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=function(){var $G__84059__$1$$=
$params$jscomp$463$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);return $G__84059__$1$$==null?null:$APP.$cljs$cst$2527$search_term$$.$cljs$core$IFn$_invoke$arity$1$($G__84059__$1$$)}(),$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=function(){var $G__84060__$1$$=$params$jscomp$463$$==null?null:$APP.$cljs$cst$747$query$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$);return $G__84060__$1$$==null?null:
$APP.$cljs$cst$3455$plugin$$.$cljs$core$IFn$_invoke$arity$1$($G__84060__$1$$)}(),$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$=$params$jscomp$463$$==null?null:$APP.$cljs$cst$2414$template$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$463$$),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard_legacy_redirect_STAR_$$,{teamId:$index$jscomp$603_team_id$jscomp$192$$,section:$section$jscomp$58$$,projectId:$project_id$jscomp$56_share_id$jscomp$37$$,searchTerm:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,
pluginUrl:$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,template:$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$});case "viewer-legacy":return $file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($route$jscomp$26$$),$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,
$APP.$cljs$cst$2278$query_params$$),$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,$APP.$cljs$cst$2406$path_params$$),$map__84063__$1_share$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$),$index$jscomp$603_team_id$jscomp$192$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84063__$1_share$jscomp$8$$,$APP.$cljs$cst$1801$index$$),$project_id$jscomp$56_share_id$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84063__$1_share$jscomp$8$$,$APP.$cljs$cst$3262$share_id$$),$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__84063__$1_share$jscomp$8$$,$APP.$cljs$cst$1371$section$$,$APP.$cljs$cst$2059$interactions$$),$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84063__$1_share$jscomp$8$$,$APP.$cljs$cst$2051$page_id$$),$imode_interactions_mode$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__84063__$1_share$jscomp$8$$,$APP.$cljs$cst$5339$interactions_mode$$,$APP.$cljs$cst$5342$show_on_click$$),$frame_id$jscomp$172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84063__$1_share$jscomp$8$$,$APP.$cljs$cst$1612$frame_id$$),$map__84063__$1_share$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84063__$1_share$jscomp$8$$,
$APP.$cljs$cst$5508$share$$),$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$),$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,$APP.$cljs$cst$1649$file_id$$),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer_legacy_redirect_STAR_$$,{pageId:$error_report_id$jscomp$1_page_id$jscomp$486_query_params$jscomp$3_search_term$jscomp$10$$,fileId:$file_id$jscomp$463_map__84062__$1_map__84064__$1_path_params$jscomp$20_plugin_url$jscomp$7$$,section:$layout$jscomp$43_section__$1$jscomp$5_template$jscomp$14$$,index:$index$jscomp$603_team_id$jscomp$192$$,shareId:$project_id$jscomp$56_share_id$jscomp$37$$,interactionsMode:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($imode_interactions_mode$jscomp$12$$),
frameId:$frame_id$jscomp$172$$,share:$map__84063__$1_share$jscomp$8$$});case "frame-preview":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$frame_preview$frame_preview_STAR_$$,{});default:return null}}()})},$app$main$ui$app$$=function(){var $route$jscomp$27$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$),$edata$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$exception$$),$profile$jscomp$97$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$app$util$theme$use_initialize$$($profile$jscomp$97$$);
document.documentElement.style.overscrollBehaviorX="none";document.body.style.overscrollBehaviorX="none";return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_route$$),{value:$route$jscomp$27$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_profile$$),{value:$profile$jscomp$97$$,children:$APP.$cljs$core$truth_$$($edata$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$static$0$exception_page_STAR_$$,{data:$edata$jscomp$1$$,
route:$route$jscomp$27$$}):(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$error_boundary$error_boundary_STAR_$$,{fallback:$app$main$ui$static$0$exception_page_STAR_$$,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$notifications$current_notification_STAR_$$,{}),$APP.$cljs$core$truth_$$($route$jscomp$27$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$page_STAR_$$,{route:$route$jscomp$27$$,profile:$profile$jscomp$97$$}):null]})})})},$app$main$ui$confirm$confirm_dialog$$=function($items$jscomp$66_map__83838_props_83837$$){$items$jscomp$66_map__83838_props_83837$$=
$APP.$rumext$v2$util$wrap_props$$($items$jscomp$66_map__83838_props_83837$$);var $map__83838__$1$$=$APP.$cljs$core$__destructure_map$$($items$jscomp$66_map__83838_props_83837$$);$items$jscomp$66_map__83838_props_83837$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$1844$items$$);var $hint_level$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$5198$hint_level$$),$message__$1$jscomp$2_on_cancel$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,
$APP.$cljs$cst$5720$on_cancel$$),$accept_fn$jscomp$4_message$jscomp$127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$141$message$$),$accept_style$jscomp$1_accept_style__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$2488$accept_style$$),$accept_label$jscomp$2_accept_label__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$2487$accept_label$$),$scd_message$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$5234$scd_message$$),$cancel_label$jscomp$1_cancel_label__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$2485$cancel_label$$),$hint$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$275$hint$$),$title$jscomp$55_title__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$939$title$$),
$error_msg$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$5192$error_msg$$),$cancel_fn$jscomp$1_on_accept$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83838__$1$$,$APP.$cljs$cst$2490$on_accept$$),$on_accept__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($cancel_fn$jscomp$1_on_accept$jscomp$21$$)?$cancel_fn$jscomp$1_on_accept$jscomp$21$$:$APP.$cljs$core$identity$$,$on_cancel__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($message__$1$jscomp$2_on_cancel$jscomp$13$$)?
$message__$1$jscomp$2_on_cancel$jscomp$13$$:$APP.$cljs$core$identity$$;$message__$1$jscomp$2_on_cancel$jscomp$13$$=$APP.$cljs$core$truth_$$($accept_fn$jscomp$4_message$jscomp$127$$)?$accept_fn$jscomp$4_message$jscomp$127$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-title");$cancel_label$jscomp$1_cancel_label__$1$$=$APP.$cljs$core$truth_$$($cancel_label$jscomp$1_cancel_label__$1$$)?$cancel_label$jscomp$1_cancel_label__$1$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-cancel");
$accept_label$jscomp$2_accept_label__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($accept_label$jscomp$2_accept_label__$1$jscomp$1$$)?$accept_label$jscomp$2_accept_label__$1$jscomp$1$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-ok");$accept_style$jscomp$1_accept_style__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($accept_style$jscomp$1_accept_style__$1$jscomp$1$$)?$accept_style$jscomp$1_accept_style__$1$jscomp$1$$:$APP.$cljs$cst$5199$danger$$;$title$jscomp$55_title__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($title$jscomp$55_title__$1$jscomp$3$$)?
$title$jscomp$55_title__$1$jscomp$3$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-title");$accept_fn$jscomp$4_message$jscomp$127$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$799$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$799$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($map__83838__$1$$):
$on_accept__$1$jscomp$2$$($map__83838__$1$$)});$cancel_fn$jscomp$1_on_accept$jscomp$21$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$800$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$800$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_cancel__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_cancel__$1$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($map__83838__$1$$):$on_cancel__$1$jscomp$1$$($map__83838__$1$$)});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$APP.$goog$events$listen$$(document,"keydown",function($event$jscomp$801$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$801$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$801$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$801$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$()),
$on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($map__83838__$1$$):$on_accept__$1$jscomp$2$$($map__83838__$1$$)):null}))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_confirm__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_confirm__modal-title",
children:$title$jscomp$55_title__$1$jscomp$3$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_confirm__modal-close-btn",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$cancel_fn$jscomp$1_on_accept$jscomp$21$$,icon:"close"})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__modal-content",children:[typeof $message__$1$jscomp$2_on_cancel$jscomp$13$$===
"string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($message__$1$jscomp$2_on_cancel$jscomp$13$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_confirm__modal-msg",children:$message__$1$jscomp$2_on_cancel$jscomp$13$$}):null,typeof $scd_message$jscomp$1$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($scd_message$jscomp$1$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_confirm__modal-scd-msg",children:$scd_message$jscomp$1$$}):null,typeof $hint$jscomp$31$$===
"string"?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$core$truth_$$($hint_level$$)?$hint_level$$:$APP.$cljs$cst$1161$info$$,appearance:$APP.$cljs$cst$5103$ghost$$,children:$hint$jscomp$31$$}):null,typeof $error_msg$jscomp$1$$==="string"?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$849$error$$,className:"main_ui_confirm__modal-error-msg",
children:$error_msg$jscomp$1$$}):null,$APP.$cljs$core$count$$($items$jscomp$66_map__83838_props_83837$$)>0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_confirm__modal-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.component-subtitle")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_confirm__component-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$267$$,
$item$jscomp$155$$){$out_arr__44092__auto__$jscomp$267$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_confirm__modal-item-element",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"component",className:"main_ui_confirm__modal-component-icon",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_confirm__modal-component-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$155$$)})]}));return $out_arr__44092__auto__$jscomp$267$$},
[],$items$jscomp$66_map__83838_props_83837$$)})]}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_confirm__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_confirm__action-buttons",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cancel_label$jscomp$1_cancel_label__$1$$,$APP.$cljs$cst$2486$omit$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",onClick:$cancel_fn$jscomp$1_on_accept$jscomp$21$$,
children:$cancel_label$jscomp$1_cancel_label__$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$1_accept_style__$1$jscomp$1$$,$APP.$cljs$cst$5199$danger$$)?"destructive":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$1_accept_style__$1$jscomp$1$$,$APP.$cljs$cst$2489$primary$$)?"primary":null,onClick:$accept_fn$jscomp$4_message$jscomp$127$$,children:$accept_label$jscomp$2_accept_label__$1$jscomp$1$$})]})})]})})},
$app$main$ui$delete_shared$delete_shared_dialog$$=function($props_83841_references$jscomp$10$$){var $cancel_label$jscomp$2_on_cancel$jscomp$14$$=$props_83841_references$jscomp$10$$["on-cancel"],$accept_style$jscomp$2_accept_style__$1$jscomp$2$$=$props_83841_references$jscomp$10$$["accept-style"],$count_libraries$$=$props_83841_references$jscomp$10$$["count-libraries"],$ids$jscomp$327$$=$props_83841_references$jscomp$10$$.ids,$on_accept$jscomp$22_title$jscomp$56$$=$props_83841_references$jscomp$10$$["on-accept"],
$origin$jscomp$86$$=$props_83841_references$jscomp$10$$.origin,$references_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$props_83841_references$jscomp$10$$=$APP.$cljs$core$_deref$$($references_STAR_$$);var $on_accept__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($on_accept$jscomp$22_title$jscomp$56$$)?$on_accept$jscomp$22_title$jscomp$56$$:$app$main$ui$delete_shared$noop$$,$on_cancel__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($cancel_label$jscomp$2_on_cancel$jscomp$14$$)?$cancel_label$jscomp$2_on_cancel$jscomp$14$$:
$app$main$ui$delete_shared$noop$$;$cancel_label$jscomp$2_on_cancel$jscomp$14$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel");$accept_style$jscomp$2_accept_style__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($accept_style$jscomp$2_accept_style__$1$jscomp$2$$)?$accept_style$jscomp$2_accept_style__$1$jscomp$2$$:$APP.$cljs$cst$5199$danger$$;var $count_files_hint$jscomp$32$$=$APP.$cljs$core$count$$($APP.$cljs$core$keys$$($props_83841_references$jscomp$10$$));$on_accept$jscomp$22_title$jscomp$56$$=
function(){var $G__83842__$1$$=$origin$jscomp$86$$ instanceof $APP.$cljs$core$Keyword$$?$origin$jscomp$86$$.$fqn$:null;switch($G__83842__$1$$){case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "unpublish":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.unpublish-shared-confirm.title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.move-shared-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83842__$1$$)].join(""));}}();var $subtitle$jscomp$2$$=function(){var $G__83845__$1$$=
$origin$jscomp$86$$ instanceof $APP.$cljs$core$Keyword$$?$origin$jscomp$86$$.$fqn$:null;switch($G__83845__$1$$){case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "unpublish":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.unpublish-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));
case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.move-shared-confirm.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83845__$1$$)].join(""));}}(),$accept_label$jscomp$3$$=function(){var $G__83848__$1$$=$origin$jscomp$86$$ instanceof $APP.$cljs$core$Keyword$$?$origin$jscomp$86$$.$fqn$:null;
switch($G__83848__$1$$){case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.accept",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "unpublish":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.unpublish-shared-confirm.accept",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.move-shared-confirm.accept",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83848__$1$$)].join(""));}}(),$no_files_msg$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.activated.no-files-message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)])),$scd_msg$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-shared-confirm.activated.scd-message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_libraries$$)]));$count_files_hint$jscomp$32$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-unpublish-shared-confirm.activated.hint",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($count_files_hint$jscomp$32$$)]));var $accept_fn$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_accept__$1$jscomp$3$$)],
function($event$jscomp$802$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$802$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_accept__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_accept__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_accept__$1$jscomp$3$$()}),$cancel_fn$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel__$1$jscomp$2$$)],function($event$jscomp$803$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$803$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $on_cancel__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel__$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel__$1$jscomp$2$$()});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$327$$)],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83840_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($references_STAR_$$,
$p1__83840_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$),$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$identity$$,$APP.$beicon$v2$core$mapcat$$(function($p1__83839_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6463$get_library_file_references$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$p1__83839_SHARP_$$],null))},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$from$$($ids$jscomp$327$$)))))))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($accept_fn$jscomp$5$$)],function(){var $key$jscomp$440$$=$APP.$goog$events$listen$$(document,"keydown",function($event$jscomp$804$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$804$$))?
($APP.$app$util$dom$prevent_default$$($event$jscomp$804$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$804$$),$accept_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$accept_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$accept_fn$jscomp$5$$()):null});return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$key$jscomp$440$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_delete_shared__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_delete_shared__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_delete_shared__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_delete_shared__modal-title",children:$on_accept$jscomp$22_title$jscomp$56$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$cancel_fn$jscomp$2$$,className:"main_ui_delete_shared__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_delete_shared__modal-content",
children:[typeof $subtitle$jscomp$2$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subtitle$jscomp$2$$,"")?(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_delete_shared__modal-subtitle",children:$subtitle$jscomp$2$$}):null,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$count_libraries$$)?$APP.$cljs$core$count$$($props_83841_references$jscomp$10$$)>0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[typeof $scd_msg$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($scd_msg$$,
"")?(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_delete_shared__modal-scd-msg",children:$scd_msg$$}):null,(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_delete_shared__element-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$268$$,$file_name$jscomp$14_p__83930$$){var $file_id$jscomp$464$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_name$jscomp$14_p__83930$$,0,null);$file_name$jscomp$14_p__83930$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_name$jscomp$14_p__83930$$,
1,null);$out_arr__44092__auto__$jscomp$268$$.push((0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_delete_shared__list-item",children:(0,$APP.$rumext$v2$jsxs$$)("span",{children:["- ",$file_name$jscomp$14_p__83930$$]})},""+($file_id$jscomp$464$$??"")));return $out_arr__44092__auto__$jscomp$268$$},[],$props_83841_references$jscomp$10$$)}),typeof $count_files_hint$jscomp$32$$==="string"&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($count_files_hint$jscomp$32$$,"")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,
{level:$APP.$cljs$cst$1161$info$$,appearance:$APP.$cljs$cst$5103$ghost$$,children:$count_files_hint$jscomp$32$$}):null]}):(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsx$$)("h3",{className:"main_ui_delete_shared__modal-msg",children:$no_files_msg$$})}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_delete_shared__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_delete_shared__action-buttons",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cancel_label$jscomp$2_on_cancel$jscomp$14$$,
$APP.$cljs$cst$2486$omit$$)?null:(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$cancel_label$jscomp$2_on_cancel$jscomp$14$$,onClick:$cancel_fn$jscomp$2$$,className:"main_ui_delete_shared__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$accept_label$jscomp$3$$,onClick:$accept_fn$jscomp$5$$,className:"main_ui_delete_shared__accept-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$2_accept_style__$1$jscomp$2$$,$APP.$cljs$cst$5199$danger$$)?
"main_ui_delete_shared__danger":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($accept_style$jscomp$2_accept_style__$1$jscomp$2$$,$APP.$cljs$cst$2489$primary$$)?"main_ui_delete_shared__primary":"")})]})})]})})},$app$main$ui$routes$check_sso_and_navigate$$=function($match$jscomp$60$$,$send_event_info_QMARK_$jscomp$2$$){var $url$jscomp$105$$=$APP.$app$util$globals$location$$.href,$route_name$jscomp$2_team_id$jscomp$193_team_id_str$$=$APP.$cljs$core$name$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($match$jscomp$60$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null)));$route_name$jscomp$2_team_id$jscomp$193_team_id_str$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)&&($APP.$cuerdas$core$starts_with_QMARK_$$($route_name$jscomp$2_team_id$jscomp$193_team_id_str$$,"dashboard")||$APP.$cuerdas$core$starts_with_QMARK_$$($route_name$jscomp$2_team_id$jscomp$193_team_id_str$$,
"workspace"))?function(){var $or__5025__auto__$jscomp$1501$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($match$jscomp$60$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2278$query_params$$,$APP.$cljs$cst$1944$team_id$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1501$$)?$or__5025__auto__$jscomp$1501$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($match$jscomp$60$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1944$team_id$$],null))}():null;$route_name$jscomp$2_team_id$jscomp$193_team_id_str$$=$route_name$jscomp$2_team_id$jscomp$193_team_id_str$$==null?null:$APP.$app$common$uuid$parse_STAR_$$($route_name$jscomp$2_team_id$jscomp$193_team_id_str$$);return $route_name$jscomp$2_team_id$jscomp$193_team_id_str$$!=null?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($authorized$jscomp$1_p__83856$$){var $map__83857__$1_redirect_uri$jscomp$4$$=
$APP.$cljs$core$__destructure_map$$($authorized$jscomp$1_p__83856$$);$authorized$jscomp$1_p__83856$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83857__$1_redirect_uri$jscomp$4$$,$APP.$cljs$cst$5091$authorized$$);$map__83857__$1_redirect_uri$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83857__$1_redirect_uri$jscomp$4$$,$APP.$cljs$cst$3405$redirect_uri$$);return $APP.$cljs$core$truth_$$($authorized$jscomp$1_p__83856$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$router$navigated$$($match$jscomp$60$$,
$send_event_info_QMARK_$jscomp$2$$)):$APP.$cljs$core$truth_$$($map__83857__$1_redirect_uri$jscomp$4$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1584$uri$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__83857__$1_redirect_uri$jscomp$4$$)]))):null},function($cause$jscomp$118$$){return $APP.$app$main$errors$on_error$$($cause$jscomp$118$$)},
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5092$check_nitrate_sso$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$route_name$jscomp$2_team_id$jscomp$193_team_id_str$$,$APP.$cljs$cst$1991$url$$,$url$jscomp$105$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$router$navigated$$($match$jscomp$60$$,$send_event_info_QMARK_$jscomp$2$$))},$app$main$ui$routes$on_navigate$$=function($match$jscomp$61_router$jscomp$9$$,
$path$jscomp$301$$,$send_event_info_QMARK_$jscomp$3$$){var $location__$1$jscomp$2_valid_location_QMARK_$$=document.location,$qs_vec__83927$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($path$jscomp$301$$,"?"),$base_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($qs_vec__83927$$,0,null);$qs_vec__83927$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($qs_vec__83927$$,1,null);$location__$1$jscomp$2_valid_location_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(""+
($location__$1$jscomp$2_valid_location_QMARK_$$.origin??"")+($location__$1$jscomp$2_valid_location_QMARK_$$.pathname??""),""+($APP.$app$config$public_uri$$??""));$match$jscomp$61_router$jscomp$9$$=$app$main$router$match$$($match$jscomp$61_router$jscomp$9$$,$path$jscomp$301$$);var $empty_path_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_path$$,"")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($base_path$$,"/"),$query_params$jscomp$4$$=$APP.$lambdaisland$uri$query_string__GT_map$cljs$0core$0IFn$0_invoke$0arity$02$$($qs_vec__83927$$);
return $location__$1$jscomp$2_valid_location_QMARK_$$?$match$jscomp$61_router$jscomp$9$$!=null?$app$main$ui$routes$check_sso_and_navigate$$($match$jscomp$61_router$jscomp$9$$,$send_event_info_QMARK_$jscomp$3$$):$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($map__83935__$1_p__83934_template$jscomp$inline_10103$$){$map__83935__$1_p__83934_template$jscomp$inline_10103$$=$APP.$cljs$core$__destructure_map$$($map__83935__$1_p__83934_template$jscomp$inline_10103$$);var $_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83935__$1_p__83934_template$jscomp$inline_10103$$,$APP.$cljs$cst$266$id$$),$map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83935__$1_p__83934_template$jscomp$inline_10103$$,$cljs$cst$6486$app_DOT_main_DOT_ui_DOT_routes_SLASH_teams$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$,
$APP.$app$common$uuid$zero$$)){$map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$=$APP.$cljs$core$__destructure_map$$($query_params$jscomp$4$$);$map__83935__$1_p__83934_template$jscomp$inline_10103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$,$APP.$cljs$cst$2414$template$$);$map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$,
$APP.$cljs$cst$3455$plugin$$);$_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$map__83935__$1_p__83934_template$jscomp$inline_10103$$!=null&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$session$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2414$template$$,$map__83935__$1_p__83934_template$jscomp$inline_10103$$),$map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$!=
null&&$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$session$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$6398$plugin_url$$,$map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3410$auth_login$$))}return $empty_path_QMARK_$$?
($_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$=$APP.$cljs$cst$3299$app_DOT_main_DOT_data_DOT_team_SLASH_current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$global$$),$APP.$cljs$core$contains_QMARK_$$($map__83844__$1$jscomp$inline_10102_plugin$jscomp$inline_10104_teams$jscomp$26$$,$_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2533$dashboard_recent$$,
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($query_params$jscomp$4$$,$APP.$cljs$cst$1944$team_id$$,$_STAR_sync_STAR__orig_val__83846$jscomp$inline_10105_id$jscomp$1088_team_id$jscomp$194$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2533$dashboard_recent$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($query_params$jscomp$4$$,$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$2507$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($map__83935__$1_p__83934_template$jscomp$inline_10103$$))))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2676$not_found$$],null)))},function($cause$jscomp$119$$){return $APP.$app$main$errors$on_error$$($cause$jscomp$119$$)},$APP.$beicon$v2$core$mapcat$$(function($profile$jscomp$99$$){return $APP.$beicon$v2$core$map$$(function($teams$jscomp$27$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($profile$jscomp$99$$,
$cljs$cst$6486$app_DOT_main_DOT_ui_DOT_routes_SLASH_teams$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$teams$jscomp$27$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3308$get_teams$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3229$get_profile$$))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$assign_exception$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2676$not_found$$],null)))},$app$main$ui$routes$init_routes$$=function(){typeof $app$main$ui$routes$init_routes_83959$$==="undefined"&&($app$main$ui$routes$init_routes_83959$$=function($meta83960$$){this.$meta83960$=$meta83960$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$ui$routes$init_routes_83959$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$ui$routes$init_routes_83959$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6487$app_DOT_main_DOT_ui_DOT_routes_SLASH_init_routes$$},$app$main$ui$routes$init_routes_83959$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_83961$$,$meta83960__$1$$){return new $app$main$ui$routes$init_routes_83959$$($meta83960__$1$$)},$app$main$ui$routes$init_routes_83959$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta83960$},$app$main$ui$routes$init_routes_83959$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$ui$routes$init_routes_83959$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3219$$,$___$1$jscomp$2129$$,$stream$jscomp$113$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$router$initialize_router$$(),$app$main$router$initialize_history$$()),$APP.$beicon$v2$core$map$$($APP.$app$main$features$recompute_features$$,
$APP.$beicon$v2$core$filter$$(function($p__83975_v2$jscomp$36$$){var $v1$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83975_v2$jscomp$36$$,0,null);$p__83975_v2$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83975_v2$jscomp$36$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v1$jscomp$45$$,$p__83975_v2$jscomp$36$$)},$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$beicon$v2$core$map$$(function($p1__83953_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__83953_SHARP_$$,
$APP.$cljs$cst$2278$query_params$$),$APP.$cljs$cst$3128$wasm$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2465$app_DOT_main_DOT_router_SLASH_navigated$$),$stream$jscomp$113$$)))))))});return new $app$main$ui$routes$init_routes_83959$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$plugins$image_data$create_image_data$$=function($obj_83855_p__83851$$){var $map__83852__$1$$=
$APP.$cljs$core$__destructure_map$$($obj_83855_p__83851$$),$name$jscomp$515$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83852__$1$$,$APP.$cljs$cst$725$name$$),$width$jscomp$260$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83852__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$225$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83852__$1$$,$APP.$cljs$cst$1527$height$$),$mtype$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83852__$1$$,
$APP.$cljs$cst$1732$mtype$$),$id$jscomp$1089$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83852__$1$$,$APP.$cljs$cst$266$id$$),$keep_aspect_ratio$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83852__$1$$,$APP.$cljs$cst$1733$keep_aspect_ratio$$);$obj_83855_p__83851$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_83855_p__83851$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ImageData"}});Object.defineProperty($obj_83855_p__83851$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ImageData"}});Object.defineProperty($obj_83855_p__83851$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($name$jscomp$515$$).call(this)}});Object.defineProperty($obj_83855_p__83851$$,"width",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($width$jscomp$260$$).call(this)}});Object.defineProperty($obj_83855_p__83851$$,"height",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($height$jscomp$225$$).call(this)}});
Object.defineProperty($obj_83855_p__83851$$,"mtype",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($mtype$jscomp$24$$).call(this)}});Object.defineProperty($obj_83855_p__83851$$,"id",{enumerable:!0,get:function(){return $APP.$cljs$core$truth_$$($id$jscomp$1089$$)?""+($id$jscomp$1089$$??""):null}});Object.defineProperty($obj_83855_p__83851$$,"keepAspectRatio",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($keep_aspect_ratio$jscomp$1$$).call(this)}});Object.defineProperty($obj_83855_p__83851$$,
"data",{enumerable:!1,get:function(){return function(){var $url$jscomp$106$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($map__83852__$1$$);return new Promise(function($resolve$jscomp$43$$,$reject$jscomp$28$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$43$$,$reject$jscomp$28$$,$APP.$beicon$v2$core$map$$(function($p1__83850_SHARP_$$){return new Uint8Array($p1__83850_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__83849_SHARP_$$){return $p1__83849_SHARP_$$.arrayBuffer()},
$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1586$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$1584$uri$$,$url$jscomp$106$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$1596$blob$$],null))))))})}.bind(this)}});return $obj_83855_p__83851$$},$app$plugins$format$format_id$$=function($id$jscomp$1090$$){return $APP.$cljs$core$truth_$$($id$jscomp$1090$$)?""+($id$jscomp$1090$$??""):null},
$app$plugins$format$format_key$$=function($kw$jscomp$4$$){return $APP.$cljs$core$truth_$$($kw$jscomp$4$$)?$APP.$app$common$data$name$$($kw$jscomp$4$$):null},$app$plugins$format$format_array$$=function($format_fn$$,$coll$jscomp$1105$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($format_fn$$,$coll$jscomp$1105$$))},$app$plugins$format$format_mixed$$=function($value$jscomp$1026$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1026$$,
$APP.$cljs$cst$1621$multiple$$)?"mixed":$value$jscomp$1026$$},$app$plugins$format$format_point$$=function($map__83982__$1_p__83981$$){$map__83982__$1_p__83981$$=$APP.$cljs$core$__destructure_map$$($map__83982__$1_p__83981$$);var $x$jscomp$1369$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83982__$1_p__83981$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$552$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83982__$1_p__83981$$,$APP.$cljs$cst$1516$y$$);return $map__83982__$1_p__83981$$!=
null?$app$util$object$without_empty$$({x:$x$jscomp$1369$$,y:$y$jscomp$552$$}):null},$app$plugins$format$shape_type$$=function($type$jscomp$733$$){switch($type$jscomp$733$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$733$$.$fqn$:null){case "frame":return"board";case "rect":return"rectangle";case "circle":return"ellipse";case "bool":return"boolean";default:return $APP.$app$common$data$name$$($type$jscomp$733$$)}},$app$plugins$format$format_bounds$$=function($map__83998__$1_p__83997$$){$map__83998__$1_p__83997$$=
$APP.$cljs$core$__destructure_map$$($map__83998__$1_p__83997$$);var $x$jscomp$1370$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83998__$1_p__83997$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$553$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83998__$1_p__83997$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$261$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83998__$1_p__83997$$,$APP.$cljs$cst$290$width$$),$height$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83998__$1_p__83997$$,
$APP.$cljs$cst$1527$height$$);return $map__83998__$1_p__83997$$!=null?$app$util$object$without_empty$$({x:$x$jscomp$1370$$,y:$y$jscomp$553$$,width:$width$jscomp$261$$,height:$height$jscomp$226$$}):null},$app$plugins$format$format_shape_info$$=function($map__84002__$1_p__84001$$){$map__84002__$1_p__84001$$=$APP.$cljs$core$__destructure_map$$($map__84002__$1_p__84001$$);var $prop$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84002__$1_p__84001$$,$APP.$cljs$cst$4225$prop$$),
$shape_id$jscomp$184$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84002__$1_p__84001$$,$APP.$cljs$cst$2554$shape_id$$),$index$jscomp$604$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84002__$1_p__84001$$,$APP.$cljs$cst$1801$index$$);return $map__84002__$1_p__84001$$!=null?$app$util$object$without_empty$$({property:$APP.$app$common$data$name$$($prop$jscomp$43$$),index:$index$jscomp$604$$,shapeId:""+($shape_id$jscomp$184$$??"")}):null},$app$plugins$format$format_stop$$=
function($map__84004__$1_p__84003$$){$map__84004__$1_p__84003$$=$APP.$cljs$core$__destructure_map$$($map__84004__$1_p__84003$$);var $color$jscomp$244$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84004__$1_p__84003$$,$APP.$cljs$cst$1303$color$$),$opacity$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84004__$1_p__84003$$,$APP.$cljs$cst$1740$opacity$$),$offset$jscomp$224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84004__$1_p__84003$$,$APP.$cljs$cst$195$offset$$);
return $map__84004__$1_p__84003$$!=null?$app$util$object$without_empty$$({color:$color$jscomp$244$$,opacity:$opacity$jscomp$54$$,offset:$offset$jscomp$224$$}):null},$app$plugins$format$format_gradient$$=function($map__84008__$1_p__84007$$){$map__84008__$1_p__84007$$=$APP.$cljs$core$__destructure_map$$($map__84008__$1_p__84007$$);var $type$jscomp$734$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,$APP.$cljs$cst$139$type$$),$start_x$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,
$APP.$cljs$cst$1735$start_x$$),$start_y$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,$APP.$cljs$cst$1736$start_y$$),$end_x$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,$APP.$cljs$cst$1737$end_x$$),$end_y$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,$APP.$cljs$cst$1738$end_y$$),$width$jscomp$262$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,
$APP.$cljs$cst$290$width$$),$stops$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84008__$1_p__84007$$,$APP.$cljs$cst$1739$stops$$);return $map__84008__$1_p__84007$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($type$jscomp$734$$),startX:$start_x$jscomp$7$$,startY:$start_y$jscomp$6$$,endX:$end_x$jscomp$6$$,endY:$end_y$jscomp$6$$,width:$width$jscomp$262$$,stops:$app$plugins$format$format_array$$($app$plugins$format$format_stop$$,$stops$jscomp$24$$)}):
null},$app$plugins$format$format_image$$=function($image$jscomp$40$$){return $image$jscomp$40$$!=null?$app$plugins$image_data$create_image_data$$($image$jscomp$40$$):null},$app$plugins$format$format_color$$=function($map__84010__$1_p__84009$$){$map__84010__$1_p__84009$$=$APP.$cljs$core$__destructure_map$$($map__84010__$1_p__84009$$);var $ref_id$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$1741$ref_id$$),$path$jscomp$302$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,
$APP.$cljs$cst$296$path$$),$file_id$jscomp$465$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$1649$file_id$$),$color$jscomp$245$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$1303$color$$),$name$jscomp$516$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$725$name$$),$ref_file$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,
$APP.$cljs$cst$1742$ref_file$$),$opacity$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$1740$opacity$$),$id$jscomp$1091$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$266$id$$),$gradient$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,$APP.$cljs$cst$1730$gradient$$),$image$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84010__$1_p__84009$$,
$APP.$cljs$cst$1617$image$$);if($map__84010__$1_p__84009$$!=null){var $id__$1$jscomp$23$$=function(){var $or__5025__auto__$jscomp$1502$$=$app$plugins$format$format_id$$($id$jscomp$1091$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1502$$)?$or__5025__auto__$jscomp$1502$$:$app$plugins$format$format_id$$($ref_id$jscomp$13$$)}(),$file_id__$1$jscomp$12$$=function(){var $or__5025__auto__$jscomp$1503$$=$app$plugins$format$format_id$$($file_id$jscomp$465$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1503$$)?
$or__5025__auto__$jscomp$1503$$:$app$plugins$format$format_id$$($ref_file$jscomp$13$$)}();return $app$util$object$without_empty$$({path:$path$jscomp$302$$,color:$color$jscomp$245$$,name:$name$jscomp$516$$,refFile:$app$plugins$format$format_id$$($ref_file$jscomp$13$$),refId:$app$plugins$format$format_id$$($ref_id$jscomp$13$$),opacity:$opacity$jscomp$55$$,id:function(){var $or__5025__auto__$jscomp$1504$$=$app$plugins$format$format_id$$($id__$1$jscomp$23$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1504$$)?
$or__5025__auto__$jscomp$1504$$:$app$plugins$format$format_id$$($ref_id$jscomp$13$$)}(),gradient:$app$plugins$format$format_gradient$$($gradient$jscomp$32$$),image:$app$plugins$format$format_image$$($image$jscomp$41$$),fileId:function(){var $or__5025__auto__$jscomp$1505$$=$app$plugins$format$format_id$$($file_id__$1$jscomp$12$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1505$$)?$or__5025__auto__$jscomp$1505$$:$app$plugins$format$format_id$$($ref_file$jscomp$13$$)}()})}return null},
$app$plugins$format$format_color_result$$=function($attrs$jscomp$185_p__84014_shapes_info$$){var $color$jscomp$246_color__$1$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$185_p__84014_shapes_info$$,0,null);$attrs$jscomp$185_p__84014_shapes_info$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attrs$jscomp$185_p__84014_shapes_info$$,1,null);$attrs$jscomp$185_p__84014_shapes_info$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$format$format_shape_info$$,$attrs$jscomp$185_p__84014_shapes_info$$));$color$jscomp$246_color__$1$jscomp$37$$=$app$plugins$format$format_color$$($color$jscomp$246_color__$1$jscomp$37$$);$APP.$app$util$object$set_BANG_$$($color$jscomp$246_color__$1$jscomp$37$$,"shapesInfo",$attrs$jscomp$185_p__84014_shapes_info$$);return $color$jscomp$246_color__$1$jscomp$37$$},$app$plugins$format$format_shadow$$=function($map__84020__$1_p__84019$$){$map__84020__$1_p__84019$$=
$APP.$cljs$core$__destructure_map$$($map__84020__$1_p__84019$$);var $id$jscomp$1092$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,$APP.$cljs$cst$266$id$$),$style$jscomp$82$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,$APP.$cljs$cst$1921$style$$),$offset_x$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,$APP.$cljs$cst$1655$offset_x$$),$offset_y$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,
$APP.$cljs$cst$1656$offset_y$$),$blur$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,$APP.$cljs$cst$1658$blur$$),$spread$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,$APP.$cljs$cst$1657$spread$$),$hidden$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,$APP.$cljs$cst$1625$hidden$$),$color$jscomp$247$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84020__$1_p__84019$$,
$APP.$cljs$cst$1303$color$$);return $map__84020__$1_p__84019$$!=null?$app$util$object$without_empty$$({id:$app$plugins$format$format_id$$($id$jscomp$1092$$),style:$app$plugins$format$format_key$$($style$jscomp$82$$),offsetX:$offset_x$jscomp$21$$,offsetY:$offset_y$jscomp$22$$,blur:$blur$jscomp$14$$,spread:$spread$jscomp$8$$,hidden:$hidden$jscomp$13$$,color:$app$plugins$format$format_color$$($color$jscomp$247$$)}):null},$app$plugins$format$format_fill$$=function($map__84022__$1_p__84021$$){$map__84022__$1_p__84021$$=
$APP.$cljs$core$__destructure_map$$($map__84022__$1_p__84021$$);var $fill_color$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84022__$1_p__84021$$,$APP.$cljs$cst$1752$fill_color$$),$fill_opacity$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84022__$1_p__84021$$,$APP.$cljs$cst$1753$fill_opacity$$),$fill_color_gradient$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84022__$1_p__84021$$,$APP.$cljs$cst$1754$fill_color_gradient$$),
$fill_color_ref_file$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84022__$1_p__84021$$,$APP.$cljs$cst$1645$fill_color_ref_file$$),$fill_color_ref_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84022__$1_p__84021$$,$APP.$cljs$cst$1751$fill_color_ref_id$$),$fill_image$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84022__$1_p__84021$$,$APP.$cljs$cst$1637$fill_image$$);return $map__84022__$1_p__84021$$!=null?$app$util$object$without_empty$$({fillColor:$fill_color$jscomp$6$$,
fillOpacity:$fill_opacity$jscomp$3$$,fillColorGradient:$app$plugins$format$format_gradient$$($fill_color_gradient$jscomp$2$$),fillColorRefFile:$app$plugins$format$format_id$$($fill_color_ref_file$$),fillColorRefId:$app$plugins$format$format_id$$($fill_color_ref_id$$),fillImage:$app$plugins$format$format_image$$($fill_image$jscomp$2$$)}):null},$app$plugins$format$format_stroke$$=function($map__84031__$1_p__84029$$){$map__84031__$1_p__84029$$=$APP.$cljs$core$__destructure_map$$($map__84031__$1_p__84029$$);
var $stroke_color_gradient$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1747$stroke_color_gradient$$),$stroke_cap_start$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1872$stroke_cap_start$$),$stroke_style$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1873$stroke_style$$),$stroke_color$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,
$APP.$cljs$cst$1745$stroke_color$$),$stroke_opacity$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1746$stroke_opacity$$),$stroke_alignment$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1875$stroke_alignment$$),$stroke_cap_end$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1876$stroke_cap_end$$),$stroke_color_ref_id$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1748$stroke_color_ref_id$$),$stroke_width$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1660$stroke_width$$),$stroke_color_ref_file$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84031__$1_p__84029$$,$APP.$cljs$cst$1646$stroke_color_ref_file$$);return $map__84031__$1_p__84029$$!=null?$app$util$object$without_empty$$({strokeCapEnd:$app$plugins$format$format_key$$($stroke_cap_end$jscomp$1$$),
strokeOpacity:$stroke_opacity$jscomp$1$$,strokeStyle:$app$plugins$format$format_key$$($stroke_style$jscomp$5$$),strokeColorRefFile:$app$plugins$format$format_id$$($stroke_color_ref_file$$),strokeColorRefId:$app$plugins$format$format_id$$($stroke_color_ref_id$$),strokeCapStart:$app$plugins$format$format_key$$($stroke_cap_start$jscomp$1$$),strokeWidth:$stroke_width$jscomp$11$$,strokeColorGradient:$app$plugins$format$format_gradient$$($stroke_color_gradient$$),strokeColor:$stroke_color$jscomp$2$$,strokeAlignment:$app$plugins$format$format_key$$($stroke_alignment$jscomp$2$$)}):
null},$app$plugins$format$format_blur$$=function($map__84037__$1_p__84036$$){$map__84037__$1_p__84036$$=$APP.$cljs$core$__destructure_map$$($map__84037__$1_p__84036$$);var $id$jscomp$1093$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84037__$1_p__84036$$,$APP.$cljs$cst$266$id$$),$value$jscomp$1027$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84037__$1_p__84036$$,$APP.$cljs$cst$260$value$$),$hidden$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84037__$1_p__84036$$,
$APP.$cljs$cst$1625$hidden$$);return $map__84037__$1_p__84036$$!=null?$app$util$object$without_empty$$({id:$app$plugins$format$format_id$$($id$jscomp$1093$$),value:$value$jscomp$1027$$,hidden:$hidden$jscomp$14$$}):null},$app$plugins$format$format_export$$=function($map__84041__$1_p__84040$$){$map__84041__$1_p__84040$$=$APP.$cljs$core$__destructure_map$$($map__84041__$1_p__84040$$);var $type$jscomp$735$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84041__$1_p__84040$$,$APP.$cljs$cst$139$type$$),
$scale$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84041__$1_p__84040$$,$APP.$cljs$cst$1910$scale$$),$suffix$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84041__$1_p__84040$$,$APP.$cljs$cst$1376$suffix$$),$skip_children$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84041__$1_p__84040$$,$APP.$cljs$cst$3844$skip_children$$);return $map__84041__$1_p__84040$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($type$jscomp$735$$),
scale:$scale$jscomp$50$$,suffix:$suffix$jscomp$33$$,skipChildren:$skip_children$jscomp$5$$}):null},$app$plugins$format$format_frame_guide_column_params$$=function($map__84049__$1_p__84048$$){$map__84049__$1_p__84048$$=$APP.$cljs$core$__destructure_map$$($map__84049__$1_p__84048$$);var $color$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84049__$1_p__84048$$,$APP.$cljs$cst$1303$color$$),$type$jscomp$736$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84049__$1_p__84048$$,
$APP.$cljs$cst$139$type$$),$size$jscomp$182$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84049__$1_p__84048$$,$APP.$cljs$cst$874$size$$),$margin$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84049__$1_p__84048$$,$APP.$cljs$cst$1946$margin$$),$item_length$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84049__$1_p__84048$$,$APP.$cljs$cst$1947$item_length$$),$gutter$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84049__$1_p__84048$$,
$APP.$cljs$cst$1948$gutter$$);return $map__84049__$1_p__84048$$!=null?$app$util$object$without_empty$$({color:$app$plugins$format$format_color$$($color$jscomp$248$$),type:$app$plugins$format$format_key$$($type$jscomp$736$$),size:$size$jscomp$182$$,margin:$margin$jscomp$8$$,itemLength:$item_length$jscomp$4$$,gutter:$gutter$jscomp$6$$}):null},$app$plugins$format$format_frame_guide$$=function($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$){$map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$=
$APP.$cljs$core$__destructure_map$$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$);var $G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,$APP.$cljs$cst$139$type$$);if($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$!=
null)switch($G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$=$G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$ instanceof $APP.$cljs$core$Keyword$$?$G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$.$fqn$:null,$G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$){case "column":$map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$=
$APP.$cljs$core$__destructure_map$$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$);$G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,$APP.$cljs$cst$139$type$$);var $display$jscomp$inline_10110_display$jscomp$inline_10116_display$jscomp$inline_10122$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,$APP.$cljs$cst$1949$display$$),$params$jscomp$inline_10111_params$jscomp$inline_10117_params$jscomp$inline_10123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,$APP.$cljs$cst$1435$params$$);
return $map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$),display:$display$jscomp$inline_10110_display$jscomp$inline_10116_display$jscomp$inline_10122$$,params:$app$plugins$format$format_frame_guide_column_params$$($params$jscomp$inline_10111_params$jscomp$inline_10117_params$jscomp$inline_10123$$)}):
null;case "row":return $map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$=$APP.$cljs$core$__destructure_map$$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$),$G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,
$APP.$cljs$cst$139$type$$),$display$jscomp$inline_10110_display$jscomp$inline_10116_display$jscomp$inline_10122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,$APP.$cljs$cst$1949$display$$),$params$jscomp$inline_10111_params$jscomp$inline_10117_params$jscomp$inline_10123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,
$APP.$cljs$cst$1435$params$$),$map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$),display:$display$jscomp$inline_10110_display$jscomp$inline_10116_display$jscomp$inline_10122$$,params:$app$plugins$format$format_frame_guide_column_params$$($params$jscomp$inline_10111_params$jscomp$inline_10117_params$jscomp$inline_10123$$)}):
null;case "square":return $map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$=$APP.$cljs$core$__destructure_map$$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$),$G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,
$APP.$cljs$cst$139$type$$),$display$jscomp$inline_10110_display$jscomp$inline_10116_display$jscomp$inline_10122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,$APP.$cljs$cst$1949$display$$),$params$jscomp$inline_10111_params$jscomp$inline_10117_params$jscomp$inline_10123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$,
$APP.$cljs$cst$1435$params$$),$map__84054__$1$jscomp$inline_10108_map__84058__$1$jscomp$inline_10114_map__84068__$1$jscomp$inline_10120_map__84071__$1_p__84070$$!=null?$app$util$object$without_empty$$({type:$app$plugins$format$format_key$$($G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$),display:$display$jscomp$inline_10110_display$jscomp$inline_10116_display$jscomp$inline_10122$$,params:$app$plugins$format$format_frame_guide_column_params$$($params$jscomp$inline_10111_params$jscomp$inline_10117_params$jscomp$inline_10123$$)}):
null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__84072__$1_type$jscomp$740_type$jscomp$inline_10109_type$jscomp$inline_10115_type$jscomp$inline_10121$$)].join(""));}else return null},$app$plugins$format$format_command$$=function($JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$){$JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$);
var $command$jscomp$24_x$jscomp$inline_10127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$,$APP.$cljs$cst$1818$command$$),$JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$,$APP.$cljs$cst$1435$params$$);if($JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$!=
null){$JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$=$app$plugins$format$format_key$$($command$jscomp$24_x$jscomp$inline_10127$$);$JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$);$command$jscomp$24_x$jscomp$inline_10127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,
$APP.$cljs$cst$1515$x$$);var $c2x$jscomp$inline_10128$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$APP.$cljs$cst$1823$c2x$$),$c2y$jscomp$inline_10129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$APP.$cljs$cst$1824$c2y$$),$ry$jscomp$inline_10130$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,
$APP.$cljs$cst$1890$ry$$),$y$jscomp$inline_10131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$APP.$cljs$cst$1516$y$$),$rx$jscomp$inline_10132$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$APP.$cljs$cst$1889$rx$$),$large_arc_flag$jscomp$inline_10133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,
$cljs$cst$6488$large_arc_flag$$),$c1x$jscomp$inline_10134$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$APP.$cljs$cst$1821$c1x$$),$x_axis_rotation$jscomp$inline_10135$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$cljs$cst$6489$x_axis_rotation$$),$c1y$jscomp$inline_10136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,
$APP.$cljs$cst$1822$c1y$$),$sweep_flag$jscomp$inline_10137$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$,$cljs$cst$6490$sweep_flag$$);$JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$=$JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$!=null?$app$util$object$without_empty$$({y:$y$jscomp$inline_10131$$,sweepFlag:$sweep_flag$jscomp$inline_10137$$,
rx:$rx$jscomp$inline_10132$$,c1x:$c1x$jscomp$inline_10134$$,largeArcFlag:$large_arc_flag$jscomp$inline_10133$$,c1y:$c1y$jscomp$inline_10136$$,x:$command$jscomp$24_x$jscomp$inline_10127$$,c2x:$c2x$jscomp$inline_10128$$,c2y:$c2y$jscomp$inline_10129$$,ry:$ry$jscomp$inline_10130$$,xAxisRotation:$x_axis_rotation$jscomp$inline_10135$$}):null;$JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$=$app$util$object$without_empty$$({command:$JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$,
params:$JSCompiler_inline_result$jscomp$2134_map__84075__$1$jscomp$inline_10126_params$jscomp$469$$})}else $JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$=null;return $JSCompiler_temp$jscomp$2132_JSCompiler_temp_const$jscomp$2133_map__84078__$1_p__84077$$},$app$plugins$format$format_animation$$=function($animation$jscomp$16$$){return $APP.$cljs$core$truth_$$($animation$jscomp$16$$)?$app$util$object$without_empty$$(function(){var $G__84083$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$);
switch($G__84083$$ instanceof $APP.$cljs$core$Keyword$$?$G__84083$$.$fqn$:null){case "dissolve":return{type:"dissolve",duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$),easing:$app$plugins$format$format_key$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$))};case "slide":return{type:"slide",way:$app$plugins$format$format_key$$($APP.$cljs$cst$1978$way$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),direction:$app$plugins$format$format_key$$($APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),
duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$),easing:$app$plugins$format$format_key$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),offsetEffect:$APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)};case "push":return{type:"push",direction:$app$plugins$format$format_key$$($APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$)),duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$),
easing:$app$plugins$format$format_key$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$16$$))};default:return null}}()):null},$app$plugins$format$format_action$$=function($interaction$jscomp$56$$,$plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$){return $APP.$cljs$core$truth_$$($interaction$jscomp$56$$)?$app$util$object$without_empty$$(function(){var $G__84086$$=$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);
switch($G__84086$$ instanceof $APP.$cljs$core$Keyword$$?$G__84086$$.$fqn$:null){case "navigate":return{type:"navigate-to",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__84090$$=$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,
$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84090$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84090$$)}():null,preserveScrollPosition:$APP.$cljs$cst$1984$preserve_scroll$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$56$$,!1),animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};case "open-overlay":return{type:"open-overlay",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?
function(){var $G__84094$$=$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84094$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84094$$)}():null,relativeTo:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1401$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?
function(){var $G__84098$$=$APP.$cljs$cst$1401$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84098$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84098$$)}():null,position:$app$plugins$format$format_key$$($APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),
manualPositionLocation:$app$plugins$format$format_point$$($APP.$cljs$cst$1986$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),closeWhenClickOutside:$APP.$cljs$cst$1988$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),addBackgroundOverlay:$APP.$cljs$cst$1989$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};
case "toggle-overlay":return{type:"toggle-overlay",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__84102$$=$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,
$G__84102$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84102$$)}():null,relativeTo:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1401$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__84106$$=$APP.$cljs$cst$1401$relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,
$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84106$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84106$$)}():null,position:$app$plugins$format$format_key$$($APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),manualPositionLocation:$app$plugins$format$format_point$$($APP.$cljs$cst$1986$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)),closeWhenClickOutside:$APP.$cljs$cst$1988$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),
addBackgroundOverlay:$APP.$cljs$cst$1989$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$),animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};case "close-overlay":return{type:"close-overlay",destination:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))?function(){var $G__84110$$=$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$);
return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84110$$):$app$plugins$format$shape_proxy$$($plugin$jscomp$16$$,$file_id$jscomp$466$$,$page_id$jscomp$487$$,$G__84110$$)}():null,animation:$app$plugins$format$format_animation$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$))};case "prev-screen":return{type:"previous-screen"};
case "open-url":return{type:"open-url",url:$APP.$cljs$cst$1991$url$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$56$$)};default:return null}}()):null},$app$plugins$parser$parse_id$$=function($id$jscomp$1094$$){return $APP.$cljs$core$truth_$$($id$jscomp$1094$$)?$APP.$app$common$uuid$parse$$($id$jscomp$1094$$):null},$app$plugins$parser$parse_keyword$$=function($kw$jscomp$5$$){return $APP.$cljs$core$truth_$$($kw$jscomp$5$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($kw$jscomp$5$$):
null},$app$plugins$parser$parse_hex$$=function($color$jscomp$250$$){return typeof $color$jscomp$250$$==="string"?$APP.$cuerdas$core$lower$$($color$jscomp$250$$):$color$jscomp$250$$},$app$plugins$parser$parse_point$$=function($point$jscomp$97$$){return $APP.$cljs$core$truth_$$($point$jscomp$97$$)?$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($point$jscomp$97$$,"x"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($point$jscomp$97$$,
"y")):null},$app$plugins$parser$parse_shape_type$$=function($type$jscomp$742$$){switch($type$jscomp$742$$){case "board":return $APP.$cljs$cst$1611$frame$$;case "boolean":return $APP.$cljs$cst$1615$bool$$;case "rectangle":return $APP.$cljs$cst$1616$rect$$;case "ellipse":return $APP.$cljs$cst$1422$circle$$;default:return $app$plugins$parser$parse_keyword$$($type$jscomp$742$$)}},$app$plugins$parser$parse_image_data$$=function($image_data$jscomp$4$$){return $image_data$jscomp$4$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$4$$,"id")),$APP.$cljs$cst$725$name$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$4$$,"name"),$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$4$$,"width"),$APP.$cljs$cst$1527$height$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$4$$,
"height"),$APP.$cljs$cst$1732$mtype$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$4$$,"mtype"),$APP.$cljs$cst$1733$keep_aspect_ratio$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($image_data$jscomp$4$$,"keepAspectRatio")],null)):null},$app$plugins$parser$parse_gradient_stop$$=function($stop$jscomp$15$$){return $stop$jscomp$15$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1303$color$$,$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stop$jscomp$15$$,"color")),$APP.$cljs$cst$1740$opacity$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stop$jscomp$15$$,"opacity"),$APP.$cljs$cst$195$offset$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stop$jscomp$15$$,"offset")],null)):null},$app$plugins$parser$parse_gradient$$=function($gradient$jscomp$33$$){return $gradient$jscomp$33$$!=
null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,"type")),$APP.$cljs$cst$1735$start_x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,"startX"),$APP.$cljs$cst$1736$start_y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,
"startY"),$APP.$cljs$cst$1737$end_x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,"endX"),$APP.$cljs$cst$1738$end_y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,"endY"),$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,"width"),$APP.$cljs$cst$1739$stops$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$parser$parse_gradient_stop$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($gradient$jscomp$33$$,
"stops"))],null)):null},$app$plugins$parser$parse_color_data$$=function($color$jscomp$251$$){if($color$jscomp$251$$!=null){var $file_id$jscomp$467$$=function(){var $or__5025__auto__$jscomp$1507$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"fileId");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1507$$)?$or__5025__auto__$jscomp$1507$$:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"refFile")}();return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$(function(){var $or__5025__auto__$jscomp$1506$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"id");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1506$$)?$or__5025__auto__$jscomp$1506$$:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"refId")}()),$APP.$cljs$cst$1649$file_id$$,$app$plugins$parser$parse_id$$($file_id$jscomp$467$$),$APP.$cljs$cst$1303$color$$,$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,
"color")),$APP.$cljs$cst$1740$opacity$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"opacity"),$APP.$cljs$cst$1730$gradient$$,$app$plugins$parser$parse_gradient$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"gradient")),$APP.$cljs$cst$1617$image$$,$app$plugins$parser$parse_image_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$251$$,"image"))],null))}return null},$app$plugins$parser$parse_color$$=
function($color$jscomp$252$$){return $color$jscomp$252$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$parser$parse_color_data$$($color$jscomp$252$$),$APP.$cljs$cst$725$name$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$252$$,"name"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$252$$,
"path")]))):null},$app$plugins$parser$parse_fill$$=function($fill$jscomp$29$$){return $fill$jscomp$29$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1752$fill_color$$,$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillColor")),$APP.$cljs$cst$1753$fill_opacity$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,
"fillOpacity"),$APP.$cljs$cst$1754$fill_color_gradient$$,$app$plugins$parser$parse_gradient$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillColorGradient")),$APP.$cljs$cst$1645$fill_color_ref_file$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillColorRefFile")),$APP.$cljs$cst$1751$fill_color_ref_id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,
"fillColorRefId")),$APP.$cljs$cst$1637$fill_image$$,$app$plugins$parser$parse_image_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($fill$jscomp$29$$,"fillImage"))],null)):null},$app$plugins$parser$parse_fills$$=function($fills$jscomp$33$$){return $fills$jscomp$33$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_fill$$),$fills$jscomp$33$$):null},
$app$plugins$parser$parse_stroke$$=function($stroke$jscomp$38$$){return $stroke$jscomp$38$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1872$stroke_cap_start$$,$APP.$cljs$cst$1873$stroke_style$$,$APP.$cljs$cst$1745$stroke_color$$,$APP.$cljs$cst$1746$stroke_opacity$$,$APP.$cljs$cst$1875$stroke_alignment$$,$APP.$cljs$cst$1876$stroke_cap_end$$,$APP.$cljs$cst$1748$stroke_color_ref_id$$,$APP.$cljs$cst$1660$stroke_width$$,
$APP.$cljs$cst$1646$stroke_color_ref_file$$,$APP.$cljs$cst$1747$stroke_color_gradient$$],[$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeCapStart")),$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeStyle")),$app$plugins$parser$parse_hex$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColor")),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,
"strokeOpacity"),$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeAlignment")),$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeCapEnd")),$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColorRefId")),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,
"strokeWidth"),$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColorRefFile")),$app$plugins$parser$parse_gradient$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($stroke$jscomp$38$$,"strokeColorGradient"))])):null},$app$plugins$parser$parse_strokes$$=function($strokes$jscomp$12$$){return $strokes$jscomp$12$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_stroke$$),$strokes$jscomp$12$$):null},$app$plugins$parser$parse_blur$$=function($blur$jscomp$16$$){return $blur$jscomp$16$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$16$$,"id")),$APP.$cljs$cst$260$value$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$16$$,
"value"),$APP.$cljs$cst$1625$hidden$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($blur$jscomp$16$$,"hidden")],null)):null},$app$plugins$parser$parse_export$$=function($export$$jscomp$15$$){return $export$$jscomp$15$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($export$$jscomp$15$$,
"type")),$APP.$cljs$cst$1910$scale$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$15$$,"scale",1),$APP.$cljs$cst$1376$suffix$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$15$$,"suffix",""),$APP.$cljs$cst$3844$skip_children$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$15$$,"skipChildren",!1)],null)):null},$app$plugins$parser$parse_exports$$=function($exports$jscomp$15$$){return $exports$jscomp$15$$!=
null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_export$$),$exports$jscomp$15$$):null},$app$plugins$parser$parse_frame_guide_column_params$$=function($params$jscomp$470$$){return $APP.$cljs$core$truth_$$($params$jscomp$470$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1303$color$$,
$app$plugins$parser$parse_color$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$470$$,"color")),$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$470$$,"type")),$APP.$cljs$cst$874$size$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$470$$,"size"),$APP.$cljs$cst$1946$margin$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$470$$,
"margin"),$APP.$cljs$cst$1947$item_length$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$470$$,"itemLength"),$APP.$cljs$cst$1948$gutter$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$470$$,"gutter")],null)):null},$app$plugins$parser$parse_frame_guide$$=function($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$){if($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$!=
null){var $G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"type");switch($G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$){case "column":return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"type")),$APP.$cljs$cst$1949$display$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"display"),$APP.$cljs$cst$1435$params$$,$app$plugins$parser$parse_frame_guide_column_params$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,
"params"))],null)):null;case "row":return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$)?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"type")),$APP.$cljs$cst$1949$display$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"display"),$APP.$cljs$cst$1435$params$$,$app$plugins$parser$parse_frame_guide_column_params$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"params"))],null)):null;case "square":if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$)){$G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_temp_const$jscomp$11359$$=$APP.$cljs$cst$139$type$$,$JSCompiler_temp_const$jscomp$11358$$=$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"type")),$JSCompiler_temp_const$jscomp$11357$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,
"display");$JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"params");$JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$=$JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1303$color$$,$app$plugins$parser$parse_color$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"color")),$APP.$cljs$cst$874$size$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$,"size")],null)):null;$G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$=$G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$.call($APP.$app$common$data$without_nils$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$JSCompiler_temp_const$jscomp$11359$$,$JSCompiler_temp_const$jscomp$11358$$,$APP.$cljs$cst$1949$display$$,$JSCompiler_temp_const$jscomp$11357$$,$APP.$cljs$cst$1435$params$$,$JSCompiler_inline_result$jscomp$11362_guide$jscomp$37_params$jscomp$inline_14200$$],null))}else $G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$=null;return $G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__84073_JSCompiler_temp$jscomp$11356_JSCompiler_temp_const$jscomp$11360$$)].join(""));}}else return null},$app$plugins$parser$parse_frame_guides$$=function($guides$jscomp$18$$){return $guides$jscomp$18$$!=null?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_frame_guide$$),$guides$jscomp$18$$):null},$app$plugins$parser$parse_animation$$=
function($animation$jscomp$17$$){if($APP.$cljs$core$truth_$$($animation$jscomp$17$$)){var $animation_type$jscomp$2$$=$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"type"));return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(function(){switch($animation_type$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$animation_type$jscomp$2$$.$fqn$:null){case "dissolve":return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1975$animation_type$$,$animation_type$jscomp$2$$,$APP.$cljs$cst$1976$duration$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"duration"),$APP.$cljs$cst$1977$easing$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"easing"))],null);case "slide":return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1975$animation_type$$,$animation_type$jscomp$2$$,$APP.$cljs$cst$1978$way$$,
$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"way")),$APP.$cljs$cst$1979$direction$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"direction")),$APP.$cljs$cst$1976$duration$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"duration"),$APP.$cljs$cst$1977$easing$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,
"easing")),$APP.$cljs$cst$1980$offset_effect$$,$APP.$cljs$core$boolean$0$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"offsetEffect"))],null);case "push":return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1975$animation_type$$,$animation_type$jscomp$2$$,$APP.$cljs$cst$1979$direction$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"direction")),$APP.$cljs$cst$1976$duration$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"duration"),$APP.$cljs$cst$1977$easing$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($animation$jscomp$17$$,"easing"))],null);default:return null}}())}return null},$app$plugins$parser$parse_action$$=function($action$jscomp$10$$){if($APP.$cljs$core$truth_$$($action$jscomp$10$$)){var $action_type$jscomp$5$$=$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,
"type"));return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(function(){switch($action_type$jscomp$5$$ instanceof $APP.$cljs$core$Keyword$$?$action_type$jscomp$5$$.$fqn$:null){case "navigate-to":return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1982$action_type$$,$APP.$cljs$cst$1957$navigate$$,$APP.$cljs$cst$1983$destination$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,
"destination"),"$id"),$APP.$cljs$cst$1984$preserve_scroll$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"preserveScrollPosition"),$APP.$cljs$cst$1985$animation$$,$app$plugins$parser$parse_animation$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"animation"))],null);case "open-overlay":case "toggle-overlay":var $JSCompiler_temp_const$jscomp$2140$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,
"destination"),"$id"),$JSCompiler_temp_const$jscomp$2139$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"relativeTo"),"$id"),$or__5025__auto__$jscomp$inline_10145$$=$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"position"));return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1982$action_type$$,$action_type$jscomp$5$$,
$APP.$cljs$cst$1983$destination$$,$JSCompiler_temp_const$jscomp$2140$$,$APP.$cljs$cst$1401$relative_to$$,$JSCompiler_temp_const$jscomp$2139$$,$APP.$cljs$cst$1987$overlay_pos_type$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_10145$$)?$or__5025__auto__$jscomp$inline_10145$$:$APP.$cljs$cst$1672$center$$,$APP.$cljs$cst$1986$overlay_position$$,$app$plugins$parser$parse_point$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"manualPositionLocation")),$APP.$cljs$cst$1988$close_click_outside$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"closeWhenClickOutside"),$APP.$cljs$cst$1989$background_overlay$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"addBackgroundOverlay"),$APP.$cljs$cst$1985$animation$$,$app$plugins$parser$parse_animation$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"animation"))],null);case "close-overlay":return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1982$action_type$$,$action_type$jscomp$5$$,$APP.$cljs$cst$1983$destination$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"destination"),"$id"),$APP.$cljs$cst$1985$animation$$,$app$plugins$parser$parse_animation$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"animation"))],null);case "previous-screen":return new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1982$action_type$$,$APP.$cljs$cst$1959$prev_screen$$],null);case "open-url":return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1982$action_type$$,$action_type$jscomp$5$$,$APP.$cljs$cst$1991$url$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($action$jscomp$10$$,"url")],null);default:return null}}())}return null},$app$plugins$parser$orientation__GT_axis$$=function($axis$jscomp$69$$){switch($axis$jscomp$69$$){case "horizontal":return $APP.$cljs$cst$1516$y$$;
case "vertical":return $APP.$cljs$cst$1515$x$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($axis$jscomp$69$$)].join(""));}},$app$plugins$exports$export_proxy$$=function($export_data_obj_84171$$,$on_change_BANG_$$){var $state$jscomp$1259$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($export_data_obj_84171$$);$export_data_obj_84171$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($export_data_obj_84171$$,Symbol.toStringTag,
{enumerable:!1,get:function(){return"ExportProxy"}});Object.defineProperty($export_data_obj_84171$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ExportProxy"}});Object.defineProperty($export_data_obj_84171$$,"type",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1259$$)))},set:function($val_type_84199$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1259$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_keyword$$($val_type_84199$$));return $on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$$()}});Object.defineProperty($export_data_obj_84171$$,"scale",{enumerable:!0,get:function(){return $APP.$cljs$cst$1910$scale$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1259$$))},set:function($val_scale_84207$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1259$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1910$scale$$,$val_scale_84207$$);return $on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$$()}});Object.defineProperty($export_data_obj_84171$$,"suffix",{enumerable:!0,get:function(){return $APP.$cljs$cst$1376$suffix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1259$$))},set:function($val_suffix_84217$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1259$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1376$suffix$$,$val_suffix_84217$$);return $on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$$()}});Object.defineProperty($export_data_obj_84171$$,"skipChildren",{enumerable:!0,get:function(){return $APP.$cljs$cst$3844$skip_children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1259$$))},set:function($val_skipchildren_84225$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1259$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3844$skip_children$$,$val_skipchildren_84225$$);return $on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$$()}});return $export_data_obj_84171$$},$app$plugins$exports$format_exports$cljs$0core$0IFn$0_invoke$0arity$02$$=function($arr$jscomp$173_exports$jscomp$17$$,$commit_fn$$){if($arr$jscomp$173_exports$jscomp$17$$!=null&&$APP.$cljs$core$fn_QMARK_$$($commit_fn$$)){var $arr_ref$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$on_change_BANG_$jscomp$1$$=function(){var $G__84327$$=$APP.$cljs$core$_deref$$($arr_ref$$);return $commit_fn$$.$cljs$core$IFn$_invoke$arity$1$?$commit_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__84327$$):$commit_fn$$($G__84327$$)};$arr$jscomp$173_exports$jscomp$17$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__84324_SHARP_$$){return $app$plugins$exports$export_proxy$$($p1__84324_SHARP_$$,$on_change_BANG_$jscomp$1$$)},
$arr$jscomp$173_exports$jscomp$17$$));$APP.$cljs$core$reset_BANG_$$($arr_ref$$,$arr$jscomp$173_exports$jscomp$17$$);return $arr$jscomp$173_exports$jscomp$17$$}return $app$plugins$format$format_array$$($app$plugins$format$format_export$$,$arr$jscomp$173_exports$jscomp$17$$)},$app$plugins$gradients$stop_proxy$$=function($obj_84117_stop_data$$,$on_change_BANG_$jscomp$2$$){var $state$jscomp$1260$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($obj_84117_stop_data$$);$obj_84117_stop_data$$=
new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84117_stop_data$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"GradientStopProxy"}});Object.defineProperty($obj_84117_stop_data$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"GradientStopProxy"}});Object.defineProperty($obj_84117_stop_data$$,"color",{enumerable:!0,get:function(){return $APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1260$$))},set:function($val_color_84140$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1260$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1303$color$$,$val_color_84140$$);return $on_change_BANG_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$2$$()}});Object.defineProperty($obj_84117_stop_data$$,"opacity",{enumerable:!0,get:function(){return $APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1260$$))},set:function($val_opacity_84148$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1260$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1740$opacity$$,$val_opacity_84148$$);return $on_change_BANG_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$2$$()}});Object.defineProperty($obj_84117_stop_data$$,"offset",{enumerable:!0,get:function(){return $APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1260$$))},set:function($val_offset_84156$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1260$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,$val_offset_84156$$);return $on_change_BANG_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$2$$()}});return $obj_84117_stop_data$$},$app$plugins$gradients$gradient_proxy$$=function($state$jscomp$1261$$,$on_change_BANG_$jscomp$3$$){var $obj_84235$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84235$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"GradientProxy"}});
Object.defineProperty($obj_84235$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"GradientProxy"}});Object.defineProperty($obj_84235$$,"type",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$)))},set:function($val_type_84259$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$139$type$$,
$app$plugins$parser$parse_keyword$$($val_type_84259$$));return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});Object.defineProperty($obj_84235$$,"startX",{enumerable:!0,get:function(){return $APP.$cljs$cst$1735$start_x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$))},set:function($val_startx_84267$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1735$start_x$$,$val_startx_84267$$);return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});Object.defineProperty($obj_84235$$,"startY",{enumerable:!0,get:function(){return $APP.$cljs$cst$1736$start_y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$))},set:function($val_starty_84275$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1736$start_y$$,$val_starty_84275$$);return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});Object.defineProperty($obj_84235$$,"endX",{enumerable:!0,get:function(){return $APP.$cljs$cst$1737$end_x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$))},set:function($val_endx_84283$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1737$end_x$$,$val_endx_84283$$);return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});Object.defineProperty($obj_84235$$,"endY",{enumerable:!0,get:function(){return $APP.$cljs$cst$1738$end_y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$))},set:function($val_endy_84291$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1738$end_y$$,$val_endy_84291$$);return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});Object.defineProperty($obj_84235$$,"width",{enumerable:!0,get:function(){return $APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$))},set:function($val_width_84299$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$val_width_84299$$);return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});Object.defineProperty($obj_84235$$,"stops",{enumerable:!0,get:function(){return function(){function $stop_change_BANG_$$(){var $new_stops$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_gradient_stop$$),
$APP.$cljs$core$_deref$$($stops_ref$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1739$stops$$,$new_stops$jscomp$2$$);return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}var $stops_ref$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$arr$jscomp$174$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__84233_SHARP_$$){return $app$plugins$gradients$stop_proxy$$($p1__84233_SHARP_$$,$stop_change_BANG_$$)},$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1261$$))));$APP.$cljs$core$reset_BANG_$$($stops_ref$$,$arr$jscomp$174$$);return $arr$jscomp$174$$}.call(this)},set:function($val_stops_84307$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1261$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1739$stops$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$parser$parse_gradient_stop$$),$val_stops_84307$$));return $on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$3$$()}});return $obj_84235$$},$app$plugins$fills$fill_proxy$$=function($fill_data$jscomp$4_obj_84430$$,$on_change_BANG_$jscomp$4$$){var $state$jscomp$1262$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($fill_data$jscomp$4_obj_84430$$);$fill_data$jscomp$4_obj_84430$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($fill_data$jscomp$4_obj_84430$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FillProxy"}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FillProxy"}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,"fillColor",{enumerable:!0,
get:function(){return $APP.$cljs$cst$1752$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1262$$))},set:function($val_fillcolor_84453$$){return function($v$jscomp$716$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1262$$,function($p1__84426_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__84426_SHARP_$$,$APP.$cljs$cst$1752$fill_color$$,$v$jscomp$716$$),
$APP.$cljs$cst$1754$fill_color_gradient$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$fill_image$$]))});return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()}.call(this,$val_fillcolor_84453$$)}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,"fillOpacity",{enumerable:!0,get:function(){return $APP.$cljs$cst$1753$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1262$$))},
set:function($val_fillopacity_84461$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1262$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1753$fill_opacity$$,$val_fillopacity_84461$$);return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,"fillColorGradient",{enumerable:!0,get:function(){return function(){var $temp__5825__auto__$jscomp$485$$=
$APP.$cljs$cst$1754$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1262$$));if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$485$$)){var $gradient_state$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($temp__5825__auto__$jscomp$485$$);return $app$plugins$gradients$gradient_proxy$$($gradient_state$$,function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1262$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1754$fill_color_gradient$$,
$APP.$cljs$core$_deref$$($gradient_state$$));return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()})}return null}.call(this)},set:function($val_fillcolorgradient_84469$$){return function($v$jscomp$718$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1262$$,function($p1__84427_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__84427_SHARP_$$,
$APP.$cljs$cst$1754$fill_color_gradient$$,$app$plugins$parser$parse_gradient$$($v$jscomp$718$$)),$APP.$cljs$cst$1752$fill_color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1637$fill_image$$]))});return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()}.call(this,$val_fillcolorgradient_84469$$)}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,"fillColorRefFile",
{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($APP.$cljs$cst$1645$fill_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1262$$)))},set:function($val_fillcolorreffile_84477$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1262$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1645$fill_color_ref_file$$,$app$plugins$parser$parse_id$$($val_fillcolorreffile_84477$$));return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,"fillColorRefId",{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($APP.$cljs$cst$1751$fill_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1262$$)))},set:function($val_fillcolorrefid_84485$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1262$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1751$fill_color_ref_id$$,$app$plugins$parser$parse_id$$($val_fillcolorrefid_84485$$));return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()}});Object.defineProperty($fill_data$jscomp$4_obj_84430$$,"fillImage",{enumerable:!0,get:function(){return $app$plugins$format$format_image$$($APP.$cljs$cst$1637$fill_image$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1262$$)))},
set:function($val_fillimage_84493$$){return function($v$jscomp$721$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1262$$,function($p1__84428_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__84428_SHARP_$$,$APP.$cljs$cst$1637$fill_image$$,$app$plugins$parser$parse_image_data$$($v$jscomp$721$$)),$APP.$cljs$cst$1752$fill_color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1754$fill_color_gradient$$]))});
return $on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$4$$()}.call(this,$val_fillimage_84493$$)}});return $fill_data$jscomp$4_obj_84430$$},$app$plugins$fills$format_fills$cljs$0core$0IFn$0_invoke$0arity$02$$=function($arr$jscomp$175_fills$jscomp$35$$,$commit_fn$jscomp$1$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arr$jscomp$175_fills$jscomp$35$$,$APP.$cljs$cst$1621$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arr$jscomp$175_fills$jscomp$35$$,
"mixed"))return"mixed";if($arr$jscomp$175_fills$jscomp$35$$!=null&&$APP.$cljs$core$fn_QMARK_$$($commit_fn$jscomp$1$$)){var $arr_ref$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_change_BANG_$jscomp$5$$=function(){var $G__84720$$=$APP.$cljs$core$_deref$$($arr_ref$jscomp$1$$);return $commit_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$commit_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__84720$$):$commit_fn$jscomp$1$$($G__84720$$)};$arr$jscomp$175_fills$jscomp$35$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__84717_SHARP_$$){return $app$plugins$fills$fill_proxy$$($p1__84717_SHARP_$$,$on_change_BANG_$jscomp$5$$)},$arr$jscomp$175_fills$jscomp$35$$));$APP.$cljs$core$reset_BANG_$$($arr_ref$jscomp$1$$,$arr$jscomp$175_fills$jscomp$35$$);return $arr$jscomp$175_fills$jscomp$35$$}return $app$plugins$format$format_array$$($app$plugins$format$format_fill$$,$arr$jscomp$175_fills$jscomp$35$$)},
$app$plugins$system_events$event$$=function($var_args$jscomp$1525$$){for(var $args__5755__auto__$jscomp$276$$=[],$len__5749__auto___84166$$=arguments.length,$i__5750__auto___84167$$=0;;)if($i__5750__auto___84167$$<$len__5749__auto___84166$$)$args__5755__auto__$jscomp$276$$.push(arguments[$i__5750__auto___84167$$]),$i__5750__auto___84167$$+=1;else break;return $app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$276$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$276$$.slice(2),0,null):null)},$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($plugin_data_plugin_id$jscomp$15$$,$name$jscomp$517$$,$p__84162_props$jscomp$427$$){$p__84162_props$jscomp$427$$=$APP.$cljs$core$__destructure_map$$($p__84162_props$jscomp$427$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($plugin_data_plugin_id$jscomp$15$$,"96dfa740-005d-8020-8007-55ede24a2bae"))return $APP.$app$main$data$event$event$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__84162_props$jscomp$427$$,
$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$name$jscomp$517$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"mcp"));$plugin_data_plugin_id$jscomp$15$$=$app$plugins$register$get_plugin_data$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$plugin_data_plugin_id$jscomp$15$$);return $APP.$app$main$data$event$event$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__84162_props$jscomp$427$$,
$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$name$jscomp$517$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugin"),$APP.$cljs$cst$2314$app_DOT_main_DOT_data_DOT_event_SLASH_context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$6492$plugin_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data_plugin_id$jscomp$15$$),$APP.$cljs$cst$6398$plugin_url$$,$APP.$cljs$cst$1991$url$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data_plugin_id$jscomp$15$$)],
null)))},$app$plugins$system_events$add_event$$=function($event$jscomp$805$$,$plugin_id$jscomp$16$$){var $plugin_data$jscomp$1$$=$app$plugins$register$get_plugin_data$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$plugin_id$jscomp$16$$);return $APP.$cljs$core$with_meta$$($event$jscomp$805$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$16$$,"96dfa740-005d-8020-8007-55ede24a2bae")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"mcp"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugin",$APP.$cljs$cst$2314$app_DOT_main_DOT_data_DOT_event_SLASH_context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$6492$plugin_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data$jscomp$1$$),$APP.$cljs$cst$6398$plugin_url$$,$APP.$cljs$cst$1991$url$$.$cljs$core$IFn$_invoke$arity$1$($plugin_data$jscomp$1$$)],null)],null))},$app$plugins$flex$flex_layout_proxy$$=
function($plugin_id$jscomp$17$$,$file_id$jscomp$468$$,$page_id$jscomp$488$$,$id$jscomp$1096$$){var $obj_84513$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84513$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FlexLayoutProxy"}});Object.defineProperty($obj_84513$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FlexLayoutProxy"}});Object.defineProperty($obj_84513$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$17$$}});Object.defineProperty($obj_84513$$,
"$id",{enumerable:!1,get:function(){return $id$jscomp$1096$$}});Object.defineProperty($obj_84513$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$468$$}});Object.defineProperty($obj_84513$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$488$$}});Object.defineProperty($obj_84513$$,"dir",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1684$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_dir_84564_value__$1$jscomp$inline_10183$$){$val_dir_84564_value__$1$jscomp$inline_10183$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_dir_84564_value__$1$jscomp$inline_10183$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$flex_direction_types$$,$val_dir_84564_value__$1$jscomp$inline_10183$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1684$layout_flex_dir$$,$val_dir_84564_value__$1$jscomp$inline_10183$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6493$dir$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6493$dir$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6493$dir$$,$val_dir_84564_value__$1$jscomp$inline_10183$$)}});
Object.defineProperty($obj_84513$$,"wrap",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1689$layout_wrap_type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_wrap_84572_value__$1$jscomp$inline_10187$$){$val_wrap_84572_value__$1$jscomp$inline_10187$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_wrap_84572_value__$1$jscomp$inline_10187$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$wrap_types$$,
$val_wrap_84572_value__$1$jscomp$inline_10187$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1689$layout_wrap_type$$,
$val_wrap_84572_value__$1$jscomp$inline_10187$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$APP.$cljs$cst$896$wrap$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$APP.$cljs$cst$896$wrap$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$APP.$cljs$cst$896$wrap$$,$val_wrap_84572_value__$1$jscomp$inline_10187$$)}});Object.defineProperty($obj_84513$$,"alignItems",{enumerable:!0,
get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1697$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_alignitems_84580_value__$1$jscomp$inline_10191$$){$val_alignitems_84580_value__$1$jscomp$inline_10191$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignitems_84580_value__$1$jscomp$inline_10191$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_items_types$$,
$val_alignitems_84580_value__$1$jscomp$inline_10191$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1697$layout_align_items$$,
$val_alignitems_84580_value__$1$jscomp$inline_10191$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6494$alignItems$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6494$alignItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6494$alignItems$$,$val_alignitems_84580_value__$1$jscomp$inline_10191$$)}});Object.defineProperty($obj_84513$$,
"alignContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1696$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_aligncontent_84588_value__$1$jscomp$inline_10195$$){$val_aligncontent_84588_value__$1$jscomp$inline_10195$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_aligncontent_84588_value__$1$jscomp$inline_10195$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_content_types$$,
$val_aligncontent_84588_value__$1$jscomp$inline_10195$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1696$layout_align_content$$,
$val_aligncontent_84588_value__$1$jscomp$inline_10195$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6495$alignContent$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6495$alignContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6495$alignContent$$,$val_aligncontent_84588_value__$1$jscomp$inline_10195$$)}});Object.defineProperty($obj_84513$$,
"justifyItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1695$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_justifyitems_84596_value__$1$jscomp$inline_10199$$){$val_justifyitems_84596_value__$1$jscomp$inline_10199$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifyitems_84596_value__$1$jscomp$inline_10199$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_items_types$$,
$val_justifyitems_84596_value__$1$jscomp$inline_10199$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1695$layout_justify_items$$,
$val_justifyitems_84596_value__$1$jscomp$inline_10199$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6496$justifyItems$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6496$justifyItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6496$justifyItems$$,$val_justifyitems_84596_value__$1$jscomp$inline_10199$$)}});Object.defineProperty($obj_84513$$,
"justifyContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1694$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_justifycontent_84604_value__$1$jscomp$inline_10203$$){$val_justifycontent_84604_value__$1$jscomp$inline_10203$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifycontent_84604_value__$1$jscomp$inline_10203$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_content_types$$,
$val_justifycontent_84604_value__$1$jscomp$inline_10203$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1694$layout_justify_content$$,
$val_justifycontent_84604_value__$1$jscomp$inline_10203$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6497$justifyContent$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6497$justifyContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6497$justifyContent$$,$val_justifycontent_84604_value__$1$jscomp$inline_10203$$)}});Object.defineProperty($obj_84513$$,
"rowGap",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_rowgap_84612$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_rowgap_84612$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6498$rowGap$$,
$val_rowgap_84612$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1686$row_gap$$,$val_rowgap_84612$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6498$rowGap$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6498$rowGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,"columnGap",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_columngap_84620$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_columngap_84620$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6499$columnGap$$,$val_columngap_84620$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1687$column_gap$$,$val_columngap_84620$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6499$columnGap$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6499$columnGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,
"verticalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_verticalpadding_84628$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_verticalpadding_84628$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,
$cljs$cst$6500$verticalPadding$$,$val_verticalpadding_84628$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val_verticalpadding_84628$$,$APP.$cljs$cst$1692$p3$$,$val_verticalpadding_84628$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6500$verticalPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6500$verticalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,"horizontalPadding",
{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_horizontalpadding_84636$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_horizontalpadding_84636$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6501$horizontalPadding$$,
$val_horizontalpadding_84636$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1091$p2$$,$val_horizontalpadding_84636$$,$APP.$cljs$cst$1693$p4$$,$val_horizontalpadding_84636$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6501$horizontalPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6501$horizontalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,"topPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_toppadding_84644$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_toppadding_84644$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6502$topPadding$$,$val_toppadding_84644$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1093$p1$$,$val_toppadding_84644$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6502$topPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6502$topPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,
"rightPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_rightpadding_84652$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_rightpadding_84652$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6503$rightPadding$$,
$val_rightpadding_84652$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1091$p2$$,$val_rightpadding_84652$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6503$rightPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6503$rightPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,"bottomPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_bottompadding_84660$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_bottompadding_84660$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6504$bottomPadding$$,$val_bottompadding_84660$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1692$p3$$,$val_bottompadding_84660$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6504$bottomPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6504$bottomPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,
"leftPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_leftpadding_84668$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_leftpadding_84668$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6505$leftPadding$$,
$val_leftpadding_84668$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1693$p4$$,$val_leftpadding_84668$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6505$leftPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6505$leftPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84513$$,"remove",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$])))}.bind(this)}});
Object.defineProperty($obj_84513$$,"appendChild",{enumerable:!1,get:function(){return function($child$jscomp$126$$){var $valid_child_QMARK_$$=$app$plugins$flex$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$plugins$flex$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$126$$):$app$plugins$flex$shape_proxy_QMARK_$$($child$jscomp$126$$),$child_page$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$126$$,
"$page"):null,$child_id$jscomp$12$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$126$$,"$id"):null,$objects$jscomp$864$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$$)?$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$468$$,$page_id$jscomp$488$$):null,$shape$jscomp$1124$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$864$$,
$id$jscomp$1096$$):null,$child_shape$jscomp$1$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$$)?$app$plugins$utils$locate_shape$$($file_id$jscomp$468$$,$page_id$jscomp$488$$,$child_id$jscomp$12$$):null,$index$jscomp$605$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$$)?$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$17$$)&&!$APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1124$$)?0:$APP.$cljs$core$count$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1124$$)):
null;return $APP.$cljs$core$not$$($valid_child_QMARK_$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6506$appendChild$$,$child$jscomp$126$$):$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)&&$app$plugins$utils$page_active_QMARK_$$($child_page$$)?$app$plugins$utils$changes_component_copy_structure_QMARK_$$($objects$jscomp$864$$,$shape$jscomp$1124$$,$child_shape$jscomp$1$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6506$appendChild$$,"Cannot change the structure of a component copy"):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child_id$jscomp$12$$]),$id$jscomp$1096$$,$index$jscomp$605$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$17$$,"add-layout-element",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($child_shape$jscomp$1$$),$APP.$cljs$cst$3674$parent_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1124$$)]))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6506$appendChild$$,"Cannot modify a page that is not currently active")}.bind(this)}});Object.defineProperty($obj_84513$$,"horizontalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1702$fix$$))},set:function($val_horizontalsizing_84690_value__$1$jscomp$inline_10231$$){$val_horizontalsizing_84690_value__$1$jscomp$inline_10231$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_horizontalsizing_84690_value__$1$jscomp$inline_10231$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_h_sizing_types$$,$val_horizontalsizing_84690_value__$1$jscomp$inline_10231$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$layout_item_h_sizing$$,$val_horizontalsizing_84690_value__$1$jscomp$inline_10231$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,
$cljs$cst$6507$horizontalSizing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6507$horizontalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6507$horizontalSizing$$,$val_horizontalsizing_84690_value__$1$jscomp$inline_10231$$)}});Object.defineProperty($obj_84513$$,"verticalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1702$fix$$))},set:function($val_verticalsizing_84698_value__$1$jscomp$inline_10235$$){$val_verticalsizing_84698_value__$1$jscomp$inline_10235$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_verticalsizing_84698_value__$1$jscomp$inline_10235$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_v_sizing_types$$,$val_verticalsizing_84698_value__$1$jscomp$inline_10235$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$17$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$488$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1096$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1714$layout_item_v_sizing$$,$val_verticalsizing_84698_value__$1$jscomp$inline_10235$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,
$cljs$cst$6508$verticalSizing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6508$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$17$$,$cljs$cst$6508$verticalSizing$$,$val_verticalsizing_84698_value__$1$jscomp$inline_10235$$)}});return $obj_84513$$},$app$plugins$flex$layout_child_proxy$$=function($plugin_id$jscomp$18$$,$file_id$jscomp$469$$,$page_id$jscomp$489$$,
$id$jscomp$1097$$){var $obj_84855$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84855$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LayoutChildProxy"}});Object.defineProperty($obj_84855$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LayoutChildProxy"}});Object.defineProperty($obj_84855$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$18$$}});Object.defineProperty($obj_84855$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1097$$}});
Object.defineProperty($obj_84855$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$469$$}});Object.defineProperty($obj_84855$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$489$$}});Object.defineProperty($obj_84855$$,"absolute",{enumerable:!0,get:function(){return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1716$layout_item_absolute$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_absolute_84906$$){return $APP.$cljs$core$boolean_QMARK_$$($val_absolute_84906$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1716$layout_item_absolute$$,$val_absolute_84906$$],null))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$4144$absolute$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$4144$absolute$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$4144$absolute$$,$val_absolute_84906$$)}});Object.defineProperty($obj_84855$$,"zIndex",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1717$layout_item_z_index$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
0)},set:function($val_zindex_84914$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_zindex_84914$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6509$zIndex$$,$val_zindex_84914$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1717$layout_item_z_index$$,$val_zindex_84914$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6509$zIndex$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6509$zIndex$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"horizontalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1702$fix$$))},set:function($val_horizontalsizing_84922_value__$1$jscomp$inline_10245$$){$val_horizontalsizing_84922_value__$1$jscomp$inline_10245$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_horizontalsizing_84922_value__$1$jscomp$inline_10245$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_h_sizing_types$$,$val_horizontalsizing_84922_value__$1$jscomp$inline_10245$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$layout_item_h_sizing$$,$val_horizontalsizing_84922_value__$1$jscomp$inline_10245$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,
$cljs$cst$6501$horizontalPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6501$horizontalPadding$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6501$horizontalPadding$$,$val_horizontalsizing_84922_value__$1$jscomp$inline_10245$$)}});Object.defineProperty($obj_84855$$,"verticalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1702$fix$$))},set:function($val_verticalsizing_84930_value__$1$jscomp$inline_10249$$){$val_verticalsizing_84930_value__$1$jscomp$inline_10249$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_verticalsizing_84930_value__$1$jscomp$inline_10249$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_v_sizing_types$$,$val_verticalsizing_84930_value__$1$jscomp$inline_10249$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1714$layout_item_v_sizing$$,$val_verticalsizing_84930_value__$1$jscomp$inline_10249$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,
$cljs$cst$6508$verticalSizing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6508$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6508$verticalSizing$$,$val_verticalsizing_84930_value__$1$jscomp$inline_10249$$)}});Object.defineProperty($obj_84855$$,"alignSelf",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1715$layout_item_align_self$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1677$auto$$))},set:function($val_alignself_84938_value__$1$jscomp$inline_10253$$){$val_alignself_84938_value__$1$jscomp$inline_10253$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignself_84938_value__$1$jscomp$inline_10253$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_align_self_types$$,$val_alignself_84938_value__$1$jscomp$inline_10253$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1715$layout_item_align_self$$,$val_alignself_84938_value__$1$jscomp$inline_10253$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6510$alignSelf$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6510$alignSelf$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6510$alignSelf$$,$val_alignself_84938_value__$1$jscomp$inline_10253$$)}});Object.defineProperty($obj_84855$$,"verticalMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_verticalmargin_84946$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_verticalmargin_84946$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6511$verticalMargin$$,$val_verticalmargin_84946$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1705$m1$$,$val_verticalmargin_84946$$,$APP.$cljs$cst$1707$m3$$,$val_verticalmargin_84946$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6511$verticalMargin$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6511$verticalMargin$$,"Plugin doesn't have 'content:write' permission")}});
Object.defineProperty($obj_84855$$,"horizontalMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_horizontalmargin_84954$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_horizontalmargin_84954$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,
$cljs$cst$6512$horizontalMargin$$,$val_horizontalmargin_84954$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1706$m2$$,$val_horizontalmargin_84954$$,$APP.$cljs$cst$1708$m4$$,$val_horizontalmargin_84954$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6512$horizontalMargin$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6512$horizontalMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"topMargin",
{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_topmargin_84962$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_topmargin_84962$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6513$topMargin$$,
$val_topmargin_84962$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1705$m1$$,$val_topmargin_84962$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6513$topMargin$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6513$topMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"rightMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rightmargin_84970$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_rightmargin_84970$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6514$rightMargin$$,$val_rightmargin_84970$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1706$m2$$,$val_rightmargin_84970$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6514$rightMargin$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6514$rightMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,
"bottomMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_bottommargin_84978$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_bottommargin_84978$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6515$bottomMargin$$,
$val_bottommargin_84978$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1707$m3$$,$val_bottommargin_84978$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6515$bottomMargin$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6515$bottomMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"leftMargin",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_leftmargin_84986$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_leftmargin_84986$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6516$leftMargin$$,$val_leftmargin_84986$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1708$m4$$,$val_leftmargin_84986$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6516$leftMargin$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6516$leftMargin$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,
"maxWidth",{enumerable:!0,get:function(){return $APP.$cljs$cst$1711$layout_item_max_w$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},set:function($val_maxwidth_85016$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_maxwidth_85016$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6517$maxWidth$$,$val_maxwidth_85016$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1711$layout_item_max_w$$,$val_maxwidth_85016$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6517$maxWidth$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,
$cljs$cst$6517$maxWidth$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"minWidth",{enumerable:!0,get:function(){return $APP.$cljs$cst$1712$layout_item_min_w$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},set:function($val_minwidth_85024$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_minwidth_85024$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6518$minWidth$$,
$val_minwidth_85024$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1712$layout_item_min_w$$,$val_minwidth_85024$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6518$minWidth$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6518$minWidth$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"maxHeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1709$layout_item_max_h$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},set:function($val_maxheight_85032$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_maxheight_85032$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$5929$maxHeight$$,$val_maxheight_85032$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1709$layout_item_max_h$$,$val_maxheight_85032$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$5929$maxHeight$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$APP.$cljs$cst$5929$maxHeight$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_84855$$,"minHeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1710$layout_item_min_h$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))},
set:function($val_minheight_85040$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_minheight_85040$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6519$minHeight$$,$val_minheight_85040$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$18$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$489$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1097$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1710$layout_item_min_h$$,$val_minheight_85040$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6519$minHeight$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$18$$,$cljs$cst$6519$minHeight$$,"Plugin doesn't have 'content:write' permission")}});return $obj_84855$$},$app$plugins$tracks$track_proxy$$=function($plugin_id$jscomp$19$$,$file_id$jscomp$470$$,$page_id$jscomp$490$$,
$shape_id$jscomp$185$$,$kind$jscomp$28$$,$index$jscomp$606$$){function $locate$$(){return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_shape$$($file_id$jscomp$470$$,$page_id$jscomp$490$$,$shape_id$jscomp$185$$),$prop$jscomp$44$$),$index$jscomp$606$$,null)}var $prop$jscomp$44$$=function(){var $G__84797__$1$$=$kind$jscomp$28$$ instanceof $APP.$cljs$core$Keyword$$?$kind$jscomp$28$$.$fqn$:null;switch($G__84797__$1$$){case "row":return $APP.$cljs$cst$1699$layout_grid_rows$$;
case "column":return $APP.$cljs$cst$1700$layout_grid_columns$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__84797__$1$$)].join(""));}}(),$obj_84805$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_84805$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TrackProxy"}});Object.defineProperty($obj_84805$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TrackProxy"}});Object.defineProperty($obj_84805$$,
"type",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($locate$$()))},set:function($val_type_84828$$){var $type$jscomp$inline_10286$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_type_84828$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$inline_10286$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$490$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_id$jscomp$185$$]),$kind$jscomp$28$$,$index$jscomp$606$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$type$jscomp$inline_10286$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$APP.$cljs$cst$139$type$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,
$APP.$cljs$cst$139$type$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$APP.$cljs$cst$139$type$$,$val_type_84828$$)}});Object.defineProperty($obj_84805$$,"value",{enumerable:!0,get:function(){return $APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($locate$$())},set:function($val_value_84837$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_value_84837$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,
$APP.$cljs$cst$260$value$$,$val_value_84837$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$19$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$490$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_id$jscomp$185$$]),$kind$jscomp$28$$,$index$jscomp$606$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,
$val_value_84837$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$APP.$cljs$cst$260$value$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$19$$,$APP.$cljs$cst$260$value$$,"Plugin doesn't have 'content:write' permission")}});return $obj_84805$$},$app$plugins$tracks$format_tracks$$=function($plugin_id$jscomp$20$$,$file_id$jscomp$471$$,$page_id$jscomp$491$$,$shape_id$jscomp$186$$,$kind$jscomp$29$$,$tracks$jscomp$7$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$607$$){return $app$plugins$tracks$track_proxy$$($plugin_id$jscomp$20$$,$file_id$jscomp$471$$,$page_id$jscomp$491$$,$shape_id$jscomp$186$$,$kind$jscomp$29$$,$index$jscomp$607$$)},$tracks$jscomp$7$$))},$app$plugins$grid$grid_layout_proxy$$=function($plugin_id$jscomp$21$$,$file_id$jscomp$472$$,$page_id$jscomp$492$$,$id$jscomp$1098$$){var $obj_85059$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85059$$,
Symbol.toStringTag,{enumerable:!1,get:function(){return"GridLayoutProxy"}});Object.defineProperty($obj_85059$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"GridLayoutProxy"}});Object.defineProperty($obj_85059$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$21$$).call(this)}});Object.defineProperty($obj_85059$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1098$$).call(this)}});Object.defineProperty($obj_85059$$,
"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$472$$).call(this)}});Object.defineProperty($obj_85059$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$492$$).call(this)}});Object.defineProperty($obj_85059$$,"dir",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1698$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($val_dir_85110_value__$1$jscomp$inline_10292$$){$val_dir_85110_value__$1$jscomp$inline_10292$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_dir_85110_value__$1$jscomp$inline_10292$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_direction_types$$,$val_dir_85110_value__$1$jscomp$inline_10292$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1698$layout_grid_dir$$,$val_dir_85110_value__$1$jscomp$inline_10292$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6493$dir$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6493$dir$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6493$dir$$,$val_dir_85110_value__$1$jscomp$inline_10292$$)}});
Object.defineProperty($obj_85059$$,"rows",{enumerable:!0,get:function(){return $app$plugins$tracks$format_tracks$$($plugin_id$jscomp$21$$,$file_id$jscomp$472$$,$page_id$jscomp$492$$,$id$jscomp$1098$$,$APP.$cljs$cst$1661$row$$,$APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}});Object.defineProperty($obj_85059$$,"columns",{enumerable:!0,get:function(){return $app$plugins$tracks$format_tracks$$($plugin_id$jscomp$21$$,$file_id$jscomp$472$$,
$page_id$jscomp$492$$,$id$jscomp$1098$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}});Object.defineProperty($obj_85059$$,"horizontalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1702$fix$$))},
set:function($val_horizontalsizing_85132_value__$1$jscomp$inline_10296$$){$val_horizontalsizing_85132_value__$1$jscomp$inline_10296$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_horizontalsizing_85132_value__$1$jscomp$inline_10296$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_h_sizing_types$$,$val_horizontalsizing_85132_value__$1$jscomp$inline_10296$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$layout_item_h_sizing$$,$val_horizontalsizing_85132_value__$1$jscomp$inline_10296$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6507$horizontalSizing$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6507$horizontalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6507$horizontalSizing$$,$val_horizontalsizing_85132_value__$1$jscomp$inline_10296$$)}});Object.defineProperty($obj_85059$$,"verticalSizing",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$1702$fix$$))},set:function($val_verticalsizing_85140_value__$1$jscomp$inline_10300$$){$val_verticalsizing_85140_value__$1$jscomp$inline_10300$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_verticalsizing_85140_value__$1$jscomp$inline_10300$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$item_v_sizing_types$$,$val_verticalsizing_85140_value__$1$jscomp$inline_10300$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1714$layout_item_v_sizing$$,$val_verticalsizing_85140_value__$1$jscomp$inline_10300$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6508$verticalSizing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6508$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6508$verticalSizing$$,$val_verticalsizing_85140_value__$1$jscomp$inline_10300$$)}});Object.defineProperty($obj_85059$$,"alignItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1697$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_alignitems_85148_value__$1$jscomp$inline_10304$$){$val_alignitems_85148_value__$1$jscomp$inline_10304$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignitems_85148_value__$1$jscomp$inline_10304$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_items_types$$,$val_alignitems_85148_value__$1$jscomp$inline_10304$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1697$layout_align_items$$,$val_alignitems_85148_value__$1$jscomp$inline_10304$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6494$alignItems$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6494$alignItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6494$alignItems$$,$val_alignitems_85148_value__$1$jscomp$inline_10304$$)}});Object.defineProperty($obj_85059$$,"alignContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1696$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_aligncontent_85156_value__$1$jscomp$inline_10308$$){$val_aligncontent_85156_value__$1$jscomp$inline_10308$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_aligncontent_85156_value__$1$jscomp$inline_10308$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$align_content_types$$,$val_aligncontent_85156_value__$1$jscomp$inline_10308$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1696$layout_align_content$$,$val_aligncontent_85156_value__$1$jscomp$inline_10308$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6495$alignContent$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6495$alignContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6495$alignContent$$,$val_aligncontent_85156_value__$1$jscomp$inline_10308$$)}});Object.defineProperty($obj_85059$$,"justifyItems",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1695$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_justifyitems_85164_value__$1$jscomp$inline_10312$$){$val_justifyitems_85164_value__$1$jscomp$inline_10312$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifyitems_85164_value__$1$jscomp$inline_10312$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_items_types$$,$val_justifyitems_85164_value__$1$jscomp$inline_10312$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1695$layout_justify_items$$,$val_justifyitems_85164_value__$1$jscomp$inline_10312$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6496$justifyItems$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6496$justifyItems$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6496$justifyItems$$,$val_justifyitems_85164_value__$1$jscomp$inline_10312$$)}});Object.defineProperty($obj_85059$$,"justifyContent",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1694$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($val_justifycontent_85172_value__$1$jscomp$inline_10316$$){$val_justifycontent_85172_value__$1$jscomp$inline_10316$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifycontent_85172_value__$1$jscomp$inline_10316$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$justify_content_types$$,$val_justifycontent_85172_value__$1$jscomp$inline_10316$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1694$layout_justify_content$$,$val_justifycontent_85172_value__$1$jscomp$inline_10316$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6497$justifyContent$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6497$justifyContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6497$justifyContent$$,$val_justifycontent_85172_value__$1$jscomp$inline_10316$$)}});Object.defineProperty($obj_85059$$,"rowGap",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rowgap_85180$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_rowgap_85180$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6498$rowGap$$,$val_rowgap_85180$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$row_gap$$,$val_rowgap_85180$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6498$rowGap$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6498$rowGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,"columnGap",
{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_columngap_85188$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_columngap_85188$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6499$columnGap$$,
$val_columngap_85188$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1687$column_gap$$,$val_columngap_85188$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6499$columnGap$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6499$columnGap$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,"verticalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_verticalpadding_85196$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_verticalpadding_85196$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6500$verticalPadding$$,$val_verticalpadding_85196$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val_verticalpadding_85196$$,$APP.$cljs$cst$1692$p3$$,$val_verticalpadding_85196$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6500$verticalPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6500$verticalPadding$$,"Plugin doesn't have 'content:write' permission")}});
Object.defineProperty($obj_85059$$,"horizontalPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_horizontalpadding_85204$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_horizontalpadding_85204$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6501$horizontalPadding$$,$val_horizontalpadding_85204$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val_horizontalpadding_85204$$,$APP.$cljs$cst$1693$p4$$,$val_horizontalpadding_85204$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6501$horizontalPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6501$horizontalPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,"topPadding",
{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_toppadding_85212$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_toppadding_85212$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6502$topPadding$$,
$val_toppadding_85212$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1093$p1$$,$val_toppadding_85212$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6502$topPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6502$topPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,"rightPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_rightpadding_85220$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_rightpadding_85220$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6503$rightPadding$$,$val_rightpadding_85220$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1091$p2$$,$val_rightpadding_85220$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6503$rightPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6503$rightPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,
"bottomPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),0)},set:function($val_bottompadding_85228$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_bottompadding_85228$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6504$bottomPadding$$,
$val_bottompadding_85228$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1692$p3$$,$val_bottompadding_85228$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6504$bottomPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6504$bottomPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,"leftPadding",{enumerable:!0,get:function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))),
0)},set:function($val_leftpadding_85236$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_leftpadding_85236$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6505$leftPadding$$,$val_leftpadding_85236$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1693$p4$$,$val_leftpadding_85236$$],null)],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6505$leftPadding$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6505$leftPadding$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85059$$,
"addRow",{enumerable:!1,get:function(){return function($type$jscomp$744_type__$1$jscomp$20$$,$value$jscomp$1077$$){$type$jscomp$744_type__$1$jscomp$20$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$744_type__$1$jscomp$20$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$744_type__$1$jscomp$20$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1675$percent$$,$type$jscomp$744_type__$1$jscomp$20$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,$type$jscomp$744_type__$1$jscomp$20$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$fixed$$,$type$jscomp$744_type__$1$jscomp$20$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1077$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6521$addRow_value$$,$value$jscomp$1077$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$1661$row$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$744_type__$1$jscomp$20$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1077$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6522$addRow$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6522$addRow$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6520$addRow_type$$,$type$jscomp$744_type__$1$jscomp$20$$)}.bind(this)}});Object.defineProperty($obj_85059$$,"addRowAtIndex",{enumerable:!1,get:function(){return function($index$jscomp$608$$,
$type$jscomp$745_type__$1$jscomp$21$$,$value$jscomp$1078$$){$type$jscomp$745_type__$1$jscomp$21$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$745_type__$1$jscomp$21$$);var $num_rows$jscomp$3$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$472$$,$page_id$jscomp$492$$,$id$jscomp$1098$$)));return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$608$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6523$addRowAtIndex_index$$,$index$jscomp$608$$):$index$jscomp$608$$<0||$index$jscomp$608$$>$num_rows$jscomp$3$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6523$addRowAtIndex_index$$,$index$jscomp$608$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$745_type__$1$jscomp$21$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1675$percent$$,
$type$jscomp$745_type__$1$jscomp$21$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,$type$jscomp$745_type__$1$jscomp$21$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$fixed$$,$type$jscomp$745_type__$1$jscomp$21$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1078$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6525$addRowAtIndex_value$$,$value$jscomp$1078$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$1661$row$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$745_type__$1$jscomp$21$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1078$$],
null),$index$jscomp$608$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6526$addRowAtIndex$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6526$addRowAtIndex$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6524$addRowAtIndex_type$$,$type$jscomp$745_type__$1$jscomp$21$$)}.bind(this)}});Object.defineProperty($obj_85059$$,"addColumn",{enumerable:!1,
get:function(){return function($type$jscomp$746_type__$1$jscomp$22$$,$value$jscomp$1079$$){$type$jscomp$746_type__$1$jscomp$22$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$746_type__$1$jscomp$22$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$746_type__$1$jscomp$22$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1675$percent$$,$type$jscomp$746_type__$1$jscomp$22$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,
$type$jscomp$746_type__$1$jscomp$22$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6528$lex$$,$type$jscomp$746_type__$1$jscomp$22$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1079$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6529$addColumn_value$$,$value$jscomp$1079$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$216$column$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$746_type__$1$jscomp$22$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1079$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6530$addColumn$$,
"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6530$addColumn$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6527$addColumn_type$$,$type$jscomp$746_type__$1$jscomp$22$$)}.bind(this)}});Object.defineProperty($obj_85059$$,"addColumnAtIndex",{enumerable:!1,get:function(){return function($index$jscomp$609$$,$type$jscomp$747_type__$1$jscomp$23$$,$value$jscomp$1080$$){$type$jscomp$747_type__$1$jscomp$23$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$747_type__$1$jscomp$23$$);var $num_columns$jscomp$2$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$472$$,$page_id$jscomp$492$$,$id$jscomp$1098$$)));return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$609$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6531$addColumnAtIndex_index$$,
$index$jscomp$609$$):$index$jscomp$609$$<0||$index$jscomp$609$$>$num_columns$jscomp$2$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6531$addColumnAtIndex_index$$,$index$jscomp$609$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$747_type__$1$jscomp$23$$)?($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1675$percent$$,$type$jscomp$747_type__$1$jscomp$23$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,
$type$jscomp$747_type__$1$jscomp$23$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$fixed$$,$type$jscomp$747_type__$1$jscomp$23$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1080$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6533$addColumnAtIndex_value$$,$value$jscomp$1080$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$216$column$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$type$jscomp$747_type__$1$jscomp$23$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1080$$],null),$index$jscomp$609$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6534$addColumnAtIndex$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6534$addColumnAtIndex$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6532$addColumnAtIndex_type$$,$type$jscomp$747_type__$1$jscomp$23$$)}.bind(this)}});Object.defineProperty($obj_85059$$,"removeRow",{enumerable:!1,get:function(){return function($index$jscomp$610$$){var $num_rows$jscomp$4$$=
$APP.$cljs$core$count$$($APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$472$$,$page_id$jscomp$492$$,$id$jscomp$1098$$)));return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$610$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6535$removeRow$$,$index$jscomp$610$$):$index$jscomp$610$$<0||$index$jscomp$610$$>=$num_rows$jscomp$4$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6535$removeRow$$,$index$jscomp$610$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$1661$row$$,$index$jscomp$610$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6535$removeRow$$,
"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6535$removeRow$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_85059$$,"removeColumn",{enumerable:!1,get:function(){return function($index$jscomp$611$$){var $num_columns$jscomp$3$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$472$$,$page_id$jscomp$492$$,
$id$jscomp$1098$$)));return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$611$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6536$removeColumn$$,$index$jscomp$611$$):$index$jscomp$611$$<0||$index$jscomp$611$$>=$num_columns$jscomp$3$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6536$removeColumn$$,$index$jscomp$611$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$216$column$$,$index$jscomp$611$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6536$removeColumn$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6536$removeColumn$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});
Object.defineProperty($obj_85059$$,"setColumn",{enumerable:!1,get:function(){return function($index$jscomp$612$$,$type$jscomp$748_type__$1$jscomp$24$$,$value$jscomp$1081$$){$type$jscomp$748_type__$1$jscomp$24$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$748_type__$1$jscomp$24$$);var $num_columns$jscomp$4$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$472$$,$page_id$jscomp$492$$,
$id$jscomp$1098$$)));return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$612$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6537$setColumn_index$$,$index$jscomp$612$$):$index$jscomp$612$$<0||$index$jscomp$612$$>=$num_columns$jscomp$4$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6537$setColumn_index$$,$index$jscomp$612$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$748_type__$1$jscomp$24$$)?
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1675$percent$$,$type$jscomp$748_type__$1$jscomp$24$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,$type$jscomp$748_type__$1$jscomp$24$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$fixed$$,$type$jscomp$748_type__$1$jscomp$24$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1081$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6539$setColumn_value$$,$value$jscomp$1081$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$216$column$$,$index$jscomp$612$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$type$jscomp$748_type__$1$jscomp$24$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1081$$],null)))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6540$setColumn$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6540$setColumn$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6538$setColumn_type$$,$type$jscomp$748_type__$1$jscomp$24$$)}.bind(this)}});
Object.defineProperty($obj_85059$$,"setRow",{enumerable:!1,get:function(){return function($index$jscomp$613$$,$type$jscomp$749_type__$1$jscomp$25$$,$value$jscomp$1082$$){$type$jscomp$749_type__$1$jscomp$25$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$749_type__$1$jscomp$25$$);var $num_rows$jscomp$5$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$472$$,$page_id$jscomp$492$$,
$id$jscomp$1098$$)));return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$613$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6541$setRow_index$$,$index$jscomp$613$$):$index$jscomp$613$$<0||$index$jscomp$613$$>=$num_rows$jscomp$5$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6541$setRow_index$$,$index$jscomp$613$$):$APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_track_types$$,$type$jscomp$749_type__$1$jscomp$25$$)?
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1675$percent$$,$type$jscomp$749_type__$1$jscomp$25$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,$type$jscomp$749_type__$1$jscomp$25$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$fixed$$,$type$jscomp$749_type__$1$jscomp$25$$))&&$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1082$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6543$setRow_value$$,$value$jscomp$1082$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]),$APP.$cljs$cst$1661$row$$,$index$jscomp$613$$,$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$type$jscomp$749_type__$1$jscomp$25$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1082$$],null)))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6544$setRow$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6544$setRow$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6542$setRow_type$$,$type$jscomp$749_type__$1$jscomp$25$$)}.bind(this)}});
Object.defineProperty($obj_85059$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1098$$]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$APP.$cljs$cst$2601$remove$$,
"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_85059$$,"appendChild",{enumerable:!1,get:function(){return function($child$jscomp$127$$,$row$jscomp$36$$,$column$jscomp$46$$){var $valid_child_QMARK_$jscomp$1$$=$app$plugins$grid$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$plugins$grid$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$127$$):
$app$plugins$grid$shape_proxy_QMARK_$$($child$jscomp$127$$),$child_page$jscomp$1$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$jscomp$1$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$127$$,"$page"):null,$child_id$jscomp$13$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$jscomp$1$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$127$$,"$id"):null,$objects$jscomp$865$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$jscomp$1$$)?$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$472$$,
$page_id$jscomp$492$$):null,$shape$jscomp$1125$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$jscomp$1$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$865$$,$id$jscomp$1098$$):null,$child_shape$jscomp$2$$=$APP.$cljs$core$truth_$$($valid_child_QMARK_$jscomp$1$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$865$$,$child_id$jscomp$13$$):null;return $APP.$cljs$core$not$$($valid_child_QMARK_$jscomp$1$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,
$cljs$cst$6545$appendChild_child$$,$child$jscomp$127$$):$row$jscomp$36$$<0||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($row$jscomp$36$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6546$appendChild_row$$,$row$jscomp$36$$):$column$jscomp$46$$<0||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($column$jscomp$46$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6547$appendChild_column$$,$column$jscomp$46$$):
$app$plugins$register$check_permission$$($plugin_id$jscomp$21$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$492$$)&&$app$plugins$utils$page_active_QMARK_$$($child_page$jscomp$1$$)?$app$plugins$utils$changes_component_copy_structure_QMARK_$$($objects$jscomp$865$$,$shape$jscomp$1125$$,$child_shape$jscomp$2$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6506$appendChild$$,"Cannot change the structure of a component copy"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$move_shapes_to_frame$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child_id$jscomp$13$$]),
$id$jscomp$1098$$,null,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$36$$,$column$jscomp$46$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$1098$$],null)],null))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6506$appendChild$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$21$$,$cljs$cst$6506$appendChild$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});return $obj_85059$$},$app$plugins$grid$layout_cell_proxy$$=function($plugin_id$jscomp$22$$,$file_id$jscomp$473$$,$page_id$jscomp$493$$,$id$jscomp$1099$$){function $locate_cell$$(){var $parent$jscomp$309_shape$jscomp$1126$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$473$$,$page_id$jscomp$493$$,$id$jscomp$1099$$);$parent$jscomp$309_shape$jscomp$1126$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$473$$,$page_id$jscomp$493$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$309_shape$jscomp$1126$$));return $APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($parent$jscomp$309_shape$jscomp$1126$$,$id$jscomp$1099$$)}var $obj_85910$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85910$$,
Symbol.toStringTag,{enumerable:!1,get:function(){return"GridCellProxy"}});Object.defineProperty($obj_85910$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"GridCellProxy"}});Object.defineProperty($obj_85910$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$22$$).call(this)}});Object.defineProperty($obj_85910$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1099$$).call(this)}});Object.defineProperty($obj_85910$$,
"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$473$$).call(this)}});Object.defineProperty($obj_85910$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$493$$).call(this)}});Object.defineProperty($obj_85910$$,"row",{enumerable:!0,get:function(){return $APP.$cljs$cst$1661$row$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_row_85964$$){var $cell$jscomp$inline_10344$$=$locate_cell$$(this),$shape$jscomp$inline_10345$$=
$app$plugins$utils$proxy__GT_shape$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_row_85964$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6548$row_value$$,$val_row_85964$$):$cell$jscomp$inline_10344$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6549$row_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10345$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10344$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1661$row$$,$val_row_85964$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1661$row$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1661$row$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85910$$,"rowSpan",{enumerable:!0,get:function(){return $APP.$cljs$cst$1662$row_span$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_rowspan_85972$$){var $shape$jscomp$inline_10349$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10350$$=$locate_cell$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_rowspan_85972$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6550$rowSpan_value$$,$val_rowspan_85972$$):$cell$jscomp$inline_10350$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6551$rowSpan_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10349$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10350$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1662$row_span$$,$val_rowspan_85972$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6552$rowSpan$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6552$rowSpan$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85910$$,"column",
{enumerable:!0,get:function(){return $APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},set:function($val_column_85980$$){var $shape$jscomp$inline_10354$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10355$$=$locate_cell$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_column_85980$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6553$column_value$$,$val_column_85980$$):$cell$jscomp$inline_10355$$==
null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6554$column_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10354$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10355$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$216$column$$,$val_column_85980$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$216$column$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$216$column$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85910$$,"columnSpan",{enumerable:!0,get:function(){return $APP.$cljs$cst$1663$column_span$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},
set:function($val_columnspan_85988$$){var $shape$jscomp$inline_10359$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10360$$=$locate_cell$$(this);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($val_columnspan_85988$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6555$columnSpan_value$$,$val_columnspan_85988$$):$cell$jscomp$inline_10360$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6556$columnSpan_cell$$,
"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10359$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10360$$),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1663$column_span$$,$val_columnspan_85988$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6557$columnSpan$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6557$columnSpan$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85910$$,"areaName",{enumerable:!0,get:function(){return $APP.$cljs$cst$1680$area_name$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this))},
set:function($val_areaname_85996$$){var $shape$jscomp$inline_10364$$=$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10365$$=$locate_cell$$(this);return typeof $val_areaname_85996$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6558$areaName_value$$,$val_areaname_85996$$):$cell$jscomp$inline_10365$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6559$areaName_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10364$$),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10365$$)]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$area_name$$,
$val_areaname_85996$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6560$areaName$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6560$areaName$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_85910$$,"position",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this)))},set:function($val_position_86004_value__$1$jscomp$inline_10371$$){var $shape$jscomp$inline_10369$$=
$app$plugins$utils$proxy__GT_shape$$(this),$cell$jscomp$inline_10370$$=$locate_cell$$(this);$val_position_86004_value__$1$jscomp$inline_10371$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_position_86004_value__$1$jscomp$inline_10371$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_position_types$$,$val_position_86004_value__$1$jscomp$inline_10371$$)?$cell$jscomp$inline_10370$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6562$position_cell$$,
"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_cells_mode$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10369$$),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10370$$)]),
$val_position_86004_value__$1$jscomp$inline_10371$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1681$position$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$APP.$cljs$cst$1681$position$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6561$position_value$$,$val_position_86004_value__$1$jscomp$inline_10371$$)}});Object.defineProperty($obj_85910$$,
"alignSelf",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1682$align_self$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this)))},set:function($val_alignself_86012_value__$1$jscomp$inline_10376$$){var $shape$jscomp$inline_10375$$=$app$plugins$utils$proxy__GT_shape$$(this);$val_alignself_86012_value__$1$jscomp$inline_10376$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_alignself_86012_value__$1$jscomp$inline_10376$$);var $cell$jscomp$inline_10377$$=
$locate_cell$$(this);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_cell_align_self_types$$,$val_alignself_86012_value__$1$jscomp$inline_10376$$)?$cell$jscomp$inline_10377$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6564$alignSelf_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10375$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10377$$)]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1682$align_self$$,$val_alignself_86012_value__$1$jscomp$inline_10376$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6510$alignSelf$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6510$alignSelf$$,
"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6563$alignSelf_value$$,$val_alignself_86012_value__$1$jscomp$inline_10376$$)}});Object.defineProperty($obj_85910$$,"justifySelf",{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1683$justify_self$$.$cljs$core$IFn$_invoke$arity$1$($locate_cell$$(this)))},set:function($val_justifyself_86020_value__$1$jscomp$inline_10382$$){var $shape$jscomp$inline_10381$$=
$app$plugins$utils$proxy__GT_shape$$(this);$val_justifyself_86020_value__$1$jscomp$inline_10382$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($val_justifyself_86020_value__$1$jscomp$inline_10382$$);var $cell$jscomp$inline_10383$$=$locate_cell$$(this);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$layout$grid_cell_justify_self_types$$,$val_justifyself_86020_value__$1$jscomp$inline_10382$$)?$cell$jscomp$inline_10383$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,
$cljs$cst$6566$justifySelf_cell$$,"cell not found"):$app$plugins$register$check_permission$$($plugin_id$jscomp$22$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$493$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10381$$),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$inline_10383$$)]),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1683$justify_self$$,$val_justifyself_86020_value__$1$jscomp$inline_10382$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6567$justifySelf$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6567$justifySelf$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$22$$,$cljs$cst$6565$justifySelf_value$$,
$val_justifyself_86020_value__$1$jscomp$inline_10382$$)}});return $obj_85910$$},$app$plugins$ruler_guides$ruler_guide_proxy$$=function($plugin_id$jscomp$23$$,$file_id$jscomp$474$$,$page_id$jscomp$494$$,$id$jscomp$1100$$){var $obj_85311$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85311$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"RulerGuideProxy"}});Object.defineProperty($obj_85311$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"RulerGuideProxy"}});
Object.defineProperty($obj_85311$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$23$$).call(this)}});Object.defineProperty($obj_85311$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$474$$).call(this)}});Object.defineProperty($obj_85311$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$494$$).call(this)}});Object.defineProperty($obj_85311$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1100$$).call(this)}});
Object.defineProperty($obj_85311$$,"board",{enumerable:!1,get:function(){var $board_id$jscomp$inline_10386$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_ruler_guide$$(this));return $APP.$cljs$core$truth_$$($board_id$jscomp$inline_10386$$)?$app$plugins$ruler_guides$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$ruler_guides$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$23$$,$file_id$jscomp$474$$,$page_id$jscomp$494$$,$board_id$jscomp$inline_10386$$):
$app$plugins$ruler_guides$shape_proxy$$($plugin_id$jscomp$23$$,$file_id$jscomp$474$$,$page_id$jscomp$494$$,$board_id$jscomp$inline_10386$$):null},set:function($val_board_85362$$){return function($guide$jscomp$38_self$jscomp$137$$,$board_id$jscomp$2_value$jscomp$1091$$){var $shape$jscomp$1135$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$474$$,$page_id$jscomp$494$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($board_id$jscomp$2_value$jscomp$1091$$,"$id"));return $APP.$cljs$core$not$$($app$plugins$ruler_guides$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$app$plugins$ruler_guides$shape_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($board_id$jscomp$2_value$jscomp$1091$$):$app$plugins$ruler_guides$shape_proxy_QMARK_$$($board_id$jscomp$2_value$jscomp$1091$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6568$board$$,"The board is not a shape proxy"):$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1135$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$494$$)?($board_id$jscomp$2_value$jscomp$1091$$=$APP.$cljs$core$truth_$$($board_id$jscomp$2_value$jscomp$1091$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($board_id$jscomp$2_value$jscomp$1091$$,"$id"):null,$guide$jscomp$38_self$jscomp$137$$=$app$plugins$utils$proxy__GT_ruler_guide$$($guide$jscomp$38_self$jscomp$137$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$38_self$jscomp$137$$,
$APP.$cljs$cst$1612$frame_id$$,$board_id$jscomp$2_value$jscomp$1091$$)),$plugin_id$jscomp$23$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6568$board$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6568$board$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$cljs$cst$6568$board$$,"The shape is not a board")}.call(this,this,$val_board_85362$$)}});Object.defineProperty($obj_85311$$,
"orientation",{enumerable:!0,get:function(){a:{var $G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$=$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_ruler_guide$$(this));$G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$=$G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$ instanceof $APP.$cljs$core$Keyword$$?$G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$.$fqn$:
null;switch($G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$){case "y":$G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$="horizontal";break a;case "x":$G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$="vertical";break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$)].join(""));
}}return $G__84112__$1$jscomp$inline_14203_JSCompiler_inline_result$jscomp$11354_axis$jscomp$inline_14202$$}});Object.defineProperty($obj_85311$$,"position",{enumerable:!0,get:function(){var $JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$=$app$plugins$utils$proxy__GT_ruler_guide$$(this);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$))){var $board_pos$jscomp$inline_10391_objects$jscomp$inline_10390$$=
$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$474$$,$page_id$jscomp$494$$);$board_pos$jscomp$inline_10391_objects$jscomp$inline_10390$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($board_pos$jscomp$inline_10391_objects$jscomp$inline_10390$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$)),$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$));
$JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$=$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$)-$board_pos$jscomp$inline_10391_objects$jscomp$inline_10390$$}else $JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$=$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$);return $JSCompiler_inline_result$jscomp$2219_guide$jscomp$inline_10389$$},
set:function($val_position_85377$$){return function($guide$jscomp$40_self$jscomp$139$$,$JSCompiler_temp$jscomp$2220_value$jscomp$1092$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($JSCompiler_temp$jscomp$2220_value$jscomp$1092$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$1681$position$$,"Not valid position");if($app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$494$$)){$guide$jscomp$40_self$jscomp$139$$=
$app$plugins$utils$proxy__GT_ruler_guide$$($guide$jscomp$40_self$jscomp$139$$);if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$40_self$jscomp$139$$))){var $objects$jscomp$inline_10393$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$474$$,$page_id$jscomp$494$$);$JSCompiler_temp$jscomp$2220_value$jscomp$1092$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_10393$$,
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$40_self$jscomp$139$$)),$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$40_self$jscomp$139$$))+$JSCompiler_temp$jscomp$2220_value$jscomp$1092$$}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$40_self$jscomp$139$$,
$APP.$cljs$cst$1681$position$$,$JSCompiler_temp$jscomp$2220_value$jscomp$1092$$)),$plugin_id$jscomp$23$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$1681$position$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$1681$position$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_position_85377$$)}});Object.defineProperty($obj_85311$$,"color",{enumerable:!0,get:function(){return $APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_ruler_guide$$(this))},
set:function($JSCompiler_inline_result$jscomp$2221_val_color_85385$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$23$$,"content:write"))if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$494$$)){var $guide$jscomp$inline_10397$$=$app$plugins$utils$proxy__GT_ruler_guide$$(this);$JSCompiler_inline_result$jscomp$2221_val_color_85385$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$inline_10397$$,
$APP.$cljs$cst$1303$color$$,$JSCompiler_inline_result$jscomp$2221_val_color_85385$$)))}else $JSCompiler_inline_result$jscomp$2221_val_color_85385$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$1303$color$$,"Cannot modify a page that is not currently active");else $JSCompiler_inline_result$jscomp$2221_val_color_85385$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,$APP.$cljs$cst$1303$color$$,"Plugin doesn't have 'content:write' permission");return $JSCompiler_inline_result$jscomp$2221_val_color_85385$$}});
Object.defineProperty($obj_85311$$,"remove",{enumerable:!1,get:function(){return function(){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$494$$)){var $guide$jscomp$42$$=$app$plugins$utils$locate_ruler_guide$$($file_id$jscomp$474$$,$page_id$jscomp$494$$,$id$jscomp$1100$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$42$$),$plugin_id$jscomp$23$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$23$$,
$APP.$cljs$cst$2601$remove$$,"Cannot modify a page that is not currently active")}.bind(this)}});return $obj_85311$$},$app$plugins$shadows$shadow_proxy$$=function($obj_85414_shadow_data$$,$on_change_BANG_$jscomp$6$$){var $state$jscomp$1263$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($obj_85414_shadow_data$$);$obj_85414_shadow_data$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85414_shadow_data$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ShadowProxy"}});
Object.defineProperty($obj_85414_shadow_data$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ShadowProxy"}});Object.defineProperty($obj_85414_shadow_data$$,"id",{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$)))},set:function($val_id_85439$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$,
$app$plugins$parser$parse_id$$($val_id_85439$$));return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"style",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$)))},set:function($val_style_85447$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1921$style$$,$app$plugins$parser$parse_keyword$$($val_style_85447$$));return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"offsetX",{enumerable:!0,get:function(){return $APP.$cljs$cst$1655$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$))},set:function($val_offsetx_85455$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1655$offset_x$$,$val_offsetx_85455$$);return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"offsetY",{enumerable:!0,get:function(){return $APP.$cljs$cst$1656$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$))},set:function($val_offsety_85463$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1656$offset_y$$,$val_offsety_85463$$);return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"blur",{enumerable:!0,get:function(){return $APP.$cljs$cst$1658$blur$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$))},set:function($val_blur_85472$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1658$blur$$,$val_blur_85472$$);return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"spread",{enumerable:!0,get:function(){return $APP.$cljs$cst$1657$spread$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$))},set:function($val_spread_85481$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1657$spread$$,$val_spread_85481$$);return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"hidden",{enumerable:!0,get:function(){return $APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$))},set:function($val_hidden_85489$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1625$hidden$$,$val_hidden_85489$$);return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});Object.defineProperty($obj_85414_shadow_data$$,"color",{enumerable:!0,get:function(){return $app$plugins$format$format_color$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1263$$)))},set:function($val_color_85497$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1263$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1303$color$$,$app$plugins$parser$parse_color$$($val_color_85497$$));return $on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$6$$()}});return $obj_85414_shadow_data$$},$app$plugins$shadows$format_shadows$cljs$0core$0IFn$0_invoke$0arity$02$$=function($arr$jscomp$176_shadows$jscomp$8$$,$commit_fn$jscomp$2$$){if($arr$jscomp$176_shadows$jscomp$8$$!=null&&$APP.$cljs$core$fn_QMARK_$$($commit_fn$jscomp$2$$)){var $arr_ref$jscomp$2$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_change_BANG_$jscomp$7$$=function(){var $G__85771$$=$APP.$cljs$core$_deref$$($arr_ref$jscomp$2$$);return $commit_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$commit_fn$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__85771$$):$commit_fn$jscomp$2$$($G__85771$$)};$arr$jscomp$176_shadows$jscomp$8$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__85684_SHARP_$$){return $app$plugins$shadows$shadow_proxy$$($p1__85684_SHARP_$$,
$on_change_BANG_$jscomp$7$$)},$arr$jscomp$176_shadows$jscomp$8$$));$APP.$cljs$core$reset_BANG_$$($arr_ref$jscomp$2$$,$arr$jscomp$176_shadows$jscomp$8$$);return $arr$jscomp$176_shadows$jscomp$8$$}return $app$plugins$format$format_array$$($app$plugins$format$format_shadow$$,$arr$jscomp$176_shadows$jscomp$8$$)},$app$plugins$strokes$stroke_proxy$$=function($obj_85694_stroke_data$$,$on_change_BANG_$jscomp$8$$){var $state$jscomp$1264$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($obj_85694_stroke_data$$);
$obj_85694_stroke_data$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_85694_stroke_data$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"StrokeProxy"}});Object.defineProperty($obj_85694_stroke_data$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"StrokeProxy"}});Object.defineProperty($obj_85694_stroke_data$$,"strokeColor",{enumerable:!0,get:function(){return $APP.$cljs$cst$1745$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$))},
set:function($val_strokecolor_85721$$){return function($v$jscomp$730$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1264$$,function($p1__85686_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__85686_SHARP_$$,$APP.$cljs$cst$1745$stroke_color$$,$v$jscomp$730$$),$APP.$cljs$cst$1747$stroke_color_gradient$$)});return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():
$on_change_BANG_$jscomp$8$$()}.call(this,$val_strokecolor_85721$$)}});Object.defineProperty($obj_85694_stroke_data$$,"strokeColorRefFile",{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($APP.$cljs$cst$1646$stroke_color_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$)))},set:function($val_strokecolorreffile_85731$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1646$stroke_color_ref_file$$,
$app$plugins$parser$parse_id$$($val_strokecolorreffile_85731$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeColorRefId",{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($APP.$cljs$cst$1748$stroke_color_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$)))},set:function($val_strokecolorrefid_85739$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1748$stroke_color_ref_id$$,$app$plugins$parser$parse_id$$($val_strokecolorrefid_85739$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeOpacity",{enumerable:!0,get:function(){return $APP.$cljs$cst$1746$stroke_opacity$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$))},
set:function($val_strokeopacity_85747$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1746$stroke_opacity$$,$val_strokeopacity_85747$$);return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeStyle",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1873$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$)))},
set:function($val_strokestyle_85757$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1873$stroke_style$$,$app$plugins$parser$parse_keyword$$($val_strokestyle_85757$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeWidth",{enumerable:!0,get:function(){return $APP.$cljs$cst$1660$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$))},
set:function($val_strokewidth_85765$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1660$stroke_width$$,$val_strokewidth_85765$$);return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeAlignment",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1875$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$)))},
set:function($val_strokealignment_85774$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1875$stroke_alignment$$,$app$plugins$parser$parse_keyword$$($val_strokealignment_85774$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeCapStart",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1872$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$)))},
set:function($val_strokecapstart_85782$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1872$stroke_cap_start$$,$app$plugins$parser$parse_keyword$$($val_strokecapstart_85782$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeCapEnd",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1876$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$)))},
set:function($val_strokecapend_85792$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1876$stroke_cap_end$$,$app$plugins$parser$parse_keyword$$($val_strokecapend_85792$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}});Object.defineProperty($obj_85694_stroke_data$$,"strokeColorGradient",{enumerable:!0,get:function(){return function(){var $temp__5825__auto__$jscomp$486$$=
$APP.$cljs$cst$1747$stroke_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1264$$));if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$486$$)){var $gradient_state$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($temp__5825__auto__$jscomp$486$$);return $app$plugins$gradients$gradient_proxy$$($gradient_state$jscomp$1$$,function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1264$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1747$stroke_color_gradient$$,$APP.$cljs$core$_deref$$($gradient_state$jscomp$1$$));return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()})}return null}.call(this)},set:function($val_strokecolorgradient_85800$$){return function($v$jscomp$739$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1264$$,function($p1__85688_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__85688_SHARP_$$,
$APP.$cljs$cst$1747$stroke_color_gradient$$,$app$plugins$parser$parse_gradient$$($v$jscomp$739$$)),$APP.$cljs$cst$1745$stroke_color$$)});return $on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_BANG_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_BANG_$jscomp$8$$()}.call(this,$val_strokecolorgradient_85800$$)}});return $obj_85694_stroke_data$$},$app$plugins$strokes$format_strokes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($arr$jscomp$177_strokes$jscomp$14$$,$commit_fn$jscomp$3$$){if($arr$jscomp$177_strokes$jscomp$14$$!=
null&&$APP.$cljs$core$fn_QMARK_$$($commit_fn$jscomp$3$$)){var $arr_ref$jscomp$3$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_change_BANG_$jscomp$9$$=function(){var $G__86143$$=$APP.$cljs$core$_deref$$($arr_ref$jscomp$3$$);return $commit_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$commit_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__86143$$):$commit_fn$jscomp$3$$($G__86143$$)};$arr$jscomp$177_strokes$jscomp$14$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86140_SHARP_$$){return $app$plugins$strokes$stroke_proxy$$($p1__86140_SHARP_$$,$on_change_BANG_$jscomp$9$$)},$arr$jscomp$177_strokes$jscomp$14$$));$APP.$cljs$core$reset_BANG_$$($arr_ref$jscomp$3$$,$arr$jscomp$177_strokes$jscomp$14$$);return $arr$jscomp$177_strokes$jscomp$14$$}return $app$plugins$format$format_array$$($app$plugins$format$format_stroke$$,$arr$jscomp$177_strokes$jscomp$14$$)},$app$plugins$text$font_data$$=function($font$jscomp$60$$,
$variant$jscomp$32$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1763$font_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$60$$),$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$2686$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$60$$),$APP.$cljs$cst$1765$font_variant_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$32$$),$APP.$cljs$cst$1768$font_style$$,
$APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$32$$),$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$2012$weight$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$32$$)],null))},$app$plugins$text$variant_data$$=function($variant$jscomp$33$$){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1765$font_variant_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$33$$),
$APP.$cljs$cst$1768$font_style$$,$APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$33$$),$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$2012$weight$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$33$$)],null))},$app$plugins$text$unsupported_weight_message$$=function($font$jscomp$61_weights$$,$G__85908_value$jscomp$1094$$){$font$jscomp$61_weights$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($or__5025__auto__$jscomp$1509_p1__85905_SHARP_$$){$or__5025__auto__$jscomp$1509_p1__85905_SHARP_$$=
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($or__5025__auto__$jscomp$1509_p1__85905_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1509_p1__85905_SHARP_$$)?$or__5025__auto__$jscomp$1509_p1__85905_SHARP_$$:0},$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2012$weight$$,$APP.$cljs$cst$2687$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$61_weights$$)))));$G__85908_value$jscomp$1094$$=
"Font weight '"+($G__85908_value$jscomp$1094$$??"")+"' not supported for the current font";return $APP.$cljs$core$seq$$($font$jscomp$61_weights$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__85908_value$jscomp$1094$$),". Supported weights: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$61_weights$$)].join(""):$G__85908_value$jscomp$1094$$},$app$plugins$text$text_props$$=function($shape$jscomp$1136$$){return $APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1136$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1136$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1817$shape$$,
$shape$jscomp$1136$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]))},$app$plugins$text$content_range__GT_text_PLUS_styles$$=function($G__87356_node$jscomp$489_sss_styles$jscomp$35$$,$start$jscomp$256$$,$end$jscomp$112$$){$G__87356_node$jscomp$489_sss_styles$jscomp$35$$=$APP.$app$common$types$text$content__GT_text_PLUS_styles$$($G__87356_node$jscomp$489_sss_styles$jscomp$35$$);$G__87356_node$jscomp$489_sss_styles$jscomp$35$$=$APP.$cljs$core$seq$$($G__87356_node$jscomp$489_sss_styles$jscomp$35$$);
for(var $result__$1$jscomp$42_taking_QMARK_$$=!1,$acc$jscomp$172$$=0,$result$jscomp$395$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;)if($G__87356_node$jscomp$489_sss_styles$jscomp$35$$){var $G__87358_to$jscomp$29_vec__86025$$=$APP.$cljs$core$first$$($G__87356_node$jscomp$489_sss_styles$jscomp$35$$),$node_style$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__87358_to$jscomp$29_vec__86025$$,0,null),$G__87359_text$jscomp$155$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__87358_to$jscomp$29_vec__86025$$,
1,null),$G__87357_from$jscomp$33$$=$acc$jscomp$172$$;$G__87358_to$jscomp$29_vec__86025$$=$acc$jscomp$172$$+$APP.$cljs$core$count$$($G__87359_text$jscomp$155$$);var $taking_QMARK___$1$$=$result__$1$jscomp$42_taking_QMARK_$$||$G__87357_from$jscomp$33$$<=$start$jscomp$256$$&&$start$jscomp$256$$<$G__87358_to$jscomp$29_vec__86025$$,$text__$1$jscomp$2$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($G__87359_text$jscomp$155$$,function(){var $y__5111__auto__$jscomp$203$$=$start$jscomp$256$$-$acc$jscomp$172$$;
return 0>$y__5111__auto__$jscomp$203$$?0:$y__5111__auto__$jscomp$203$$}(),$end$jscomp$112$$-$acc$jscomp$172$$);$result__$1$jscomp$42_taking_QMARK_$$=function(){var $G__86034$$=$result$jscomp$395$$;return $taking_QMARK___$1$$&&$APP.$cljs$core$seq$$($text__$1$jscomp$2$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__86034$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node_style$jscomp$2$$,$APP.$cljs$cst$1593$text$$,$text__$1$jscomp$2$$)):$G__86034$$}();$G__87356_node$jscomp$489_sss_styles$jscomp$35$$=
$G__87357_from$jscomp$33$$>$end$jscomp$112$$||$end$jscomp$112$$>=$G__87358_to$jscomp$29_vec__86025$$?$APP.$cljs$core$rest$$($G__87356_node$jscomp$489_sss_styles$jscomp$35$$):null;$G__87357_from$jscomp$33$$=$taking_QMARK___$1$$;$G__87359_text$jscomp$155$$=$result__$1$jscomp$42_taking_QMARK_$$;$result__$1$jscomp$42_taking_QMARK_$$=$G__87357_from$jscomp$33$$;$acc$jscomp$172$$=$G__87358_to$jscomp$29_vec__86025$$;$result$jscomp$395$$=$G__87359_text$jscomp$155$$}else return $result$jscomp$395$$},$app$plugins$text$text_range_proxy$$=
function($plugin_id$jscomp$24$$,$file_id$jscomp$475$$,$page_id$jscomp$495$$,$id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$){var $obj_86145$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_86145$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TextRange"}});Object.defineProperty($obj_86145$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TextRange"}});Object.defineProperty($obj_86145$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$24$$).call(this)}});
Object.defineProperty($obj_86145$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1101$$).call(this)}});Object.defineProperty($obj_86145$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$475$$).call(this)}});Object.defineProperty($obj_86145$$,"$page",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($page_id$jscomp$495$$).call(this)}});Object.defineProperty($obj_86145$$,"$start",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($start$jscomp$257$$).call(this)}});
Object.defineProperty($obj_86145$$,"$end",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($end$jscomp$113$$).call(this)}});Object.defineProperty($obj_86145$$,"shape",{enumerable:!0,get:function(){return $app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$format$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$24$$,$file_id$jscomp$475$$,$page_id$jscomp$495$$,$id$jscomp$1101$$):$app$plugins$format$shape_proxy$$($plugin_id$jscomp$24$$,$file_id$jscomp$475$$,
$page_id$jscomp$495$$,$id$jscomp$1101$$)}});Object.defineProperty($obj_86145$$,"characters",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10432$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,
$range_data$jscomp$inline_10432$$))}});Object.defineProperty($obj_86145$$,"fontId",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10435$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1763$font_id$$,$range_data$jscomp$inline_10435$$))},
set:function($val_fontid_86224$$){var $font$jscomp$inline_10439$$=typeof $val_fontid_86224$$==="string"?$APP.$app$main$fonts$get_font_data$$($val_fontid_86224$$):null,$variant$jscomp$inline_10440$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10439$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10439$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6569$fontId$$,$val_fontid_86224$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$font_data$$($font$jscomp$inline_10439$$,$variant$jscomp$inline_10440$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6569$fontId$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,
$cljs$cst$6569$fontId$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"fontFamily",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10443$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1764$font_family$$,
$range_data$jscomp$inline_10443$$))},set:function($val_fontfamily_86232$$){var $font$jscomp$inline_10447$$=$APP.$app$main$fonts$find_font_data$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2686$family$$,$val_fontfamily_86232$$],null)),$variant$jscomp$inline_10448$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10447$$);return typeof $val_fontfamily_86232$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6570$fontFamily$$,$val_fontfamily_86232$$):
$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$font_data$$($font$jscomp$inline_10447$$,$variant$jscomp$inline_10448$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6570$fontFamily$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6570$fontFamily$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"fontVariantId",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10451$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1765$font_variant_id$$,
$range_data$jscomp$inline_10451$$))},set:function($val_fontvariantid_86240$$){var $font$jscomp$inline_10455_variant$jscomp$inline_10456$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId"));$font$jscomp$inline_10455_variant$jscomp$inline_10456$$=$APP.$app$main$fonts$get_variant$$($font$jscomp$inline_10455_variant$jscomp$inline_10456$$,$val_fontvariantid_86240$$);return typeof $val_fontvariantid_86240$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,
$cljs$cst$6571$fontVariantId$$,$val_fontvariantid_86240$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$variant_data$$($font$jscomp$inline_10455_variant$jscomp$inline_10456$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,
$cljs$cst$6571$fontVariantId$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6571$fontVariantId$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"fontSize",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10459$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,
$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1766$font_size$$,$range_data$jscomp$inline_10459$$))},set:function($val_fontsize_86248_value__$1$jscomp$inline_10463$$){$val_fontsize_86248_value__$1$jscomp$inline_10463$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($val_fontsize_86248_value__$1$jscomp$inline_10463$$??""));return $APP.$cljs$core$empty_QMARK_$$($val_fontsize_86248_value__$1$jscomp$inline_10463$$)||
$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$font_size_re$$,$val_fontsize_86248_value__$1$jscomp$inline_10463$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6572$fontSize$$,$val_fontsize_86248_value__$1$jscomp$inline_10463$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,
$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1766$font_size$$,$val_fontsize_86248_value__$1$jscomp$inline_10463$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6572$fontSize$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6572$fontSize$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"fontWeight",{enumerable:!0,
get:function(){var $range_data$jscomp$inline_10466$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1767$font_weight$$,$range_data$jscomp$inline_10466$$))},set:function($val_fontweight_86256$$){var $font$jscomp$inline_14207$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"fontId")),$variant$jscomp$inline_14209_weight$jscomp$inline_14208$$=""+($val_fontweight_86256$$??""),$or__5025__auto__$jscomp$inline_14210$$=$app$main$fonts$find_variant$$($font$jscomp$inline_14207$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1921$style$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontStyle"),$APP.$cljs$cst$2012$weight$$,$variant$jscomp$inline_14209_weight$jscomp$inline_14208$$],null));$variant$jscomp$inline_14209_weight$jscomp$inline_14208$$=
$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_14210$$)?$or__5025__auto__$jscomp$inline_14210$$:$app$main$fonts$find_variant$$($font$jscomp$inline_14207$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2012$weight$$,$variant$jscomp$inline_14209_weight$jscomp$inline_14208$$],null));return $variant$jscomp$inline_14209_weight$jscomp$inline_14208$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6573$fontWeight$$,$app$plugins$text$unsupported_weight_message$$($font$jscomp$inline_14207$$,
$val_fontweight_86256$$)):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$variant_data$$($variant$jscomp$inline_14209_weight$jscomp$inline_14208$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6573$fontWeight$$,
"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6573$fontWeight$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"fontStyle",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10471$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);
return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1768$font_style$$,$range_data$jscomp$inline_10471$$))},set:function($val_fontstyle_86264$$){var $font$jscomp$inline_14214_variant$jscomp$inline_14216$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$style$jscomp$inline_14215$$=""+($val_fontstyle_86264$$??""),$or__5025__auto__$jscomp$inline_14217$$=$app$main$fonts$find_variant$$($font$jscomp$inline_14214_variant$jscomp$inline_14216$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2012$weight$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontWeight"),$APP.$cljs$cst$1921$style$$,$style$jscomp$inline_14215$$],null));$font$jscomp$inline_14214_variant$jscomp$inline_14216$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_14217$$)?$or__5025__auto__$jscomp$inline_14217$$:$app$main$fonts$find_variant$$($font$jscomp$inline_14214_variant$jscomp$inline_14216$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1921$style$$,$style$jscomp$inline_14215$$],null));return $font$jscomp$inline_14214_variant$jscomp$inline_14216$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6574$fontStyle$$,"Font style '"+($val_fontstyle_86264$$??"")+"' not supported for the current font"):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,
$start$jscomp$257$$,$end$jscomp$113$$,$app$plugins$text$variant_data$$($font$jscomp$inline_14214_variant$jscomp$inline_14216$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6574$fontStyle$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6574$fontStyle$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"lineHeight",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10476$$=
$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1771$line_height$$,$range_data$jscomp$inline_10476$$))},set:function($val_lineheight_86272_value__$1$jscomp$inline_10480$$){$val_lineheight_86272_value__$1$jscomp$inline_10480$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+
($val_lineheight_86272_value__$1$jscomp$inline_10480$$??""));return $APP.$cljs$core$empty_QMARK_$$($val_lineheight_86272_value__$1$jscomp$inline_10480$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$line_height_re$$,$val_lineheight_86272_value__$1$jscomp$inline_10480$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6575$lineHeight$$,$val_lineheight_86272_value__$1$jscomp$inline_10480$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1771$line_height$$,$val_lineheight_86272_value__$1$jscomp$inline_10480$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6575$lineHeight$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6575$lineHeight$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"letterSpacing",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10483$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1772$letter_spacing$$,
$range_data$jscomp$inline_10483$$))},set:function($val_letterspacing_86280_value__$1$jscomp$inline_10487$$){$val_letterspacing_86280_value__$1$jscomp$inline_10487$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($val_letterspacing_86280_value__$1$jscomp$inline_10487$$??""));return typeof $val_letterspacing_86280_value__$1$jscomp$inline_10487$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$letter_spacing_re$$,$val_letterspacing_86280_value__$1$jscomp$inline_10487$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6576$letterSpacing$$,$val_letterspacing_86280_value__$1$jscomp$inline_10487$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1772$letter_spacing$$,$val_letterspacing_86280_value__$1$jscomp$inline_10487$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6576$letterSpacing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6576$letterSpacing$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"textTransform",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10490$$=
$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1775$text_transform$$,$range_data$jscomp$inline_10490$$))},set:function($val_texttransform_86288$$){return typeof $val_texttransform_86288$$==="string"&&$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_transform_re$$,
$val_texttransform_86288$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6577$textTransform$$,$val_texttransform_86288$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1775$text_transform$$,$val_texttransform_86288$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6577$textTransform$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6577$textTransform$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"textDecoration",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10496$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1774$text_decoration$$,$range_data$jscomp$inline_10496$$))},set:function($val_textdecoration_86296$$){return typeof $val_textdecoration_86296$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_decoration_re$$,$val_textdecoration_86296$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6578$textDecoration$$,
$val_textdecoration_86296$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1774$text_decoration$$,$val_textdecoration_86296$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,
$cljs$cst$6578$textDecoration$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$cljs$cst$6578$textDecoration$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"direction",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10502$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,
$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1979$direction$$,$range_data$jscomp$inline_10502$$))},set:function($val_direction_86304$$){return typeof $val_direction_86304$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_direction_re$$,$val_direction_86304$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$1979$direction$$,$val_direction_86304$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1979$direction$$,$val_direction_86304$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$1979$direction$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$1979$direction$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"align",{enumerable:!0,get:function(){var $range_data$jscomp$inline_10508$$=$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);return $app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1769$text_align$$,
$range_data$jscomp$inline_10508$$))},set:function($val_align_86312$$){return typeof $val_align_86312$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_align_re$$,$val_align_86312$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$4832$align$$,$val_align_86312$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,
$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1769$text_align$$,$val_align_86312$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$4832$align$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$4832$align$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"fills",{enumerable:!0,get:function(){var $fills$jscomp$inline_14219_range_data$jscomp$inline_10514$$=
$app$plugins$text$content_range__GT_text_PLUS_styles$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$start$jscomp$257$$,$end$jscomp$113$$);$fills$jscomp$inline_14219_range_data$jscomp$inline_10514$$=$app$plugins$utils$mixed_value$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1639$fills$$,$fills$jscomp$inline_14219_range_data$jscomp$inline_10514$$));return $app$plugins$fills$format_fills$cljs$0core$0IFn$0_invoke$0arity$02$$($fills$jscomp$inline_14219_range_data$jscomp$inline_10514$$,
null)},set:function($val_fills_86326_value__$1$jscomp$inline_10518$$){$val_fills_86326_value__$1$jscomp$inline_10518$$=$app$plugins$parser$parse_fills$$($val_fills_86326_value__$1$jscomp$inline_10518$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$fills$schema_COLON_fill$$],null),$val_fills_86326_value__$1$jscomp$inline_10518$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,
$APP.$cljs$cst$1639$fills$$,$val_fills_86326_value__$1$jscomp$inline_10518$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$24$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$495$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1639$fills$$,$val_fills_86326_value__$1$jscomp$inline_10518$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$1639$fills$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$24$$,$APP.$cljs$cst$1639$fills$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_86145$$,"applyTypography",{enumerable:!1,get:function(){return function($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$){$attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$=
$app$plugins$utils$proxy__GT_library_typography$$($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$);$attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$,$APP.$cljs$cst$1647$typography_ref_file$$,$file_id$jscomp$475$$),$APP.$cljs$cst$1762$typography_ref_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$)),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($id$jscomp$1101$$,$start$jscomp$257$$,$end$jscomp$113$$,$attrs$jscomp$186_typography$jscomp$41_typography__$1$jscomp$5$$))}.bind(this)}});
return $obj_86145$$},$app$plugins$text$add_text_props$$=function($shape_proxy$$,$plugin_id$jscomp$25$$){function $set_fn87088_87634$$($id$jscomp$1103_self$jscomp$160$$,$value$jscomp$1109$$){$id$jscomp$1103_self$jscomp$160$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1103_self$jscomp$160$$,"$id");var $value__$1$jscomp$111$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1109$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2045$auto_height$$,null,$APP.$cljs$cst$1676$fixed$$,null,$APP.$cljs$cst$2046$auto_width$$,null],null),null),$value__$1$jscomp$111$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1103_self$jscomp$160$$],null),function($p1__87067_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87067_SHARP_$$,$APP.$cljs$cst$1776$grow_type$$,$value__$1$jscomp$111$$)}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1103_self$jscomp$160$$)):
null])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6580$growType$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6580$growType$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6580$growType$$,$value__$1$jscomp$111$$)}function $set_fn87088_87590$$($self$jscomp$159_shape$jscomp$1137$$,$value$jscomp$1108$$){var $editor$jscomp$12_id$jscomp$1102$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$159_shape$jscomp$1137$$,"$id");if(typeof $value$jscomp$1108$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($value$jscomp$1108$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6579$characters$$,$value$jscomp$1108$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)){if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2230$workspace_editor_state$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$editor$jscomp$12_id$jscomp$1102$$))return $self$jscomp$159_shape$jscomp$1137$$=$app$plugins$utils$proxy__GT_shape$$($self$jscomp$159_shape$jscomp$1137$$),$editor$jscomp$12_id$jscomp$1102$$=$app$util$text_editor$create_editor_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$text_editor$import_content$$($app$common$types$text$change_text$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self$jscomp$159_shape$jscomp$1137$$,$APP.$cljs$cst$1642$content$$),$value$jscomp$1108$$))),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($self$jscomp$159_shape$jscomp$1137$$,
$editor$jscomp$12_id$jscomp$1102$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$editor$jscomp$12_id$jscomp$1102$$],null),function($p1__87065_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__87065_SHARP_$$,$APP.$cljs$cst$1642$content$$,$app$common$types$text$change_text$$,
$value$jscomp$1108$$)}));return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($editor$jscomp$12_id$jscomp$1102$$)):null}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6579$characters$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,
$cljs$cst$6579$characters$$,"Plugin doesn't have 'content:write' permission")}var $page_id$jscomp$496$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_proxy$$,"$page");Object.defineProperty($shape_proxy$$,"characters",function(){return{enumerable:!0,get:function(){return $APP.$app$common$types$text$content__GT_text$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42827__auto__$$){return $set_fn87088_87590$$(this,
$value__42827__auto__$$)}}}());Object.defineProperty($shape_proxy$$,"growType",function(){return{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42827__auto__$jscomp$1$$){return $set_fn87088_87634$$(this,$value__42827__auto__$jscomp$1$$)}}}());Object.defineProperty($shape_proxy$$,"fontId",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42827__auto__$jscomp$2$$){var $id$jscomp$inline_10522$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_10523$$=typeof $value__42827__auto__$jscomp$2$$==="string"?$APP.$app$main$fonts$get_font_data$$($value__42827__auto__$jscomp$2$$):null,$variant$jscomp$inline_10524$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10523$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10523$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,
$cljs$cst$6569$fontId$$,$value__42827__auto__$jscomp$2$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10522$$,$app$plugins$text$font_data$$($font$jscomp$inline_10523$$,$variant$jscomp$inline_10524$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6569$fontId$$,
"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6569$fontId$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontFamily",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42827__auto__$jscomp$3$$){var $id$jscomp$inline_10528$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_10529$$=$APP.$app$main$fonts$find_font_data$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2686$family$$,$value__42827__auto__$jscomp$3$$],null)),$variant$jscomp$inline_10530$$=$APP.$app$main$fonts$get_default_variant$$($font$jscomp$inline_10529$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10529$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6570$fontFamily$$,
$value__42827__auto__$jscomp$3$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10528$$,$app$plugins$text$font_data$$($font$jscomp$inline_10529$$,$variant$jscomp$inline_10530$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6570$fontFamily$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6570$fontFamily$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontVariantId",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1765$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42827__auto__$jscomp$4$$){var $id$jscomp$inline_10534$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_10535_variant$jscomp$inline_10536$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId"));$font$jscomp$inline_10535_variant$jscomp$inline_10536$$=$APP.$app$main$fonts$get_variant$$($font$jscomp$inline_10535_variant$jscomp$inline_10536$$,$value__42827__auto__$jscomp$4$$);return $APP.$cljs$core$not$$($font$jscomp$inline_10535_variant$jscomp$inline_10536$$)?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6571$fontVariantId$$,$value__42827__auto__$jscomp$4$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10534$$,$app$plugins$text$variant_data$$($font$jscomp$inline_10535_variant$jscomp$inline_10536$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,
$cljs$cst$6571$fontVariantId$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6571$fontVariantId$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontSize",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$){var $id$jscomp$inline_10540$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$??""));return $APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$font_size_re$$,
$value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6572$fontSize$$,$value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10540$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1766$font_size$$,$value__$1$jscomp$inline_10541_value__42827__auto__$jscomp$5$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6572$fontSize$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6572$fontSize$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontWeight",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42827__auto__$jscomp$6$$){var $id$jscomp$inline_14223$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_14224$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$variant$jscomp$inline_14226_weight$jscomp$inline_14225$$=""+($value__42827__auto__$jscomp$6$$??""),$or__5025__auto__$jscomp$inline_14227$$=$app$main$fonts$find_variant$$($font$jscomp$inline_14224$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1921$style$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontStyle"),$APP.$cljs$cst$2012$weight$$,$variant$jscomp$inline_14226_weight$jscomp$inline_14225$$],null));$variant$jscomp$inline_14226_weight$jscomp$inline_14225$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_14227$$)?$or__5025__auto__$jscomp$inline_14227$$:$app$main$fonts$find_variant$$($font$jscomp$inline_14224$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2012$weight$$,
$variant$jscomp$inline_14226_weight$jscomp$inline_14225$$],null));return $variant$jscomp$inline_14226_weight$jscomp$inline_14225$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6573$fontWeight$$,$app$plugins$text$unsupported_weight_message$$($font$jscomp$inline_14224$$,$value__42827__auto__$jscomp$6$$)):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_14223$$,
$app$plugins$text$variant_data$$($variant$jscomp$inline_14226_weight$jscomp$inline_14225$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6573$fontWeight$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6573$fontWeight$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"fontStyle",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42827__auto__$jscomp$7$$){var $id$jscomp$inline_14231$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$font$jscomp$inline_14232_variant$jscomp$inline_14234$$=$APP.$app$main$fonts$get_font_data$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontId")),$style$jscomp$inline_14233$$=""+($value__42827__auto__$jscomp$7$$??""),$or__5025__auto__$jscomp$inline_14235$$=$app$main$fonts$find_variant$$($font$jscomp$inline_14232_variant$jscomp$inline_14234$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2012$weight$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"fontWeight"),$APP.$cljs$cst$1921$style$$,$style$jscomp$inline_14233$$],null));$font$jscomp$inline_14232_variant$jscomp$inline_14234$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_14235$$)?$or__5025__auto__$jscomp$inline_14235$$:$app$main$fonts$find_variant$$($font$jscomp$inline_14232_variant$jscomp$inline_14234$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1921$style$$,$style$jscomp$inline_14233$$],null));return $font$jscomp$inline_14232_variant$jscomp$inline_14234$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6574$fontStyle$$,"Font style '"+($value__42827__auto__$jscomp$7$$??"")+"' not supported for the current font"):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_14231$$,
$app$plugins$text$variant_data$$($font$jscomp$inline_14232_variant$jscomp$inline_14234$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6574$fontStyle$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6574$fontStyle$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"lineHeight",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1771$line_height$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$){var $id$jscomp$inline_10549$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$??""));return $APP.$cljs$core$empty_QMARK_$$($value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$)||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$line_height_re$$,
$value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6575$lineHeight$$,$value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10549$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1771$line_height$$,$value__$1$jscomp$inline_10550_value__42827__auto__$jscomp$8$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6575$lineHeight$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6575$lineHeight$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"letterSpacing",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1772$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$){var $id$jscomp$inline_10554$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$(""+($value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$??""));return typeof $value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$letter_spacing_re$$,
$value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6576$letterSpacing$$,$value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10554$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1772$letter_spacing$$,$value__$1$jscomp$inline_10555_value__42827__auto__$jscomp$9$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6576$letterSpacing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6576$letterSpacing$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"textTransform",function(){return{enumerable:!0,
get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1775$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42827__auto__$jscomp$10$$){var $id$jscomp$inline_10559$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42827__auto__$jscomp$10$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_transform_re$$,
$value__42827__auto__$jscomp$10$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6577$textTransform$$,$value__42827__auto__$jscomp$10$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10559$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1775$text_transform$$,
$value__42827__auto__$jscomp$10$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6577$textTransform$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6577$textTransform$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"textDecoration",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1774$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42827__auto__$jscomp$11$$){var $id$jscomp$inline_10563$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42827__auto__$jscomp$11$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_decoration_re$$,$value__42827__auto__$jscomp$11$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6578$textDecoration$$,$value__42827__auto__$jscomp$11$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10563$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1774$text_decoration$$,$value__42827__auto__$jscomp$11$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6578$textDecoration$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,
$cljs$cst$6578$textDecoration$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"direction",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1770$text_direction$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},set:function($value__42827__auto__$jscomp$12$$){var $id$jscomp$inline_10567$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id");return typeof $value__42827__auto__$jscomp$12$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_direction_re$$,$value__42827__auto__$jscomp$12$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6581$textDirection$$,$value__42827__auto__$jscomp$12$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10567$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1770$text_direction$$,$value__42827__auto__$jscomp$12$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6581$textDirection$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6581$textDirection$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"align",function(){return{enumerable:!0,get:function(){return $app$plugins$format$format_mixed$$($APP.$cljs$cst$1769$text_align$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this))))},
set:function($value__42827__auto__$jscomp$13$$){var $id$jscomp$inline_10571$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42827__auto__$jscomp$13$$!=="string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$text_align_re$$,$value__42827__auto__$jscomp$13$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$APP.$cljs$cst$4832$align$$,$value__42827__auto__$jscomp$13$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10571$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1769$text_align$$,$value__42827__auto__$jscomp$13$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$APP.$cljs$cst$4832$align$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,
$APP.$cljs$cst$4832$align$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"verticalAlign",function(){return{enumerable:!0,get:function(){return $APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$text$text_props$$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42827__auto__$jscomp$14$$){var $id$jscomp$inline_10575$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return typeof $value__42827__auto__$jscomp$14$$!==
"string"||$APP.$cljs$core$not$$($APP.$cljs$core$re_matches$$($app$plugins$text$vertical_align_re$$,$value__42827__auto__$jscomp$14$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6582$verticalAlign$$,$value__42827__auto__$jscomp$14$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$25$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$496$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$inline_10575$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1773$vertical_align$$,$value__42827__auto__$jscomp$14$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6582$verticalAlign$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$25$$,$cljs$cst$6582$verticalAlign$$,"Plugin doesn't have 'content:write' permission")}}}());Object.defineProperty($shape_proxy$$,"textBounds",function(){return{enumerable:!0,get:function(){var $JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$=
$app$plugins$utils$proxy__GT_shape$$(this);var $points$jscomp$inline_14238_y$jscomp$inline_14243$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$rect__GT_points$$,$APP.$app$common$geom$shapes$text$position_data__GT_rect$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1899$position_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$)]));
$JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$inline_14238_y$jscomp$inline_14243$$,$APP.$app$common$geom$shapes$transforms$transform_matrix$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$,null)));var $height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$);$JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$,$APP.$cljs$cst$1515$x$$);$points$jscomp$inline_14238_y$jscomp$inline_14243$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$,
$APP.$cljs$cst$1516$y$$);var $width$jscomp$inline_14244$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$,$APP.$cljs$cst$1527$height$$);return{x:$JSCompiler_inline_result$jscomp$11339_shape$jscomp$inline_14237_x$jscomp$inline_14242$$,
y:$points$jscomp$inline_14238_y$jscomp$inline_14243$$,width:$width$jscomp$inline_14244$$,height:$height$jscomp$inline_14245_map__84114__$1$jscomp$inline_14241$$}}}}());return $shape_proxy$$},$app$plugins$tokens$token_attr_plugin__GT_token_attr$$=function($k$jscomp$737_k__$1$jscomp$23$$){$k$jscomp$737_k__$1$jscomp$23$$=typeof $k$jscomp$737_k__$1$jscomp$23$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$737_k__$1$jscomp$23$$):$k$jscomp$737_k__$1$jscomp$23$$;return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$tokens$map_COLON_token_attr_plugin__GT_token_attr$$,
$k$jscomp$737_k__$1$jscomp$23$$,$k$jscomp$737_k__$1$jscomp$23$$)},$app$plugins$tokens$applied_tokens_plugin__GT_applied_tokens$$=function($value$jscomp$1123$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__86028_v$jscomp$740$$){var $k$jscomp$738$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__86028_v$jscomp$740$$,0,null);$p__86028_v$jscomp$740$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__86028_v$jscomp$740$$,
1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$tokens$map_COLON_token_attr__GT_token_attr_plugin$$,$k$jscomp$738$$,$k$jscomp$738$$),$p__86028_v$jscomp$740$$],null)}),$value$jscomp$1123$$)},$app$plugins$tokens$token_attr_QMARK_$$=function($attr$jscomp$97_attr$jscomp$inline_10577$$){$attr$jscomp$97_attr$jscomp$inline_10577$$=$app$plugins$tokens$token_attr_plugin__GT_token_attr$$($attr$jscomp$97_attr$jscomp$inline_10577$$);
return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$token$all_keys$$,$attr$jscomp$97_attr$jscomp$inline_10577$$)},$app$plugins$tokens$apply_token_to_shapes$$=function($plugin_id$jscomp$26$$,$file_id$jscomp$476_token$jscomp$215$$,$set_id$jscomp$46$$,$id$jscomp$1117$$,$shape_ids$jscomp$121$$,$attrs$jscomp$187$$){$file_id$jscomp$476_token$jscomp$215$$=$app$plugins$utils$locate_token$$($file_id$jscomp$476_token$jscomp$215$$,$set_id$jscomp$46$$,$id$jscomp$1117$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__86125_SHARP_$$){return!$app$plugins$tokens$token_attr_QMARK_$$($p1__86125_SHARP_$$)},
$attrs$jscomp$187$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$26$$,$cljs$cst$6595$applyToSelected$$,$attrs$jscomp$187$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$file_id$jscomp$476_token$jscomp$215$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$tokens$token_attr_plugin__GT_token_attr$$),$attrs$jscomp$187$$),$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$121$$,$APP.$cljs$cst$4735$expand_with_children$$,!1],null)),$plugin_id$jscomp$26$$))},$app$plugins$tokens$shadow_entry__GT_js$$=function($m$jscomp$258$$){var $out$jscomp$19$$={};$m$jscomp$258$$.forEach(function($sym$jscomp$25$$,$JSCompiler_inline_result$jscomp$2278_k$jscomp$740$$){a:switch($JSCompiler_inline_result$jscomp$2278_k$jscomp$740$$){case "offset-x":$JSCompiler_inline_result$jscomp$2278_k$jscomp$740$$=
"offsetX";break a;case "offset-y":$JSCompiler_inline_result$jscomp$2278_k$jscomp$740$$="offsetY"}return $APP.$app$util$object$set_BANG_$$($out$jscomp$19$$,$JSCompiler_inline_result$jscomp$2278_k$jscomp$740$$,$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($sym$jscomp$25$$))});return $out$jscomp$19$$},$app$plugins$tokens$get_resolved_value$$=function($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$,
$JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$){$JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$=$APP.$app$main$data$tokenscript$resolve_tokens$$($JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$);$JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)),$APP.$cljs$cst$4686$resolved_value$$);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)))$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=
$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$),$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$==
null?null:$APP.$cljs$core$sequential_QMARK_$$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)?$APP.$cljs$core$clj__GT_js$$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$):
[$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$];else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1997$typography$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)))if($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=
$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$),$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)){$JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$=
$APP.$cljs$core$clj__GT_js$$($APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$));var $JSCompiler_temp_const$jscomp$inline_14250$$=$APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$);
var $G__86383$jscomp$inline_14252_JSCompiler_inline_result$jscomp$inline_14251$$=$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$);$G__86383$jscomp$inline_14252_JSCompiler_inline_result$jscomp$inline_14251$$=$G__86383$jscomp$inline_14252_JSCompiler_inline_result$jscomp$inline_14251$$==
null?null:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__86383$jscomp$inline_14252_JSCompiler_inline_result$jscomp$inline_14251$$);$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=[{fontFamilies:$JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$,fontSizes:$JSCompiler_temp_const$jscomp$inline_14250$$,
fontWeights:$G__86383$jscomp$inline_14252_JSCompiler_inline_result$jscomp$inline_14251$$,letterSpacing:$APP.$cljs$cst$1772$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$),lineHeight:$APP.$cljs$cst$1771$line_height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$),
textCase:$APP.$cljs$cst$1995$text_case$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$),textDecoration:$APP.$cljs$cst$1774$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)}]}else $JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=
null;else $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$))?($JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=
$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$),$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$!=
null?$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$tokens$shadow_entry__GT_js$$,$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$)):null):$JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$=
$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($JSCompiler_temp_const$jscomp$inline_14249_resolved_tokens$jscomp$31_resolved_value$jscomp$13_tokens_tree$jscomp$15$$);return $JSCompiler_temp$jscomp$2279_JSCompiler_temp$jscomp$2280_JSCompiler_temp$jscomp$2281_JSCompiler_temp$jscomp$inline_14248_entries$jscomp$inline_10586_m$jscomp$inline_14247_token$jscomp$216_v$jscomp$inline_10584$$},$app$plugins$tokens$shape_proxy_QMARK_$$=function($s$jscomp$616$$){return $app$util$object$type_of_QMARK_$$($s$jscomp$616$$,
"ShapeProxy")},$app$plugins$tokens$token_set_proxy_QMARK_$$=function($p$jscomp$271$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$271$$,"TokenSetProxy")},$app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$03$$=function($plugin_id$jscomp$28$$,$file_id$jscomp$478$$,$id$jscomp$1119$$){return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$($plugin_id$jscomp$28$$,$file_id$jscomp$478$$,$id$jscomp$1119$$,null)},$app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$=
function($plugin_id$jscomp$29$$,$file_id$jscomp$479$$,$id$jscomp$1120$$,$initial_name$$){function $schema_addtoken_87042_87783$$($G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$){var $tokens_tree$jscomp$18$$=$APP.$app$common$types$tokens_lib$tokens_tree$$($APP.$app$common$types$tokens_lib$get_tokens$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$479$$),$id$jscomp$1120$$)),$JSCompiler_temp_const$jscomp$2292$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;
$G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$),"type");$G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$=$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$):
(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$2292$$,[$APP.$cljs$cst$498$tuple$$,$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($tokens_tree$jscomp$18$$,$G__87112$jscomp$inline_10626_JSCompiler_inline_result$jscomp$2293_args$jscomp$268$$,
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$938$decode_SLASH_json$$,$app$common$files$tokens$convert_dtcg_token$$]))],null)}var $obj_86945$$=new $APP.$app$util$object$Proxy$$,$schema_name_86994_87764$$=$APP.$app$common$files$tokens$make_token_set_name_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$479$$),$id$jscomp$1120$$),$coercer_fn_name_86992_87765$$=$schema_name_86994_87764$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_name_86994_87764$$)?
null:$APP.$app$common$schema$coercer$$($schema_name_86994_87764$$),$coercer_fn_active_87002_87770$$=$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$==null||$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?null:$APP.$app$common$schema$coercer$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$),$schema_gettokenbyid_87035_87779$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,
$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$coercer_fn_gettokenbyid_87033_87780$$=$schema_gettokenbyid_87035_87779$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_gettokenbyid_87035_87779$$)?null:$APP.$app$common$schema$coercer$$($schema_gettokenbyid_87035_87779$$),$coercer_fn_addtoken_87040_87784$$=$schema_addtoken_87042_87783$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addtoken_87042_87783$$)?null:$APP.$app$common$schema$coercer$$($schema_addtoken_87042_87783$$);Object.defineProperty($obj_86945$$,
Symbol.toStringTag,{enumerable:!1,get:function(){return"TokenSetProxy"}});Object.defineProperty($obj_86945$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokenSetProxy"}});Object.defineProperty($obj_86945$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_86963$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$29$$);try{return $internal_fn_plugin_86963$$.call(this)}catch($e87071$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87071$$)}}});
Object.defineProperty($obj_86945$$,"$file-id",{enumerable:!1,get:function(){var $internal_fn_fileid_86970$$=$APP.$cljs$core$constantly$$($file_id$jscomp$479$$);try{return $internal_fn_fileid_86970$$.call(this)}catch($e87073$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87073$$)}}});Object.defineProperty($obj_86945$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_86977$$=$APP.$cljs$core$constantly$$($id$jscomp$1120$$);try{return $internal_fn_id_86977$$.call(this)}catch($e87076$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87076$$)}}});
Object.defineProperty($obj_86945$$,"id",{enumerable:!0,get:function(){try{return""+($id$jscomp$1120$$??"")}catch($e87080$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87080$$)}}});Object.defineProperty($obj_86945$$,"name",{enumerable:!0,get:function(){try{var $set$jscomp$inline_10611$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$479$$,$id$jscomp$1120$$);return $set$jscomp$inline_10611$$!=null?$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$inline_10611$$):
$initial_name$$}catch($e87086$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87086$$)}},set:function($val_name_86996$$){try{var $schema_name_86994__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_name_86994_87764$$)?$schema_name_86994_87764$$($val_name_86996$$):$schema_name_86994_87764$$,$coercer_fn_name_86992__$1$$=$coercer_fn_name_86992_87765$$==null?$APP.$app$common$schema$coercer$$($schema_name_86994__$1$$):$coercer_fn_name_86992_87765$$,$val_name_86996__$1$$=$APP.$app$common$json$__GT_clj$$($val_name_86996$$,
null),$name$jscomp$inline_10615$$=$coercer_fn_name_86992__$1$$($val_name_86996__$1$$),$set$jscomp$inline_10616$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$479$$,$id$jscomp$1120$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$rename_token_set$$($set$jscomp$inline_10616$$,$name$jscomp$inline_10615$$))}catch($e87091$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87091$$)}}});Object.defineProperty($obj_86945$$,
"active",{enumerable:!1,get:function(){try{var $tokens_lib$jscomp$inline_10618$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$479$$),$set$jscomp$inline_10619$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$479$$,$id$jscomp$1120$$);return $APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$($tokens_lib$jscomp$inline_10618$$,$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$inline_10619$$))}catch($e87092$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87092$$)}},
set:function($val_active_87006$$){try{var $schema_active_87004__$1$$=$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?(0,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)($val_active_87006$$):$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$,$coercer_fn_active_87002__$1$$=$coercer_fn_active_87002_87770$$==null?$APP.$app$common$schema$coercer$$($schema_active_87004__$1$$):$coercer_fn_active_87002_87770$$,$val_active_87006__$1$$=$APP.$app$common$json$__GT_clj$$($val_active_87006$$,
null),$value$jscomp$inline_10623$$=$coercer_fn_active_87002__$1$$($val_active_87006__$1$$),$set$jscomp$inline_10624$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$479$$,$id$jscomp$1120$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$set_enabled_token_set$$($APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$inline_10624$$),$value$jscomp$inline_10623$$))}catch($e87095$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87095$$)}}});
Object.defineProperty($obj_86945$$,"toggleActive",{enumerable:!1,get:function(){return function(){try{var $set$jscomp$29$$=$app$plugins$utils$locate_token_set$$($file_id$jscomp$479$$,$id$jscomp$1120$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_set$$($APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$29$$)))}catch($e87096$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87096$$)}}.bind(this)}});
Object.defineProperty($obj_86945$$,"tokens",{enumerable:!1,get:function(){function $internal_fn_tokens_87016$$(){var $tokens_lib$jscomp$62$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$479$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86909_SHARP_$$){return $app$plugins$tokens$token_proxy$$($plugin_id$jscomp$29$$,$file_id$jscomp$479$$,$id$jscomp$1120$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__86909_SHARP_$$))},
$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$62$$,$id$jscomp$1120$$))))}try{return $internal_fn_tokens_87016$$.call(this,this)}catch($e87099$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87099$$)}}});Object.defineProperty($obj_86945$$,"tokensByType",{enumerable:!1,get:function(){function $internal_fn_tokensbytype_87023$$(){var $tokens$jscomp$81_tokens_lib$jscomp$63$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$479$$);$tokens$jscomp$81_tokens_lib$jscomp$63$$=
$APP.$app$common$types$tokens_lib$get_tokens$$($tokens$jscomp$81_tokens_lib$jscomp$63$$,$id$jscomp$1120$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__87100_tokens__$1$jscomp$13$$){var $type$jscomp$750$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__87100_tokens__$1$jscomp$13$$,0,null);$p__87100_tokens__$1$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__87100_tokens__$1$jscomp$13$$,
1,null);return[$APP.$cljs$core$name$$($type$jscomp$750$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86913_SHARP_$$){return $app$plugins$tokens$token_proxy$$($plugin_id$jscomp$29$$,$file_id$jscomp$479$$,$id$jscomp$1120$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__86913_SHARP_$$))},$p__87100_tokens__$1$jscomp$13$$))]},$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$group_by$$(function($G__87104_p1__86910_SHARP_$$){$G__87104_p1__86910_SHARP_$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__87104_p1__86910_SHARP_$$);return $APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__87104_p1__86910_SHARP_$$):(0,$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$)($G__87104_p1__86910_SHARP_$$)},
$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$vals$$($tokens$jscomp$81_tokens_lib$jscomp$63$$))))))}try{return $internal_fn_tokensbytype_87023$$.call(this,this)}catch($e87107$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87107$$)}}});Object.defineProperty($obj_86945$$,"getTokenById",{enumerable:!1,get:function(){var $internal_fn_gettokenbyid_87032__$1$$=function($token_id$jscomp$26$$){try{return $app$plugins$utils$locate_token$$($file_id$jscomp$479$$,
$id$jscomp$1120$$,$token_id$jscomp$26$$)!=null?$app$plugins$tokens$token_proxy$$($plugin_id$jscomp$29$$,$file_id$jscomp$479$$,$id$jscomp$1120$$,$token_id$jscomp$26$$):null}catch($e87108$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87108$$)}}.bind(this);return function(){try{var $val_gettokenbyid_87037$$=Array.from(arguments),$val_gettokenbyid_87037__$1$$=$APP.$app$common$json$__GT_clj$$($val_gettokenbyid_87037$$,null),$schema_gettokenbyid_87035__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_gettokenbyid_87035_87779$$)?
$schema_gettokenbyid_87035_87779$$($val_gettokenbyid_87037__$1$$):$schema_gettokenbyid_87035_87779$$,$val_gettokenbyid_87037__$2$$=($coercer_fn_gettokenbyid_87033_87780$$==null?$APP.$app$common$schema$coercer$$($schema_gettokenbyid_87035__$1$$):$coercer_fn_gettokenbyid_87033_87780$$)($val_gettokenbyid_87037__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_gettokenbyid_87032__$1$$,$val_gettokenbyid_87037__$2$$)}catch($e87109$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87109$$)}}}});
Object.defineProperty($obj_86945$$,"addToken",{enumerable:!1,get:function(){var $internal_fn_addtoken_87039__$1$$=function($attrs$jscomp$190$$){try{var $tokens_lib$jscomp$64$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$479$$),$token$jscomp$227$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$190$$])),$tokens_tree$jscomp$19$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$get_all_tokens_map$$($tokens_lib$jscomp$64$$),
$APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$64$$,$id$jscomp$1120$$)])),$token$jscomp$227$$.name,$token$jscomp$227$$),$resolved_tokens$jscomp$32$$=$APP.$app$main$data$tokenscript$resolve_tokens$$($tokens_tree$jscomp$19$$),$map__87114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$32$$,$token$jscomp$227$$.name),$map__87114__$1$$=$APP.$cljs$core$__destructure_map$$($map__87114$$),$errors$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__87114__$1$$,
$APP.$cljs$cst$570$errors$$),$resolved_value$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__87114__$1$$,$APP.$cljs$cst$4686$resolved_value$$);if($APP.$cljs$core$truth_$$($resolved_value$jscomp$14$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1120$$,$token$jscomp$227$$),$plugin_id$jscomp$29$$)),$app$plugins$tokens$token_proxy$$($plugin_id$jscomp$29$$,
$file_id$jscomp$479$$,$id$jscomp$1120$$,$token$jscomp$227$$.id);$app$plugins$utils$not_valid$$($plugin_id$jscomp$29$$,$cljs$cst$6596$addToken$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($errors$jscomp$49$$));return null}catch($e87113$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87113$$)}}.bind(this);return function(){try{var $val_addtoken_87044$$=Array.from(arguments),$val_addtoken_87044__$1$$=$APP.$app$common$json$__GT_clj$$($val_addtoken_87044$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$],null)),$schema_addtoken_87042__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addtoken_87042_87783$$)?$schema_addtoken_87042_87783$$($val_addtoken_87044__$1$$):$schema_addtoken_87042_87783$$,$val_addtoken_87044__$2$$=($coercer_fn_addtoken_87040_87784$$==null?$APP.$app$common$schema$coercer$$($schema_addtoken_87042__$1$$):$coercer_fn_addtoken_87040_87784$$)($val_addtoken_87044__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addtoken_87039__$1$$,
$val_addtoken_87044__$2$$)}catch($e87115$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87115$$)}}}});Object.defineProperty($obj_86945$$,"duplicate",{enumerable:!1,get:function(){return function(){try{var $id_ref$jscomp$8$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$duplicate_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1120$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3999$id_ref$$,$id_ref$jscomp$8$$],null)));return $APP.$cljs$core$_deref$$($id_ref$jscomp$8$$)!=null?$app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$03$$($plugin_id$jscomp$29$$,$file_id$jscomp$479$$,$APP.$cljs$core$_deref$$($id_ref$jscomp$8$$)):null}catch($e87120$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87120$$)}}.bind(this)}});Object.defineProperty($obj_86945$$,"remove",{enumerable:!1,
get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_set$$($id$jscomp$1120$$))}catch($e87123$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$29$$)($e87123$$)}}.bind(this)}});return $obj_86945$$},$app$plugins$tokens$token_set_name$$=function($set$jscomp$30$$){return $set$jscomp$30$$!=null?$app$plugins$tokens$token_set_proxy_QMARK_$$($set$jscomp$30$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($set$jscomp$30$$,
"name"):$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$30$$):null},$app$plugins$tokens$tokens_catalog$$=function($plugin_id$jscomp$31$$,$file_id$jscomp$482$$){function $schema_addtheme_87531_87910$$($args$jscomp$269$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$app$common$schema$dissoc_key$$($app$common$files$tokens$make_token_theme_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$482$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$first$$($args$jscomp$269$$),$APP.$cljs$cst$1613$group$$,""),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$first$$($args$jscomp$269$$),$APP.$cljs$cst$725$name$$,"")))],null)}var $obj_87482$$=new $APP.$app$util$object$Proxy$$,$coercer_fn_addtheme_87529_87911$$=$schema_addtheme_87531_87910$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addtheme_87531_87910$$)?null:$APP.$app$common$schema$coercer$$($schema_addtheme_87531_87910$$),
$schema_addset_87538_87914$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$app$common$schema$merge$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$schema$dissoc_key$$($APP.$app$common$schema$schema$$($app$common$files$tokens$make_token_set_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$482$$)))),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4820$active$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$],null)],null)]))],null),$coercer_fn_addset_87536_87915$$=$schema_addset_87538_87914$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addset_87538_87914$$)?
null:$APP.$app$common$schema$coercer$$($schema_addset_87538_87914$$),$schema_getthemebyid_87545_87918$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$coercer_fn_getthemebyid_87543_87919$$=$schema_getthemebyid_87545_87918$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_getthemebyid_87545_87918$$)?null:$APP.$app$common$schema$coercer$$($schema_getthemebyid_87545_87918$$),
$schema_getsetbyid_87552_87922$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null),$coercer_fn_getsetbyid_87550_87923$$=$schema_getsetbyid_87552_87922$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_getsetbyid_87552_87922$$)?null:$APP.$app$common$schema$coercer$$($schema_getsetbyid_87552_87922$$);Object.defineProperty($obj_87482$$,Symbol.toStringTag,{enumerable:!1,
get:function(){return"TokensCatalog"}});Object.defineProperty($obj_87482$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokensCatalog"}});Object.defineProperty($obj_87482$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_87500$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$31$$);try{return $internal_fn_plugin_87500$$.call(this)}catch($e87556$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87556$$)}}});Object.defineProperty($obj_87482$$,
"$id",{enumerable:!1,get:function(){var $internal_fn_id_87507$$=$APP.$cljs$core$constantly$$($file_id$jscomp$482$$);try{return $internal_fn_id_87507$$.call(this)}catch($e87557$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87557$$)}}});Object.defineProperty($obj_87482$$,"themes",{enumerable:!1,get:function(){function $internal_fn_themes_87514$$(){var $themes$jscomp$21_tokens_lib$jscomp$67$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$482$$);$themes$jscomp$21_tokens_lib$jscomp$67$$=
$APP.$cljs$core$truth_$$($themes$jscomp$21_tokens_lib$jscomp$67$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__87478_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__87478_SHARP_$$),$APP.$app$common$uuid$zero$$)},$APP.$app$common$types$tokens_lib$get_themes$$($themes$jscomp$21_tokens_lib$jscomp$67$$)):null;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__87479_SHARP_$$){return $app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$31$$,$file_id$jscomp$482$$,$APP.$app$common$types$tokens_lib$get_id$$($p1__87479_SHARP_$$))},$themes$jscomp$21_tokens_lib$jscomp$67$$))}try{return $internal_fn_themes_87514$$.call(this,this)}catch($e87558$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87558$$)}}});Object.defineProperty($obj_87482$$,"sets",{enumerable:!1,get:function(){function $internal_fn_sets_87521$$(){var $sets$jscomp$24_tokens_lib$jscomp$68$$=
$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$482$$);$sets$jscomp$24_tokens_lib$jscomp$68$$=$APP.$cljs$core$truth_$$($sets$jscomp$24_tokens_lib$jscomp$68$$)?$APP.$app$common$types$tokens_lib$get_sets$$($sets$jscomp$24_tokens_lib$jscomp$68$$):null;return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__87480_SHARP_$$){return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$03$$($plugin_id$jscomp$31$$,
$file_id$jscomp$482$$,$APP.$app$common$types$tokens_lib$get_id$$($p1__87480_SHARP_$$))},$sets$jscomp$24_tokens_lib$jscomp$68$$))}try{return $internal_fn_sets_87521$$.call(this,this)}catch($e87559$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87559$$)}}});Object.defineProperty($obj_87482$$,"addTheme",{enumerable:!1,get:function(){var $internal_fn_addtheme_87528__$1$$=function($attrs$jscomp$191$$){try{var $theme$jscomp$44$$=$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs$jscomp$191$$]));
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$($theme$jscomp$44$$));return $app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$31$$,$file_id$jscomp$482$$,$theme$jscomp$44$$.id)}catch($e87560$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87560$$)}}.bind(this);return function(){try{var $val_addtheme_87533$$=Array.from(arguments),$val_addtheme_87533__$1$$=$APP.$app$common$json$__GT_clj$$($val_addtheme_87533$$,
null),$schema_addtheme_87531__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addtheme_87531_87910$$)?$schema_addtheme_87531_87910$$($val_addtheme_87533__$1$$):$schema_addtheme_87531_87910$$,$val_addtheme_87533__$2$$=($coercer_fn_addtheme_87529_87911$$==null?$APP.$app$common$schema$coercer$$($schema_addtheme_87531__$1$$):$coercer_fn_addtheme_87529_87911$$)($val_addtheme_87533__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addtheme_87528__$1$$,$val_addtheme_87533__$2$$)}catch($e87561$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87561$$)}}}});
Object.defineProperty($obj_87482$$,"addSet",{enumerable:!1,get:function(){var $internal_fn_addset_87535__$1$$=function($attrs$jscomp$192$$){try{var $active_QMARK_$jscomp$7$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$cst$4820$active$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$192$$)),$attrs__$1$jscomp$26$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$192$$,$APP.$cljs$cst$4820$active$$),$APP.$cljs$cst$725$name$$,$APP.$app$common$types$tokens_lib$normalize_set_name$$),
$set$jscomp$31$$=$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs__$1$jscomp$26$$]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$create_token_set$$($set$jscomp$31$$));$active_QMARK_$jscomp$7$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$set_enabled_token_set$$($set$jscomp$31$$.name,
!0));return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$04$$($plugin_id$jscomp$31$$,$file_id$jscomp$482$$,$set$jscomp$31$$.id,$set$jscomp$31$$.name)}catch($e87562$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87562$$)}}.bind(this);return function(){try{var $val_addset_87540$$=Array.from(arguments),$val_addset_87540__$1$$=$APP.$app$common$json$__GT_clj$$($val_addset_87540$$,null),$schema_addset_87538__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addset_87538_87914$$)?
$schema_addset_87538_87914$$($val_addset_87540__$1$$):$schema_addset_87538_87914$$,$val_addset_87540__$2$$=($coercer_fn_addset_87536_87915$$==null?$APP.$app$common$schema$coercer$$($schema_addset_87538__$1$$):$coercer_fn_addset_87536_87915$$)($val_addset_87540__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addset_87535__$1$$,$val_addset_87540__$2$$)}catch($e87563$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87563$$)}}}});Object.defineProperty($obj_87482$$,
"getThemeById",{enumerable:!1,get:function(){var $internal_fn_getthemebyid_87542__$1$$=function($theme_id$jscomp$11$$){try{return $app$plugins$utils$locate_token_theme$$($file_id$jscomp$482$$,$theme_id$jscomp$11$$)!=null?$app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$31$$,$file_id$jscomp$482$$,$theme_id$jscomp$11$$):null}catch($e87564$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87564$$)}}.bind(this);return function(){try{var $val_getthemebyid_87547$$=Array.from(arguments),
$val_getthemebyid_87547__$1$$=$APP.$app$common$json$__GT_clj$$($val_getthemebyid_87547$$,null),$schema_getthemebyid_87545__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_getthemebyid_87545_87918$$)?$schema_getthemebyid_87545_87918$$($val_getthemebyid_87547__$1$$):$schema_getthemebyid_87545_87918$$,$val_getthemebyid_87547__$2$$=($coercer_fn_getthemebyid_87543_87919$$==null?$APP.$app$common$schema$coercer$$($schema_getthemebyid_87545__$1$$):$coercer_fn_getthemebyid_87543_87919$$)($val_getthemebyid_87547__$1$$);
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_getthemebyid_87542__$1$$,$val_getthemebyid_87547__$2$$)}catch($e87565$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87565$$)}}}});Object.defineProperty($obj_87482$$,"getSetById",{enumerable:!1,get:function(){var $internal_fn_getsetbyid_87549__$1$$=function($set_id$jscomp$48$$){try{return $app$plugins$utils$locate_token_set$$($file_id$jscomp$482$$,$set_id$jscomp$48$$)!=null?$app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$03$$($plugin_id$jscomp$31$$,
$file_id$jscomp$482$$,$set_id$jscomp$48$$):null}catch($e87566$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87566$$)}}.bind(this);return function(){try{var $val_getsetbyid_87554$$=Array.from(arguments),$val_getsetbyid_87554__$1$$=$APP.$app$common$json$__GT_clj$$($val_getsetbyid_87554$$,null),$schema_getsetbyid_87552__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_getsetbyid_87552_87922$$)?$schema_getsetbyid_87552_87922$$($val_getsetbyid_87554__$1$$):$schema_getsetbyid_87552_87922$$,
$val_getsetbyid_87554__$2$$=($coercer_fn_getsetbyid_87550_87923$$==null?$APP.$app$common$schema$coercer$$($schema_getsetbyid_87552__$1$$):$coercer_fn_getsetbyid_87550_87923$$)($val_getsetbyid_87554__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_getsetbyid_87549__$1$$,$val_getsetbyid_87554__$2$$)}catch($e87567$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$31$$)($e87567$$)}}}});return $obj_87482$$},$app$plugins$shape$interaction_proxy$$=function($plugin_id$jscomp$32$$,
$file_id$jscomp$483$$,$page_id$jscomp$497$$,$shape_id$jscomp$187$$,$index$jscomp$614$$){var $obj_87652$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_87652$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"InteractionProxy"}});Object.defineProperty($obj_87652$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"InteractionProxy"}});Object.defineProperty($obj_87652$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$32$$}});Object.defineProperty($obj_87652$$,
"$file",{enumerable:!1,get:function(){return $file_id$jscomp$483$$}});Object.defineProperty($obj_87652$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$497$$}});Object.defineProperty($obj_87652$$,"$shape",{enumerable:!1,get:function(){return $shape_id$jscomp$187$$}});Object.defineProperty($obj_87652$$,"$index",{enumerable:!1,get:function(){return $index$jscomp$614$$}});Object.defineProperty($obj_87652$$,"shape",{enumerable:!1,get:function(){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$?
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$32$$,$file_id$jscomp$483$$,$page_id$jscomp$497$$,$shape_id$jscomp$187$$):$app$plugins$shape$shape_proxy$$($plugin_id$jscomp$32$$,$file_id$jscomp$483$$,$page_id$jscomp$497$$,$shape_id$jscomp$187$$)}});Object.defineProperty($obj_87652$$,"trigger",{enumerable:!0,get:function(){return $app$plugins$format$format_key$$($APP.$cljs$cst$1562$event_type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_interaction$$(this)))},
set:function($val_trigger_87717$$){return function($_$jscomp$3305$$,$value$jscomp$1129$$){var $value__$1$jscomp$116$$=$app$plugins$parser$parse_keyword$$($value$jscomp$1129$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$interactions$event_types$$,$value__$1$jscomp$116$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($app$plugins$utils$locate_shape$$($file_id$jscomp$483$$,
$page_id$jscomp$497$$,$shape_id$jscomp$187$$),$index$jscomp$614$$,function($p1__87644_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87644_SHARP_$$,$APP.$cljs$cst$1562$event_type$$,$value__$1$jscomp$116$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$497$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$32$$,$APP.$cljs$cst$4491$trigger$$,$value__$1$jscomp$116$$)}.call(this,this,$val_trigger_87717$$)}});Object.defineProperty($obj_87652$$,
"delay",{enumerable:!0,get:function(){return $APP.$cljs$cst$1330$delay$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_interaction$$(this))},set:function($val_delay_87725$$){return function($_$jscomp$3306$$,$value$jscomp$1130$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($value$jscomp$1130$$))||$value$jscomp$1130$$<0?$app$plugins$utils$not_valid$$($plugin_id$jscomp$32$$,$APP.$cljs$cst$1330$delay$$,$value$jscomp$1130$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($app$plugins$utils$locate_shape$$($file_id$jscomp$483$$,
$page_id$jscomp$497$$,$shape_id$jscomp$187$$),$index$jscomp$614$$,function($p1__87646_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87646_SHARP_$$,$APP.$cljs$cst$1330$delay$$,$value$jscomp$1130$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$497$$],null)))}.call(this,this,$val_delay_87725$$)}});Object.defineProperty($obj_87652$$,"action",{enumerable:!0,get:function(){return $app$plugins$format$format_action$$($app$plugins$utils$proxy__GT_interaction$$(this),
$plugin_id$jscomp$32$$,$file_id$jscomp$483$$,$page_id$jscomp$497$$)},set:function($val_action_87733$$){return function($interaction$jscomp$57_self$jscomp$174$$,$value$jscomp$1131$$){var $params$jscomp$472$$=$app$plugins$parser$parse_action$$($value$jscomp$1131$$);$interaction$jscomp$57_self$jscomp$174$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$proxy__GT_interaction$$($interaction$jscomp$57_self$jscomp$174$$),$params$jscomp$472$$);return $APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$interactions$schema_COLON_interaction$$,
$interaction$jscomp$57_self$jscomp$174$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$32$$,$APP.$cljs$cst$2694$action$$,$interaction$jscomp$57_self$jscomp$174$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($app$plugins$utils$locate_shape$$($file_id$jscomp$483$$,$page_id$jscomp$497$$,$shape_id$jscomp$187$$),$index$jscomp$614$$,function($p1__87648_SHARP_$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($p1__87648_SHARP_$$,
$params$jscomp$472$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$497$$],null)))}.call(this,this,$val_action_87733$$)}});Object.defineProperty($obj_87652$$,"remove",{enumerable:!1,get:function(){return function(){var $JSCompiler_temp_const$jscomp$1278$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1280$$=$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$shape_id$jscomp$187$$],null),$index$jscomp$614$$);return $JSCompiler_temp_const$jscomp$1278$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1280$$)}.bind(this)}});return $obj_87652$$},$app$plugins$shape$text_props$$=function($shape$jscomp$1138$$){return $APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1138$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1138$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1817$shape$$,
$shape$jscomp$1138$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]))},$app$plugins$shape$blur_defaults$$=function($blur$jscomp$17$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1925$layer_blur$$,$APP.$cljs$cst$260$value$$,4,$APP.$cljs$cst$1625$hidden$$,!1],null),$blur$jscomp$17$$)},$app$plugins$shape$background_blur_defaults$$=
function($blur$jscomp$18$$){return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1197$background_blur$$,$APP.$cljs$cst$260$value$$,4,$APP.$cljs$cst$1625$hidden$$,!1],null),$blur$jscomp$18$$)},$app$plugins$shape$commit_fills_BANG_$$=function($plugin_id$jscomp$33$$,$self$jscomp$175$$,$value$jscomp$1132$$){var $shape$jscomp$1139$$=$app$plugins$utils$proxy__GT_shape$$($self$jscomp$175$$),
$id$jscomp$1122$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1139$$),$value__$1$jscomp$117$$=$app$plugins$parser$parse_fills$$($value$jscomp$1132$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$fills$schema_COLON_fill$$],null),$value__$1$jscomp$117$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1639$fills$$,
$value__$1$jscomp$117$$):$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$175$$,"$page"))?$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1139$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($id$jscomp$1122$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1639$fills$$,$value__$1$jscomp$117$$],null))):
$app$plugins$register$check_permission$$($plugin_id$jscomp$33$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1122$$],null),function($p1__87825_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87825_SHARP_$$,$APP.$cljs$cst$1639$fills$$,$value__$1$jscomp$117$$)})):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1639$fills$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$33$$,$APP.$cljs$cst$1639$fills$$,"Cannot modify a page that is not currently active")},$app$plugins$shape$commit_strokes_BANG_$$=function($plugin_id$jscomp$34$$,$self$jscomp$176$$,$value$jscomp$1133$$){var $id$jscomp$1123$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$176$$,"$id"),$value__$1$jscomp$118$$=
$app$plugins$parser$parse_strokes$$($value$jscomp$1133$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$shape$schema_COLON_stroke$$],null),$value__$1$jscomp$118$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$34$$,$APP.$cljs$cst$1641$strokes$$,$value__$1$jscomp$118$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$34$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$176$$,"$page"))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1123$$],null),function($p1__87826_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87826_SHARP_$$,
$APP.$cljs$cst$1641$strokes$$,$value__$1$jscomp$118$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$34$$,$APP.$cljs$cst$1641$strokes$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$34$$,$APP.$cljs$cst$1641$strokes$$,"Plugin doesn't have 'content:write' permission")},$app$plugins$shape$commit_shadows_BANG_$$=function($plugin_id$jscomp$35$$,$self$jscomp$177$$,$value$jscomp$1134$$){var $id$jscomp$1124$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$177$$,
"$id"),$value__$1$jscomp$119$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$){$JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$=$JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$!=null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,
"id")),$APP.$cljs$cst$1921$style$$,$app$plugins$parser$parse_keyword$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,"style")),$APP.$cljs$cst$1655$offset_x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,"offsetX"),$APP.$cljs$cst$1656$offset_y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,
"offsetY"),$APP.$cljs$cst$1658$blur$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,"blur"),$APP.$cljs$cst$1657$spread$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,"spread"),$APP.$cljs$cst$1625$hidden$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,"hidden"),$APP.$cljs$cst$1303$color$$,
$app$plugins$parser$parse_color$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$,"color"))],null)):null;return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$1922$drop_shadow$$,$APP.$cljs$cst$1303$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,
"#000000",$APP.$cljs$cst$1740$opacity$$,.2],null),$APP.$cljs$cst$1655$offset_x$$,4,$APP.$cljs$cst$1656$offset_y$$,4,$APP.$cljs$cst$1658$blur$$,4,$APP.$cljs$cst$1657$spread$$,0,$APP.$cljs$cst$1625$hidden$$,!1],null),$JSCompiler_inline_result$jscomp$2135_p1__87871_SHARP_$$)},$value$jscomp$1134$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$shape$shadow$schema_COLON_shadow$$],
null),$value__$1$jscomp$119$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$35$$,$APP.$cljs$cst$4141$shadows$$,$value__$1$jscomp$119$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$35$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$177$$,"$page"))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1124$$],null),function($p1__87872_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87872_SHARP_$$,$APP.$cljs$cst$1659$shadow$$,$value__$1$jscomp$119$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$35$$,$APP.$cljs$cst$4141$shadows$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$35$$,$APP.$cljs$cst$4141$shadows$$,"Plugin doesn't have 'content:write' permission")},
$app$plugins$shape$commit_exports_BANG_$$=function($plugin_id$jscomp$36$$,$self$jscomp$178$$,$value$jscomp$1135$$){var $id$jscomp$1125$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$178$$,"$id"),$value__$1$jscomp$120$$=$app$plugins$parser$parse_exports$$($value$jscomp$1135$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$shape$export$0$schema_COLON_export$$],
null),$value__$1$jscomp$120$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$36$$,$APP.$cljs$cst$1877$exports$$,$value__$1$jscomp$120$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$36$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$178$$,"$page"))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1125$$],null),function($p1__87873_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87873_SHARP_$$,$APP.$cljs$cst$1877$exports$$,$value__$1$jscomp$120$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$36$$,$APP.$cljs$cst$1877$exports$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$36$$,$APP.$cljs$cst$1877$exports$$,"Plugin doesn't have 'content:write' permission")},
$app$plugins$shape$shape_proxy_QMARK_$$=function($p$jscomp$274$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$274$$,"ShapeProxy")},$app$plugins$shape$token_proxy_QMARK_$$=function($t$jscomp$105$$){return $app$util$object$type_of_QMARK_$$($t$jscomp$105$$,"TokenProxy")},$app$plugins$shape$z_order_location$$=function($G__87874__$1_plugin_id$jscomp$37$$,$file_id$jscomp$484_parent$jscomp$310$$,$page_id$jscomp$498$$,$id$jscomp$1126_shape$jscomp$1140$$,$loc$jscomp$10$$){$id$jscomp$1126_shape$jscomp$1140$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$484_parent$jscomp$310$$,$page_id$jscomp$498$$,$id$jscomp$1126_shape$jscomp$1140$$);$file_id$jscomp$484_parent$jscomp$310$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$484_parent$jscomp$310$$,$page_id$jscomp$498$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1126_shape$jscomp$1140$$));if($app$plugins$utils$natural_child_ordering_QMARK_$$($G__87874__$1_plugin_id$jscomp$37$$)&&$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$484_parent$jscomp$310$$))switch($G__87874__$1_plugin_id$jscomp$37$$=
$loc$jscomp$10$$ instanceof $APP.$cljs$core$Keyword$$?$loc$jscomp$10$$.$fqn$:null,$G__87874__$1_plugin_id$jscomp$37$$){case "top":return $APP.$cljs$cst$1568$bottom$$;case "bottom":return $APP.$cljs$cst$1567$top$$;case "up":return $APP.$cljs$cst$1969$down$$;case "down":return $APP.$cljs$cst$1970$up$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__87874__$1_plugin_id$jscomp$37$$)].join(""));}else return $loc$jscomp$10$$},$app$plugins$user$add_session_properties$$=
function($user_proxy$$,$session_id$jscomp$12$$){var $get_fn86385_86828$$=$APP.$cljs$core$constantly$$($session_id$jscomp$12$$);Object.defineProperty($user_proxy$$,"$session",function(){return{enumerable:!1,get:function(){return $get_fn86385_86828$$.$cljs$core$IFn$_invoke$arity$1$?$get_fn86385_86828$$.$cljs$core$IFn$_invoke$arity$1$(this):$get_fn86385_86828$$(this)}}}());Object.defineProperty($user_proxy$$,"id",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_profile$$($session_id$jscomp$12$$)))}}}());
Object.defineProperty($user_proxy$$,"name",function(){return{enumerable:!0,get:function(){return $APP.$cljs$cst$1365$fullname$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_profile$$($session_id$jscomp$12$$))}}}());Object.defineProperty($user_proxy$$,"avatarUrl",function(){return{enumerable:!0,get:function(){return $APP.$app$config$resolve_profile_photo_url$$($app$plugins$utils$locate_profile$$($session_id$jscomp$12$$))}}}());Object.defineProperty($user_proxy$$,"color",function(){return{enumerable:!0,
get:function(){return $APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_presence$$($session_id$jscomp$12$$))}}}());Object.defineProperty($user_proxy$$,"sessionId",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($session_id$jscomp$12$$)}}}());return $user_proxy$$},$app$plugins$user$current_user_proxy$$=function($plugin_id$jscomp$41$$){var $session_id$jscomp$13$$=$APP.$cljs$cst$2343$session_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return $app$plugins$user$add_session_properties$$(function(){var $obj_86555$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_86555$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"CurrentUserProxy"}});Object.defineProperty($obj_86555$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"CurrentUserProxy"}});Object.defineProperty($obj_86555$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$41$$}});return $obj_86555$$}(),$session_id$jscomp$13$$)},
$app$plugins$user$active_user_proxy$$=function($plugin_id$jscomp$42$$,$session_id$jscomp$14$$){return $app$plugins$user$add_session_properties$$(function(){var $obj_86595$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_86595$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ActiveUserProxy"}});Object.defineProperty($obj_86595$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ActiveUserProxy"}});Object.defineProperty($obj_86595$$,"$plugin",{enumerable:!1,
get:function(){return $plugin_id$jscomp$42$$}});Object.defineProperty($obj_86595$$,"position",{enumerable:!0,get:function(){return $app$plugins$format$format_point$$($APP.$cljs$cst$2171$point$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_presence$$($session_id$jscomp$14$$)))}});Object.defineProperty($obj_86595$$,"zoom",{enumerable:!0,get:function(){return $APP.$cljs$cst$2204$zoom$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_presence$$($session_id$jscomp$14$$))}});return $obj_86595$$}(),
$session_id$jscomp$14$$)},$app$plugins$user$add_user_properties$$=function($user_proxy$jscomp$1$$,$data$jscomp$533$$){Object.defineProperty($user_proxy$jscomp$1$$,"id",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$533$$))}}}());Object.defineProperty($user_proxy$jscomp$1$$,"name",function(){return{enumerable:!0,get:function(){return $APP.$cljs$cst$1365$fullname$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$533$$)}}}());
Object.defineProperty($user_proxy$jscomp$1$$,"avatarUrl",function(){return{enumerable:!0,get:function(){return $APP.$app$config$resolve_profile_photo_url$$($data$jscomp$533$$)}}}());return $user_proxy$jscomp$1$$},$app$plugins$user$user_proxy$$=function($plugin_id$jscomp$43$$,$data$jscomp$534$$){return $app$plugins$user$add_user_properties$$(function(){var $obj_86791$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_86791$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"UserProxy"}});
Object.defineProperty($obj_86791$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"UserProxy"}});Object.defineProperty($obj_86791$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$43$$}});return $obj_86791$$}(),$data$jscomp$534$$)},$app$plugins$user$user_proxy_QMARK_$$=function($p$jscomp$277$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$277$$,"UserProxy")||$app$util$object$type_of_QMARK_$$($p$jscomp$277$$,"CurrentUserProxy")||$app$util$object$type_of_QMARK_$$($p$jscomp$277$$,
"ActiveUserProxy")},$app$plugins$comments$comment_proxy$$=function($plugin_id$jscomp$44$$,$file_id$jscomp$486$$,$page_id$jscomp$501$$,$thread_id$jscomp$17$$,$data$jscomp$535$$){var $data_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$535$$),$obj_89550$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89550$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"CommentProxy"}});Object.defineProperty($obj_89550$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,
get:function(){return"CommentProxy"}});Object.defineProperty($obj_89550$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$44$$}});Object.defineProperty($obj_89550$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$486$$}});Object.defineProperty($obj_89550$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$501$$}});Object.defineProperty($obj_89550$$,"$thread",{enumerable:!1,get:function(){return $thread_id$jscomp$17$$}});Object.defineProperty($obj_89550$$,"$id",
{enumerable:!1,get:function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$)}});Object.defineProperty($obj_89550$$,"user",{enumerable:!0,get:function(){return $app$plugins$user$user_proxy$$($plugin_id$jscomp$44$$,$APP.$app$main$data$comments$get_owner$$($data$jscomp$535$$))}});Object.defineProperty($obj_89550$$,"owner",{enumerable:!0,get:function(){return $app$plugins$user$user_proxy$$($plugin_id$jscomp$44$$,$APP.$app$main$data$comments$get_owner$$($data$jscomp$535$$))}});
Object.defineProperty($obj_89550$$,"date",{enumerable:!0,get:function(){return $APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$)}});Object.defineProperty($obj_89550$$,"content",{enumerable:!0,get:function(){return $APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data_STAR_$$))},set:function($val_content_89635$$){return function($content$jscomp$281$$){var $profile$jscomp$100$$=$APP.$cljs$cst$1931$profile$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return typeof $content$jscomp$281$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($content$jscomp$281$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$44$$,$APP.$cljs$cst$1642$content$$,"Not valid"):$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$100$$),$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$44$$,$APP.$cljs$cst$1642$content$$,
"Cannot change content from another user's comments"):$app$plugins$register$check_permission$$($plugin_id$jscomp$44$$,"comment:write")?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$44$$,"update-comment",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3483$thread_id$$,$thread_id$jscomp$17$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$),$APP.$cljs$cst$3490$content_size$$,$APP.$cljs$core$count$$($content$jscomp$281$$)])));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($data_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1642$content$$,$content$jscomp$281$$)},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$retrieve_comment_threads$$($file_id$jscomp$486$$))},
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3504$update_comment$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$),$APP.$cljs$cst$1642$content$$,$content$jscomp$281$$],null)))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$44$$,$APP.$cljs$cst$1642$content$$,"Plugin doesn't have 'comment:write' permission")}.call(this,$val_content_89635$$)}});Object.defineProperty($obj_89550$$,
"remove",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$46$$,$reject$jscomp$31$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$44$$,"comment:write"))return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$44$$,"update-comment",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3483$thread_id$$,
$thread_id$jscomp$17$$])));return $resolve$jscomp$46$$.$cljs$core$IFn$_invoke$arity$0$?$resolve$jscomp$46$$.$cljs$core$IFn$_invoke$arity$0$():$resolve$jscomp$46$$()},$reject$jscomp$31$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$retrieve_comment_threads$$($file_id$jscomp$486$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3509$delete_comment$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$535$$)],null))));$app$plugins$utils$not_valid$$($plugin_id$jscomp$44$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'comment:write' permission");return $reject$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$31$$.$cljs$core$IFn$_invoke$arity$1$("Plugin doesn't have 'comment:write' permission"):$reject$jscomp$31$$("Plugin doesn't have 'comment:write' permission")})}.bind(this)}});
return $obj_89550$$},$app$plugins$comments$comment_thread_proxy$$=function($plugin_id$jscomp$45$$,$file_id$jscomp$487$$,$page_id$jscomp$502$$,$data$jscomp$536$$){var $data_STAR_$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$536$$),$obj_90179$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_90179$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"CommentThreadProxy"}});Object.defineProperty($obj_90179$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,
get:function(){return"CommentThreadProxy"}});Object.defineProperty($obj_90179$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$45$$}});Object.defineProperty($obj_90179$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$487$$}});Object.defineProperty($obj_90179$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$502$$}});Object.defineProperty($obj_90179$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)}});
Object.defineProperty($obj_90179$$,"page",{enumerable:!1,get:function(){return $app$plugins$utils$locate_page$$($file_id$jscomp$487$$,$page_id$jscomp$502$$)}});Object.defineProperty($obj_90179$$,"seqNumber",{enumerable:!0,get:function(){return $APP.$cljs$cst$3479$seqn$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)}});Object.defineProperty($obj_90179$$,"board",{enumerable:!0,get:function(){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$45$$,$file_id$jscomp$487$$,
$page_id$jscomp$502$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$))}});Object.defineProperty($obj_90179$$,"owner",{enumerable:!0,get:function(){return $app$plugins$user$user_proxy$$($plugin_id$jscomp$45$$,$APP.$app$main$data$comments$get_owner$$($data$jscomp$536$$))}});Object.defineProperty($obj_90179$$,"position",{enumerable:!0,get:function(){return $app$plugins$format$format_point$$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$)))},
set:function($val_position_90264$$){return function($position$jscomp$258_position__$1$jscomp$11$$){$position$jscomp$258_position__$1$jscomp$11$$=$app$plugins$parser$parse_point$$($position$jscomp$258_position__$1$jscomp$11$$);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$258_position__$1$jscomp$11$$)))||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$258_position__$1$jscomp$11$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$1681$position$$,"Not valid point"):$app$plugins$register$check_permission$$($plugin_id$jscomp$45$$,"comment:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$502$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$comments$update_comment_thread_position$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$258_position__$1$jscomp$11$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$258_position__$1$jscomp$11$$)],null))),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($data_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1681$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$258_position__$1$jscomp$11$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$1681$position$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$1681$position$$,"Plugin doesn't have 'comment:write' permission")}.call(this,$val_position_90264$$)}});Object.defineProperty($obj_90179$$,"resolved",{enumerable:!0,get:function(){return $APP.$cljs$cst$3498$is_resolved$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$))},
set:function($JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$){$APP.$cljs$core$boolean_QMARK_$$($JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$45$$,"comment:write")?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$comments$update_comment_thread$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($data_STAR_$jscomp$1$$),
$APP.$cljs$cst$3498$is_resolved$$,$JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$)),$plugin_id$jscomp$45$$)),$JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$=$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($data_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3498$is_resolved$$,$JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$)):$JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$4829$resolved$$,
"Plugin doesn't have 'comment:write' permission"):$JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$4829$resolved$$,"Not a boolean type");return $JSCompiler_inline_result$jscomp$2319_val_resolved_90274$$}});Object.defineProperty($obj_90179$$,"findComments",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$47$$,$reject$jscomp$32$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$45$$,
"comment:read"))return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__90363_comments$jscomp$4$$){$G__90363_comments$jscomp$4$$=$app$plugins$format$format_array$$(function($p1__90165_SHARP_$$){return $app$plugins$comments$comment_proxy$$($plugin_id$jscomp$45$$,$file_id$jscomp$487$$,$page_id$jscomp$502$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),$p1__90165_SHARP_$$)},$G__90363_comments$jscomp$4$$);return $resolve$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?
$resolve$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($G__90363_comments$jscomp$4$$):$resolve$jscomp$47$$($G__90363_comments$jscomp$4$$)},$reject$jscomp$32$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3515$get_comments$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3483$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)],null)));$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$cljs$cst$6653$findComments$$,
"Plugin doesn't have 'comment:read' permission");return $reject$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$("Plugin doesn't have 'comment:read' permission"):$reject$jscomp$32$$("Plugin doesn't have 'comment:read' permission")})}.bind(this)}});Object.defineProperty($obj_90179$$,"reply",{enumerable:!1,get:function(){return function($content$jscomp$282$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$45$$,"comment:write")?typeof $content$jscomp$282$$!==
"string"||$APP.$cljs$core$empty_QMARK_$$($content$jscomp$282$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$cljs$cst$6654$reply$$,"Not valid"):new Promise(function($resolve$jscomp$48$$,$reject$jscomp$33$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__90380_result$jscomp$396$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$45$$,"create-comment",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3483$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$487$$,$APP.$cljs$cst$3490$content_size$$,$APP.$cljs$core$count$$($content$jscomp$282$$)])));$G__90380_result$jscomp$396$$=$app$plugins$comments$comment_proxy$$($plugin_id$jscomp$45$$,$file_id$jscomp$487$$,$page_id$jscomp$502$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),
$G__90380_result$jscomp$396$$);return $resolve$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($G__90380_result$jscomp$396$$):$resolve$jscomp$48$$($G__90380_result$jscomp$396$$)},$reject$jscomp$33$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3502$create_comment$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3483$thread_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$),
$APP.$cljs$cst$1642$content$$,$content$jscomp$282$$],null)))}):$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$cljs$cst$6654$reply$$,"Plugin doesn't have 'comment:write' permission")}.bind(this)}});Object.defineProperty($obj_90179$$,"remove",{enumerable:!1,get:function(){return function(){var $profile$jscomp$101$$=$APP.$cljs$cst$1931$profile$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $app$plugins$register$check_permission$$($plugin_id$jscomp$45$$,
"comment:write")?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$101$$),$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$2601$remove$$,"Cannot change content from another user's comments"):new Promise(function($resolve$jscomp$49$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$comments$delete_comment_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$536$$)],null),function(){return $resolve$jscomp$49$$.$cljs$core$IFn$_invoke$arity$0$?$resolve$jscomp$49$$.$cljs$core$IFn$_invoke$arity$0$():$resolve$jscomp$49$$()}),$plugin_id$jscomp$45$$))}):$app$plugins$utils$not_valid$$($plugin_id$jscomp$45$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'comment:write' permission")}.bind(this)}});return $obj_90179$$},$app$plugins$page$flow_proxy$$=function($plugin_id$jscomp$46$$,
$file_id$jscomp$488$$,$page_id$jscomp$503$$,$id$jscomp$1130$$){var $obj_90793$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_90793$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FlowProxy"}});Object.defineProperty($obj_90793$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FlowProxy"}});Object.defineProperty($obj_90793$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$46$$}});Object.defineProperty($obj_90793$$,"$file",{enumerable:!1,
get:function(){return $file_id$jscomp$488$$}});Object.defineProperty($obj_90793$$,"$page",{enumerable:!1,get:function(){return $page_id$jscomp$503$$}});Object.defineProperty($obj_90793$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1130$$}});Object.defineProperty($obj_90793$$,"page",{enumerable:!1,get:function(){return $app$plugins$page$page_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$page$page_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$46$$,$file_id$jscomp$488$$,
$page_id$jscomp$503$$):$app$plugins$page$page_proxy$$($plugin_id$jscomp$46$$,$file_id$jscomp$488$$,$page_id$jscomp$503$$)}});Object.defineProperty($obj_90793$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_flow$$(this))},set:function($val_name_90851$$){return function($_$jscomp$3321$$,$value$jscomp$1180$$){return typeof $value$jscomp$1180$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($value$jscomp$1180$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$46$$,
$APP.$cljs$cst$725$name$$,$value$jscomp$1180$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_flow$$($page_id$jscomp$503$$,$id$jscomp$1130$$,function($p1__90790_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__90790_SHARP_$$,$APP.$cljs$cst$725$name$$,$value$jscomp$1180$$)}))}.call(this,this,$val_name_90851$$)}});Object.defineProperty($obj_90793$$,"startingBoard",{enumerable:!0,get:function(){var $temp__5825__auto__$jscomp$inline_10777$$=
$APP.$cljs$cst$2061$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_flow$$(this));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_10777$$)?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$46$$,$file_id$jscomp$488$$,$page_id$jscomp$503$$,$temp__5825__auto__$jscomp$inline_10777$$):null},set:function($val_startingboard_90859$$){return function($_$jscomp$3322$$,$value$jscomp$1181$$){return $app$plugins$shape$shape_proxy_QMARK_$$($value$jscomp$1181$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_flow$$($page_id$jscomp$503$$,$id$jscomp$1130$$,function($p1__90791_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__90791_SHARP_$$,$APP.$cljs$cst$2061$starting_frame$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$1181$$,"$id"))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$46$$,$cljs$cst$6655$startingBoard$$,$value$jscomp$1181$$)}.call(this,
this,$val_startingboard_90859$$)}});Object.defineProperty($obj_90793$$,"remove",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$($page_id$jscomp$503$$,$id$jscomp$1130$$))}.bind(this)}});return $obj_90793$$},$app$plugins$page$page_proxy$$=function($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,$id$jscomp$1131$$){var $obj_90900$$=new $APP.$app$util$object$Proxy$$;
Object.defineProperty($obj_90900$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PageProxy"}});Object.defineProperty($obj_90900$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PageProxy"}});Object.defineProperty($obj_90900$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$47$$}});Object.defineProperty($obj_90900$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$489$$}});Object.defineProperty($obj_90900$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1131$$}});
Object.defineProperty($obj_90900$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1131$$??"")}});Object.defineProperty($obj_90900$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$(this))},set:function($val_name_90951$$){return typeof $val_name_90951$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$725$name$$,$val_name_90951$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,
"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$rename_page$$($id$jscomp$1131$$,$val_name_90951$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'content:write' permission")}});Object.defineProperty($obj_90900$$,"getRoot",{enumerable:!1,get:function(){return function(){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,
$id$jscomp$1131$$,$APP.$app$common$uuid$zero$$)}.bind(this)}});Object.defineProperty($obj_90900$$,"root",{enumerable:!1,get:function(){return this.getRoot()}});Object.defineProperty($obj_90900$$,"remove",{enumerable:!1,get:function(){return function(){var $pages$jscomp$16$$=$APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_file$$($file_id$jscomp$489$$)));return $app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,
"content:write")?$app$plugins$utils$locate_page$$($file_id$jscomp$489$$,$id$jscomp$1131$$)==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$2601$remove$$,"Page not found"):$APP.$cljs$core$count$$($pages$jscomp$16$$)<=1?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$2601$remove$$,"Cannot remove the last page of the file"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$delete_page$$($id$jscomp$1131$$)):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_90900$$,"background",{enumerable:!0,get:function(){var $or__5025__auto__$jscomp$inline_10783$$=$APP.$cljs$cst$2066$background$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$(this));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_10783$$)?$or__5025__auto__$jscomp$inline_10783$$:"#E8E9EA"},
set:function($val_background_90980$$){return typeof $val_background_90980$$==="string"&&$APP.$app$common$types$color$valid_hex_color_QMARK_$$($val_background_90980$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$change_canvas_color$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1131$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1303$color$$,$val_background_90980$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$2066$background$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$APP.$cljs$cst$2066$background$$,$val_background_90980$$)}});Object.defineProperty($obj_90900$$,"flows",{enumerable:!0,get:function(){return function($flows$jscomp$12_self$jscomp$234$$){$flows$jscomp$12_self$jscomp$234$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2064$flows$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$($flows$jscomp$12_self$jscomp$234$$)),
$APP.$cljs$core$PersistentVector$EMPTY$$);return $app$plugins$format$format_array$$(function($p1__90892_SHARP_$$){return $app$plugins$page$flow_proxy$$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,$id$jscomp$1131$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__90892_SHARP_$$))},$APP.$cljs$core$vals$$($flows$jscomp$12_self$jscomp$234$$))}.call(this,this)}});Object.defineProperty($obj_90900$$,"rulerGuides",{enumerable:!0,get:function(){return function($guides$jscomp$20_self$jscomp$235$$){$guides$jscomp$20_self$jscomp$235$$=
$APP.$cljs$cst$2065$guides$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_page$$($guides$jscomp$20_self$jscomp$235$$));return $app$plugins$format$format_array$$(function($p1__90894_SHARP_$$){return $app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,$id$jscomp$1131$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__90894_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90893_SHARP_$$){return $APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__90893_SHARP_$$)==
null},$APP.$cljs$core$vals$$($guides$jscomp$20_self$jscomp$235$$)))}.call(this,this)}});Object.defineProperty($obj_90900$$,"getShapeById",{enumerable:!1,get:function(){return function($shape_id$jscomp$188_shape_id__$1$jscomp$8$$){if(typeof $shape_id$jscomp$188_shape_id__$1$jscomp$8$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6656$getShapeById$$,$shape_id$jscomp$188_shape_id__$1$jscomp$8$$);$shape_id$jscomp$188_shape_id__$1$jscomp$8$$=$APP.$app$common$uuid$parse$$($shape_id$jscomp$188_shape_id__$1$jscomp$8$$);
return $app$plugins$utils$locate_shape$$($file_id$jscomp$489$$,$id$jscomp$1131$$,$shape_id$jscomp$188_shape_id__$1$jscomp$8$$)!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,$id$jscomp$1131$$,$shape_id$jscomp$188_shape_id__$1$jscomp$8$$):null}.bind(this)}});Object.defineProperty($obj_90900$$,"findShapes",{enumerable:!1,get:function(){return function($criteria$jscomp$1_page$jscomp$193$$){var $criteria__$1$$=$criteria$jscomp$1_page$jscomp$193$$!=
null?$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($criteria$jscomp$1_page$jscomp$193$$,"name"),$cljs$cst$6491$name_like$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($criteria$jscomp$1_page$jscomp$193$$,"nameLike"),$APP.$cljs$cst$139$type$$,$app$plugins$parser$parse_shape_type$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($criteria$jscomp$1_page$jscomp$193$$,
"type"))],null)):null,$match_criteria_QMARK__xf$jscomp$5$$=$criteria__$1$$!=null?function($p__91109_shape$jscomp$1187$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__91109_shape$jscomp$1187$$,0,null);$p__91109_shape$jscomp$1187$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__91109_shape$jscomp$1187$$,1,null);var $and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$=$APP.$cljs$core$not$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$)),$APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__91109_shape$jscomp$1187$$)));return $and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$?($and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$=($and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$=
$APP.$cljs$core$not$$($cljs$cst$6491$name_like$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$)))?$and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$:$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__91109_shape$jscomp$1187$$)),$APP.$cuerdas$core$lower$$($cljs$cst$6491$name_like$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$))),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$)?
$APP.$cljs$core$not$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($criteria__$1$$),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p__91109_shape$jscomp$1187$$)):$and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$):$and__5023__auto__$jscomp$1092_and__5023__auto____$1$jscomp$179_or__5025__auto__$jscomp$inline_10788$$}:
$APP.$cljs$core$identity$$;return $file_id$jscomp$489$$!=null&&$id$jscomp$1131$$!=null?($criteria$jscomp$1_page$jscomp$193$$=$app$plugins$utils$locate_page$$($file_id$jscomp$489$$,$id$jscomp$1131$$),$match_criteria_QMARK__xf$jscomp$5$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($match_criteria_QMARK__xf$jscomp$5$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__90895_SHARP_$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$47$$,
$file_id$jscomp$489$$,$id$jscomp$1131$$,$APP.$cljs$core$first$$($p1__90895_SHARP_$$))})),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($match_criteria_QMARK__xf$jscomp$5$$,$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($criteria$jscomp$1_page$jscomp$193$$)))):null}.bind(this)}});Object.defineProperty($obj_90900$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$445$$){if(typeof $key$jscomp$445$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6657$page_plugin_data_key$$,$key$jscomp$445$$);var $page$jscomp$194$$=$app$plugins$utils$locate_page$$($file_id$jscomp$489$$,$id$jscomp$1131$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$194$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$47$$))),$key$jscomp$445$$)}.bind(this)}});Object.defineProperty($obj_90900$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$446$$,$value$jscomp$1184$$){return typeof $key$jscomp$446$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6617$setPluginData_key$$,$key$jscomp$446$$):$value$jscomp$1184$$!=null&&typeof $value$jscomp$1184$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,
$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1184$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$489$$,$APP.$cljs$cst$1629$page$$,$id$jscomp$1131$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$47$$)),$key$jscomp$446$$,
$value$jscomp$1184$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6619$setPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_90900$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $page$jscomp$195$$=$app$plugins$utils$locate_page$$($file_id$jscomp$489$$,$id$jscomp$1131$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$195$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$47$$)))))}.bind(this)}});Object.defineProperty($obj_90900$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$21$$,$key$jscomp$447$$){if(typeof $namespace$jscomp$21$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6658$page_plugin_data_namespace$$,$namespace$jscomp$21$$);
if(typeof $key$jscomp$447$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6657$page_plugin_data_key$$,$key$jscomp$447$$);var $page$jscomp$196$$=$app$plugins$utils$locate_page$$($file_id$jscomp$489$$,$id$jscomp$1131$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$196$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",
$namespace$jscomp$21$$)),$key$jscomp$447$$)}.bind(this)}});Object.defineProperty($obj_90900$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$22$$,$key$jscomp$448$$,$value$jscomp$1185$$){return typeof $namespace$jscomp$22$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$22$$):typeof $key$jscomp$448$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6623$setSharedPluginData_key$$,
$key$jscomp$448$$):$value$jscomp$1185$$!=null&&typeof $value$jscomp$1185$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1185$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$489$$,$APP.$cljs$cst$1629$page$$,$id$jscomp$1131$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",
$namespace$jscomp$22$$),$key$jscomp$448$$,$value$jscomp$1185$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6625$setSharedPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_90900$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$23$$){if(typeof $namespace$jscomp$23$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6658$page_plugin_data_namespace$$,
$namespace$jscomp$23$$);var $page$jscomp$197$$=$app$plugins$utils$locate_page$$($file_id$jscomp$489$$,$id$jscomp$1131$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$197$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$23$$))))}.bind(this)}});
Object.defineProperty($obj_90900$$,"openPage",{enumerable:!1,get:function(){return function($new_window$jscomp$3$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"content:read")?$new_window$jscomp$3$$===!0?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2051$page_id$$,$id$jscomp$1131$$,$APP.$cljs$cst$2467$app_DOT_main_DOT_router_SLASH_new_window$$,
!0]))),Promise.resolve(null)):$app$plugins$utils$page_active_QMARK_$$($id$jscomp$1131$$)?Promise.resolve(null):new Promise(function($resolve$jscomp$50$$){$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $resolve$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$50$$(null)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__90896_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($p1__90896_SHARP_$$),
$id$jscomp$1131$$)},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4434$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialized$$),$APP.$app$main$store$stream$$))));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2051$page_id$$,$id$jscomp$1131$$])))}):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6659$openPage$$,"Plugin doesn't have 'content:read' permission")}.bind(this)}});Object.defineProperty($obj_90900$$,"createFlow",{enumerable:!1,get:function(){return function($name$jscomp$521$$,$frame$jscomp$131$$){if(typeof $name$jscomp$521$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($name$jscomp$521$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6660$createFlow_name$$,$name$jscomp$521$$);if($app$plugins$shape$shape_proxy_QMARK_$$($frame$jscomp$131$$)){var $flow_id$jscomp$13$$=
$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$04$$($flow_id$jscomp$13$$,$id$jscomp$1131$$,$name$jscomp$521$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$131$$,"$id")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$47$$,"add-flow")]));return $app$plugins$page$flow_proxy$$($plugin_id$jscomp$47$$,
$file_id$jscomp$489$$,$id$jscomp$1131$$,$flow_id$jscomp$13$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6661$createFlow_frame$$,$frame$jscomp$131$$)}.bind(this)}});Object.defineProperty($obj_90900$$,"removeFlow",{enumerable:!1,get:function(){return function($flow$jscomp$13$$){return $app$util$object$type_of_QMARK_$$($flow$jscomp$13$$,"FlowProxy")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1131$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($flow$jscomp$13$$,"$id")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$47$$,"remove-flow")])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6662$removeFlow_flow$$,$flow$jscomp$13$$)}.bind(this)}});Object.defineProperty($obj_90900$$,"addRulerGuide",{enumerable:!1,get:function(){return function($orientation$jscomp$10$$,$value$jscomp$1186$$,$board$$){var $ruler_id$jscomp$3_shape$jscomp$1188$$=
$app$plugins$utils$proxy__GT_shape$$($board$$);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1186$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6646$addRulerGuide$$,"Value not a safe number"):$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["vertical",null,"horizontal",null],null),null),$orientation$jscomp$10$$)?$ruler_id$jscomp$3_shape$jscomp$1188$$==
null||$app$plugins$shape$shape_proxy_QMARK_$$($board$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ruler_id$jscomp$3_shape$jscomp$1188$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($id$jscomp$1131$$)?($ruler_id$jscomp$3_shape$jscomp$1188$$=$APP.$app$common$uuid$next$$(),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$266$id$$,$ruler_id$jscomp$3_shape$jscomp$1188$$,$APP.$cljs$cst$2062$axis$$,$app$plugins$parser$orientation__GT_axis$$($orientation$jscomp$10$$),$APP.$cljs$cst$1681$position$$,$value$jscomp$1186$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$core$truth_$$($board$$)?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($board$$,"$id"):null],null))),$plugin_id$jscomp$47$$)),$app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,$id$jscomp$1131$$,
$ruler_id$jscomp$3_shape$jscomp$1188$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6646$addRulerGuide$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6646$addRulerGuide$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6646$addRulerGuide$$,"The shape is not a board"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6646$addRulerGuide$$,
"Orientation should be either 'vertical' or 'horizontal'")}.bind(this)}});Object.defineProperty($obj_90900$$,"removeRulerGuide",{enumerable:!1,get:function(){return function($guide$jscomp$44_value$jscomp$1187$$){return $app$util$object$type_of_QMARK_$$($guide$jscomp$44_value$jscomp$1187$$,"RulerGuideProxy")?$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($id$jscomp$1131$$)?($guide$jscomp$44_value$jscomp$1187$$=$app$plugins$utils$proxy__GT_ruler_guide$$($guide$jscomp$44_value$jscomp$1187$$),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$44_value$jscomp$1187$$),$plugin_id$jscomp$47$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6647$removeRulerGuide$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6647$removeRulerGuide$$,"Plugin doesn't have 'comment:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,
$cljs$cst$6647$removeRulerGuide$$,"Guide not provided")}.bind(this)}});Object.defineProperty($obj_90900$$,"addCommentThread",{enumerable:!1,get:function(){return function($content$jscomp$283$$,$position$jscomp$259_position__$1$jscomp$12$$,$board$jscomp$1$$){var $shape$jscomp$1189$$=$APP.$cljs$core$truth_$$($board$jscomp$1$$)?$app$plugins$utils$proxy__GT_shape$$($board$jscomp$1$$):null;$position$jscomp$259_position__$1$jscomp$12$$=$app$plugins$parser$parse_point$$($position$jscomp$259_position__$1$jscomp$12$$);
if(typeof $content$jscomp$283$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($content$jscomp$283$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6663$addCommentThread$$,"Content not valid");if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$259_position__$1$jscomp$12$$)))||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$259_position__$1$jscomp$12$$))))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,
$cljs$cst$6663$addCommentThread$$,"Position not valid");if($board$jscomp$1$$==null||$app$plugins$shape$shape_proxy_QMARK_$$($board$jscomp$1$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1189$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"comment:write")){var $position__$2$$=$board$jscomp$1$$!=null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($position$jscomp$259_position__$1$jscomp$12$$,
$APP.$cljs$cst$1515$x$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($board$jscomp$1$$)),$APP.$cljs$cst$1516$y$$,$APP.$cljs$core$_$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($board$jscomp$1$$)):$position$jscomp$259_position__$1$jscomp$12$$;return new Promise(function($resolve$jscomp$51$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$comments$create_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$489$$,$APP.$cljs$cst$2051$page_id$$,$id$jscomp$1131$$,$APP.$cljs$cst$1681$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($position__$2$$),$APP.$cljs$cst$1642$content$$,$content$jscomp$283$$],null),function($G__91277_data$jscomp$537$$){$G__91277_data$jscomp$537$$=$app$plugins$comments$comment_thread_proxy$$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,$id$jscomp$1131$$,$G__91277_data$jscomp$537$$);return $resolve$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$?
$resolve$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$($G__91277_data$jscomp$537$$):$resolve$jscomp$51$$($G__91277_data$jscomp$537$$)},!1),$plugin_id$jscomp$47$$))})}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6663$addCommentThread$$,"Plugin doesn't have 'comment:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6663$addCommentThread$$,"Board not valid")}.bind(this)}});Object.defineProperty($obj_90900$$,"removeCommentThread",{enumerable:!1,
get:function(){return function($thread$jscomp$54$$){return $app$util$object$type_of_QMARK_$$($thread$jscomp$54$$,"CommentThreadProxy")?$app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"comment:write")?new Promise(function($resolve$jscomp$52$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$delete_comment_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($thread$jscomp$54$$,"$id")],null),function(){return $resolve$jscomp$52$$.$cljs$core$IFn$_invoke$arity$0$?$resolve$jscomp$52$$.$cljs$core$IFn$_invoke$arity$0$():$resolve$jscomp$52$$()}))}):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6664$removeCommentThread$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6664$removeCommentThread$$,"Comment thread not valid")}.bind(this)}});
Object.defineProperty($obj_90900$$,"findCommentThreads",{enumerable:!1,get:function(){return function($criteria$jscomp$2$$){var $only_yours$$=$APP.$cljs$core$boolean$0$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($criteria$jscomp$2$$,"onlyYours",!1)),$show_resolved$$=$APP.$cljs$core$boolean$0$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($criteria$jscomp$2$$,"showResolved",!0)),$user_id$jscomp$1$$=$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return new Promise(function($resolve$jscomp$53$$,$reject$jscomp$34$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$47$$,"comment:read"))return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($threads$jscomp$13$$){var $G__91281_threads__$1$jscomp$1$$=function(){var $G__91280__$1$$=$show_resolved$$?$threads$jscomp$13$$:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$not$$,$APP.$cljs$cst$3498$is_resolved$$),
$threads$jscomp$13$$);return $only_yours$$?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__90897_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3480$participants$$.$cljs$core$IFn$_invoke$arity$1$($p1__90897_SHARP_$$),$user_id$jscomp$1$$)},$G__91280__$1$$):$G__91280__$1$$}();$G__91281_threads__$1$jscomp$1$$=$app$plugins$format$format_array$$(function($p1__90898_SHARP_$$){return $app$plugins$comments$comment_thread_proxy$$($plugin_id$jscomp$47$$,$file_id$jscomp$489$$,
$id$jscomp$1131$$,$p1__90898_SHARP_$$)},$G__91281_threads__$1$jscomp$1$$);return $resolve$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$($G__91281_threads__$1$jscomp$1$$):$resolve$jscomp$53$$($G__91281_threads__$1$jscomp$1$$)},$reject$jscomp$34$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3513$get_comment_threads$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$489$$],
null)));$app$plugins$utils$not_valid$$($plugin_id$jscomp$47$$,$cljs$cst$6665$findCommentThreads$$,"Plugin doesn't have 'comment:read' permission");return $reject$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$34$$.$cljs$core$IFn$_invoke$arity$1$("Plugin doesn't have 'comment:read' permission"):$reject$jscomp$34$$("Plugin doesn't have 'comment:read' permission")})}.bind(this)}});return $obj_90900$$},$app$plugins$file$file_proxy$$=function($plugin_id$jscomp$49$$,$id$jscomp$1132$$){var $obj_91788$$=
new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_91788$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FileProxy"}});Object.defineProperty($obj_91788$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FileProxy"}});Object.defineProperty($obj_91788$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$49$$}});Object.defineProperty($obj_91788$$,"$id",{enumerable:!1,get:function(){return $id$jscomp$1132$$}});Object.defineProperty($obj_91788$$,
"id",{enumerable:!0,get:function(){return $app$plugins$format$format_id$$($id$jscomp$1132$$)}});Object.defineProperty($obj_91788$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_file$$($id$jscomp$1132$$))}});Object.defineProperty($obj_91788$$,"revn",{enumerable:!0,get:function(){return $APP.$cljs$cst$2279$revn$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_file$$($id$jscomp$1132$$))}});Object.defineProperty($obj_91788$$,
"pages",{enumerable:!0,get:function(){return this.getPages()}});Object.defineProperty($obj_91788$$,"getPages",{enumerable:!1,get:function(){return function(){var $file$jscomp$212$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91783_SHARP_$$){return $app$plugins$page$page_proxy$$($plugin_id$jscomp$49$$,
$id$jscomp$1132$$,$p1__91783_SHARP_$$)}),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$212$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2236$pages$$)))}.bind(this)}});Object.defineProperty($obj_91788$$,"validate",{enumerable:!1,get:function(){return function(){var $file$jscomp$213$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$),$libraries$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1933$files$$);try{return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($code$jscomp$66_p__91983$$){var $map__91984__$1_page_id$jscomp$504$$=$APP.$cljs$core$__destructure_map$$($code$jscomp$66_p__91983$$);$code$jscomp$66_p__91983$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91984__$1_page_id$jscomp$504$$,$APP.$cljs$cst$273$code$$);var $hint$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91984__$1_page_id$jscomp$504$$,
$APP.$cljs$cst$275$hint$$),$shape_id$jscomp$189$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91984__$1_page_id$jscomp$504$$,$APP.$cljs$cst$2554$shape_id$$);$map__91984__$1_page_id$jscomp$504$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91984__$1_page_id$jscomp$504$$,$APP.$cljs$cst$2051$page_id$$);return{code:$APP.$cljs$core$name$$($code$jscomp$66_p__91983$$),hint:$hint$jscomp$33$$,shapeId:$shape_id$jscomp$189$$==null?null:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$189$$),
pageId:$map__91984__$1_page_id$jscomp$504$$==null?null:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__91984__$1_page_id$jscomp$504$$)}},$APP.$app$common$files$validate$validate_file$$($file$jscomp$213$$,$libraries$jscomp$162$$)))}catch($e91980$$){return[{code:"validation-error",hint:$APP.$cljs$core$ex_message$$($e91980$$),shapeId:null,pageId:null}]}}.bind(this)}});Object.defineProperty($obj_91788$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$449$$){if(typeof $key$jscomp$449$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6669$getPluginData_key$$,$key$jscomp$449$$);var $file$jscomp$214$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$214$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$49$$))),$key$jscomp$449$$)}.bind(this)}});Object.defineProperty($obj_91788$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$450$$,$value$jscomp$1189$$){return typeof $key$jscomp$450$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($key$jscomp$450$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6617$setPluginData_key$$,
$key$jscomp$450$$):typeof $value$jscomp$1189$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1189$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($id$jscomp$1132$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$49$$)),$key$jscomp$450$$,$value$jscomp$1189$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6619$setPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_91788$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $file$jscomp$215$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$215$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",""+($plugin_id$jscomp$49$$??"")))))}.bind(this)}});Object.defineProperty($obj_91788$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$24$$,
$key$jscomp$451$$){if(typeof $namespace$jscomp$24$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6620$getSharedPluginData_namespace$$,$namespace$jscomp$24$$);if(typeof $key$jscomp$451$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6621$getSharedPluginData_key$$,$key$jscomp$451$$);var $file$jscomp$216$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$216$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$24$$)),$key$jscomp$451$$)}.bind(this)}});Object.defineProperty($obj_91788$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$25$$,$key$jscomp$452$$,$value$jscomp$1190$$){return typeof $namespace$jscomp$25$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($namespace$jscomp$25$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,
$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$25$$):typeof $key$jscomp$452$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($key$jscomp$452$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6623$setSharedPluginData_key$$,$key$jscomp$452$$):typeof $value$jscomp$1190$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1190$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,"content:write")?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($id$jscomp$1132$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$25$$),$key$jscomp$452$$,$value$jscomp$1190$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6625$setSharedPluginData$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_91788$$,
"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$26$$){if(typeof $namespace$jscomp$26$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6626$getSharedPluginDataKeys$$,$namespace$jscomp$26$$);var $file$jscomp$217$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$217$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$26$$))))}.bind(this)}});Object.defineProperty($obj_91788$$,"createPage",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,"content:write")){var $page_id$jscomp$505$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$pages$create_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$505$$,$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1132$$],null)),$plugin_id$jscomp$49$$));return $app$plugins$page$page_proxy$$($plugin_id$jscomp$49$$,$id$jscomp$1132$$,$page_id$jscomp$505$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$49$$,$cljs$cst$6670$createPage$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_91788$$,"export",{enumerable:!1,get:function(){return function($format$jscomp$45$$,
$type$jscomp$751$$){return new Promise(function($resolve$jscomp$57$$,$reject$jscomp$38$$){var $type__$1$jscomp$26$$=function(){var $or__5025__auto__$jscomp$1516$$=$app$plugins$parser$parse_keyword$$($type$jscomp$751$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1516$$)?$or__5025__auto__$jscomp$1516$$:$APP.$cljs$cst$2132$all$$}();if($format$jscomp$45$$==null||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,
["penpot",null,"zip",null],null),null),$format$jscomp$45$$)){if($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($APP.$app$main$data$exports$files$valid_types$$),$type__$1$jscomp$26$$)){var $file$jscomp$218$$=$app$plugins$utils$locate_file$$($id$jscomp$1132$$),$features__$1$jscomp$35$$=$APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$team_id$jscomp$195$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
a:switch($format$jscomp$45$$){case "zip":var $format__$1$jscomp$3$$=$APP.$cljs$cst$2493$legacy_zip$$;break a;default:$format__$1$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$cljs$cst$6671$export_file_v3$$)?$APP.$cljs$cst$2494$binfile_v3$$:$APP.$cljs$cst$2492$binfile_v1$$}return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$57$$,$reject$jscomp$38$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$49$$,
"export-binary-files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$954$format$$,$format__$1$jscomp$3$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$26$$])))},$APP.$beicon$v2$core$map$$(function($p1__91784_SHARP_$$){return new Uint8Array($APP.$cljs$cst$1586$body$$.$cljs$core$IFn$_invoke$arity$1$($p1__91784_SHARP_$$))},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($msg$jscomp$51$$){console.log($msg$jscomp$51$$);var $G__92133_G__92133__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$51$$);
$G__92133_G__92133__$1$$=$G__92133_G__92133__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__92133_G__92133__$1$$.$fqn$:null;switch($G__92133_G__92133__$1$$){case "error":return $APP.$beicon$v2$core$throw$0$$($APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("cannot export file",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$6672$export_file$$],null)));case "progress":return $APP.$beicon$v2$core$empty$$();case "finish":return $APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$1584$uri$$,$APP.$cljs$cst$1584$uri$$.$cljs$core$IFn$_invoke$arity$1$($msg$jscomp$51$$),$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$3747$no_cors$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$194$buffer$$],null));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__92133_G__92133__$1$$)].join(""));}},$APP.$app$main$worker$ask_many_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$3139$cmd$$,$cljs$cst$6673$export_files$$,$APP.$cljs$cst$954$format$$,$format__$1$jscomp$3$$,$APP.$cljs$cst$139$type$$,$type__$1$jscomp$26$$,$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$195$$,$APP.$cljs$cst$227$features$$,$features__$1$jscomp$35$$,$APP.$cljs$cst$1933$files$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$218$$],null)],null)))))))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$38$$,$APP.$cljs$cst$954$format$$,
"Invalid type: "+($type__$1$jscomp$26$$??""))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$38$$,$APP.$cljs$cst$954$format$$,"Invalid format: "+($format$jscomp$45$$??""))})}.bind(this)}});Object.defineProperty($obj_91788$$,"findVersions",{enumerable:!1,get:function(){return function($criteria$jscomp$3$$){var $user$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$03$$($criteria$jscomp$3$$,"createdBy",null);return new Promise(function($resolve$jscomp$58$$,$reject$jscomp$39$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,
"content:read")?$user$jscomp$9$$==null||$app$plugins$user$user_proxy_QMARK_$$($user$jscomp$9$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p__92134_snapshots$jscomp$1$$){var $G__92138_users$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__92134_snapshots$jscomp$1$$,0,null);$p__92134_snapshots$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__92134_snapshots$jscomp$1$$,1,null);var $users__$1$jscomp$1$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,
$G__92138_users$jscomp$12$$);$G__92138_users$jscomp$12$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91786_SHARP_$$){return $app$plugins$file$file_version_proxy$$($plugin_id$jscomp$49$$,$id$jscomp$1132$$,$users__$1$jscomp$1$$,$p1__91786_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91785_SHARP_$$){return $APP.$cljs$core$not$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($user$jscomp$9$$,
"id"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(""+($APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__91785_SHARP_$$)??""),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($user$jscomp$9$$,"id"))},$p__92134_snapshots$jscomp$1$$))));return $resolve$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$($G__92138_users$jscomp$12$$):$resolve$jscomp$58$$($G__92138_users$jscomp$12$$)},$reject$jscomp$39$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$zip$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6668$get_team_users$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1132$$],null)),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5139$get_file_snapshots$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1132$$],null))))):$app$plugins$utils$reject_not_valid$$($reject$jscomp$39$$,$cljs$cst$6675$findVersions_user$$,"Created by user is not a valid user object"):$app$plugins$utils$reject_not_valid$$($reject$jscomp$39$$,
$cljs$cst$6674$findVersions$$,"Plugin doesn't have 'content:read' permission")})}.bind(this)}});Object.defineProperty($obj_91788$$,"saveVersion",{enumerable:!1,get:function(){return function($label$jscomp$62$$){var $users_promise$$=new Promise(function($resolve$jscomp$59$$,$reject$jscomp$40$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$59$$,$reject$jscomp$40$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6668$get_team_users$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1132$$],null)))}),$create_version_promise$$=new Promise(function($resolve$jscomp$60$$,$reject$jscomp$41$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$49$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$create_version_from_plugins$$($id$jscomp$1132$$,$label$jscomp$62$$,$resolve$jscomp$60$$,$reject$jscomp$41$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$49$$,"create-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1132$$]))])):$app$plugins$utils$reject_not_valid$$($reject$jscomp$41$$,$cljs$cst$6676$saveVersion$$,"Plugin doesn't have 'content:write' permission")});return Promise.all([$users_promise$$,$create_version_promise$$]).then(function($data$jscomp$539_p__92139$$){var $users$jscomp$13_users__$1$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$539_p__92139$$,0,null);$data$jscomp$539_p__92139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$539_p__92139$$,1,null);$users$jscomp$13_users__$1$jscomp$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$users$jscomp$13_users__$1$jscomp$2$$);return $app$plugins$file$file_version_proxy$$($plugin_id$jscomp$49$$,$id$jscomp$1132$$,$users$jscomp$13_users__$1$jscomp$2$$,
$data$jscomp$539_p__92139$$)})}.bind(this)}});return $obj_91788$$},$app$plugins$events$get_theme$$=function($state$jscomp$1265_theme$jscomp$46$$){$state$jscomp$1265_theme$jscomp$46$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1265_theme$jscomp$46$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,$APP.$cljs$cst$3208$theme$$],null));return $APP.$cljs$core$not$$($state$jscomp$1265_theme$jscomp$46$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1265_theme$jscomp$46$$,"system")?$app$util$theme$get_system_theme$$():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1265_theme$jscomp$46$$,"default")?"dark":$state$jscomp$1265_theme$jscomp$46$$},$app$plugins$events$add_listener$$=function($type$jscomp$753$$,$key$jscomp$453_plugin_id$jscomp$53$$,$callback$jscomp$92$$,$props$jscomp$429$$){var $plugin_id__$1$$=$app$plugins$parser$parse_id$$($key$jscomp$453_plugin_id$jscomp$53$$);
$key$jscomp$453_plugin_id$jscomp$53$$=Symbol();var $debounced_callback$$=$APP.$goog$functions$debounce$$(function($value$jscomp$1191$$){try{return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6678$app_DOT_plugins_DOT_events_SLASH_void$$,$value$jscomp$1191$$)?$callback$jscomp$92$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$92$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$92$$():$callback$jscomp$92$$.$cljs$core$IFn$_invoke$arity$1$?$callback$jscomp$92$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1191$$):
$callback$jscomp$92$$($value$jscomp$1191$$)}catch($e92465$$){return console.error($e92465$$)}},10);$APP.$cljs$core$add_watch$$($APP.$app$main$store$state$$,$key$jscomp$453_plugin_id$jscomp$53$$,function($_$jscomp$3336_result$jscomp$397$$,$___$1$jscomp$2137$$,$old_val$jscomp$16$$,$new_val$jscomp$17$$){$_$jscomp$3336_result$jscomp$397$$=$app$plugins$events$handle_state_change$$.$cljs$core$IFn$_invoke$arity$5$($type$jscomp$753$$,$plugin_id__$1$$,$old_val$jscomp$16$$,$new_val$jscomp$17$$,$props$jscomp$429$$);
return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$,$_$jscomp$3336_result$jscomp$397$$)?$debounced_callback$$.$cljs$core$IFn$_invoke$arity$1$?$debounced_callback$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3336_result$jscomp$397$$):$debounced_callback$$($_$jscomp$3336_result$jscomp$397$$):null});return $key$jscomp$453_plugin_id$jscomp$53$$},$app$plugins$fonts$font_variant_proxy$$=function($name$jscomp$522$$,$id$jscomp$1133$$,
$weight$jscomp$15$$,$style$jscomp$87$$){var $obj_89222$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89222$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FontVariantProxy"}});Object.defineProperty($obj_89222$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FontVariantProxy"}});Object.defineProperty($obj_89222$$,"name",{enumerable:!0,get:function(){return $name$jscomp$522$$}});Object.defineProperty($obj_89222$$,"fontVariantId",{enumerable:!0,get:function(){return $id$jscomp$1133$$}});
Object.defineProperty($obj_89222$$,"fontWeight",{enumerable:!0,get:function(){return $weight$jscomp$15$$}});Object.defineProperty($obj_89222$$,"fontStyle",{enumerable:!0,get:function(){return $style$jscomp$87$$}});return $obj_89222$$},$app$plugins$fonts$font_proxy$$=function($plugin_id$jscomp$54$$,$map__89648__$1_obj_89650_p__89647$$){$map__89648__$1_obj_89650_p__89647$$=$APP.$cljs$core$__destructure_map$$($map__89648__$1_obj_89650_p__89647$$);var $id$jscomp$1134$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89648__$1_obj_89650_p__89647$$,
$APP.$cljs$cst$266$id$$),$family$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89648__$1_obj_89650_p__89647$$,$APP.$cljs$cst$2686$family$$),$name$jscomp$523$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89648__$1_obj_89650_p__89647$$,$APP.$cljs$cst$725$name$$),$variants$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89648__$1_obj_89650_p__89647$$,$APP.$cljs$cst$2687$variants$$);if($map__89648__$1_obj_89650_p__89647$$!=null){var $default_variant$$=
$APP.$app$main$fonts$get_default_variant$$($map__89648__$1_obj_89650_p__89647$$);$map__89648__$1_obj_89650_p__89647$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FontProxy"}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FontProxy"}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"name",{enumerable:!0,
get:function(){return $name$jscomp$523$$}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"fontId",{enumerable:!0,get:function(){return $id$jscomp$1134$$}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"fontFamily",{enumerable:!0,get:function(){return $family$jscomp$10$$}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"fontStyle",{enumerable:!0,get:function(){return $APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,
"fontVariantId",{enumerable:!0,get:function(){return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"fontWeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$2012$weight$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"variants",{enumerable:!0,get:function(){return function(){return $app$plugins$format$format_array$$(function($id__$1$jscomp$57_p__89749$$){var $map__89750__$1_weight$jscomp$16$$=
$APP.$cljs$core$__destructure_map$$($id__$1$jscomp$57_p__89749$$);$id__$1$jscomp$57_p__89749$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89750__$1_weight$jscomp$16$$,$APP.$cljs$cst$266$id$$);var $name__$1$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89750__$1_weight$jscomp$16$$,$APP.$cljs$cst$725$name$$),$style$jscomp$88$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89750__$1_weight$jscomp$16$$,$APP.$cljs$cst$1921$style$$);$map__89750__$1_weight$jscomp$16$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__89750__$1_weight$jscomp$16$$,$APP.$cljs$cst$2012$weight$$);return $app$plugins$fonts$font_variant_proxy$$($name__$1$jscomp$27$$,$id__$1$jscomp$57_p__89749$$,$map__89750__$1_weight$jscomp$16$$,$style$jscomp$88$$)},$variants$jscomp$13$$)}.call(this)}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"applyToText",{enumerable:!1,get:function(){return function($text$jscomp$156_text_id$$,$values$jscomp$105_variant$jscomp$44$$){return $app$plugins$shape$shape_proxy_QMARK_$$($text$jscomp$156_text_id$$)?
$app$plugins$register$check_permission$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$156_text_id$$,"$plugin"),"content:write")?$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$156_text_id$$,"$page"))?($text$jscomp$156_text_id$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$156_text_id$$,"$id"),$values$jscomp$105_variant$jscomp$44$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$1763$font_id$$,$id$jscomp$1134$$,$APP.$cljs$cst$1764$font_family$$,$family$jscomp$10$$,$APP.$cljs$cst$1768$font_style$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$105_variant$jscomp$44$$,"fontStyle"),$APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1765$font_variant_id$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$105_variant$jscomp$44$$,
"fontVariantId"),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1767$font_weight$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$105_variant$jscomp$44$$,"fontWeight"),$APP.$cljs$cst$2012$weight$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$))],null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_attrs$$($text$jscomp$156_text_id$$,
$values$jscomp$105_variant$jscomp$44$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6679$applyToText$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6679$applyToText$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6679$applyToText$$,$text$jscomp$156_text_id$$)}.bind(this)}});Object.defineProperty($map__89648__$1_obj_89650_p__89647$$,"applyToRange",
{enumerable:!1,get:function(){return function($end$jscomp$115_range$jscomp$19$$,$values$jscomp$106_variant$jscomp$45$$){if($app$util$object$type_of_QMARK_$$($end$jscomp$115_range$jscomp$19$$,"TextRange")){if($app$plugins$register$check_permission$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"$plugin"),"content:write")){if($app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,
"$page"))){var $range_id$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"$id"),$start$jscomp$259$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"$start");$end$jscomp$115_range$jscomp$19$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$115_range$jscomp$19$$,"$end");$values$jscomp$106_variant$jscomp$45$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1763$font_id$$,
$id$jscomp$1134$$,$APP.$cljs$cst$1764$font_family$$,$family$jscomp$10$$,$APP.$cljs$cst$1768$font_style$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$106_variant$jscomp$45$$,"fontStyle"),$APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1765$font_variant_id$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$106_variant$jscomp$45$$,
"fontVariantId"),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$)),$APP.$cljs$cst$1767$font_weight$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$106_variant$jscomp$45$$,"fontWeight"),$APP.$cljs$cst$2012$weight$$.$cljs$core$IFn$_invoke$arity$1$($default_variant$$))],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($range_id$$,
$start$jscomp$259$$,$end$jscomp$115_range$jscomp$19$$,$values$jscomp$106_variant$jscomp$45$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6680$applyToRange$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6680$applyToRange$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$54$$,$cljs$cst$6680$applyToRange$$,$end$jscomp$115_range$jscomp$19$$)}.bind(this)}});
return $map__89648__$1_obj_89650_p__89647$$}return null},$app$plugins$fonts$fonts_subcontext$$=function($plugin_id$jscomp$55$$){var $obj_90303$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_90303$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PenpotFontsSubcontext"}});Object.defineProperty($obj_90303$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PenpotFontsSubcontext"}});Object.defineProperty($obj_90303$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$55$$).call(this)}});
Object.defineProperty($obj_90303$$,"all",{enumerable:!0,get:function(){return $app$plugins$format$format_array$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$fonts$font_proxy$$,$plugin_id$jscomp$55$$),$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))}});Object.defineProperty($obj_90303$$,"findById",{enumerable:!1,get:function(){return function($id$jscomp$1135$$){return typeof $id$jscomp$1135$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$55$$,
$cljs$cst$6681$findbyId$$,$id$jscomp$1135$$):$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$55$$,$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__90300_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__90300_SHARP_$$)),$APP.$cuerdas$core$lower$$($id$jscomp$1135$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$))))}.bind(this)}});Object.defineProperty($obj_90303$$,
"findByName",{enumerable:!1,get:function(){return function($name$jscomp$524$$){return typeof $name$jscomp$524$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$55$$,$cljs$cst$6682$findByName$$,$name$jscomp$524$$):$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$55$$,$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__90301_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__90301_SHARP_$$)),
$APP.$cuerdas$core$lower$$($name$jscomp$524$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$))))}.bind(this)}});Object.defineProperty($obj_90303$$,"findAllById",{enumerable:!1,get:function(){return function($id$jscomp$1136$$){return typeof $id$jscomp$1136$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$55$$,$cljs$cst$6683$findAllById$$,$APP.$cljs$core$name$$):$app$plugins$format$format_array$$(function($font$jscomp$73$$){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$73$$)),
$APP.$cuerdas$core$lower$$($id$jscomp$1136$$)))?$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$55$$,$font$jscomp$73$$):null},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))}.bind(this)}});Object.defineProperty($obj_90303$$,"findAllByName",{enumerable:!1,get:function(){return function($name$jscomp$525$$){return typeof $name$jscomp$525$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$55$$,$cljs$cst$6684$findAllByName$$,$name$jscomp$525$$):$app$plugins$format$format_array$$(function($font$jscomp$74$$){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$74$$)),
$APP.$cuerdas$core$lower$$($name$jscomp$525$$)))?$app$plugins$fonts$font_proxy$$($plugin_id$jscomp$55$$,$font$jscomp$74$$):null},$APP.$cljs$core$vals$$($APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)))}.bind(this)}});return $obj_90303$$},$app$plugins$history$history_subcontext$$=function($plugin_id$jscomp$56$$){var $obj_87930$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_87930$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"HistorySubcontext"}});Object.defineProperty($obj_87930$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"HistorySubcontext"}});Object.defineProperty($obj_87930$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$56$$}});Object.defineProperty($obj_87930$$,"undoBlockBegin",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$56$$,"content:write")){var $id$jscomp$1137$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($id$jscomp$1137$$));
return $id$jscomp$1137$$}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$56$$,$APP.$cljs$cst$1805$resize$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});Object.defineProperty($obj_87930$$,"undoBlockFinish",{enumerable:!1,get:function(){return function($block_id$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$56$$,"content:write")?$APP.$cljs$core$not$$($block_id$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$56$$,$cljs$cst$6685$undoBlockFinish$$,
$block_id$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($block_id$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$56$$,$APP.$cljs$cst$1805$resize$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});return $obj_87930$$},$app$plugins$library$get_variant_components$$=function($file_id$jscomp$494$$,$variant_id$jscomp$58$$){return $app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_file$$($file_id$jscomp$494$$)),
$variant_id$jscomp$58$$)},$app$plugins$library$variant_proxy$$=function($plugin_id$jscomp$59$$,$file_id$jscomp$495$$,$id$jscomp$1140$$){var $obj_91174$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_91174$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"VariantProxy"}});Object.defineProperty($obj_91174$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"VariantProxy"}});Object.defineProperty($obj_91174$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$59$$).call(this)}});
Object.defineProperty($obj_91174$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$495$$).call(this)}});Object.defineProperty($obj_91174$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1140$$).call(this)}});Object.defineProperty($obj_91174$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1140$$??"")}});Object.defineProperty($obj_91174$$,"libraryId",{enumerable:!0,get:function(){return""+($file_id$jscomp$495$$??
"")}});Object.defineProperty($obj_91174$$,"properties",{enumerable:!0,get:function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2017$variant_properties$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$library$get_variant_components$$($file_id$jscomp$495$$,
$id$jscomp$1140$$)])))))}});Object.defineProperty($obj_91174$$,"currentValues",{enumerable:!1,get:function(){return function($property$jscomp$87$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$260$value$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__91279__$1_p__91278_variant_properties$jscomp$6$$){$map__91279__$1_p__91278_variant_properties$jscomp$6$$=
$APP.$cljs$core$__destructure_map$$($map__91279__$1_p__91278_variant_properties$jscomp$6$$);$map__91279__$1_p__91278_variant_properties$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91279__$1_p__91278_variant_properties$jscomp$6$$,$APP.$cljs$cst$2017$variant_properties$$);return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__91171_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__91171_SHARP_$$),
$property$jscomp$87$$)},$map__91279__$1_p__91278_variant_properties$jscomp$6$$)},$app$plugins$library$get_variant_components$$($file_id$jscomp$495$$,$id$jscomp$1140$$)))))}.bind(this)}});Object.defineProperty($obj_91174$$,"variantComponents",{enumerable:!1,get:function(){return function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91172_SHARP_$$){return $app$plugins$library$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$?
$app$plugins$library$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$59$$,$file_id$jscomp$495$$,$p1__91172_SHARP_$$):$app$plugins$library$lib_component_proxy$$($plugin_id$jscomp$59$$,$file_id$jscomp$495$$,$p1__91172_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$app$plugins$library$get_variant_components$$($file_id$jscomp$495$$,$id$jscomp$1140$$))))}.bind(this)}});Object.defineProperty($obj_91174$$,"addVariant",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$59$$,
"add-new-variant"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1140$$)]))}.bind(this)}});Object.defineProperty($obj_91174$$,"addProperty",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$59$$,"add-new-property"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$1140$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3573$property_value$$,"Value 1"],null)]))]))}.bind(this)}});Object.defineProperty($obj_91174$$,"removeProperty",{enumerable:!1,get:function(){return function($pos$jscomp$167$$){var $nprops$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($app$plugins$library$get_variant_components$$($file_id$jscomp$495$$,
$id$jscomp$1140$$))));return!$APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$167$$)||$pos$jscomp$167$$>=$nprops$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$59$$,$APP.$cljs$cst$1411$pos$$,$pos$jscomp$167$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$59$$,"remove-property"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$remove_property$$($id$jscomp$1140$$,$pos$jscomp$167$$)]))}.bind(this)}});
Object.defineProperty($obj_91174$$,"renameProperty",{enumerable:!1,get:function(){return function($pos$jscomp$168$$,$name$jscomp$526$$){var $nprops$jscomp$1$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($app$plugins$library$get_variant_components$$($file_id$jscomp$495$$,$id$jscomp$1140$$))));return!$APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$168$$)||$pos$jscomp$168$$>=$nprops$jscomp$1$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$59$$,
$APP.$cljs$cst$1411$pos$$,$pos$jscomp$168$$):typeof $name$jscomp$526$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$59$$,$APP.$cljs$cst$725$name$$,$name$jscomp$526$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_property_name$$($id$jscomp$1140$$,$pos$jscomp$168$$,$name$jscomp$526$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4491$trigger$$,"plugin:rename-property"],null)))}.bind(this)}});return $obj_91174$$},
$app$plugins$library$lib_component_proxy$$=function($plugin_id$jscomp$60$$,$file_id$jscomp$496$$,$id$jscomp$1141$$){var $obj_91393$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_91393$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryComponentProxy"}});Object.defineProperty($obj_91393$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryComponentProxy"}});Object.defineProperty($obj_91393$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$60$$).call(this)}});
Object.defineProperty($obj_91393$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1141$$).call(this)}});Object.defineProperty($obj_91393$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$496$$).call(this)}});Object.defineProperty($obj_91393$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1141$$??"")}});Object.defineProperty($obj_91393$$,"libraryId",{enumerable:!0,get:function(){return""+($file_id$jscomp$496$$??
"")}});Object.defineProperty($obj_91393$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_component$$(this))},set:function($JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$){if(typeof $JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$!=="string")$JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,
$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$60$$,"library:write")){var $component$jscomp$inline_10862$$=$app$plugins$utils$proxy__GT_library_component$$(this);$JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$=""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_10862$$),
"")??"")+" / "+($JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$??"");$JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($id$jscomp$1141$$,$JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$))}else $JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2340_val_name_91451_value__$1$jscomp$inline_10863$$}});Object.defineProperty($obj_91393$$,"path",{enumerable:!0,get:function(){return $APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_component$$(this))},set:function($JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$){if(typeof $JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$!==
"string")$JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$296$path$$,$JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$60$$,"library:write")){var $component$jscomp$inline_10867$$=$app$plugins$utils$proxy__GT_library_component$$(this);$JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$=
""+($JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$??"")+" / "+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_10867$$)??"");$JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($id$jscomp$1141$$,$JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$))}else $JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$296$path$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2341_val_path_91459_value__$1$jscomp$inline_10868$$}});Object.defineProperty($obj_91393$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$60$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$delete_component$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1141$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91393$$,"instance",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$60$$,"content:write")){var $id_ref$jscomp$9$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$instantiate_component$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$496$$,
$id$jscomp$1141$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3999$id_ref$$,$id_ref$jscomp$9$$,$APP.$cljs$cst$1792$origin$$,"plugin"],null)),$plugin_id$jscomp$60$$));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$60$$,$APP.$cljs$core$_deref$$($id_ref$jscomp$9$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$3142$instance$$,"Plugin doesn't have 'content:write' permission")}.bind(this)}});
Object.defineProperty($obj_91393$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$463$$){if(typeof $key$jscomp$463$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6692$component_plugin_data_key$$,$key$jscomp$463$$);var $component$jscomp$148$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$148$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$60$$))),$key$jscomp$463$$)}.bind(this)}});Object.defineProperty($obj_91393$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$464$$,$value$jscomp$1215$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$496$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6686$setPluginData_non_local_library$$,$file_id$jscomp$496$$):typeof $key$jscomp$464$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6617$setPluginData_key$$,$key$jscomp$464$$):$value$jscomp$1215$$!=null&&typeof $value$jscomp$1215$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1215$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$60$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$496$$,$APP.$cljs$cst$1630$component$$,$id$jscomp$1141$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$60$$)),$key$jscomp$464$$,$value$jscomp$1215$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6619$setPluginData$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91393$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $component$jscomp$149$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$149$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$60$$)))))}.bind(this)}});Object.defineProperty($obj_91393$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$33$$,$key$jscomp$465$$){if(typeof $namespace$jscomp$33$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6693$component_plugin_data_namespace$$,$namespace$jscomp$33$$);
if(typeof $key$jscomp$465$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6692$component_plugin_data_key$$,$key$jscomp$465$$);var $component$jscomp$150$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$150$$,$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$33$$)),$key$jscomp$465$$)}.bind(this)}});Object.defineProperty($obj_91393$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$34$$,$key$jscomp$466$$,$value$jscomp$1216$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$496$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6687$setSharedPluginData_non_local_library$$,$file_id$jscomp$496$$):typeof $namespace$jscomp$34$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$34$$):typeof $key$jscomp$466$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6623$setSharedPluginData_key$$,$key$jscomp$466$$):$value$jscomp$1216$$!=null&&typeof $value$jscomp$1216$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1216$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$60$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$496$$,$APP.$cljs$cst$1630$component$$,$id$jscomp$1141$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$34$$),
$key$jscomp$466$$,$value$jscomp$1216$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6625$setSharedPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91393$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$35$$){if(typeof $namespace$jscomp$35$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$cljs$cst$6693$component_plugin_data_namespace$$,$namespace$jscomp$35$$);
var $component$jscomp$151$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$151$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$35$$))))}.bind(this)}});
Object.defineProperty($obj_91393$$,"mainInstance",{enumerable:!1,get:function(){return function(){var $file$jscomp$219_root$jscomp$71$$=$app$plugins$utils$locate_file$$($file_id$jscomp$496$$),$component$jscomp$152$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);$file$jscomp$219_root$jscomp$71$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$219_root$jscomp$71$$),$component$jscomp$152$$);
return $file$jscomp$219_root$jscomp$71$$!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$60$$,$file_id$jscomp$496$$,$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$152$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$219_root$jscomp$71$$)):null}.bind(this)}});Object.defineProperty($obj_91393$$,"isVariant",{enumerable:!1,get:function(){return function(){var $component$jscomp$153$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,
$id$jscomp$1141$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$153$$)}.bind(this)}});Object.defineProperty($obj_91393$$,"variants",{enumerable:!1,get:function(){var $component$jscomp$inline_10870$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$inline_10870$$)?$app$plugins$library$variant_proxy$$($plugin_id$jscomp$60$$,$file_id$jscomp$496$$,$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$inline_10870$$)):
null}});Object.defineProperty($obj_91393$$,"variantProps",{enumerable:!0,get:function(){return function(){var $component$jscomp$155$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$155$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$174$$,$name$jscomp$527_p__91780$$){var $map__91781__$1_value$jscomp$1217$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$527_p__91780$$);
$name$jscomp$527_p__91780$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91781__$1_value$jscomp$1217$$,$APP.$cljs$cst$725$name$$);$map__91781__$1_value$jscomp$1217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__91781__$1_value$jscomp$1217$$,$APP.$cljs$cst$260$value$$);return $APP.$app$util$object$set_BANG_$$($acc$jscomp$174$$,$name$jscomp$527_p__91780$$,$map__91781__$1_value$jscomp$1217$$)},{},$APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$155$$)):
null}.call(this)}});Object.defineProperty($obj_91393$$,"variantError",{enumerable:!0,get:function(){var $file$jscomp$inline_10872_root$jscomp$inline_10874$$=$app$plugins$utils$locate_file$$($file_id$jscomp$496$$),$component$jscomp$inline_10873$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);$file$jscomp$inline_10872_root$jscomp$inline_10874$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$inline_10872_root$jscomp$inline_10874$$),
$component$jscomp$inline_10873$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$inline_10873$$)?$APP.$cljs$cst$2019$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$inline_10872_root$jscomp$inline_10874$$):null}});Object.defineProperty($obj_91393$$,"transformInVariant",{enumerable:!1,get:function(){return function(){var $component$jscomp$157$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$157$$)?
!$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$157$$):$component$jscomp$157$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,"transform-in-variant"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2070$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$157$$))])):
null}.bind(this)}});Object.defineProperty($obj_91393$$,"addVariant",{enumerable:!1,get:function(){return function(){var $component$jscomp$158$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,$id$jscomp$1141$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$158$$)?$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$158$$):$component$jscomp$158$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,
"add-new-variant"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2070$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$158$$))])):null}.bind(this)}});Object.defineProperty($obj_91393$$,"setVariantProperty",{enumerable:!1,get:function(){return function($pos$jscomp$169$$,$value$jscomp$1218$$){var $nprops$jscomp$2$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_library_component$$($file_id$jscomp$496$$,
$id$jscomp$1141$$)));return!$APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$169$$)||$pos$jscomp$169$$>=$nprops$jscomp$2$$?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$1411$pos$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$169$$)):typeof $value$jscomp$1218$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$60$$,$APP.$cljs$cst$725$name$$,$value$jscomp$1218$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$system_events$event$$($plugin_id$jscomp$60$$,
"variant-edit-property-value"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$update_property_value$$($id$jscomp$1141$$,$pos$jscomp$169$$,$value$jscomp$1218$$)]))}.bind(this)}});return $obj_91393$$},$app$plugins$library$library_proxy$$=function($plugin_id$jscomp$61$$,$file_id$jscomp$497$$){var $obj_91995$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_91995$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryProxy"}});
Object.defineProperty($obj_91995$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryProxy"}});Object.defineProperty($obj_91995$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$61$$).call(this)}});Object.defineProperty($obj_91995$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$497$$).call(this)}});Object.defineProperty($obj_91995$$,"id",{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_file$$(this)))}});
Object.defineProperty($obj_91995$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_file$$(this))}});Object.defineProperty($obj_91995$$,"colors",{enumerable:!0,get:function(){return function(){var $colors$jscomp$28_file$jscomp$221$$=$app$plugins$utils$locate_file$$($file_id$jscomp$497$$);$colors$jscomp$28_file$jscomp$221$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91989_SHARP_$$){return $app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$61$$,
$file_id$jscomp$497$$,$p1__91989_SHARP_$$)},$APP.$cljs$core$keys$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$28_file$jscomp$221$$))));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$colors$jscomp$28_file$jscomp$221$$)}.call(this,this)}});Object.defineProperty($obj_91995$$,"typographies",{enumerable:!0,get:function(){return function(){var $file$jscomp$222_typographies$jscomp$16$$=
$app$plugins$utils$locate_file$$($file_id$jscomp$497$$);$file$jscomp$222_typographies$jscomp$16$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91990_SHARP_$$){return $app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$61$$,$file_id$jscomp$497$$,$p1__91990_SHARP_$$)},$APP.$cljs$core$keys$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$222_typographies$jscomp$16$$))));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$file$jscomp$222_typographies$jscomp$16$$)}.call(this,this)}});Object.defineProperty($obj_91995$$,"components",{enumerable:!0,get:function(){return function(){var $components$jscomp$26_file$jscomp$223$$=$app$plugins$utils$locate_file$$($file_id$jscomp$497$$),$data$jscomp$540$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$26_file$jscomp$223$$);$components$jscomp$26_file$jscomp$223$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91992_SHARP_$$){return $app$plugins$library$lib_component_proxy$$($plugin_id$jscomp$61$$,
$file_id$jscomp$497$$,$p1__91992_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__91991_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__91991_SHARP_$$,$data$jscomp$540$$)},$APP.$cljs$core$second$$),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2552$deleted$$,
$APP.$cljs$core$second$$),$APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$540$$)))));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$components$jscomp$26_file$jscomp$223$$)}.call(this,this)}});Object.defineProperty($obj_91995$$,"tokens",{enumerable:!0,get:function(){return $app$plugins$tokens$tokens_catalog$$($plugin_id$jscomp$61$$,$file_id$jscomp$497$$)}});Object.defineProperty($obj_91995$$,"createColor",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$61$$,
"library:write")){var $color_id$jscomp$13$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$color_id$jscomp$13$$,$APP.$cljs$cst$725$name$$,"Color",$APP.$cljs$cst$1303$color$$,"#000000",$APP.$cljs$cst$1740$opacity$$,1],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3970$rename_QMARK_$$,!1],null)),$plugin_id$jscomp$61$$));return $app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$61$$,$file_id$jscomp$497$$,$color_id$jscomp$13$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6694$createColor$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91995$$,"createTypography",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$61$$,
"library:write")){var $typography_id$jscomp$11$$=$APP.$app$common$uuid$next$$(),$JSCompiler_temp_const$jscomp$11341$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$,$id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$typography_id$jscomp$11$$,$APP.$cljs$cst$725$name$$,"Typography"],null));var $JSCompiler_inline_result$jscomp$11343_letter_spacing$jscomp$inline_14280$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1772$letter_spacing$$);var $font_family$jscomp$inline_14281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1764$font_family$$),$line_height$jscomp$inline_14282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1771$line_height$$),
$path$jscomp$inline_14283$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$296$path$$),$font_style$jscomp$inline_14284$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1768$font_style$$),$text_transform$jscomp$inline_14285$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,
$APP.$cljs$cst$1775$text_transform$$),$font_id$jscomp$inline_14286$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1763$font_id$$),$font_size$jscomp$inline_14287$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1766$font_size$$),$font_weight$jscomp$inline_14288$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,
$APP.$cljs$cst$1767$font_weight$$),$name$jscomp$inline_14289$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$725$name$$),$font_variant_id$jscomp$inline_14290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,$APP.$cljs$cst$1765$font_variant_id$$);$id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$,
$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$11343_letter_spacing$jscomp$inline_14280$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1771$line_height$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1768$font_style$$,$APP.$cljs$cst$1775$text_transform$$,$APP.$cljs$cst$1763$font_id$$,$APP.$cljs$cst$1766$font_size$$,$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1765$font_variant_id$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1772$letter_spacing$$,$APP.$cljs$cst$1764$font_family$$],[$APP.$cljs$core$truth_$$($line_height$jscomp$inline_14282$$)?$line_height$jscomp$inline_14282$$:"1.2",$path$jscomp$inline_14283$$,$APP.$cljs$core$truth_$$($font_style$jscomp$inline_14284$$)?$font_style$jscomp$inline_14284$$:"normal",$APP.$cljs$core$truth_$$($text_transform$jscomp$inline_14285$$)?$text_transform$jscomp$inline_14285$$:"none",$APP.$cljs$core$truth_$$($font_id$jscomp$inline_14286$$)?$font_id$jscomp$inline_14286$$:
"sourcesanspro",$APP.$cljs$core$truth_$$($font_size$jscomp$inline_14287$$)?$font_size$jscomp$inline_14287$$:"14",$APP.$cljs$core$truth_$$($font_weight$jscomp$inline_14288$$)?$font_weight$jscomp$inline_14288$$:"480",$APP.$cljs$core$truth_$$($name$jscomp$inline_14289$$)?$name$jscomp$inline_14289$$:"Typography 1",$APP.$cljs$core$truth_$$($font_variant_id$jscomp$inline_14290$$)?$font_variant_id$jscomp$inline_14290$$:"regular",$APP.$cljs$core$truth_$$($id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$)?
$id$jscomp$inline_14291_map__51538__$1$jscomp$inline_14279$$:$APP.$app$common$uuid$next$$(),$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11343_letter_spacing$jscomp$inline_14280$$)?$JSCompiler_inline_result$jscomp$11343_letter_spacing$jscomp$inline_14280$$:"0",$APP.$cljs$core$truth_$$($font_family$jscomp$inline_14281$$)?$font_family$jscomp$inline_14281$$:"sourcesanspro"]));$JSCompiler_temp_const$jscomp$11341$$.call($APP.$app$main$store$emit_BANG_$$,$app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$11343_letter_spacing$jscomp$inline_14280$$,
!1),$plugin_id$jscomp$61$$));return $app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$61$$,$file_id$jscomp$497$$,$typography_id$jscomp$11$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6695$createTypography$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91995$$,"createComponent",{enumerable:!1,get:function(){return function($ids$jscomp$330_shapes$jscomp$246$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$61$$,
"library:write")){var $id_ref$jscomp$10$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$ids$jscomp$330_shapes$jscomp$246$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__91993_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__91993_SHARP_$$,"$id")}),$ids$jscomp$330_shapes$jscomp$246$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_component$cljs$0core$0IFn$0_invoke$0arity$02$$($id_ref$jscomp$10$$,
$ids$jscomp$330_shapes$jscomp$246$$),$plugin_id$jscomp$61$$));return $app$plugins$library$lib_component_proxy$$($plugin_id$jscomp$61$$,$file_id$jscomp$497$$,$APP.$cljs$core$_deref$$($id_ref$jscomp$10$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6696$createComponent$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91995$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$467$$){if(typeof $key$jscomp$467$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6697$file_plugin_data_key$$,$key$jscomp$467$$);var $file$jscomp$224$$=$app$plugins$utils$locate_file$$($file_id$jscomp$497$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$224$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$61$$))),$key$jscomp$467$$)}.bind(this)}});Object.defineProperty($obj_91995$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$468$$,$value$jscomp$1219$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$497$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6686$setPluginData_non_local_library$$,$file_id$jscomp$497$$):typeof $key$jscomp$468$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6617$setPluginData_key$$,$key$jscomp$468$$):$value$jscomp$1219$$!=null&&typeof $value$jscomp$1219$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1219$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$61$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($file_id$jscomp$497$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$61$$)),$key$jscomp$468$$,$value$jscomp$1219$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6619$setPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});
Object.defineProperty($obj_91995$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $file$jscomp$225$$=$app$plugins$utils$locate_file$$($file_id$jscomp$497$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$225$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$61$$)))))}.bind(this)}});Object.defineProperty($obj_91995$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$36$$,$key$jscomp$469$$){if(typeof $namespace$jscomp$36$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6698$file_plugin_data_namespace$$,$namespace$jscomp$36$$);if(typeof $key$jscomp$469$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6697$file_plugin_data_key$$,$key$jscomp$469$$);var $file$jscomp$226$$=$app$plugins$utils$locate_file$$($file_id$jscomp$497$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$226$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$36$$)),$key$jscomp$469$$)}.bind(this)}});Object.defineProperty($obj_91995$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$37$$,$key$jscomp$470$$,$value$jscomp$1220$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$497$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6687$setSharedPluginData_non_local_library$$,$file_id$jscomp$497$$):typeof $namespace$jscomp$37$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$37$$):typeof $key$jscomp$470$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6623$setSharedPluginData_key$$,$key$jscomp$470$$):$value$jscomp$1220$$!=null&&typeof $value$jscomp$1220$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1220$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$61$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$05$$($file_id$jscomp$497$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$37$$),$key$jscomp$470$$,
$value$jscomp$1220$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$cljs$cst$6625$setSharedPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_91995$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$38$$){if(typeof $namespace$jscomp$38$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$61$$,$APP.$cljs$cst$394$namespace$$,$namespace$jscomp$38$$);var $file$jscomp$227$$=$app$plugins$utils$locate_file$$($file_id$jscomp$497$$);
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$227$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$38$$))))}.bind(this)}});return $obj_91995$$},$app$plugins$library$library_subcontext$$=
function($plugin_id$jscomp$62$$){var $obj_92223$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_92223$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PenpotLibrarySubcontext"}});Object.defineProperty($obj_92223$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PenpotLibrarySubcontext"}});Object.defineProperty($obj_92223$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$62$$).call(this)}});Object.defineProperty($obj_92223$$,
"local",{enumerable:!0,get:function(){return $app$plugins$library$library_proxy$$($plugin_id$jscomp$62$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))}});Object.defineProperty($obj_92223$$,"connected",{enumerable:!0,get:function(){var $libraries$jscomp$inline_10877$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1933$files$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$library$library_proxy$$,$plugin_id$jscomp$62$$),$APP.$cljs$core$keys$$($libraries$jscomp$inline_10877$$)))}});Object.defineProperty($obj_92223$$,"availableLibraries",{enumerable:!1,get:function(){return function(){var $team_id$jscomp$196$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return new Promise(function($resolve$jscomp$61$$,
$reject$jscomp$42$$){var $current_libs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1933$files$$));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$61$$,$reject$jscomp$42$$,$APP.$beicon$v2$core$map$$(function($result$jscomp$398$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$1142_p__92301$$){var $library_summary_map__92302__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1142_p__92301$$);$id$jscomp$1142_p__92301$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_summary_map__92302__$1$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$528$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_summary_map__92302__$1$$,$APP.$cljs$cst$725$name$$);$library_summary_map__92302__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_summary_map__92302__$1$$,$APP.$cljs$cst$4049$library_summary$$);return{id:""+($id$jscomp$1142_p__92301$$??""),name:$name$jscomp$528$$,numColors:$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($library_summary_map__92302__$1$$)),numComponents:$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($library_summary_map__92302__$1$$)),
numTypographies:$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($library_summary_map__92302__$1$$))}},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92221_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($current_libs$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__92221_SHARP_$$))},$result$jscomp$398$$)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3381$get_team_shared_files$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$196$$],null))))})}.bind(this)}});Object.defineProperty($obj_92223$$,"connectLibrary",{enumerable:!1,get:function(){return function($library_id$jscomp$64$$){return new Promise(function($resolve$jscomp$62$$,$reject$jscomp$43$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$62$$,"library:write")){if(typeof $library_id$jscomp$64$$!=="string")return $app$plugins$utils$reject_not_valid$$($reject$jscomp$43$$,
$cljs$cst$6699$connectLibrary$$,$library_id$jscomp$64$$);var $file_id$jscomp$498$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$library_id__$1$$=$APP.$app$common$uuid$parse$$($library_id$jscomp$64$$);$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){var $G__92304$$=$app$plugins$library$library_proxy$$($plugin_id$jscomp$62$$,$library_id__$1$$);return $resolve$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$?
$resolve$jscomp$62$$.$cljs$core$IFn$_invoke$arity$1$($G__92304$$):$resolve$jscomp$62$$($G__92304$$)},$reject$jscomp$43$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4051$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_attach_library_finished$$),$APP.$app$main$store$stream$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$link_file_to_library$$($file_id$jscomp$498$$,
$library_id__$1$$),$plugin_id$jscomp$62$$))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$43$$,$cljs$cst$6699$connectLibrary$$,"Plugin doesn't have 'library:write' permission")})}.bind(this)}});return $obj_92223$$},$app$plugins$local_storage$prefix_key$$=function($plugin_id$jscomp$63$$,$key$jscomp$471$$){return"penpot-plugins:"+($plugin_id$jscomp$63$$??"")+"/"+($key$jscomp$471$$??"")},$app$plugins$local_storage$local_storage_proxy$$=function($plugin_id$jscomp$64$$){var $obj_88773$$=
new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_88773$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LocalStorageProxy"}});Object.defineProperty($obj_88773$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LocalStorageProxy"}});Object.defineProperty($obj_88773$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$64$$}});Object.defineProperty($obj_88773$$,"getItem",{enumerable:!1,get:function(){return function($key$jscomp$472$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$64$$,
"allow:localstorage")?typeof $key$jscomp$472$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$64$$,$cljs$cst$6700$getItem$$,"The key must be a string"):$app$plugins$local_storage$local_storage$$.getItem($app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$64$$,$key$jscomp$472$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$64$$,$cljs$cst$6700$getItem$$,"Plugin doesn't have 'allow:localstorage' permission")}.bind(this)}});Object.defineProperty($obj_88773$$,"setItem",{enumerable:!1,
get:function(){return function($key$jscomp$473$$,$value$jscomp$1221$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$64$$,"allow:localstorage")?typeof $key$jscomp$473$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$64$$,$cljs$cst$6701$setItem$$,"The key must be a string"):$app$plugins$local_storage$local_storage$$.setItem($app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$64$$,$key$jscomp$473$$),$value$jscomp$1221$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$64$$,
$cljs$cst$6701$setItem$$,"Plugin doesn't have 'allow:localstorage' permission")}.bind(this)}});Object.defineProperty($obj_88773$$,"removeItem",{enumerable:!1,get:function(){return function($key$jscomp$474$$){return $app$plugins$register$check_permission$$($plugin_id$jscomp$64$$,"allow:localstorage")?typeof $key$jscomp$474$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$64$$,$cljs$cst$6702$removeItem$$,"The key must be a string"):$app$plugins$local_storage$local_storage$$.removeItem($app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$64$$,
$key$jscomp$474$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$64$$,$cljs$cst$6702$removeItem$$,"Plugin doesn't have 'allow:localstorage' permission")}.bind(this)}});Object.defineProperty($obj_88773$$,"getKeys",{enumerable:!1,get:function(){return function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__88771_SHARP_$$){return $APP.$cuerdas$core$replace$$($p1__88771_SHARP_$$,$app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$64$$,
""),"")},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__88770_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__88770_SHARP_$$,$app$plugins$local_storage$prefix_key$$($plugin_id$jscomp$64$$,""))},Object.keys($app$plugins$local_storage$local_storage$$))))}.bind(this)}});return $obj_88773$$},$app$plugins$viewport$viewport_proxy$$=function($plugin_id$jscomp$65$$){var $obj_89263$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89263$$,Symbol.toStringTag,
{enumerable:!1,get:function(){return"ViewportProxy"}});Object.defineProperty($obj_89263$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ViewportProxy"}});Object.defineProperty($obj_89263$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$65$$}});Object.defineProperty($obj_89263$$,"center",{enumerable:!0,get:function(){var $vp$jscomp$inline_10881_y$jscomp$inline_10883$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1942$vbox$$),$x$jscomp$inline_10882$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10881_y$jscomp$inline_10883$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10881_y$jscomp$inline_10883$$)/2;$vp$jscomp$inline_10881_y$jscomp$inline_10883$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10881_y$jscomp$inline_10883$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vp$jscomp$inline_10881_y$jscomp$inline_10883$$)/
2;return Object.freeze({x:$x$jscomp$inline_10882$$,y:$vp$jscomp$inline_10881_y$jscomp$inline_10883$$})},set:function($val_center_89299$$){return function($new_y$jscomp$3_value$jscomp$1222$$){var $new_x$jscomp$3$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($new_y$jscomp$3_value$jscomp$1222$$,"x");$new_y$jscomp$3_value$jscomp$1222$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($new_y$jscomp$3_value$jscomp$1222$$,"y");if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($new_x$jscomp$3$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$65$$,
$cljs$cst$6703$center_x$$,$new_x$jscomp$3$$);if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($new_y$jscomp$3_value$jscomp$1222$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$65$$,$cljs$cst$6704$center_y$$,$new_y$jscomp$3_value$jscomp$1222$$);var $old_y_vb$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1937$workspace_local$$),
$APP.$cljs$cst$1942$vbox$$),$old_x$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)/2;$old_y_vb$jscomp$1$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($old_y_vb$jscomp$1$$)/2;var $delta_x$jscomp$9$$=$new_x$jscomp$3$$-$old_x$$,$delta_y$jscomp$7$$=$new_y$jscomp$3_value$jscomp$1222$$-$old_y_vb$jscomp$1$$;
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,function($p1__89219_SHARP_$$){return $p1__89219_SHARP_$$+$delta_x$jscomp$9$$},$APP.$cljs$cst$1516$y$$,function($p1__89220_SHARP_$$){return $p1__89220_SHARP_$$+$delta_y$jscomp$7$$}],null)))}.call(this,$val_center_89299$$)}});Object.defineProperty($obj_89263$$,"zoom",{enumerable:!0,get:function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2204$zoom$$)},set:function($JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$)))$JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$65$$,$APP.$cljs$cst$2204$zoom$$,$JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$);else{var $z$jscomp$inline_10886$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2204$zoom$$);$JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$/$z$jscomp$inline_10886$$))}return $JSCompiler_inline_result$jscomp$2346_val_zoom_89307$$}});Object.defineProperty($obj_89263$$,"bounds",{enumerable:!0,get:function(){var $vbox$jscomp$inline_10888$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1942$vbox$$);return Object.freeze($app$plugins$format$format_bounds$$($vbox$jscomp$inline_10888$$))}});Object.defineProperty($obj_89263$$,"zoomReset",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}.bind(this)}});
Object.defineProperty($obj_89263$$,"zoomToFitAll",{enumerable:!1,get:function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}.bind(this)}});Object.defineProperty($obj_89263$$,"zoomIntoView",{enumerable:!1,get:function(){return function($ids$jscomp$331_shapes$jscomp$247$$){return $APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$331_shapes$jscomp$247$$)?($ids$jscomp$331_shapes$jscomp$247$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$1191$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1191$$,"$id")},$ids$jscomp$331_shapes$jscomp$247$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$zoom$fit_to_shapes$$($ids$jscomp$331_shapes$jscomp$247$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$65$$,$cljs$cst$6705$zoomIntoView$$,"Argument should be valid shapes")}.bind(this)}});
return $obj_89263$$},$app$plugins$api$create_shape$$=function($plugin_id$jscomp$66$$,$type$jscomp$754$$){var $changes$jscomp$339_page$jscomp$198$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shape$jscomp$1192$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$type$jscomp$754$$,$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$cst$1516$y$$,0,$APP.$cljs$cst$290$width$$,
100,$APP.$cljs$cst$1527$height$$,100],null));$changes$jscomp$339_page$jscomp$198$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$changes$jscomp$339_page$jscomp$198$$),$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$339_page$jscomp$198$$)),
$shape$jscomp$1192$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$339_page$jscomp$198$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$66$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$type$jscomp$754$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$66$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1192$$))},$app$plugins$api$create_context$$=function($plugin_id$jscomp$67$$){var $obj_92521$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_92521$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"PenpotContext"}});Object.defineProperty($obj_92521$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"PenpotContext"}});Object.defineProperty($obj_92521$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$67$$}});
Object.defineProperty($obj_92521$$,"version",{enumerable:!0,get:function(){return $APP.$cljs$core$constantly$$($APP.$cljs$cst$1283$base$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)).call(this,this)}});Object.defineProperty($obj_92521$$,"root",{enumerable:!0,get:function(){return this.getRoot()}});Object.defineProperty($obj_92521$$,"currentFile",{enumerable:!0,get:function(){return this.getFile()}});Object.defineProperty($obj_92521$$,"currentPage",{enumerable:!0,get:function(){return this.getPage()}});
Object.defineProperty($obj_92521$$,"theme",{enumerable:!0,get:function(){return this.getTheme()}});Object.defineProperty($obj_92521$$,"localStorage",{enumerable:!0,get:function(){return $app$plugins$local_storage$local_storage_proxy$$($plugin_id$jscomp$67$$)}});Object.defineProperty($obj_92521$$,"selection",{enumerable:!0,get:function(){return this.getSelectedShapes()},set:function($val_selection_92595$$){return function($_$jscomp$3343_ids$jscomp$332$$,$shapes$jscomp$248$$){return $APP.$cljs$core$array_QMARK_$$($shapes$jscomp$248$$)&&
$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$248$$)?($_$jscomp$3343_ids$jscomp$332$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92479_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92479_SHARP_$$,"$id")}),$shapes$jscomp$248$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shapes$$($_$jscomp$3343_ids$jscomp$332$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6706$selection$$,$shapes$jscomp$248$$)}.call(this,this,$val_selection_92595$$)}});Object.defineProperty($obj_92521$$,"viewport",{enumerable:!0,get:function(){return this.getViewport()}});Object.defineProperty($obj_92521$$,"currentUser",{enumerable:!0,get:function(){return this.getCurrentUser()}});Object.defineProperty($obj_92521$$,"activeUsers",{enumerable:!0,get:function(){return this.getActiveUsers()}});Object.defineProperty($obj_92521$$,
"fonts",{enumerable:!0,get:function(){return $app$plugins$fonts$fonts_subcontext$$($plugin_id$jscomp$67$$)}});Object.defineProperty($obj_92521$$,"flags",{enumerable:!0,get:function(){return $app$plugins$flags$flags_proxy$$($plugin_id$jscomp$67$$)}});Object.defineProperty($obj_92521$$,"library",{enumerable:!0,get:function(){return $app$plugins$library$library_subcontext$$($plugin_id$jscomp$67$$)}});Object.defineProperty($obj_92521$$,"history",{enumerable:!0,get:function(){return $app$plugins$history$history_subcontext$$($plugin_id$jscomp$67$$)}});
Object.defineProperty($obj_92521$$,"addListener",{enumerable:!1,get:function(){return function($type$jscomp$755$$,$callback$jscomp$93$$,$props$jscomp$430$$){return $app$plugins$events$add_listener$$($type$jscomp$755$$,$plugin_id$jscomp$67$$,$callback$jscomp$93$$,$props$jscomp$430$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"removeListener",{enumerable:!1,get:function(){return function($listener_id$$){return $APP.$cljs$core$remove_watch$$($APP.$app$main$store$state$$,$listener_id$$)}.bind(this)}});
Object.defineProperty($obj_92521$$,"getViewport",{enumerable:!1,get:function(){return function(){return $app$plugins$viewport$viewport_proxy$$($plugin_id$jscomp$67$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"getFile",{enumerable:!1,get:function(){return function(){return $APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))!=null?$app$plugins$file$file_proxy$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))):
null}.bind(this)}});Object.defineProperty($obj_92521$$,"getPage",{enumerable:!1,get:function(){return function(){var $file_id$jscomp$499$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$507$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $file_id$jscomp$499$$!=null&&$page_id$jscomp$507$$!=null?$app$plugins$page$page_proxy$$($plugin_id$jscomp$67$$,
$file_id$jscomp$499$$,$page_id$jscomp$507$$):null}.bind(this)}});Object.defineProperty($obj_92521$$,"getSelectedShapes",{enumerable:!1,get:function(){return function(){var $selection$jscomp$17$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1938$selected$$],null));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$shape$shape_proxy$$,$plugin_id$jscomp$67$$)),$selection$jscomp$17$$))}.bind(this)}});Object.defineProperty($obj_92521$$,"shapesColors",{enumerable:!1,get:function(){return function($shapes$jscomp$249_shapes__$1$jscomp$41$$){if($APP.$cljs$core$array_QMARK_$$($shapes$jscomp$249_shapes__$1$jscomp$41$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,
$shapes$jscomp$249_shapes__$1$jscomp$41$$)){var $objects$jscomp$881$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$();$shapes$jscomp$249_shapes__$1$jscomp$41$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__92484_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$881$$,$p1__92484_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92483_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92483_SHARP_$$,
"$id")},$shapes$jscomp$249_shapes__$1$jscomp$41$$)]));var $file_id$jscomp$500$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shared_libs$$=$APP.$cljs$cst$1933$files$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return $app$plugins$format$format_array$$($app$plugins$format$format_color_result$$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$2656$attrs$$,$APP.$app$main$data$workspace$colors$extract_all_colors$$($shapes$jscomp$249_shapes__$1$jscomp$41$$,
$file_id$jscomp$500$$,$shared_libs$$)))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6707$shapesColors_shapes$$,$shapes$jscomp$249_shapes__$1$jscomp$41$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"replaceColor",{enumerable:!1,get:function(){return function($shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$,$new_color$jscomp$6_new_color__$1$$){$old_color$jscomp$6_old_color__$1$jscomp$2$$=
$app$plugins$parser$parse_color_data$$($old_color$jscomp$6_old_color__$1$jscomp$2$$);$new_color$jscomp$6_new_color__$1$$=$app$plugins$parser$parse_color_data$$($new_color$jscomp$6_new_color__$1$$);if($APP.$cljs$core$array_QMARK_$$($shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$)){if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_color$$,
$old_color$jscomp$6_old_color__$1$jscomp$2$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6709$replaceColor_oldColor$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$);if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_color$$,$new_color$jscomp$6_new_color__$1$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6710$replaceColor_newColor$$,$new_color$jscomp$6_new_color__$1$$);
var $file_id$jscomp$501$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shared_libs$jscomp$1$$=$APP.$cljs$cst$1933$files$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$objects$jscomp$882$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$();$shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__92486_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$882$$,
$p1__92486_SHARP_$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92485_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92485_SHARP_$$,"$id")},$shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$)]));$shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$2656$attrs$$,
$APP.$app$main$data$workspace$colors$extract_all_colors$$($shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$,$file_id$jscomp$501$$,$shared_libs$jscomp$1$$));$shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$);return $APP.$cljs$core$truth_$$($shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_color_in_selected$$($shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$,$new_color$jscomp$6_new_color__$1$$,$old_color$jscomp$6_old_color__$1$jscomp$2$$)):null}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6708$replaceColor_shapes$$,$shapes$jscomp$250_shapes__$1$jscomp$42_shapes_by_color_temp__5825__auto__$jscomp$490$$)}.bind(this)}});
Object.defineProperty($obj_92521$$,"getRoot",{enumerable:!1,get:function(){return function(){return $APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))!=null&&$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))!=null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$67$$,$APP.$app$common$uuid$zero$$):null}.bind(this)}});
Object.defineProperty($obj_92521$$,"getTheme",{enumerable:!1,get:function(){return function(){var $theme$jscomp$47$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,$APP.$cljs$cst$3208$theme$$],null));return $APP.$cljs$core$not$$($theme$jscomp$47$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$47$$,
"system")?$app$util$theme$get_system_theme$$():$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($theme$jscomp$47$$,"default")?"dark":$theme$jscomp$47$$}.bind(this)}});Object.defineProperty($obj_92521$$,"getCurrentUser",{enumerable:!1,get:function(){return function(){return $app$plugins$user$current_user_proxy$$($plugin_id$jscomp$67$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"getActiveUsers",{enumerable:!1,get:function(){return function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92488_SHARP_$$){return $app$plugins$user$active_user_proxy$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__92488_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92487_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__92487_SHARP_$$),$APP.$cljs$cst$2343$session_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))},
$APP.$cljs$core$vals$$($APP.$cljs$cst$2224$workspace_presence$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$))))))}.bind(this)}});Object.defineProperty($obj_92521$$,"uploadMediaUrl",{enumerable:!1,get:function(){return function($name$jscomp$529$$,$url$jscomp$107$$){if(typeof $name$jscomp$529$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6711$uploadMedia_name$$,$name$jscomp$529$$);if(typeof $url$jscomp$107$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,
$cljs$cst$6712$uploadMedia_url$$,$url$jscomp$107$$);var $file_id$jscomp$502$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return new Promise(function($resolve$jscomp$63$$,$reject$jscomp$44$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$63$$,$reject$jscomp$44$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$67$$,
"add-media"))},$APP.$beicon$v2$core$map$$($app$plugins$format$format_image$$,$APP.$beicon$v2$core$take$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3732$create_file_media_object_from_url$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,$name$jscomp$529$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$502$$,$APP.$cljs$cst$1991$url$$,$url$jscomp$107$$,$APP.$cljs$cst$2585$is_local$$,!0],null))))))})}.bind(this)}});Object.defineProperty($obj_92521$$,
"uploadMediaData",{enumerable:!1,get:function(){return function($name$jscomp$530$$,$data$jscomp$541$$,$mime_type$$){var $file_id$jscomp$503$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));return new Promise(function($resolve$jscomp$64$$,$reject$jscomp$45$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$64$$,$reject$jscomp$45$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$67$$,
"add-media"))},$APP.$beicon$v2$core$map$$($app$plugins$format$format_image$$,$APP.$beicon$v2$core$take$$($APP.$app$main$data$workspace$media$process_blobs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$503$$,$APP.$cljs$cst$3743$local_QMARK_$$,!1,$APP.$cljs$cst$725$name$$,$name$jscomp$530$$,$APP.$cljs$cst$3748$blobs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new Blob([$data$jscomp$541$$ instanceof
Uint8Array?$data$jscomp$541$$:$data$jscomp$541$$ instanceof ArrayBuffer?new Uint8Array($data$jscomp$541$$):$APP.$cljs$core$array_QMARK_$$($data$jscomp$541$$)?Uint8Array.from($data$jscomp$541$$):$data$jscomp$541$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$type$$($data$jscomp$541$$),Object)?Uint8Array.from(Object.values($data$jscomp$541$$)):$data$jscomp$541$$],{type:$mime_type$$})],null),$APP.$cljs$cst$3745$on_image$$,$APP.$cljs$core$identity$$,$APP.$cljs$cst$3746$on_svg$$,
$APP.$cljs$core$identity$$],null))))))})}.bind(this)}});Object.defineProperty($obj_92521$$,"group",{enumerable:!1,get:function(){return function($shapes$jscomp$251$$){var $valid_shapes_QMARK_$$=$APP.$cljs$core$array_QMARK_$$($shapes$jscomp$251$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$251$$),$file_id$jscomp$504$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$508$$=
$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$objects$jscomp$883$$=$valid_shapes_QMARK_$$?$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$504$$,$page_id$jscomp$508$$):null,$id$jscomp$1143$$=$APP.$app$common$uuid$next$$(),$ids$jscomp$333$$=$valid_shapes_QMARK_$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92489_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92489_SHARP_$$,
"$id")}),$shapes$jscomp$251$$):null,$shape_objs$$=$valid_shapes_QMARK_$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92490_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$883$$,$p1__92490_SHARP_$$)},$ids$jscomp$333$$):null;if($valid_shapes_QMARK_$$){if($shapes$jscomp$251$$.length===0)return null;if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__92493_SHARP_$$){return!$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92493_SHARP_$$,
"$page"))},$shapes$jscomp$251$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1613$group$$,"Cannot modify a page that is not currently active");if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__92494_SHARP_$$){return $APP.$cljs$core$boolean$0$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$883$$,$p1__92494_SHARP_$$))},$shape_objs$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1613$group$$,
"Cannot change the structure of a component copy");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$groups$group_shapes$$($id$jscomp$1143$$,$ids$jscomp$333$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$67$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$core$type$$]))]));
return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$67$$,$file_id$jscomp$504$$,$page_id$jscomp$508$$,$id$jscomp$1143$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6713$group_shapes$$,$shapes$jscomp$251$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"ungroup",{enumerable:!1,get:function(){return function(){function $G__93455$$($group$jscomp$66$$,$var_args$jscomp$1530$$){var $G__93459__i_rest$jscomp$22$$=null;if(arguments.length>
1){$G__93459__i_rest$jscomp$22$$=0;for(var $G__93459__a$$=Array(arguments.length-1);$G__93459__i_rest$jscomp$22$$<$G__93459__a$$.length;)$G__93459__a$$[$G__93459__i_rest$jscomp$22$$]=arguments[$G__93459__i_rest$jscomp$22$$+1],++$G__93459__i_rest$jscomp$22$$;$G__93459__i_rest$jscomp$22$$=new $APP.$cljs$core$IndexedSeq$$($G__93459__a$$,0,null)}return $G__93455__delegate$$.call(this,$group$jscomp$66$$,$G__93459__i_rest$jscomp$22$$)}function $G__93455__delegate$$($group$jscomp$65$$,$rest$jscomp$21$$){var $valid_group_QMARK_$$=
$app$plugins$shape$shape_proxy_QMARK_$$($group$jscomp$65$$),$valid_rest_QMARK_$$=$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$rest$jscomp$21$$),$shape_objs$jscomp$1_shapes$jscomp$252$$=$valid_group_QMARK_$$&&$valid_rest_QMARK_$$?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$65$$],null),$rest$jscomp$21$$):null,$file_id$jscomp$505_ids$jscomp$334$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$page_id$jscomp$509$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$objects$jscomp$884$$=$APP.$cljs$core$truth_$$($shape_objs$jscomp$1_shapes$jscomp$252$$)?$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$505_ids$jscomp$334$$,$page_id$jscomp$509$$):null;$file_id$jscomp$505_ids$jscomp$334$$=$APP.$cljs$core$truth_$$($shape_objs$jscomp$1_shapes$jscomp$252$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92495_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92495_SHARP_$$,"$id")}),$shape_objs$jscomp$1_shapes$jscomp$252$$):null;$shape_objs$jscomp$1_shapes$jscomp$252$$=$APP.$cljs$core$truth_$$($shape_objs$jscomp$1_shapes$jscomp$252$$)?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92496_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$884$$,
$p1__92496_SHARP_$$)},$file_id$jscomp$505_ids$jscomp$334$$):null;return $valid_group_QMARK_$$?$valid_rest_QMARK_$$?$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1517$$=!$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($group$jscomp$65$$,"$page"));return $or__5025__auto__$jscomp$1517$$?$or__5025__auto__$jscomp$1517$$:$APP.$cljs$core$some$$(function($p1__92497_SHARP_$$){return!$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92497_SHARP_$$,
"$page"))},$rest$jscomp$21$$)}())?$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$4973$ungroup$$,"Cannot modify a page that is not currently active"):$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__92498_SHARP_$$){return $APP.$cljs$core$boolean$0$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$884$$,$p1__92498_SHARP_$$))},$shape_objs$jscomp$1_shapes$jscomp$252$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$4973$ungroup$$,
"Cannot change the structure of a component copy"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$groups$ungroup_shapes$$($file_id$jscomp$505_ids$jscomp$334$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$4973$ungroup$$,$rest$jscomp$21$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$4973$ungroup$$,$group$jscomp$65$$)}$G__93455$$.$cljs$lang$maxFixedArity$=1;$G__93455$$.$cljs$lang$applyTo$=function($arglist__93460_rest$jscomp$23$$){var $group$jscomp$67$$=
$APP.$cljs$core$first$$($arglist__93460_rest$jscomp$23$$);$arglist__93460_rest$jscomp$23$$=$APP.$cljs$core$rest$$($arglist__93460_rest$jscomp$23$$);return $G__93455__delegate$$($group$jscomp$67$$,$arglist__93460_rest$jscomp$23$$)};$G__93455$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__93455__delegate$$;return $G__93455$$}().bind(this)}});Object.defineProperty($obj_92521$$,"createBoard",{enumerable:!1,get:function(){return function(){return $app$plugins$api$create_shape$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1611$frame$$)}.bind(this)}});
Object.defineProperty($obj_92521$$,"createRectangle",{enumerable:!1,get:function(){return function(){return $app$plugins$api$create_shape$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1616$rect$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"createEllipse",{enumerable:!1,get:function(){return function(){return $app$plugins$api$create_shape$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1422$circle$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"createPath",{enumerable:!1,get:function(){return function(){var $changes$jscomp$340_page$jscomp$199$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$shape$jscomp$1193$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1642$content$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1818$command$$,$APP.$cljs$cst$1819$move_to$$,
$APP.$cljs$cst$1435$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$cst$1516$y$$,0],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1818$command$$,$APP.$cljs$cst$1820$line_to$$,$APP.$cljs$cst$1435$params$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,100,$APP.$cljs$cst$1516$y$$,100],null)],null)],null)],null));$changes$jscomp$340_page$jscomp$199$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$changes$jscomp$340_page$jscomp$199$$),$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$340_page$jscomp$199$$)),$shape$jscomp$1193$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$340_page$jscomp$199$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$67$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$296$path$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$67$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1193$$))}.bind(this)}});Object.defineProperty($obj_92521$$,"createText",{enumerable:!1,get:function(){return function($shape$jscomp$1194_text$jscomp$157$$){if(typeof $shape$jscomp$1194_text$jscomp$157$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6714$createText$$,$shape$jscomp$1194_text$jscomp$157$$);
if($APP.$cljs$core$empty_QMARK_$$($shape$jscomp$1194_text$jscomp$157$$))return null;var $changes$jscomp$341_page$jscomp$200$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));$shape$jscomp$1194_text$jscomp$157$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$cst$1516$y$$,0,$APP.$cljs$cst$290$width$$,1,$APP.$cljs$cst$1527$height$$,1,$APP.$cljs$cst$1776$grow_type$$,$APP.$cljs$cst$2046$auto_width$$],null)),$APP.$cljs$cst$1642$content$$,$app$common$types$text$change_text$$,$shape$jscomp$1194_text$jscomp$157$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1639$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1752$fill_color$$,"#000000",$APP.$cljs$cst$1753$fill_opacity$$,1],null)],null)],null)),$APP.$cljs$cst$1899$position_data$$);$changes$jscomp$341_page$jscomp$200$$=$APP.$app$common$files$changes_builder$add_object$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$changes$jscomp$341_page$jscomp$200$$),
$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$341_page$jscomp$200$$)),$shape$jscomp$1194_text$jscomp$157$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$341_page$jscomp$200$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$67$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1593$text$$]))]));$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1194_text$jscomp$157$$)));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$67$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1194_text$jscomp$157$$))}.bind(this)}});Object.defineProperty($obj_92521$$,"createShapeFromSvg",{enumerable:!1,get:function(){return function($svg_string$jscomp$4$$){if($APP.$cljs$core$not$$($app$main$data$workspace$media$valid_svg_string_QMARK_$$($svg_string$jscomp$4$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6715$createShapeFromSvg$$,$svg_string$jscomp$4$$);var $id$jscomp$1144$$=$APP.$app$common$uuid$next$$(),
$file_id$jscomp$506$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$510$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$media$create_svg_shape$$($id$jscomp$1144$$,$svg_string$jscomp$4$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$67$$,
"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1543$svg$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$67$$,$file_id$jscomp$506$$,$page_id$jscomp$510$$,$id$jscomp$1144$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"createShapeFromSvgWithImages",{enumerable:!1,get:function(){return function($svg_string$jscomp$5$$){return new Promise(function($resolve$jscomp$65$$,$reject$jscomp$46$$){if($APP.$cljs$core$not$$($app$main$data$workspace$media$valid_svg_string_QMARK_$$($svg_string$jscomp$5$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,
$cljs$cst$6715$createShapeFromSvg$$,"Svg not valid"),$reject$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$?$reject$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$("Svg not valid"):$reject$jscomp$46$$("Svg not valid");var $id$jscomp$1145$$=$APP.$app$common$uuid$next$$(),$file_id$jscomp$507$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$511$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$media$create_svg_shape_with_images$$($file_id$jscomp$507$$,$id$jscomp$1145$$,$svg_string$jscomp$5$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),function(){var $G__93112$$=$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$67$$,$file_id$jscomp$507$$,$page_id$jscomp$511$$,$id$jscomp$1145$$);return $resolve$jscomp$65$$.$cljs$core$IFn$_invoke$arity$1$?
$resolve$jscomp$65$$.$cljs$core$IFn$_invoke$arity$1$($G__93112$$):$resolve$jscomp$65$$($G__93112$$)},$reject$jscomp$46$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$67$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1593$text$$]))]))})}.bind(this)}});Object.defineProperty($obj_92521$$,"createBoolean",{enumerable:!1,
get:function(){return function($bool_type$jscomp$11_bool_type__$1$jscomp$1$$,$ids$jscomp$335_shapes$jscomp$253$$){$bool_type$jscomp$11_bool_type__$1$jscomp$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$11_bool_type__$1$jscomp$1$$);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$bool_types$$,$bool_type$jscomp$11_bool_type__$1$jscomp$1$$)){if($APP.$cljs$core$array_QMARK_$$($ids$jscomp$335_shapes$jscomp$253$$)&&!$APP.$cljs$core$empty_QMARK_$$($ids$jscomp$335_shapes$jscomp$253$$)&&
$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$335_shapes$jscomp$253$$)){if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__92501_SHARP_$$){return!$app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92501_SHARP_$$,"$page"))},$ids$jscomp$335_shapes$jscomp$253$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6718$createBoolean$$,"Cannot modify a page that is not currently active");
$ids$jscomp$335_shapes$jscomp$253$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92502_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92502_SHARP_$$,"$id")}),$ids$jscomp$335_shapes$jscomp$253$$);var $shape_id$jscomp$193$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$bool$create_bool$$.$cljs$core$IFn$_invoke$arity$variadic$($bool_type$jscomp$11_bool_type__$1$jscomp$1$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1729$ids$$,$ids$jscomp$335_shapes$jscomp$253$$,$APP.$cljs$cst$3709$force_shape_id$$,$shape_id$jscomp$193$$])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$67$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$421$boolean$$]))]));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$67$$,
$shape_id$jscomp$193$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6717$createBoolean_shapes$$,$ids$jscomp$335_shapes$jscomp$253$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6716$createBoolean_boolType$$,$bool_type$jscomp$11_bool_type__$1$jscomp$1$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"generateMarkup",{enumerable:!1,get:function(){return function($resolved_code_shapes$jscomp$254$$,$options$jscomp$651$$){var $type$jscomp$756$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($options$jscomp$651$$,"type"),"html");return $APP.$cljs$core$array_QMARK_$$($resolved_code_shapes$jscomp$254$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$resolved_code_shapes$jscomp$254$$)?$type$jscomp$756$$==null||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["svg",
null,"html",null],null),null),$type$jscomp$756$$)?($resolved_code_shapes$jscomp$254$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$175$$,$_$jscomp$3344_shape$jscomp$1195$$,$resolved_shapes_shapes__$1$jscomp$43$$){$_$jscomp$3344_shape$jscomp$1195$$=$APP.$cljs$core$first$$($resolved_shapes_shapes__$1$jscomp$43$$);var $objects$jscomp$885$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3344_shape$jscomp$1195$$),
$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3344_shape$jscomp$1195$$));$resolved_shapes_shapes__$1$jscomp$43$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__92503_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$885$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__92503_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$885$$,
$resolved_shapes_shapes__$1$jscomp$43$$)]));return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$175$$,$APP.$app$util$code_gen$generate_formatted_markup_code$$($objects$jscomp$885$$,$type$jscomp$756$$,$resolved_shapes_shapes__$1$jscomp$43$$))},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$2051$page_id$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($s$jscomp$617$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_shape$$($s$jscomp$617$$),
$APP.$cljs$cst$2051$page_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$617$$,"$page")),$APP.$cljs$cst$1649$file_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$617$$,"$file"))}),$resolved_code_shapes$jscomp$254$$))),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$67$$,"copy-inspect-code")),$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$resolved_code_shapes$jscomp$254$$)):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6720$generateMarkup_type$$,$type$jscomp$756$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6719$generateMarkup_shapes$$,$resolved_code_shapes$jscomp$254$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"generateStyle",{enumerable:!1,get:function(){return function($resolved_styles_shapes$jscomp$255$$,$JSCompiler_temp$jscomp$2080_options$jscomp$652$$){var $type$jscomp$757$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$2080_options$jscomp$652$$,
"type"),"css"),$prelude_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$2080_options$jscomp$652$$,"withPrelude"),!1),$children_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$2080_options$jscomp$652$$,"includeChildren"),!0);if($APP.$cljs$core$array_QMARK_$$($resolved_styles_shapes$jscomp$255$$)&&
$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$resolved_styles_shapes$jscomp$255$$)){if($type$jscomp$757$$==null||$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,["css",null],null),null),$type$jscomp$757$$)){if($prelude_QMARK_$$==null||$APP.$cljs$core$boolean_QMARK_$$($prelude_QMARK_$$)){if($children_QMARK_$$==null||$APP.$cljs$core$boolean_QMARK_$$($children_QMARK_$$)){$resolved_styles_shapes$jscomp$255$$=
$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$176$$,$_$jscomp$3345_resolved_shapes$jscomp$1_shape$jscomp$1196$$,$shapes__$1$jscomp$44$$){$_$jscomp$3345_resolved_shapes$jscomp$1_shape$jscomp$1196$$=$APP.$cljs$core$first$$($shapes__$1$jscomp$44$$);var $objects$jscomp$886$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3345_resolved_shapes$jscomp$1_shape$jscomp$1196$$),$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3345_resolved_shapes$jscomp$1_shape$jscomp$1196$$));
$_$jscomp$3345_resolved_shapes$jscomp$1_shape$jscomp$1196$$=function(){var $G__93160$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$886$$,$shapes__$1$jscomp$44$$);return $APP.$cljs$core$truth_$$($children_QMARK_$$)?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__92506_SHARP_$$){return $APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$886$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__92506_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__93160$$])):
$G__93160$$}();return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$176$$,$APP.$app$util$code_gen$generate_style_code$$.$cljs$core$IFn$_invoke$arity$5$($objects$jscomp$886$$,$type$jscomp$757$$,$shapes__$1$jscomp$44$$,$_$jscomp$3345_resolved_shapes$jscomp$1_shape$jscomp$1196$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4163$with_prelude_QMARK_$$,$prelude_QMARK_$$],null)))},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$group_by$$($APP.$cljs$cst$2051$page_id$$,
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($s$jscomp$618$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_shape$$($s$jscomp$618$$),$APP.$cljs$cst$2051$page_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$618$$,"$page")),$APP.$cljs$cst$1649$file_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$618$$,
"$file"))}),$resolved_styles_shapes$jscomp$255$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$$($plugin_id$jscomp$67$$,"copy-inspect-style"));if($APP.$cljs$core$truth_$$($prelude_QMARK_$$))a:switch($type$jscomp$757$$){case "css":$JSCompiler_temp$jscomp$2080_options$jscomp$652$$="\nhtml, body {\n  margin: 0;\n  min-height: 100%;\n  min-width: 100%;\n  padding: 0;\n}\n\nbody {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  width: 100vw;\n  min-height: 100vh;\n}\n\n* {\n  box-sizing: border-box;\n}\n\n.text-node { background-clip: text !important; -webkit-background-clip: text !important; }\n\n";
break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$757$$)].join(""));}else $JSCompiler_temp$jscomp$2080_options$jscomp$652$$="";return""+($JSCompiler_temp$jscomp$2080_options$jscomp$652$$??"")+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n\n",$resolved_styles_shapes$jscomp$255$$)??"")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6724$generateStyle_includeChildren$$,$children_QMARK_$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,
$cljs$cst$6723$generateStyle_withPrelude$$,$prelude_QMARK_$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6722$generateStyle_type$$,$type$jscomp$757$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6721$generateStyle_shapes$$,$resolved_styles_shapes$jscomp$255$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"generateFontFaces",{enumerable:!1,get:function(){return function($shapes$jscomp$256$$){return new Promise(function($resolve$jscomp$66$$,
$reject$jscomp$47$$){var $all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$00$$();$all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$),$APP.$app$common$files$helpers$selected_with_children$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92507_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92507_SHARP_$$,
"$id")},$shapes$jscomp$256$$)));$all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$=$APP.$app$main$ui$shapes$text$fontfaces$shapes__GT_fonts$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__92509_SHARP_$$){return $resolve$jscomp$66$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$66$$.$cljs$core$IFn$_invoke$arity$1$($p1__92509_SHARP_$$):$resolve$jscomp$66$$($p1__92509_SHARP_$$)},$reject$jscomp$47$$,
$beicon$v2$core$first$$($APP.$beicon$v2$core$map$$(function($p1__92508_SHARP_$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$p1__92508_SHARP_$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$($APP.$app$main$fonts$fetch_font_css$$,$APP.$beicon$v2$core$from$$($all_children$jscomp$5_fonts$jscomp$46_objects$jscomp$887$$))))))})}.bind(this)}});Object.defineProperty($obj_92521$$,
"openViewer",{enumerable:!1,get:function(){return function(){var $params$jscomp$474$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1371$section$$,"interactions"],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$474$$])))}.bind(this)}});
Object.defineProperty($obj_92521$$,"createPage",{enumerable:!1,get:function(){return function(){var $file_id$jscomp$508$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$id$jscomp$1146$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$pages$create_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2051$page_id$$,
$id$jscomp$1146$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$508$$],null)),$plugin_id$jscomp$67$$));return $app$plugins$page$page_proxy$$($plugin_id$jscomp$67$$,$file_id$jscomp$508$$,$id$jscomp$1146$$)}.bind(this)}});Object.defineProperty($obj_92521$$,"openPage",{enumerable:!1,get:function(){return function($page$jscomp$201$$,$new_window$jscomp$4$$){var $id$jscomp$1147$$=$app$util$object$type_of_QMARK_$$($page$jscomp$201$$,"PageProxy")?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page$jscomp$201$$,
"$id"):typeof $page$jscomp$201$$==="string"?$APP.$app$common$uuid$parse_STAR_$$($page$jscomp$201$$):null;return $id$jscomp$1147$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6659$openPage$$,"Expected a Page object or a page UUID string"):$new_window$jscomp$4$$===!0?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2051$page_id$$,
$id$jscomp$1147$$,$APP.$cljs$cst$2467$app_DOT_main_DOT_router_SLASH_new_window$$,!0]))),Promise.resolve(null)):$app$plugins$utils$page_active_QMARK_$$($id$jscomp$1147$$)?Promise.resolve(null):new Promise(function($resolve$jscomp$67$$){$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $resolve$jscomp$67$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$67$$.$cljs$core$IFn$_invoke$arity$1$(null):$resolve$jscomp$67$$(null)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__92510_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($p1__92510_SHARP_$$),
$id$jscomp$1147$$)},$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4434$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_initialized$$),$APP.$app$main$store$stream$$))));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2051$page_id$$,$id$jscomp$1147$$])))})}.bind(this)}});
Object.defineProperty($obj_92521$$,"alignHorizontal",{enumerable:!1,get:function(){return function($ids$jscomp$336_shapes$jscomp$257$$,$direction$jscomp$34$$){var $dir$jscomp$11$$=function(){switch($direction$jscomp$34$$){case "left":return $APP.$cljs$cst$3472$hleft$$;case "center":return $APP.$cljs$cst$3470$hcenter$$;case "right":return $APP.$cljs$cst$3471$hright$$;default:return null}}();return $dir$jscomp$11$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6725$alignHorizontal_direction$$,
"Direction not valid"):$APP.$cljs$core$array_QMARK_$$($ids$jscomp$336_shapes$jscomp$257$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$336_shapes$jscomp$257$$)?($ids$jscomp$336_shapes$jscomp$257$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92511_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92511_SHARP_$$,
"$id")}),$ids$jscomp$336_shapes$jscomp$257$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($dir$jscomp$11$$,$ids$jscomp$336_shapes$jscomp$257$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6726$alignHorizontal_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_92521$$,"alignVertical",{enumerable:!1,get:function(){return function($ids$jscomp$337_shapes$jscomp$258$$,
$direction$jscomp$35$$){var $dir$jscomp$12$$=function(){switch($direction$jscomp$35$$){case "top":return $APP.$cljs$cst$3468$vtop$$;case "center":return $APP.$cljs$cst$3473$vcenter$$;case "bottom":return $APP.$cljs$cst$3469$vbottom$$;default:return null}}();return $dir$jscomp$12$$==null?$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6727$alignVertical_direction$$,"Direction not valid"):$APP.$cljs$core$array_QMARK_$$($ids$jscomp$337_shapes$jscomp$258$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,
$ids$jscomp$337_shapes$jscomp$258$$)?($ids$jscomp$337_shapes$jscomp$258$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92512_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92512_SHARP_$$,"$id")}),$ids$jscomp$337_shapes$jscomp$258$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($dir$jscomp$12$$,
$ids$jscomp$337_shapes$jscomp$258$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6728$alignVertical_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_92521$$,"distributeHorizontal",{enumerable:!1,get:function(){return function($ids$jscomp$338_shapes$jscomp$259$$){return $APP.$cljs$core$array_QMARK_$$($ids$jscomp$338_shapes$jscomp$259$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$338_shapes$jscomp$259$$)?($ids$jscomp$338_shapes$jscomp$259$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92515_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92515_SHARP_$$,"$id")}),$ids$jscomp$338_shapes$jscomp$259$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1926$horizontal$$,
$ids$jscomp$338_shapes$jscomp$259$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6729$distributeHorizontal_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_92521$$,"distributeVertical",{enumerable:!1,get:function(){return function($ids$jscomp$339_shapes$jscomp$260$$){return $APP.$cljs$core$array_QMARK_$$($ids$jscomp$339_shapes$jscomp$260$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$339_shapes$jscomp$260$$)?($ids$jscomp$339_shapes$jscomp$260$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__92516_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92516_SHARP_$$,"$id")}),$ids$jscomp$339_shapes$jscomp$260$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1927$vertical$$,$ids$jscomp$339_shapes$jscomp$260$$))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6730$distributeVertical_shapes$$,"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_92521$$,"flatten",{enumerable:!1,get:function(){return function($ids$jscomp$340_shapes$jscomp$261$$){if($APP.$cljs$core$array_QMARK_$$($ids$jscomp$340_shapes$jscomp$261$$)&&$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$ids$jscomp$340_shapes$jscomp$261$$)){var $file_id$jscomp$509$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$page_id$jscomp$512$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$));$ids$jscomp$340_shapes$jscomp$261$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92517_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92517_SHARP_$$,"$id")},$ids$jscomp$340_shapes$jscomp$261$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$convert_selected_to_path$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$ids$jscomp$340_shapes$jscomp$261$$)));return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92518_SHARP_$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$67$$,$file_id$jscomp$509$$,$page_id$jscomp$512$$,$p1__92518_SHARP_$$)},$ids$jscomp$340_shapes$jscomp$261$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$cljs$cst$6731$flatten_shapes$$,
"Not valid shapes")}.bind(this)}});Object.defineProperty($obj_92521$$,"createVariantFromComponents",{enumerable:!1,get:function(){return function($ids$jscomp$341_shapes$jscomp$262$$){if($APP.$cljs$core$not$$($APP.$cljs$core$seq$$($ids$jscomp$341_shapes$jscomp$262$$))||!$APP.$cljs$core$every_QMARK_$$($app$plugins$utils$is_main_component_proxy_QMARK_$$,$ids$jscomp$341_shapes$jscomp$262$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1619$shapes$$,$ids$jscomp$341_shapes$jscomp$262$$);
var $file_id$jscomp$510$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$first$$($ids$jscomp$341_shapes$jscomp$262$$),"$file"),$page_id$jscomp$513$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$first$$($ids$jscomp$341_shapes$jscomp$262$$),"$page");$ids$jscomp$341_shapes$jscomp$262$$=$APP.$cljs$core$vec$$($APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__92519_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__92519_SHARP_$$,
"$id")},$ids$jscomp$341_shapes$jscomp$262$$)));if($APP.$cljs$core$every_QMARK_$$(function($component$jscomp$159_id$jscomp$1148_shape$jscomp$1197$$){$component$jscomp$159_id$jscomp$1148_shape$jscomp$1197$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$510$$,$page_id$jscomp$513$$,$component$jscomp$159_id$jscomp$1148_shape$jscomp$1197$$);$component$jscomp$159_id$jscomp$1148_shape$jscomp$1197$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$510$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$159_id$jscomp$1148_shape$jscomp$1197$$));
return!$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$159_id$jscomp$1148_shape$jscomp$1197$$)},$ids$jscomp$341_shapes$jscomp$262$$)){var $variant_id$jscomp$59$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids$jscomp$341_shapes$jscomp$262$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4491$trigger$$,"plugin:combine-as-variants",
$APP.$cljs$cst$2016$variant_id$$,$variant_id$jscomp$59$$],null)),$plugin_id$jscomp$67$$));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$67$$,$variant_id$jscomp$59$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$67$$,$APP.$cljs$cst$1619$shapes$$,"One of the components is not on the same page or is already a variant")}.bind(this)}});return $obj_92521$$},$app$plugins$init_plugins_runtime$$=function(){$shadow$js$shim$module$0$0penpot$0plugins_runtime$$.initPluginsRuntime(function($plugin_id$jscomp$68$$){return $app$plugins$api$create_context$$($plugin_id$jscomp$68$$)});
return $APP.$cljs$core$truth_$$($APP.$promesa$protocols$_pending_QMARK_$$($APP.$app$plugins$register$runtime_ready_promise$$))?$APP.$promesa$protocols$_resolve_BANG_$$($APP.$app$plugins$register$runtime_ready_promise$$,!0):null},$app$plugins$initialize$$=function(){typeof $app$plugins$initialize_93449$$==="undefined"&&($app$plugins$initialize_93449$$=function($meta93450$$){this.$meta93450$=$meta93450$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$plugins$initialize_93449$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$initialize_93449$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6733$app_DOT_plugins_SLASH_initialize$$},$app$plugins$initialize_93449$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_93451$$,$meta93450__$1$$){return new $app$plugins$initialize_93449$$($meta93450__$1$$)},$app$plugins$initialize_93449$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta93450$},$app$plugins$initialize_93449$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$plugins$initialize_93449$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3347$$,$___$1$jscomp$2138$$,$stream$jscomp$114$$){$APP.$app$main$errors$is_plugin_error_QMARK_$$=$shadow$js$shim$module$0$0penpot$0plugins_runtime$$.isPluginError;return $APP.$beicon$v2$core$ignore$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$init_plugins_runtime$$,
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function(){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2340$async$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3132$app_DOT_main_DOT_features_SLASH_initialize$$),$stream$jscomp$114$$))))))});return new $app$plugins$initialize_93449$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$initialize_rasterizer$$=function(){typeof $app$main$initialize_rasterizer_93456$$==="undefined"&&($app$main$initialize_rasterizer_93456$$=function($meta93457$$){this.$meta93457$=$meta93457$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$initialize_rasterizer_93456$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_rasterizer_93456$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6736$app_DOT_main_SLASH_initialize_rasterizer$$},
$app$main$initialize_rasterizer_93456$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_93458$$,$meta93457__$1$$){return new $app$main$initialize_rasterizer_93456$$($meta93457__$1$$)},$app$main$initialize_rasterizer_93456$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta93457$},$app$main$initialize_rasterizer_93456$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_rasterizer_93456$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function(){return $app$main$rasterizer$init_BANG_$$()});return new $app$main$initialize_rasterizer_93456$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$initialize$$=function(){typeof $app$main$initialize_93462$$==="undefined"&&($app$main$initialize_93462$$=function($meta93463$$){this.$meta93463$=$meta93463$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$initialize_93462$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$initialize_93462$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6737$app_DOT_main_SLASH_initialize$$},$app$main$initialize_93462$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_93464$$,$meta93463__$1$$){return new $app$main$initialize_93462$$($meta93463__$1$$)},$app$main$initialize_93462$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta93463$},$app$main$initialize_93462$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$initialize_93462$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$3349$$,$state$jscomp$1266$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1266$$,$APP.$cljs$cst$2343$session_id$$,$APP.$app$config$session_id$$)},$app$main$initialize_93462$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$initialize_93462$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3350$$,$___$1$jscomp$2141$$,
$stream$jscomp$115$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$event$initialize$$(),$APP.$app$main$data$profile$refresh_profile$$()),$APP.$beicon$v2$core$map$$($APP.$app$main$data$auth$logged_out$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_deleted_event_QMARK_$$,$stream$jscomp$115$$)),$APP.$beicon$v2$core$map$$(function(){return $app$main$ui$routes$init_routes$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,
$stream$jscomp$115$$))),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$websocket$initialize$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$is_authenticated_QMARK_$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$profile$profile_fetched_QMARK_$$,$stream$jscomp$115$$))))),$APP.$beicon$v2$core$map$$(function(){return $app$main$initialize_rasterizer$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3132$app_DOT_main_DOT_features_SLASH_initialize$$),
$stream$jscomp$115$$))))});return new $app$main$initialize_93462$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$init$$=function($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$){globalThis.penpotStartDate=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$transit$encode_str$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$time$now$$(),null));if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("2.17.0-1784706138",
$APP.$app$config$version_tag$$))return $APP.$app$config$throttled_reload$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$984$reason$$,"stale JS: compiled\x3d2.17.0-1784706138 expected\x3d"+($APP.$app$config$version_tag$$??"")]));$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$=$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$.defaultTranslations;
$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$!=null&&($APP.$app$util$i18n$get_translations$$().en=$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$);$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$=$app$util$worker$init$$();
$APP.$app$util$worker$ask_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$3150$configure$$,$APP.$cljs$cst$3151$config$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3152$public_uri$$,$APP.$app$config$public_uri$$,$APP.$cljs$cst$3153$build_data$$,$APP.$app$config$build_date$$,
$APP.$cljs$cst$1726$version$$,$APP.$app$config$version$$],null)],null),null);$APP.$app$main$worker$instance$$=$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$;$APP.$app$util$i18n$load$$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$i18n$_STAR_current_locale_STAR_$$,"en")||$APP.$app$util$i18n$load$$("en");$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$=
$APP.$goog$dom$getElement$$("css-cursors");$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$!=null?$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$={add:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$css$add_rule$$,$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$.sheet)}:
($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("style"),$APP.$app$util$dom$set_attribute_BANG_$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"id","css-cursors"),$APP.$app$util$dom$set_attribute_BANG_$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,
"type","text/css"),$APP.$app$util$dom$append_child_BANG_$$(document.head,$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$),$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$={add:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$css$add_rule$$,$G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$.sheet)});
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"comments","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%6D%36%2E%39%20%31%32%2E%35%31%39%2D%32%2E%35%33%34%39%20%32%2E%30%32%32%32%2D%30%2E%31%37%30%33%39%2D%32%2E%38%30%32%31%63%2D%30%2E%39%34%31%37%38%2D%30%2E%35%35%39%39%36%2D%32%2E%39%33%33%2D%32%2E%32%39%34%38%2D%33%2E%33%36%32%31%2D%34%2E%37%35%31%35%2D%30%2E%34%32%39%30%37%2D%32%2E%34%35%35%31%20%32%2E%36%36%34%32%2D%34%2E%37%37%35%35%20%34%2E%32%36%33%36%2D%35%2E%36%32%38%32%20%33%2E%37%30%33%36%2D%30%2E%34%39%35%36%37%20%31%30%2E%38%36%32%2D%30%2E%31%32%31%35%39%20%39%2E%38%36%38%35%20%35%2E%33%33%36%32%2D%30%2E%39%39%34%34%34%20%35%2E%34%35%37%38%2D%35%2E%37%39%30%38%20%36%2E%31%35%36%34%2D%38%2E%30%36%35%35%20%35%2E%38%32%33%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%6D%37%2E%38%36%34%32%20%30%2E%33%38%36%39%38%63%2D%32%2E%32%36%20%30%2E%30%32%37%38%38%32%2D%34%2E%35%36%38%37%20%30%2E%38%38%36%37%39%2D%36%2E%31%30%31%34%20%32%2E%35%38%36%2D%31%2E%30%31%34%36%20%31%2E%31%30%35%32%2D%31%2E%36%31%34%38%20%32%2E%36%32%30%31%2D%31%2E%34%38%31%36%20%34%2E%31%32%39%36%20%30%2E%31%30%35%33%33%20%31%2E%37%34%38%38%20%31%2E%31%32%39%32%20%33%2E%33%33%39%36%20%32%2E%34%39%33%39%20%34%2E%33%39%32%39%20%30%2E%32%35%30%39%33%20%30%2E%31%39%38%32%37%20%30%2E%35%31%32%37%31%20%30%2E%33%38%32%36%20%30%2E%37%37%39%39%31%20%30%2E%35%35%38%34%31%20%30%2E%30%32%39%34%33%31%20%30%2E%39%38%39%30%32%2D%30%2E%30%32%36%33%33%33%20%31%2E%39%38%35%38%20%30%2E%30%37%32%38%30%32%20%32%2E%39%36%39%34%20%30%2E%31%36%33%34%32%20%30%2E%33%39%37%33%31%20%30%2E%37%33%37%33%31%20%30%2E%34%39%35%36%37%20%31%2E%30%34%33%32%20%30%2E%32%30%33%36%39%20%30%2E%38%31%32%34%34%2D%30%2E%36%36%39%39%33%20%31%2E%36%33%33%34%2D%31%2E%33%33%30%36%20%32%2E%34%34%36%36%2D%32%2E%30%30%31%33%20%30%2E%37%36%30%35%35%20%30%2E%30%37%37%34%35%20%31%2E%35%33%31%39%20%30%2E%30%33%34%38%36%20%32%2E%32%38%37%38%2D%30%2E%30%36%38%31%35%20%32%2E%31%32%38%33%2D%30%2E%33%34%36%32%20%34%2E%31%38%30%37%2D%31%2E%34%39%39%34%20%35%2E%33%37%34%39%2D%33%2E%33%32%35%37%20%30%2E%38%31%30%38%39%2D%31%2E%32%32%31%34%20%31%2E%31%37%37%32%2D%32%2E%37%36%31%38%20%30%2E%38%35%35%38%31%2D%34%2E%32%30%35%35%2D%30%2E%33%31%32%31%32%2D%31%2E%34%38%34%37%2D%31%2E%32%37%36%34%2D%32%2E%37%37%31%31%2D%32%2E%34%39%36%32%2D%33%2E%36%34%34%37%2D%31%2E%35%31%36%34%2D%31%2E%31%30%33%36%2D%33%2E%34%31%30%31%2D%31%2E%36%33%30%33%2D%35%2E%32%37%35%38%2D%31%2E%35%39%34%37%7A%6D%30%2E%31%37%34%32%36%20%31%2E%33%30%38%39%63%31%2E%38%36%39%36%20%30%2E%30%30%36%39%37%20%33%2E%38%30%32%37%20%30%2E%36%35%36%37%37%20%35%2E%31%32%31%37%20%32%2E%30%33%30%37%20%30%2E%38%30%33%39%32%20%30%2E%38%32%32%35%31%20%31%2E%33%32%38%32%20%31%2E%39%35%33%33%20%31%2E%32%36%38%36%20%33%2E%31%30%37%32%2D%30%2E%30%32%34%37%38%20%31%2E%33%30%38%39%2D%30%2E%37%32%36%34%37%20%32%2E%35%33%36%34%2D%31%2E%36%39%36%31%20%33%2E%33%38%39%32%2D%31%2E%33%38%34%38%20%31%2E%32%33%31%34%2D%33%2E%32%37%39%32%20%31%2E%38%32%31%36%2D%35%2E%31%31%30%31%20%31%2E%37%32%30%39%2D%30%2E%33%31%35%39%39%20%30%2E%30%31%30%38%34%2D%30%2E%36%33%39%37%33%2D%30%2E%30%38%38%32%39%2D%30%2E%39%34%36%34%32%2D%30%2E%30%34%39%35%37%2D%30%2E%35%39%38%36%38%20%30%2E%34%38%37%31%35%2D%31%2E%31%39%36%36%20%30%2E%39%37%34%33%31%2D%31%2E%37%39%33%37%20%31%2E%34%36%32%32%2D%30%2E%30%31%35%34%39%2D%30%2E%36%38%39%33%2D%30%2E%30%31%32%33%39%32%2D%31%2E%33%37%39%34%2D%30%2E%30%32%30%31%33%37%2D%32%2E%30%36%39%34%2D%31%2E%33%36%37%37%2D%30%2E%36%38%39%32%39%2D%32%2E%36%30%39%33%2D%31%2E%38%30%34%36%2D%33%2E%30%38%37%31%2D%33%2E%32%39%33%39%2D%30%2E%34%31%32%30%33%2D%31%2E%32%35%34%37%2D%30%2E%31%37%35%30%33%2D%32%2E%37%30%36%38%20%30%2E%36%34%35%31%35%2D%33%2E%37%35%36%33%20%31%2E%32%39%31%31%2D%31%2E%37%33%37%32%20%33%2E%35%31%2D%32%2E%35%35%31%39%20%35%2E%36%31%38%31%2D%32%2E%35%34%30%33%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 2 20, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"create-artboard","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%34%2D%31%76%35%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%35%20%34%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%76%2D%32%7A%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%33%2E%35%2D%31%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%39%20%39%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"create-ellipse","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%34%61%33%20%33%20%30%20%31%31%2D%36%20%30%20%33%20%33%20%30%20%30%31%36%20%30%7A%6D%2D%31%20%30%61%32%20%32%20%30%20%31%31%2D%34%20%30%20%32%20%32%20%30%20%30%31%34%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%36%2D%33%2E%35%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%4D%31%35%2E%35%20%34%61%33%2E%35%20%33%2E%35%20%30%20%31%31%2D%37%20%30%20%33%2E%35%20%33%2E%35%20%30%20%30%31%37%20%30%7A%4D%31%32%20%37%61%33%20%33%20%30%20%31%30%30%2D%36%20%33%20%33%20%30%20%30%30%30%20%36%7A%6D%30%2D%31%61%32%20%32%20%30%20%31%30%30%2D%34%20%32%20%32%20%30%20%30%30%30%20%34%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"create-polygon","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%73%74%72%6F%6B%65%3D%27%23%66%66%66%27%20%73%74%72%6F%6B%65%2D%77%69%64%74%68%3D%27%2E%35%27%20%64%3D%27%4D%31%32%2E%32%2E%39%4C%31%32%20%2E%35%6C%2D%2E%33%2E%34%2D%33%2E%34%20%36%2D%2E%32%2E%33%48%31%35%2E%39%6C%2D%2E%33%2D%2E%33%2D%33%2E%34%2D%36%7A%6D%31%20%34%2E%38%68%2D%32%2E%35%4C%31%32%20%33%2E%35%6C%31%2E%33%20%32%2E%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"create-rectangle","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%39%20%37%56%31%68%36%76%36%48%39%7A%6D%31%2D%35%68%34%76%34%68%2D%34%56%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%38%2E%35%2E%35%68%37%76%37%68%2D%37%76%2D%37%7A%6D%2D%33%20%33%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%34%2D%37%68%34%76%34%68%2D%34%56%32%7A%6D%2E%35%20%33%2E%35%68%33%76%2D%33%68%2D%33%76%33%7A%4D%39%20%37%56%31%68%36%76%36%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"create-shape","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%37%20%37%56%31%68%31%76%36%68%36%76%31%48%38%76%36%48%37%56%38%48%31%56%37%68%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%36%2E%35%2E%35%68%32%76%36%68%36%76%32%68%2D%36%76%36%68%2D%32%76%2D%36%68%2D%36%76%2D%32%68%36%76%2D%36%7A%4D%37%20%37%48%31%76%31%68%36%76%36%68%31%56%38%68%36%56%37%48%38%56%31%48%37%76%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"duplicate","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%35%2E%31%20%30%4C%31%36%20%31%30%2E%39%48%39%2E%32%4C%35%2E%31%20%31%35%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%35%2E%37%20%31%2E%35%6C%38%2E%37%20%38%2E%36%48%39%6C%2D%33%2E%33%20%33%2E%34%7A%6D%33%20%37%2E%39%68%34%4C%36%2E%35%20%33%2E%33%76%38%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%30%20%30%76%31%35%6C%34%2E%31%2D%34%2E%31%68%32%2E%34%76%2E%38%6C%2E%38%2D%2E%38%68%33%2E%36%4C%39%2E%33%20%39%2E%35%68%33%2E%34%4C%36%2E%35%20%33%2E%33%76%33%2E%32%7A%6D%31%20%32%2E%33%6C%35%2E%34%20%35%2E%35%76%32%2E%31%48%33%2E%37%4C%31%20%31%32%2E%37%7A%6D%37%2E%34%20%37%2E%34%6C%2E%32%2E%32%68%2D%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%32%2E%37%56%32%2E%33%6C%37%2E%37%20%37%2E%36%68%2D%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"hand","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%33%2E%35%20%35%2E%33%38%76%2D%33%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%2D%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%38%2D%2E%32%34%20%31%2E%32%34%2D%2E%31%35%20%32%20%2E%35%76%37%2E%35%63%30%20%33%2D%33%20%34%2D%33%20%34%68%2D%37%73%2D%33%2D%31%2E%31%35%2D%33%2D%34%76%2D%35%2E%35%63%2E%38%32%2D%2E%38%36%20%31%2E%32%35%2D%2E%39%20%32%2D%2E%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%30%63%2D%2E%37%33%20%30%2D%31%2E%36%2E%32%39%2D%31%2E%39%38%20%31%2E%30%34%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2E%31%37%63%2D%2E%33%33%2D%2E%31%33%2D%2E%36%39%2D%2E%32%2D%31%2E%30%32%2D%2E%32%2D%2E%37%33%20%30%2D%31%2E%36%2E%33%2D%31%2E%39%38%20%31%2E%30%35%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2E%32%33%56%34%2E%36%61%31%2E%34%39%20%31%2E%34%39%20%30%20%30%30%2D%2E%35%39%20%30%63%2D%2E%34%37%2E%31%2D%2E%38%37%2E%34%33%2D%31%2E%33%2E%38%38%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%31%34%2E%33%35%76%35%2E%35%39%63%30%20%31%2E%36%35%2E%38%37%20%32%2E%38%20%31%2E%37%20%33%2E%35%61%36%2E%35%34%20%36%2E%35%34%20%30%20%30%30%31%2E%35%32%2E%39%37%6C%2E%31%2E%30%35%2E%30%34%2E%30%31%68%2E%30%31%61%2E%35%2E%35%20%30%20%30%30%2E%31%38%2E%30%34%68%37%2E%31%31%63%2E%30%36%20%30%20%2E%31%31%20%30%20%2E%31%37%2D%2E%30%33%68%2E%30%31%6C%2E%30%33%2D%2E%30%31%2E%31%32%2D%2E%30%35%41%35%2E%34%20%35%2E%34%20%30%20%30%30%31%33%2E%34%20%31%35%63%2E%38%34%2D%2E%37%20%31%2E%37%31%2D%31%2E%38%34%20%31%2E%37%31%2D%33%2E%35%36%56%33%2E%38%61%2E%35%2E%35%20%30%20%30%30%2D%2E%31%38%2D%2E%33%39%20%33%20%33%20%30%20%30%30%2D%31%2E%32%2D%2E%37%20%31%2E%39%35%20%31%2E%39%35%20%30%20%30%30%2D%2E%36%35%2D%2E%30%34%76%2D%2E%34%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2D%2E%32%32%63%2D%2E%33%38%2D%2E%37%35%2D%31%2E%32%35%2D%31%2E%30%34%2D%31%2E%39%38%2D%31%2E%30%34%2D%2E%33%33%20%30%2D%2E%37%2E%30%36%2D%31%2E%30%32%2E%32%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2D%2E%31%38%43%39%2E%36%2E%33%20%38%2E%37%33%20%30%20%38%20%30%7A%6D%30%20%31%2E%30%32%63%2E%34%38%20%30%20%2E%38%35%2E%31%37%20%31%2E%30%32%2E%33%39%76%33%2E%39%32%68%31%2E%30%31%56%32%2E%34%35%63%2E%31%36%2D%2E%32%33%2E%35%32%2D%2E%34%32%20%31%2E%30%32%2D%2E%34%32%2E%34%38%20%30%20%2E%38%34%2E%31%38%20%31%2E%30%31%2E%34%76%32%2E%39%68%31%2E%30%32%56%33%2E%37%31%63%2E%31%36%2D%2E%30%32%2E%33%2D%2E%30%32%2E%34%20%30%20%2E%31%37%2E%30%34%2E%33%35%2E%31%34%2E%36%32%2E%33%34%76%37%2E%33%38%63%30%20%31%2E%33%33%2D%2E%36%36%20%32%2E%32%31%2D%31%2E%33%35%20%32%2E%37%38%61%34%2E%39%38%20%34%2E%39%38%20%30%20%30%31%2D%31%2E%32%35%2E%37%36%6C%2D%2E%30%34%2E%30%31%48%34%2E%35%32%61%34%2E%37%35%20%34%2E%37%35%20%30%20%30%31%2D%31%2E%32%37%2D%2E%38%32%20%33%2E%35%35%20%33%2E%35%35%20%30%20%30%31%2D%31%2E%33%35%2D%32%2E%37%33%56%36%2E%30%35%63%2E%33%32%2D%2E%33%31%2E%35%31%2D%2E%34%31%2E%36%35%2D%2E%34%34%2E%30%38%2D%2E%30%32%2E%32%20%30%20%2E%33%37%2E%30%36%76%32%2E%37%31%68%31%2E%30%32%56%32%2E%34%33%63%2E%31%36%2D%2E%32%32%2E%35%33%2D%2E%34%20%31%2E%30%31%2D%2E%34%2E%35%20%30%20%2E%38%36%2E%31%39%20%31%2E%30%32%2E%34%32%76%32%2E%38%38%68%31%2E%30%31%56%31%2E%34%31%63%2E%31%37%2D%2E%32%32%2E%35%34%2D%2E%34%20%31%2E%30%32%2D%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"move-pointer","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%36%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%7A%4D%38%20%31%31%76%33%2E%32%7A%27%20%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%31%4C%36%20%33%6C%2E%35%2E%35%20%31%2D%31%56%37%68%2D%35%6C%31%2D%31%2D%2E%35%2D%2E%35%2D%32%20%32%20%32%20%32%20%2E%35%2D%2E%35%2D%31%2D%31%68%35%76%35%2E%35%6C%2D%31%2D%31%2D%2E%35%2E%35%20%32%20%32%20%32%2D%32%2D%2E%35%2D%2E%35%2D%31%20%31%56%38%68%35%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%68%2D%35%56%32%2E%35%6C%31%20%31%4C%31%30%20%33%20%38%20%31%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%35%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%20%38%20%2E%33%7A%4D%38%20%31%6C%32%20%32%2D%2E%35%2E%35%2D%31%2D%31%56%37%68%35%6C%2D%31%2D%31%20%2E%35%2D%2E%35%20%32%20%32%2D%32%20%32%2D%2E%35%2D%2E%35%20%31%2D%31%68%2D%35%76%35%2E%35%6C%31%2D%31%20%2E%35%2E%35%2D%32%20%32%2D%32%2D%32%20%2E%35%2D%2E%35%20%31%20%31%56%38%68%2D%35%6C%31%20%31%2D%2E%35%2E%35%2D%32%2D%32%20%32%2D%32%20%2E%35%2E%35%2D%31%20%31%68%35%56%32%2E%35%6C%2D%31%20%31%4C%36%20%33%6C%32%2D%32%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"pen","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%63%2D%2E%37%2E%32%20%30%20%2E%33%2D%2E%37%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%6C%2D%2E%33%2E%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%20%2E%37%2D%2E%37%20%32%2E%33%20%32%2E%33%20%32%2E%36%2D%32%2E%36%4C%31%32%20%39%2E%34%6C%2E%37%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%32%2E%33%20%31%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%63%30%20%2E%38%20%30%20%31%2E%35%2D%2E%33%20%32%2E%31%6C%2D%2E%38%2D%2E%38%4C%31%32%20%38%63%30%2D%32%2E%39%2D%32%2D%34%2E%36%2D%35%2D%35%61%34%36%2E%34%20%34%36%2E%34%20%30%20%30%31%2D%35%2D%31%6C%2E%33%20%31%2E%31%63%2E%32%2E%39%2E%35%20%32%2E%32%2E%37%20%33%2E%39%2E%34%20%33%20%32%2E%31%20%35%20%35%20%35%68%31%2E%33%6C%2E%38%2E%37%63%2D%2E%36%2E%32%2D%31%2E%33%2E%33%2D%32%2E%31%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%2E%36%20%31%2E%36%63%2E%32%2D%2E%31%2E%36%2D%2E%31%2E%38%20%30%6C%35%20%35%61%2E%35%2E%35%20%30%20%31%31%2D%2E%38%2E%38%6C%2D%35%2D%35%61%2E%35%2E%35%20%30%20%30%31%30%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%37%2E%35%20%39%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"pen-node","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'36px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%37%20%30%2D%2E%30%30%31%2D%2E%31%30%31%2E%36%39%39%2D%2E%33%30%31%6C%33%20%33%20%34%2D%34%2E%31%2D%33%2D%33%20%2E%33%2D%2E%36%63%30%2D%31%2E%37%2D%2E%36%2D%33%2E%30%39%39%2D%31%2E%38%2D%34%2E%30%39%39%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%33%2E%36%32%39%20%31%33%2E%38%30%38%61%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%20%36%2E%39%37%39%20%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%2D%36%2E%39%37%39%7A%6D%30%20%31%2E%38%36%36%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%31%2E%30%30%32%20%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%31%2D%2E%30%30%32%2D%33%2E%32%34%38%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%33%33%33%20%30%20%2E%36%33%39%2D%2E%30%32%38%2E%39%33%37%2D%2E%30%36%33%6C%32%2E%37%36%32%20%32%2E%37%36%32%20%34%2D%34%2E%31%2D%32%2E%37%32%39%2D%32%2E%37%32%38%63%2E%30%31%38%2D%2E%32%38%2E%30%33%2D%2E%35%36%32%2E%30%33%2D%2E%38%37%31%20%30%2D%31%2E%37%2D%2E%36%30%31%2D%33%2E%31%2D%31%2E%38%30%31%2D%34%2E%31%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%32%2E%35%33%37%20%31%2E%37%33%36%63%31%2E%33%31%2E%33%30%36%20%32%2E%36%33%2E%35%37%33%20%33%2E%39%36%33%2E%37%36%34%20%33%20%2E%34%20%35%20%32%2E%31%20%35%20%35%6C%2D%2E%31%20%31%2E%33%2E%31%2E%31%2E%36%39%39%2E%37%20%31%2E%36%30%32%20%31%2E%35%39%39%2D%32%2E%36%30%32%20%32%2E%36%30%32%2D%31%2E%36%2D%31%2E%36%30%32%2D%2E%30%30%34%2D%2E%30%30%34%2D%2E%36%39%35%2D%2E%36%39%35%2D%2E%30%34%37%2E%30%34%37%2D%2E%30%35%32%2D%2E%30%34%37%48%38%2E%32%31%39%63%2D%32%2E%39%20%30%2D%34%2E%36%2D%32%2D%35%2D%35%2D%2E%32%2D%31%2E%37%2D%2E%35%2D%32%2E%39%39%39%2D%2E%37%2D%33%2E%38%39%39%4C%36%2E%33%33%20%37%2E%31%33%63%2D%2E%33%34%2E%38%38%34%2E%31%32%20%32%2E%30%38%39%20%31%2E%33%38%39%20%32%2E%30%38%39%20%32%20%30%20%32%2D%33%20%30%2D%33%2D%2E%32%32%34%20%30%2D%2E%34%31%39%2E%30%34%2D%2E%35%39%32%2E%31%30%37%6C%2D%33%2E%38%37%31%2D%33%2E%38%37%7A%4D%34%2E%33%34%38%20%31%34%2E%39%35%61%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%20%36%2E%31%33%35%20%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%2D%36%2E%31%33%35%7A%6D%30%20%31%2E%30%32%34%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%30%20%34%2E%30%39%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%30%2D%34%2E%30%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"pencil","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%6D%30%20%31%2E%35%4C%31%32%2E%35%20%33%20%32%2E%36%20%31%33%6C%2D%31%2E%31%2D%31%2E%32%20%39%2E%39%2D%31%30%7A%6D%32%20%32%4C%31%34%2E%35%20%35%20%34%2E%36%20%31%35%6C%2D%31%2E%32%2D%31%2E%32%20%31%30%2D%31%30%7A%4D%31%20%31%32%2E%39%6C%32%2E%34%20%32%2E%33%48%31%76%2D%32%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"picker","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%30%37%20%31%33%2E%30%37%36%76%32%2E%34%30%31%6C%32%2E%32%32%34%2E%30%32%35%20%37%2E%38%36%2D%37%2E%34%30%35%73%2D%2E%30%35%2D%2E%38%38%35%2D%2E%32%35%33%2D%31%2E%30%38%37%63%2D%2E%32%30%32%2D%2E%32%30%32%2D%32%2E%32%35%2D%31%2E%37%34%34%2D%32%2E%32%35%2D%31%2E%37%34%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%2E%33%34%33%20%31%35%2E%39%37%34%61%2E%35%31%34%2E%35%31%34%20%30%20%30%31%2D%2E%33%31%37%2D%2E%33%32%31%63%2D%2E%30%32%33%2D%2E%30%37%2D%2E%30%32%36%2D%2E%32%33%2D%2E%30%32%36%2D%31%2E%34%33%20%30%2D%31%2E%34%36%38%2D%2E%30%30%31%2D%31%2E%34%34%35%2E%30%39%2D%31%2E%35%38%36%2E%30%32%2D%2E%30%33%32%20%31%2E%37%30%33%2D%31%2E%37%32%34%20%33%2E%37%34%2D%33%2E%37%35%39%61%35%39%36%2E%38%30%35%20%35%39%36%2E%38%30%35%20%30%20%30%30%33%2E%37%2D%33%2E%37%31%36%63%30%2D%2E%30%30%39%2D%2E%33%36%37%2D%2E%33%38%34%2D%2E%38%31%36%2D%2E%38%33%33%61%32%39%2E%39%20%32%39%2E%39%20%30%20%30%31%2D%2E%38%31%37%2D%2E%38%33%33%63%30%2D%2E%30%31%2E%34%37%34%2D%2E%34%39%20%31%2E%30%35%34%2D%31%2E%30%37%6C%31%2E%30%35%33%2D%31%2E%30%35%33%2E%39%34%38%2E%39%34%36%2E%39%34%37%2E%39%34%37%20%31%2E%34%31%37%2D%31%2E%34%31%33%43%31%32%2E%33%36%36%2E%38%30%36%20%31%32%2E%37%36%35%2E%34%31%38%20%31%32%2E%38%35%36%2E%33%35%37%63%2E%32%33%38%2D%2E%31%36%31%2E%35%32%2D%2E%32%38%2E%37%39%32%2D%2E%33%33%34%2E%31%37%2D%2E%30%33%34%2E%35%38%36%2D%2E%30%33%2E%37%36%2E%30%30%38%2E%38%30%31%2E%31%37%33%20%31%2E%34%31%2E%37%39%34%20%31%2E%35%37%20%31%2E%36%30%33%2E%30%33%2E%31%35%2E%30%33%2E%35%36%39%20%30%20%2E%37%31%38%61%32%2E%32%32%37%20%32%2E%32%32%37%20%30%20%30%31%2D%2E%33%33%34%2E%37%39%33%63%2D%2E%30%36%31%2E%30%39%2D%2E%34%35%2E%34%39%2D%31%2E%34%39%36%20%31%2E%35%34%4C%31%32%2E%37%33%34%20%36%2E%31%6C%2E%39%34%37%2E%39%34%38%2E%39%34%37%2E%39%34%37%2D%31%2E%30%35%33%20%31%2E%30%35%34%63%2D%2E%35%38%2E%35%38%2D%31%2E%30%36%31%20%31%2E%30%35%34%2D%31%2E%30%37%20%31%2E%30%35%34%2D%2E%30%31%20%30%2D%2E%33%38%34%2D%2E%33%36%38%2D%2E%38%33%33%2D%2E%38%31%37%2D%2E%34%35%2D%2E%34%35%2D%2E%38%32%34%2D%2E%38%31%37%2D%2E%38%33%34%2D%2E%38%31%37%2D%2E%30%30%39%20%30%2D%31%2E%36%38%20%31%2E%36%36%36%2D%33%2E%37%31%36%20%33%2E%37%30%31%61%34%39%33%2E%30%39%33%20%34%39%33%2E%30%39%33%20%30%20%30%31%2D%33%2E%37%35%39%20%33%2E%37%34%63%2D%2E%31%34%2E%30%39%31%2D%2E%31%31%37%2E%30%39%2D%31%2E%35%39%2E%30%38%39%2D%31%2E%31%38%37%20%30%2D%31%2E%33%36%36%2D%2E%30%30%34%2D%31%2E%34%33%2D%2E%30%32%37%7A%6D%36%2E%30%32%34%2D%34%2E%36%33%33%61%35%39%32%2E%37%32%33%20%35%39%32%2E%37%32%33%20%30%20%30%30%33%2E%36%36%33%2D%33%2E%36%38%63%30%2D%2E%30%32%2D%31%2E%36%37%2D%31%2E%36%39%2D%31%2E%36%39%2D%31%2E%36%39%2D%2E%30%31%20%30%2D%31%2E%36%36%36%20%31%2E%36%34%38%2D%33%2E%36%38%20%33%2E%36%36%33%4C%2E%39%39%36%20%31%33%2E%32%39%37%76%2E%38%33%34%63%30%20%2E%36%32%37%2E%30%30%35%2E%38%33%39%2E%30%32%2E%38%35%34%2E%30%31%35%2E%30%31%34%2E%32%32%37%2E%30%32%2E%38%35%34%2E%30%32%68%2E%38%33%33%6C%33%2E%36%36%34%2D%33%2E%36%36%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"pointer-inner","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%20%31%34%2E%36%56%33%2E%34%6C%38%2E%32%20%38%2E%32%48%34%6C%2D%33%20%33%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%30%20%31%37%56%31%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%4C%30%20%31%37%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%33%2E%34%76%31%31%2E%32%6C%33%2D%33%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"pointer-move","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'42px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%31%37%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%20%31%2E%32%36%33%20%31%2E%32%36%33%2E%35%32%36%2D%2E%35%32%36%76%31%2E%32%36%33%68%2D%2E%39%34%37%6C%2E%35%32%36%2D%2E%35%32%37%4C%36%2E%32%20%31%37%2E%32%32%32%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%4C%36%2E%32%20%32%32%2E%39%30%37%6C%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%36%2D%2E%35%32%36%68%2E%39%34%37%76%31%2E%34%37%34%6C%2D%2E%35%32%36%2D%2E%36%33%32%2D%31%2E%32%36%33%20%31%2E%33%36%39%20%32%2E%38%34%32%20%32%2E%38%34%32%20%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%37%2E%35%32%37%76%2D%31%2E%34%37%34%68%2E%39%34%38%6C%2D%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%34%20%31%2E%32%36%34%20%32%2E%38%34%32%2D%32%2E%38%34%33%2D%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%34%20%31%2E%32%36%33%2E%35%32%37%2E%35%32%37%68%2D%2E%39%34%38%76%2D%31%2E%32%36%33%6C%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%33%2D%31%2E%32%36%33%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%39%30%37%6C%2D%32%2E%31%30%35%20%32%2E%31%30%35%2E%35%32%36%2E%35%32%36%20%31%2E%30%35%32%2D%31%2E%30%35%33%76%33%2E%30%35%33%48%35%2E%36%37%34%6C%31%2E%30%35%32%2D%31%2E%30%35%33%2D%2E%35%32%36%2D%2E%35%32%36%2D%32%2E%31%30%35%20%32%2E%31%30%35%4C%36%2E%32%20%32%32%2E%31%37%6C%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%32%2D%31%2E%30%35%32%48%38%2E%34%31%76%33%2E%32%36%33%4C%37%2E%33%35%38%20%32%32%2E%38%6C%2D%2E%35%32%36%2E%35%32%37%20%32%2E%31%30%35%20%32%2E%31%30%35%20%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%33%20%31%2E%30%35%33%56%32%30%2E%35%39%48%31%32%2E%32%6C%2D%31%2E%30%35%33%20%31%2E%30%35%32%2E%35%32%37%2E%35%32%37%20%32%2E%31%30%35%2D%32%2E%31%30%36%2D%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%37%2E%35%32%36%20%31%2E%30%35%33%20%31%2E%30%35%33%48%39%2E%34%36%33%76%2D%33%2E%30%35%33%6C%31%2E%30%35%33%20%31%2E%30%35%33%2E%35%32%36%2D%2E%35%32%36%7A%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"pointer-node","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'32px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%39%2E%31%34%33%20%31%39%2E%34%32%39%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%30%30%2D%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%30%30%20%33%2E%32%34%38%7A%6D%33%2E%34%38%39%2D%31%2E%36%32%34%61%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%31%31%2D%36%2E%39%37%38%20%30%20%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%30%31%36%2E%39%37%38%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%31%32%2E%32%31%20%31%37%2E%38%30%35%61%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%31%31%2D%36%2E%31%33%35%20%30%20%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%30%31%36%2E%31%33%35%20%30%7A%6D%2D%31%2E%30%32%32%20%30%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%2D%34%2E%30%39%20%30%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%34%2E%30%39%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"resize-alt","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%2E%35%2E%35%76%34%2E%39%68%2D%31%2E%38%56%33%2E%36%4C%39%2E%32%20%38%6C%34%2E%35%20%34%2E%34%76%2D%31%2E%38%68%31%2E%38%76%34%2E%39%68%2D%34%2E%39%76%2D%31%2E%38%68%31%2E%38%4C%38%20%39%2E%32%6C%2D%34%2E%34%20%34%2E%35%68%31%2E%38%76%31%2E%38%48%2E%35%76%2D%34%2E%39%68%31%2E%38%76%31%2E%38%4C%36%2E%38%20%38%20%32%2E%33%20%33%2E%35%76%32%48%2E%35%76%2D%35%68%34%2E%39%76%31%2E%38%48%33%2E%35%4C%38%20%36%2E%38%6C%34%2E%34%2D%34%2E%35%68%2D%31%2E%38%56%2E%35%68%34%2E%39%7A%6D%2D%31%2E%39%20%31%2E%33%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"zoom","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%34%39%36%34%39%30%35%2C%30%2E%30%33%33%32%31%39%31%31%20%30%2E%30%30%37%34%34%2C%30%2E%30%30%37%34%35%33%34%20%43%20%34%2E%36%39%39%39%39%32%37%2C%30%2E%30%33%31%30%39%32%20%32%2E%39%34%35%30%35%32%32%2C%30%2E%38%33%30%37%34%37%36%34%20%31%2E%37%34%38%36%31%39%36%2C%32%2E%31%36%34%39%31%36%33%20%30%2E%35%36%31%38%32%38%38%38%2C%33%2E%34%32%36%30%30%33%39%20%2D%30%2E%30%34%39%37%31%31%33%35%2C%35%2E%31%35%36%33%33%38%20%30%2E%30%34%31%37%37%31%31%35%2C%36%2E%38%36%38%30%36%36%31%20%30%2E%31%30%32%38%38%36%37%39%2C%38%2E%37%36%30%35%39%39%37%20%31%2E%30%36%33%37%35%33%39%2C%31%30%2E%35%35%36%38%31%34%20%32%2E%35%34%36%31%34%32%36%2C%31%31%2E%37%31%32%38%33%33%20%63%20%30%2E%30%30%31%39%32%2C%30%2E%30%30%31%35%20%30%2E%30%30%35%35%33%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%34%35%2C%30%20%31%2E%32%39%32%32%33%36%35%2C%31%2E%30%32%33%32%35%34%20%32%2E%39%37%36%36%34%30%37%2C%31%2E%35%31%31%32%35%34%20%34%2E%36%31%33%37%30%38%35%2C%31%2E%33%34%39%30%38%31%20%31%2E%31%31%36%31%30%39%34%2C%2D%30%2E%30%37%37%35%33%20%32%2E%31%30%37%31%37%31%35%2C%2D%30%2E%35%38%30%35%31%39%20%33%2E%30%31%31%32%30%38%39%2C%2D%31%2E%31%36%32%37%34%34%20%31%2E%32%39%36%38%37%33%2C%31%2E%31%37%34%38%34%36%20%32%2E%37%38%34%35%35%2C%32%2E%37%30%33%30%36%31%20%33%2E%39%38%30%31%36%32%2C%33%2E%38%30%38%37%33%31%20%6C%20%30%2E%30%32%39%38%2C%30%2E%30%32%32%33%36%20%30%2E%30%33%37%32%38%2C%30%2E%30%32%32%33%36%20%63%20%30%2E%37%30%30%37%31%35%2C%30%2E%34%36%33%35%38%38%20%31%2E%36%35%37%32%34%33%2C%2D%30%2E%30%31%33%30%34%20%31%2E%36%39%39%33%38%38%2C%2D%30%2E%38%35%37%31%35%36%20%30%2E%30%32%38%33%38%2C%2D%30%2E%33%35%32%32%31%37%20%2D%30%2E%31%33%36%30%33%32%2C%2D%30%2E%36%35%39%31%39%39%20%2D%30%2E%32%39%30%36%38%36%2C%2D%30%2E%38%34%32%32%34%33%20%2D%30%2E%31%35%38%37%34%35%2C%2D%30%2E%31%38%37%38%38%38%20%2D%30%2E%33%30%38%36%35%31%2C%2D%30%2E%33%31%32%33%34%31%20%2D%30%2E%33%37%32%36%37%34%2C%2D%30%2E%33%38%37%35%38%32%20%6C%20%2D%30%2E%30%30%37%34%2C%2D%30%2E%30%30%37%34%20%2D%30%2E%30%31%34%39%32%2C%2D%30%2E%30%31%34%39%32%20%43%20%31%34%2E%31%31%36%32%34%2C%31%32%2E%34%37%37%39%34%20%31%32%2E%39%37%30%32%32%35%2C%31%31%2E%33%35%32%31%39%36%20%31%31%2E%38%34%30%36%34%2C%31%30%2E%32%31%34%36%38%32%20%31%32%2E%35%32%37%35%39%35%2C%39%2E%31%37%36%30%30%33%37%20%31%33%2E%30%39%39%38%31%36%2C%38%2E%30%31%30%31%30%38%37%20%31%33%2E%31%30%30%32%38%2C%36%2E%37%32%36%34%35%30%31%20%31%33%2E%31%33%34%36%33%31%2C%35%2E%36%35%32%31%33%37%32%20%31%32%2E%39%30%37%35%31%39%2C%34%2E%35%36%30%30%35%36%20%31%32%2E%33%39%39%36%35%32%2C%33%2E%35%39%35%39%38%35%37%20%31%31%2E%34%31%35%30%31%31%2C%31%2E%36%35%37%39%31%30%34%20%39%2E%34%34%35%37%33%33%38%2C%30%2E%32%36%30%36%33%30%36%39%20%37%2E%32%35%36%37%34%35%39%2C%30%2E%30%36%33%30%33%33%30%35%20%68%20%2D%30%2E%30%30%37%34%34%20%43%20%37%2E%31%37%30%32%35%31%2C%30%2E%30%35%35%34%37%31%39%37%20%37%2E%30%38%39%38%36%30%34%2C%30%2E%30%36%30%32%39%31%31%36%20%37%2E%30%31%30%37%38%31%2C%30%2E%30%35%35%35%37%39%35%38%20%56%20%30%2E%30%33%33%32%31%39%31%31%20%48%20%36%2E%35%31%31%33%39%37%33%20%63%20%2D%30%2E%30%30%34%39%32%2C%36%2E%30%39%38%65%2D%35%20%2D%30%2E%30%31%2C%2D%37%2E%31%31%34%65%2D%35%20%2D%30%2E%30%31%34%39%32%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%34%34%2C%31%2E%30%30%36%32%32%30%36%39%20%68%20%30%2E%30%30%37%34%34%20%63%20%30%2E%32%31%35%37%36%33%33%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%35%33%32%39%34%2C%30%2E%30%30%39%31%38%20%30%2E%36%34%38%34%35%33%35%2C%30%2E%30%32%39%38%31%36%20%31%2E%38%31%33%36%36%31%34%2C%30%2E%31%36%31%37%32%31%31%20%33%2E%35%31%32%31%33%38%2C%31%2E%33%36%33%34%33%36%39%20%34%2E%33%33%37%39%32%39%2C%32%2E%39%38%38%38%34%38%20%68%20%30%2E%30%30%37%34%20%76%20%30%2E%30%30%37%34%34%20%63%20%30%2E%34%32%33%30%35%35%2C%30%2E%38%30%30%35%33%34%32%20%30%2E%36%32%30%31%39%32%2C%31%2E%37%32%31%38%30%32%35%20%30%2E%35%38%38%38%36%31%2C%32%2E%36%33%38%35%34%34%34%20%6C%20%2D%30%2E%30%30%37%34%2C%30%2E%30%30%37%34%34%20%76%20%30%2E%30%30%37%34%34%20%43%20%31%32%2E%30%38%37%31%35%35%2C%37%2E%32%39%33%30%35%35%36%20%31%31%2E%36%39%36%35%35%36%2C%37%2E%37%38%38%30%31%35%35%20%31%31%2E%34%39%37%37%38%2C%38%2E%33%33%36%34%30%33%32%20%31%31%2E%39%35%39%30%37%33%2C%37%2E%30%35%32%39%34%34%32%20%31%31%2E%39%35%34%36%34%38%2C%35%2E%36%31%31%36%30%30%35%20%31%31%2E%33%37%38%35%32%34%2C%34%2E%33%37%31%31%34%38%34%20%31%30%2E%35%36%36%30%35%32%2C%32%2E%35%35%36%33%39%35%35%20%38%2E%36%39%39%37%34%30%39%2C%31%2E%32%38%37%32%38%32%38%20%36%2E%36%39%30%32%38%31%2C%31%2E%32%38%35%34%30%34%39%20%63%20%2D%30%2E%30%31%36%34%34%38%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%34%35%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%32%38%34%2C%30%20%43%20%35%2E%36%38%33%35%30%30%36%2C%31%2E%32%34%36%39%38%39%39%20%34%2E%38%30%35%34%30%36%37%2C%31%2E%36%38%38%34%39%33%39%20%33%2E%39%38%34%36%36%35%38%2C%32%2E%31%37%32%33%36%39%38%20%34%2E%38%30%35%31%35%39%38%2C%31%2E%36%39%32%34%31%37%36%20%35%2E%35%36%30%36%32%34%2C%31%2E%30%33%32%38%31%34%37%20%36%2E%35%30%33%39%34%34%31%2C%31%2E%30%33%39%34%33%39%38%20%5A%20%6D%20%30%2E%31%30%34%33%36%30%38%2C%31%2E%32%35%32%31%38%35%37%20%68%20%30%2E%30%31%34%39%32%31%20%30%2E%30%30%37%34%34%20%63%20%30%2E%30%32%35%39%38%38%2C%30%20%30%2E%30%34%35%38%38%36%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%35%39%36%32%38%2C%30%20%31%2E%35%37%37%39%34%32%36%2C%30%2E%30%30%31%34%37%20%33%2E%31%32%37%34%36%30%37%2C%31%2E%30%35%33%33%34%20%33%2E%37%37%31%34%36%34%37%2C%32%2E%34%39%36%39%31%38%31%20%76%20%30%2E%30%30%37%34%35%20%63%20%30%2E%34%37%35%33%31%31%2C%31%2E%30%32%33%33%39%37%38%20%30%2E%35%30%39%31%35%36%2C%32%2E%32%36%35%35%39%33%36%20%30%2E%30%39%36%38%39%2C%33%2E%33%31%36%38%30%31%35%20%43%20%31%30%2E%30%30%34%33%39%37%2C%39%2E%35%33%33%30%32%37%36%20%38%2E%36%32%36%32%30%35%37%2C%31%30%2E%36%33%34%34%38%37%20%37%2E%31%31%35%31%33%2C%31%30%2E%38%30%33%35%30%37%20%36%2E%34%33%36%39%35%36%31%2C%31%30%2E%38%37%39%38%35%32%20%35%2E%37%35%32%30%39%34%34%2C%31%30%2E%38%32%39%39%31%38%20%35%2E%31%34%37%34%30%39%35%2C%31%30%2E%35%39%34%38%31%20%68%20%2D%30%2E%30%30%37%34%34%20%6C%20%2D%30%2E%30%31%34%39%32%31%2C%2D%30%2E%30%30%37%34%20%43%20%33%2E%35%31%39%36%39%36%39%2C%31%30%2E%30%34%31%30%32%39%20%32%2E%33%31%37%32%33%33%39%2C%38%2E%33%38%34%35%36%33%31%20%32%2E%33%30%30%31%37%37%36%2C%36%2E%36%38%39%31%38%32%34%20%76%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%43%20%32%2E%32%34%32%32%35%39%35%2C%35%2E%33%34%37%35%38%33%35%20%32%2E%38%39%38%33%39%31%39%2C%33%2E%39%39%37%39%32%36%36%20%33%2E%39%35%34%38%35%31%37%2C%33%2E%31%38%36%30%34%33%39%20%76%20%2D%30%2E%30%30%37%34%35%20%43%20%34%2E%37%30%38%33%33%32%36%2C%32%2E%35%39%30%31%34%20%35%2E%36%36%36%32%34%32%38%2C%32%2E%32%35%34%32%39%38%35%20%36%2E%36%30%38%32%39%32%39%2C%32%2E%32%39%31%36%32%35%35%20%5A%20%4D%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%43%20%32%2E%30%32%32%37%35%31%32%2C%33%2E%35%30%33%31%33%37%32%20%31%2E%32%33%33%35%31%35%36%2C%35%2E%30%37%36%31%32%39%31%20%31%2E%33%30%31%34%31%30%34%2C%36%2E%37%31%31%35%34%33%20%63%20%30%2E%30%32%35%36%31%2C%32%2E%30%36%38%39%30%33%39%20%31%2E%34%35%35%36%36%38%36%2C%33%2E%38%39%33%31%20%33%2E%33%36%38%39%37%36%2C%34%2E%36%35%30%39%37%36%20%43%20%34%2E%31%37%32%37%36%37%37%2C%31%31%2E%31%36%38%37%36%33%20%33%2E%35%38%38%30%32%31%2C%31%31%2E%32%35%32%38%30%37%20%33%2E%31%37%32%32%33%35%35%2C%31%30%2E%39%32%32%37%36%33%20%31%2E%39%32%31%31%31%36%2C%39%2E%39%35%30%33%35%38%34%20%31%2E%31%30%34%34%36%37%34%2C%38%2E%34%30%35%30%36%31%20%31%2E%30%35%35%34%34%35%33%2C%36%2E%38%33%30%37%39%38%38%20%76%20%2D%30%2E%30%30%37%34%35%20%2D%30%2E%30%30%37%34%35%20%43%20%30%2E%39%37%37%30%35%35%31%36%2C%35%2E%33%38%30%30%34%31%36%20%31%2E%34%39%37%38%37%37%33%2C%33%2E%39%30%31%31%36%36%35%20%32%2E%34%38%36%35%31%34%37%2C%32%2E%38%35%30%36%33%37%20%6C%20%30%2E%30%30%37%34%35%2C%2D%30%2E%30%30%37%34%35%20%43%20%32%2E%36%39%32%30%39%38%2C%32%2E%36%32%31%35%32%35%35%20%33%2E%30%35%30%39%35%31%36%2C%32%2E%36%37%31%32%32%34%34%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%5A%20%6D%20%38%2E%31%33%39%32%30%37%32%2C%36%2E%30%35%32%32%33%31%33%20%63%20%2D%30%2E%32%30%37%37%37%34%2C%30%2E%35%31%31%36%32%36%34%20%2D%30%2E%32%31%34%36%32%39%2C%31%2E%30%38%32%30%36%30%39%20%2D%30%2E%35%35%31%35%35%38%2C%31%2E%35%32%37%39%36%34%35%20%6C%20%2D%30%2E%32%36%30%38%37%2C%30%2E%33%35%30%33%31%34%20%30%2E%33%30%35%35%39%32%2C%30%2E%33%31%33%30%34%36%20%63%20%31%2E%32%30%32%31%30%35%2C%31%2E%32%31%35%33%31%33%20%32%2E%34%32%35%35%34%32%2C%32%2E%33%39%36%33%36%38%20%33%2E%36%30%30%30%33%34%2C%33%2E%36%31%34%39%34%31%20%30%2E%31%34%34%30%35%2C%30%2E%31%36%33%37%31%38%20%30%2E%32%38%32%30%31%32%2C%30%2E%32%38%34%33%38%32%20%30%2E%33%35%30%33%31%35%2C%30%2E%33%36%35%32%32%20%30%2E%30%37%32%35%37%2C%30%2E%30%38%35%38%39%20%30%2E%30%36%32%32%38%2C%30%2E%30%38%30%32%37%20%30%2E%30%35%39%36%33%2C%30%2E%31%30%34%33%35%20%76%20%30%2E%30%31%34%39%32%20%30%2E%30%31%34%39%32%20%63%20%2D%36%2E%35%39%65%2D%34%2C%30%2E%30%31%37%32%35%20%2D%30%2E%31%33%31%30%35%35%2C%30%2E%30%37%34%30%37%20%2D%30%2E%31%34%31%36%31%34%2C%30%2E%30%36%37%30%38%20%2D%31%2E%32%31%31%30%37%2C%2D%31%2E%31%32%34%37%35%34%20%2D%32%2E%37%36%37%34%39%34%2C%2D%32%2E%37%34%36%36%30%32%20%2D%34%2E%31%33%36%36%38%39%2C%2D%33%2E%39%36%35%32%38%33%20%4C%20%31%30%2E%33%34%32%34%39%2C%31%30%2E%36%37%36%38%20%31%30%2E%30%31%34%35%33%38%2C%31%30%2E%39%31%35%33%31%31%20%43%20%39%2E%31%33%38%31%38%34%34%2C%31%31%2E%35%34%37%32%33%20%38%2E%31%32%38%32%30%32%2C%31%31%2E%39%39%33%31%36%34%20%37%2E%30%39%32%37%36%39%34%2C%31%32%2E%30%36%33%31%34%37%20%68%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%63%20%2D%30%2E%35%32%39%38%39%31%38%2C%30%2E%30%35%33%39%34%20%2D%30%2E%39%37%39%37%37%37%37%2C%2D%30%2E%33%33%34%30%34%36%20%2D%31%2E%35%30%35%36%32%38%31%2C%2D%30%2E%34%33%39%37%35%36%20%30%2E%35%35%33%33%39%36%38%2C%30%2E%31%30%35%37%34%33%20%31%2E%31%31%31%31%32%35%2C%30%2E%32%34%37%35%32%37%20%31%2E%36%35%34%36%37%33%38%2C%30%2E%31%38%36%33%33%37%20%31%2E%38%38%31%32%39%35%37%2C%2D%30%2E%32%31%30%34%33%32%20%33%2E%34%38%30%35%34%35%39%2C%2D%31%2E%35%34%34%39%31%39%20%34%2E%31%39%36%33%31%32%39%2C%2D%33%2E%32%37%32%30%38%30%35%20%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%36%39%30%36%33%31%20%43%20%34%2E%38%34%39%35%32%30%38%2C%30%2E%35%32%35%32%37%34%30%35%20%33%2E%32%31%38%34%36%38%36%2C%31%2E%32%37%35%31%39%38%31%20%32%2E%31%31%36%38%30%37%38%2C%32%2E%35%30%37%36%38%34%34%20%31%2E%30%32%38%32%36%31%36%2C%33%2E%36%36%34%33%37%37%33%20%30%2E%34%36%32%30%33%33%35%2C%35%2E%32%36%39%39%32%34%39%20%30%2E%35%34%38%30%31%38%33%37%2C%36%2E%38%34%34%38%38%37%34%20%30%2E%36%30%32%30%38%39%35%39%2C%38%2E%35%38%31%32%39%34%33%20%31%2E%34%39%31%39%38%33%32%2C%31%30%2E%32%35%35%39%35%37%20%32%2E%38%36%31%39%37%33%38%2C%31%31%2E%33%32%30%37%35%31%20%63%20%31%2E%31%39%30%34%34%38%36%2C%30%2E%39%34%34%39%35%39%20%32%2E%37%35%37%30%39%31%38%2C%31%2E%34%30%31%31%36%31%20%34%2E%32%36%36%37%32%35%38%2C%31%2E%32%34%37%34%37%37%20%31%2E%31%35%36%34%33%37%33%2C%2D%30%2E%30%37%38%31%36%20%32%2E%32%34%38%31%31%36%39%2C%2D%30%2E%35%37%30%35%36%36%20%33%2E%31%38%31%32%31%31%34%2C%2D%31%2E%32%34%33%34%30%32%20%31%2E%33%36%33%39%38%37%2C%31%2E%32%31%34%30%34%35%20%32%2E%39%35%36%32%32%2C%32%2E%38%36%35%38%30%31%20%34%2E%31%39%33%31%36%31%2C%34%2E%30%30%39%36%39%31%20%30%2E%33%35%37%34%38%35%2C%30%2E%32%33%36%35%31%20%30%2E%39%30%38%35%33%35%2C%2D%30%2E%30%33%34%31%35%20%30%2E%39%32%35%31%35%2C%2D%30%2E%34%36%38%39%38%36%20%30%2E%30%34%32%37%2C%2D%30%2E%33%38%38%32%39%32%20%2D%30%2E%33%33%32%30%38%32%2C%2D%30%2E%36%31%33%33%37%36%20%2D%30%2E%35%35%30%34%36%34%2C%2D%30%2E%38%37%30%30%32%32%20%43%20%31%33%2E%36%39%35%38%30%38%2C%31%32%2E%37%36%39%32%20%31%32%2E%34%37%35%31%36%31%2C%31%31%2E%35%38%31%30%38%31%20%31%31%2E%32%37%37%35%34%35%2C%31%30%2E%33%37%30%33%30%35%20%31%32%2E%30%37%30%31%31%38%2C%39%2E%33%32%31%33%38%37%33%20%31%32%2E%35%39%36%34%32%35%2C%38%2E%30%34%33%30%38%38%36%20%31%32%2E%35%39%35%31%36%31%2C%36%2E%37%32%31%33%34%39%20%31%32%2E%36%32%39%33%30%37%2C%35%2E%37%32%32%32%32%34%35%20%31%32%2E%34%31%38%38%30%31%2C%34%2E%37%31%33%33%32%31%37%20%31%31%2E%39%35%30%39%38%35%2C%33%2E%38%32%38%30%32%34%33%20%31%31%2E%30%34%35%32%38%33%2C%32%2E%30%34%35%33%32%34%38%20%39%2E%32%30%38%33%37%30%31%2C%30%2E%37%34%33%37%37%32%38%35%20%37%2E%32%30%35%37%35%30%33%2C%30%2E%35%36%35%32%30%32%37%31%20%36%2E%39%37%33%31%38%30%31%2C%30%2E%35%34%32%36%38%38%36%33%20%36%2E%37%33%39%33%39%30%37%2C%30%2E%35%33%33%36%38%33%30%35%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%37%30%36%30%31%34%20%5A%20%4D%20%36%2E%36%39%31%35%36%38%32%2C%31%2E%37%38%39%39%33%36%37%20%43%20%38%2E%34%38%36%33%38%36%2C%31%2E%37%39%31%36%31%34%20%31%30%2E%31%39%33%39%35%32%2C%32%2E%39%34%39%37%34%34%20%31%30%2E%39%32%31%34%37%31%2C%34%2E%35%38%30%35%32%36%31%20%31%31%2E%34%35%37%34%38%35%2C%35%2E%37%33%34%36%31%38%37%20%31%31%2E%34%39%35%39%35%38%2C%37%2E%31%31%30%38%36%31%20%31%31%2E%30%33%31%36%37%37%2C%38%2E%32%39%34%37%30%35%37%20%31%30%2E%34%30%37%39%30%33%2C%39%2E%38%39%33%31%30%31%35%20%38%2E%38%38%33%36%36%31%32%2C%31%31%2E%31%31%37%30%32%39%20%37%2E%31%36%39%35%36%32%35%2C%31%31%2E%33%30%38%37%35%38%20%36%2E%34%32%38%39%32%35%37%2C%31%31%2E%33%39%32%31%33%35%20%35%2E%36%36%35%32%39%34%35%2C%31%31%2E%33%33%38%30%32%37%20%34%2E%39%36%35%39%39%37%33%2C%31%31%2E%30%36%36%31%33%32%20%33%2E%31%34%35%33%30%39%32%2C%31%30%2E%34%34%36%35%32%33%20%31%2E%38%31%36%32%30%34%32%2C%38%2E%36%32%31%32%31%39%33%20%31%2E%37%39%36%38%34%32%31%2C%36%2E%36%39%36%36%35%31%31%20%31%2E%37%33%31%32%31%33%37%2C%35%2E%31%39%33%33%34%33%36%20%32%2E%34%35%37%30%34%37%35%2C%33%2E%36%39%37%38%34%30%37%20%33%2E%36%34%35%38%34%38%37%2C%32%2E%37%38%34%32%35%34%35%20%34%2E%34%38%38%36%32%38%34%2C%32%2E%31%32%36%30%36%33%39%20%35%2E%35%35%37%39%30%36%33%2C%31%2E%37%34%37%37%34%39%31%20%36%2E%36%33%31%35%32%35%38%2C%31%2E%37%39%30%32%38%39%34%20%63%20%30%2E%30%31%39%38%38%32%2C%30%20%30%2E%30%34%30%30%33%39%2C%2D%33%2E%36%30%32%65%2D%34%20%30%2E%30%36%30%30%33%36%2C%2D%33%2E%34%38%39%65%2D%34%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"zoom-in","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%31%33%36%34%30%32%2C%30%2E%30%33%33%34%30%32%37%38%20%30%2E%30%30%37%39%32%2C%30%2E%30%30%37%39%30%38%33%20%43%20%34%2E%37%31%33%30%35%39%36%2C%30%2E%30%33%31%37%30%36%33%20%32%2E%39%35%34%33%35%30%35%2C%30%2E%38%33%33%30%35%31%38%35%20%31%2E%37%35%34%39%30%30%31%2C%32%2E%31%37%30%35%38%35%35%20%30%2E%35%36%35%31%31%35%36%36%2C%33%2E%34%33%34%38%35%34%31%20%2D%30%2E%30%34%38%39%33%31%37%39%2C%35%2E%31%36%39%37%38%35%39%20%30%2E%30%34%32%37%38%30%36%39%2C%36%2E%38%38%35%38%33%31%37%20%30%2E%31%30%34%30%35%30%39%33%2C%38%2E%37%38%33%31%33%38%34%20%31%2E%30%36%37%34%39%37%33%2C%31%30%2E%35%38%34%34%39%20%32%2E%35%35%33%36%32%34%37%2C%31%31%2E%37%34%33%34%32%34%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%31%2C%30%20%31%2E%32%39%35%34%39%36%34%2C%31%2E%30%32%35%38%33%36%20%32%2E%39%38%35%30%38%33%34%2C%31%2E%35%31%34%38%38%31%20%34%2E%36%32%36%32%37%39%36%2C%31%2E%33%35%32%32%39%38%20%31%2E%31%31%38%39%32%34%34%2C%2D%30%2E%30%37%37%37%32%20%32%2E%31%31%32%36%32%35%36%2C%2D%30%2E%35%38%32%37%36%32%20%33%2E%30%31%38%39%34%33%37%2C%2D%31%2E%31%36%36%34%35%35%20%31%2E%33%30%30%31%34%35%2C%31%2E%31%37%37%38%30%39%20%32%2E%37%39%31%30%34%34%2C%32%2E%37%30%39%32%30%39%20%33%2E%39%38%39%36%37%31%2C%33%2E%38%31%37%36%36%39%20%6C%20%30%2E%30%32%39%36%35%2C%30%2E%30%32%33%37%32%20%30%2E%30%33%37%35%37%2C%30%2E%30%32%31%37%33%20%63%20%30%2E%37%30%32%34%39%34%2C%30%2E%34%36%34%37%37%39%20%31%2E%36%36%31%39%35%39%2C%2D%30%2E%30%31%33%37%33%20%31%2E%37%30%34%32%31%2C%2D%30%2E%38%35%39%39%39%32%20%30%2E%30%32%38%34%36%2C%2D%30%2E%33%35%33%31%30%37%20%2D%30%2E%31%33%37%35%35%37%2C%2D%30%2E%36%36%30%36%39%31%20%2D%30%2E%32%39%32%36%30%32%2C%2D%30%2E%38%34%34%31%39%37%20%2D%30%2E%31%35%39%31%34%36%2C%2D%30%2E%31%38%38%33%36%20%2D%30%2E%33%30%39%34%37%37%2C%2D%30%2E%33%31%32%30%36%38%20%2D%30%2E%33%37%33%36%36%33%2C%2D%30%2E%33%38%37%35%30%31%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%35%2C%2D%30%2E%30%31%35%38%20%43%20%31%34%2E%31%35%33%38%32%36%2C%31%32%2E%35%30%38%36%38%39%20%31%33%2E%30%30%33%38%36%2C%31%31%2E%33%38%31%32%35%36%20%31%31%2E%38%37%31%34%32%35%2C%31%30%2E%32%34%30%38%37%33%20%31%32%2E%35%36%30%31%31%33%2C%39%2E%31%39%39%35%37%34%34%20%31%33%2E%31%33%34%32%39%2C%38%2E%30%33%30%33%38%30%37%20%31%33%2E%31%33%34%37%35%35%2C%36%2E%37%34%33%34%38%34%34%20%31%33%2E%31%36%39%31%39%33%2C%35%2E%36%36%36%34%36%31%38%20%31%32%2E%39%34%32%30%35%33%2C%34%2E%35%37%32%34%32%30%37%20%31%32%2E%34%33%32%39%30%36%2C%33%2E%36%30%35%39%31%38%32%20%31%31%2E%34%34%35%37%38%31%2C%31%2E%36%36%32%39%35%34%39%20%39%2E%34%37%31%32%38%37%35%2C%30%2E%32%36%31%31%35%34%34%36%20%37%2E%32%37%36%37%37%39%32%2C%30%2E%30%36%33%30%35%38%34%33%20%68%20%2D%30%2E%30%30%37%39%32%20%43%20%37%2E%31%38%39%36%31%38%31%2C%30%2E%30%35%35%34%37%38%32%38%20%37%2E%31%30%38%39%32%37%39%2C%30%2E%30%35%39%38%37%33%37%31%20%37%2E%30%32%39%36%34%38%37%2C%30%2E%30%35%35%31%35%30%32%35%20%56%20%30%2E%30%33%33%34%30%32%37%38%20%48%20%36%2E%35%32%39%34%35%36%35%20%63%20%2D%30%2E%30%30%34%39%34%2C%36%2E%31%31%37%65%2D%35%20%2D%30%2E%30%31%30%38%36%35%2C%2D%37%2E%31%33%32%65%2D%35%20%2D%30%2E%30%31%35%38%30%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%32%2C%31%2E%30%30%38%32%39%31%36%32%20%68%20%30%2E%30%30%37%39%32%20%63%20%30%2E%32%31%36%33%30%37%35%2C%2D%30%2E%30%30%33%31%33%20%30%2E%34%33%36%37%38%36%33%2C%30%2E%30%30%38%39%37%20%30%2E%36%35%30%34%34%36%37%2C%30%2E%30%32%39%36%35%34%20%31%2E%38%31%38%32%33%36%34%2C%30%2E%31%36%32%31%32%39%20%33%2E%35%31%39%36%34%32%31%2C%31%2E%33%36%37%36%38%35%32%20%34%2E%33%34%37%35%31%36%31%2C%32%2E%39%39%37%31%39%36%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%32%34%31%32%31%2C%30%2E%38%30%32%35%35%33%33%20%30%2E%36%32%32%35%34%35%2C%31%2E%37%32%36%32%32%38%33%20%30%2E%35%39%31%31%33%35%2C%32%2E%36%34%35%32%38%32%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%33%20%76%20%30%2E%30%30%37%39%32%20%43%20%31%32%2E%31%31%39%30%39%36%2C%37%2E%33%31%31%31%30%38%36%20%31%31%2E%37%32%38%36%37%35%2C%37%2E%38%30%36%39%38%31%35%20%31%31%2E%35%32%39%33%39%39%2C%38%2E%33%35%36%37%35%32%34%20%31%31%2E%39%39%31%38%35%34%2C%37%2E%30%37%30%30%35%36%31%20%31%31%2E%39%38%36%33%37%35%2C%35%2E%36%32%36%34%37%38%20%31%31%2E%34%30%38%37%39%39%2C%34%2E%33%38%32%38%39%37%31%20%31%30%2E%35%39%34%32%37%36%2C%32%2E%35%36%33%35%36%35%37%20%38%2E%37%32%33%38%39%35%39%2C%31%2E%32%39%30%37%30%37%33%20%36%2E%37%30%39%33%36%37%39%2C%31%2E%32%38%38%38%32%34%37%20%63%20%2D%30%2E%30%31%36%34%38%39%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%39%30%31%2C%2D%31%2E%30%36%36%65%2D%34%20%2D%30%2E%30%33%37%35%37%2C%30%20%43%20%35%2E%36%39%39%38%36%32%34%2C%31%2E%32%35%30%33%31%32%35%20%34%2E%38%31%39%36%37%36%35%2C%31%2E%36%39%33%33%39%37%34%20%33%2E%39%39%36%38%36%35%36%2C%32%2E%31%37%38%34%39%33%38%20%34%2E%38%31%39%34%32%39%34%2C%31%2E%36%39%37%33%33%31%20%35%2E%35%37%35%38%34%39%31%2C%31%2E%30%33%35%30%35%32%36%20%36%2E%35%32%31%35%34%38%39%2C%31%2E%30%34%31%36%39%34%34%20%5A%20%6D%20%2D%30%2E%30%37%33%31%34%39%2C%31%2E%32%35%33%34%34%34%38%20%63%20%30%2E%30%35%39%30%39%37%2C%2D%35%2E%35%34%34%65%2D%34%20%30%2E%31%31%38%39%30%36%32%2C%2D%33%2E%36%31%37%65%2D%34%20%30%2E%31%37%37%39%33%34%36%2C%30%2E%30%30%31%39%38%20%68%20%30%2E%30%31%35%38%30%31%20%30%2E%30%30%35%39%33%20%63%20%30%2E%30%32%36%30%35%34%2C%30%20%30%2E%30%34%37%35%31%33%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%36%31%32%38%39%2C%30%20%31%2E%35%38%31%39%32%32%36%2C%30%2E%30%30%31%34%38%20%33%2E%31%33%34%34%37%36%36%2C%31%2E%30%35%35%37%31%36%33%20%33%2E%37%38%30%31%30%35%32%2C%32%2E%35%30%32%39%33%35%37%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%37%36%35%31%2C%31%2E%30%32%35%39%37%39%31%20%30%2E%35%31%30%31%37%38%2C%32%2E%32%37%31%35%32%36%20%30%2E%30%39%36%38%37%2C%33%2E%33%32%35%33%38%35%33%20%2D%30%2E%35%35%35%36%34%2C%31%2E%34%32%33%38%31%39%36%20%2D%31%2E%39%33%37%30%32%37%2C%32%2E%35%32%37%32%33%35%38%20%2D%33%2E%34%35%31%39%31%33%33%2C%32%2E%36%39%36%36%38%32%38%20%2D%30%2E%36%37%39%38%38%34%38%2C%30%2E%30%37%36%35%33%20%2D%31%2E%33%36%36%38%37%38%37%2C%30%2E%30%32%38%31%32%20%2D%31%2E%39%37%33%30%38%38%37%2C%2D%30%2E%32%30%37%35%38%39%20%68%20%2D%30%2E%30%30%35%39%33%20%6C%20%2D%30%2E%30%31%35%38%30%31%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%33%30%31%39%36%39%2C%31%30%2E%30%36%36%38%31%36%20%32%2E%33%32%35%35%37%30%39%2C%38%2E%34%30%35%35%37%37%36%20%32%2E%33%30%38%34%37%31%2C%36%2E%37%30%35%39%32%30%37%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%35%39%33%20%43%20%32%2E%32%35%30%34%30%37%36%2C%35%2E%33%36%32%30%31%39%34%20%32%2E%39%30%38%30%38%34%38%2C%34%2E%30%30%38%36%32%34%31%20%33%2E%39%36%37%32%30%39%38%2C%33%2E%31%39%34%36%39%33%35%20%76%20%2D%30%2E%30%30%37%39%31%20%43%20%34%2E%36%37%35%33%37%39%39%2C%32%2E%36%33%33%37%32%31%31%20%35%2E%35%36%31%39%34%34%32%2C%32%2E%33%30%33%34%35%35%33%20%36%2E%34%34%38%33%39%37%39%2C%32%2E%32%39%35%31%33%39%32%20%5A%20%4D%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%43%20%32%2E%30%32%38%35%37%30%39%2C%33%2E%35%31%31%31%35%34%34%20%31%2E%32%33%38%30%34%35%35%2C%35%2E%30%38%38%31%32%39%33%20%31%2E%33%30%36%31%31%30%39%2C%36%2E%37%32%37%36%36%38%31%20%31%2E%33%33%31%37%38%35%35%2C%38%2E%38%30%31%37%39%30%34%20%32%2E%37%36%34%37%36%36%2C%31%30%2E%36%33%31%37%32%34%20%34%2E%36%38%32%38%39%39%36%2C%31%31%2E%33%39%31%35%31%31%20%34%2E%31%38%34%30%32%35%37%2C%31%31%2E%31%39%37%32%36%37%20%33%2E%35%39%39%31%35%38%31%2C%31%31%2E%32%38%31%35%30%37%20%33%2E%31%38%32%33%32%34%35%2C%31%30%2E%39%35%30%36%33%20%31%2E%39%32%38%30%34%38%38%2C%39%2E%39%37%35%37%37%32%39%20%31%2E%31%30%38%31%32%36%38%2C%38%2E%34%32%36%35%30%30%36%20%31%2E%30%35%38%39%38%31%32%2C%36%2E%38%34%38%32%36%37%36%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%30%2E%39%38%30%33%39%30%34%38%2C%35%2E%33%39%32%39%37%39%34%20%31%2E%35%30%33%31%38%33%2C%33%2E%39%31%31%37%37%35%36%20%32%2E%34%39%34%33%31%33%32%2C%32%2E%38%35%38%35%39%36%34%20%6C%20%30%2E%30%30%37%39%31%2C%2D%30%2E%30%30%37%39%31%20%43%20%32%2E%37%30%30%38%34%39%38%2C%32%2E%36%32%38%34%37%30%35%20%33%2E%30%35%39%33%36%35%2C%32%2E%36%37%37%31%34%33%32%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%5A%20%4D%20%35%2E%35%31%33%32%35%36%39%2C%33%2E%33%34%32%39%37%31%37%20%56%20%33%2E%38%34%35%31%34%30%33%20%35%2E%34%38%38%30%36%32%37%20%48%20%33%2E%33%36%38%31%36%36%37%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%35%2E%35%31%33%32%35%36%39%20%56%20%39%2E%37%39%39%39%39%31%38%20%48%20%37%2E%36%38%38%30%30%34%31%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%39%2E%38%33%33%30%39%34%34%20%56%20%35%2E%34%38%38%30%36%32%37%20%48%20%37%2E%36%38%38%30%30%34%31%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%20%6D%20%31%2E%30%31%36%31%39%39%36%2C%31%2E%30%31%30%32%36%38%34%20%68%20%30%2E%31%34%32%33%34%36%39%20%76%20%32%2E%31%34%33%31%31%34%32%20%68%20%32%2E%31%34%35%30%39%31%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%36%2E%36%37%31%38%30%33%38%20%56%20%38%2E%37%39%31%37%30%30%36%20%48%20%36%2E%35%32%39%34%35%36%35%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%34%2E%33%38%34%33%36%36%32%20%56%20%36%2E%34%39%36%33%35%34%33%20%48%20%36%2E%35%32%39%34%35%36%35%20%5A%20%4D%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%43%20%31%31%2E%32%34%35%39%37%33%2C%39%2E%30%37%31%33%32%36%20%31%31%2E%32%33%38%34%37%35%2C%39%2E%36%34%33%35%38%38%38%20%31%30%2E%39%30%30%36%39%38%2C%31%30%2E%30%39%30%36%31%37%20%6C%20%2D%30%2E%32%36%30%39%37%2C%30%2E%33%35%31%39%31%34%20%30%2E%33%30%36%34%34%33%2C%30%2E%33%31%34%33%34%37%20%63%20%31%2E%32%30%35%31%33%37%2C%31%2E%32%31%38%33%37%39%20%32%2E%34%33%30%36%34%37%2C%32%2E%34%30%32%32%37%32%20%33%2E%36%30%38%31%30%32%2C%33%2E%36%32%33%39%31%39%20%30%2E%31%34%34%34%31%33%2C%30%2E%31%36%34%31%33%31%20%30%2E%32%38%33%34%33%39%2C%30%2E%32%38%34%37%31%33%20%30%2E%33%35%31%39%31%34%2C%30%2E%33%36%35%37%35%31%20%30%2E%30%37%32%37%35%2C%30%2E%30%38%36%31%20%30%2E%30%36%31%39%37%2C%30%2E%30%38%30%36%34%20%30%2E%30%35%39%33%31%2C%30%2E%31%30%34%37%38%35%20%76%20%30%2E%30%31%33%38%35%20%30%2E%30%31%35%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%39%20%2D%30%2E%31%33%31%37%36%31%2C%30%2E%30%37%34%32%33%20%2D%30%2E%31%34%32%33%34%37%2C%30%2E%30%36%37%32%32%20%2D%31%2E%32%31%34%31%32%35%2C%2D%31%2E%31%32%37%35%38%34%20%2D%32%2E%37%37%33%32%31%31%2C%2D%32%2E%37%35%34%30%37%20%2D%34%2E%31%34%35%38%35%39%2C%2D%33%2E%39%37%35%38%32%34%20%6C%20%2D%30%2E%33%30%36%34%34%33%2C%2D%30%2E%32%36%38%38%37%38%20%2D%30%2E%33%33%30%31%36%38%2C%30%2E%32%33%39%32%32%20%63%20%2D%30%2E%38%37%38%35%36%31%39%2C%30%2E%36%33%33%35%31%34%20%2D%31%2E%38%38%39%39%35%32%2C%31%2E%30%38%30%34%38%31%20%2D%32%2E%39%32%37%39%39%36%39%2C%31%2E%31%35%30%36%34%31%20%68%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%36%2E%35%36%35%36%33%39%35%2C%31%32%2E%31%34%37%34%33%39%20%36%2E%31%31%35%35%36%31%35%2C%31%31%2E%37%35%38%34%35%37%20%35%2E%35%38%38%33%38%34%37%2C%31%31%2E%36%35%32%34%38%31%20%36%2E%31%34%33%31%37%37%34%2C%31%31%2E%37%35%38%34%39%20%36%2E%37%30%32%32%30%33%33%2C%31%31%2E%39%30%31%36%34%35%20%37%2E%32%34%37%31%32%33%34%2C%31%31%2E%38%34%30%33%30%32%20%39%2E%31%33%33%31%36%33%39%2C%31%31%2E%36%32%39%33%33%39%20%31%30%2E%37%33%36%36%39%37%2C%31%30%2E%32%38%39%39%32%39%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%5A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%43%20%34%2E%38%35%37%38%35%32%37%2C%30%2E%35%33%30%35%30%31%31%36%20%33%2E%32%32%33%38%31%38%31%2C%31%2E%32%38%33%36%31%30%32%20%32%2E%31%31%39%33%37%39%31%2C%32%2E%35%31%39%32%30%35%31%20%31%2E%30%32%38%30%38%37%32%2C%33%2E%36%37%38%38%31%35%34%20%30%2E%34%35%39%34%35%32%30%35%2C%35%2E%32%38%37%37%38%36%35%20%30%2E%35%34%35%36%35%32%38%38%2C%36%2E%38%36%36%37%32%31%34%20%30%2E%35%39%39%38%36%31%36%37%2C%38%2E%36%30%37%35%30%38%31%20%31%2E%34%39%31%32%37%37%36%2C%31%30%2E%32%38%37%31%32%38%20%32%2E%38%36%34%37%32%33%39%2C%31%31%2E%33%35%34%36%30%38%20%63%20%31%2E%31%39%33%34%35%31%2C%30%2E%39%34%37%33%34%32%20%32%2E%37%36%34%38%37%38%32%2C%31%2E%34%30%33%35%36%32%20%34%2E%32%37%38%33%31%39%31%2C%31%2E%32%34%39%34%39%31%20%31%2E%31%35%39%33%35%34%35%2C%2D%30%2E%30%37%38%33%36%20%32%2E%32%35%33%35%32%32%32%2C%2D%30%2E%35%37%31%30%30%34%20%33%2E%31%38%38%39%37%2C%2D%31%2E%32%34%35%35%33%37%20%31%2E%33%36%37%34%32%37%2C%31%2E%32%31%37%31%30%37%20%32%2E%39%36%33%31%33%32%2C%32%2E%38%37%32%35%35%32%20%34%2E%32%30%33%31%39%32%2C%34%2E%30%31%39%33%32%37%20%30%2E%33%35%38%33%38%37%2C%30%2E%32%33%37%31%30%34%20%30%2E%39%31%32%35%35%33%2C%2D%30%2E%30%33%34%35%38%20%30%2E%39%32%39%32%31%2C%2D%30%2E%34%37%30%35%33%37%20%30%2E%30%34%32%38%31%2C%2D%30%2E%33%38%39%32%37%31%20%2D%30%2E%33%33%34%36%33%39%2C%2D%30%2E%36%31%34%35%38%33%20%2D%30%2E%35%35%33%35%37%31%2C%2D%30%2E%38%37%31%38%37%35%20%43%20%31%33%2E%37%32%35%39%31%33%2C%31%32%2E%38%30%36%30%37%34%20%31%32%2E%35%30%33%33%37%37%2C%31%31%2E%36%31%35%35%30%32%20%31%31%2E%33%30%32%37%34%31%2C%31%30%2E%34%30%31%36%37%33%20%31%32%2E%30%39%37%33%31%33%2C%39%2E%33%35%30%31%30%39%34%20%31%32%2E%36%32%34%36%37%34%2C%38%2E%30%36%37%32%34%30%39%20%31%32%2E%36%32%33%34%30%35%2C%36%2E%37%34%32%31%36%37%36%20%31%32%2E%36%35%37%36%33%37%2C%35%2E%37%34%30%35%32%32%39%20%31%32%2E%34%34%35%39%30%38%2C%34%2E%37%32%39%33%37%36%39%20%31%31%2E%39%37%36%39%31%32%2C%33%2E%38%34%31%38%34%36%36%20%31%31%2E%30%36%38%39%32%36%2C%32%2E%30%35%34%36%35%30%34%20%39%2E%32%32%37%38%31%38%36%2C%30%2E%37%35%30%38%33%38%39%33%20%37%2E%32%32%30%31%34%38%2C%30%2E%35%37%31%38%31%38%33%39%20%36%2E%39%38%36%39%39%31%37%2C%30%2E%35%34%39%32%34%36%31%31%20%36%2E%37%35%32%34%38%39%34%2C%30%2E%35%33%38%37%38%32%35%31%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%5A%20%4D%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%63%20%30%2E%30%36%37%31%38%31%2C%2D%35%2E%39%36%33%65%2D%34%20%30%2E%31%33%34%33%38%39%32%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%36%35%38%35%2C%30%2E%30%30%33%39%36%20%30%2E%30%31%39%39%33%32%2C%30%20%30%2E%30%33%39%32%36%34%2C%2D%31%2E%31%33%65%2D%35%20%30%2E%30%35%39%33%31%31%2C%30%20%31%2E%37%39%39%33%34%34%39%2C%30%2E%30%30%31%36%38%20%33%2E%35%31%31%34%30%33%32%2C%31%2E%31%36%32%36%31%39%34%20%34%2E%32%34%30%37%35%36%32%2C%32%2E%37%39%37%35%31%35%20%30%2E%35%33%37%33%36%36%2C%31%2E%31%35%37%30%30%33%35%20%30%2E%35%37%36%31%36%36%2C%32%2E%35%33%35%39%34%20%30%2E%31%31%30%37%31%35%2C%33%2E%37%32%32%37%37%31%31%20%43%20%31%30%2E%34%33%30%32%36%34%2C%39%2E%39%32%32%32%37%35%20%38%2E%39%30%32%39%38%34%2C%31%31%2E%31%35%30%35%33%32%20%37%2E%31%38%34%35%36%31%35%2C%31%31%2E%33%34%32%37%34%35%20%36%2E%34%34%32%30%35%37%2C%31%31%2E%34%32%36%33%33%33%20%35%2E%36%37%35%32%38%38%38%2C%31%31%2E%33%37%32%31%35%20%34%2E%39%37%34%32%32%37%38%2C%31%31%2E%30%39%39%35%37%20%33%2E%31%34%38%39%34%37%33%2C%31%30%2E%34%37%38%33%39%38%20%31%2E%38%31%36%35%33%32%34%2C%38%2E%36%34%37%38%36%35%34%20%31%2E%37%39%37%31%32%30%36%2C%36%2E%37%31%38%34%34%33%33%20%31%2E%37%33%31%33%32%37%36%2C%35%2E%32%31%31%33%34%34%31%20%32%2E%34%35%39%37%38%37%32%2C%33%2E%37%31%31%38%38%31%35%20%33%2E%36%35%31%35%38%37%31%2C%32%2E%37%39%35%39%39%31%31%20%34%2E%34%34%33%36%38%35%34%2C%32%2E%31%37%37%33%38%31%20%35%2E%34%33%35%34%33%39%32%2C%31%2E%38%30%34%35%35%31%33%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%5A%20%4D%20%36%2E%30%31%36%31%32%39%31%2C%33%2E%38%35%31%37%33%31%38%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%33%2E%38%37%31%30%33%38%39%20%76%20%31%2E%31%35%36%35%36%39%37%20%68%20%32%2E%31%34%35%30%39%30%32%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%37%2E%31%37%32%36%39%38%38%20%56%20%37%2E%31%35%33%33%39%32%35%20%48%20%39%2E%33%31%37%37%39%30%32%20%56%20%35%2E%39%39%36%38%32%32%38%20%48%20%37%2E%31%37%32%36%39%38%38%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_static_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"zoom-out","url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%30%33%35%37%30%34%2C%30%2E%30%33%33%34%30%34%35%36%20%30%2E%30%30%37%39%31%2C%30%2E%30%30%37%38%39%35%37%20%43%20%34%2E%37%30%35%38%36%31%34%2C%30%2E%30%33%31%37%31%30%37%35%20%32%2E%39%34%39%39%35%31%35%2C%30%2E%38%33%31%37%37%39%31%36%20%31%2E%37%35%32%34%31%33%38%2C%32%2E%31%36%37%31%38%31%31%20%30%2E%35%36%34%35%32%35%35%39%2C%33%2E%34%32%39%34%33%34%37%20%2D%30%2E%30%34%38%35%34%32%32%31%2C%35%2E%31%36%31%36%30%31%33%20%30%2E%30%34%33%30%32%34%31%31%2C%36%2E%38%37%34%39%31%32%31%20%30%2E%31%30%34%31%37%37%34%38%2C%38%2E%37%36%39%31%39%34%39%20%31%2E%30%36%36%31%30%36%35%2C%31%30%2E%35%36%37%36%37%35%20%32%2E%35%34%39%38%36%36%34%2C%31%31%2E%37%32%34%37%36%32%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%33%37%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%2C%30%20%31%2E%32%39%33%34%33%30%34%2C%31%2E%30%32%34%32%30%32%20%32%2E%39%37%38%33%34%36%37%2C%31%2E%35%31%32%34%36%37%20%34%2E%36%31%36%39%33%31%34%2C%31%2E%33%35%30%31%34%33%20%31%2E%31%31%37%31%34%2C%2D%30%2E%30%37%37%36%20%32%2E%31%30%39%32%36%31%36%2C%2D%30%2E%35%38%31%38%33%33%20%33%2E%30%31%34%31%33%33%32%2C%2D%31%2E%31%36%34%35%39%36%20%31%2E%32%39%38%30%37%31%2C%31%2E%31%37%35%39%33%32%20%32%2E%37%38%38%35%37%2C%32%2E%37%30%34%38%39%31%20%33%2E%39%38%35%32%38%36%2C%33%2E%38%31%31%35%38%34%20%6C%20%30%2E%30%32%39%36%2C%30%2E%30%32%33%36%38%20%30%2E%30%33%37%35%31%2C%30%2E%30%32%31%37%20%63%20%30%2E%37%30%31%33%37%32%2C%30%2E%34%36%34%30%31%37%20%31%2E%36%35%37%33%34%2C%2D%30%2E%30%31%33%37%35%20%31%2E%36%39%39%35%32%31%2C%2D%30%2E%38%35%38%36%34%33%20%30%2E%30%32%38%32%37%2C%2D%30%2E%33%35%32%35%34%34%20%2D%30%2E%31%33%35%33%38%36%2C%2D%30%2E%36%35%39%36%33%38%20%2D%30%2E%32%39%30%31%36%31%2C%2D%30%2E%38%34%32%38%35%31%20%2D%30%2E%31%35%38%39%2C%2D%30%2E%31%38%38%30%36%20%2D%30%2E%33%30%38%39%37%32%2C%2D%30%2E%33%31%31%35%37%20%2D%30%2E%33%37%33%30%36%37%2C%2D%30%2E%33%38%36%38%38%33%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%33%2C%2D%30%2E%30%31%35%37%38%20%43%20%31%34%2E%31%33%31%32%38%32%2C%31%32%2E%34%38%38%38%30%38%20%31%32%2E%39%38%33%34%34%34%2C%31%31%2E%33%36%33%31%37%32%20%31%31%2E%38%35%32%38%31%36%2C%31%30%2E%32%32%34%36%30%36%20%31%32%2E%35%34%30%34%30%37%2C%39%2E%31%38%34%39%36%37%32%20%31%33%2E%31%31%33%36%37%31%2C%38%2E%30%31%37%36%33%37%20%31%33%2E%31%31%34%31%33%33%2C%36%2E%37%33%32%37%39%31%37%20%31%33%2E%31%34%38%35%31%38%2C%35%2E%36%35%37%34%38%35%36%20%31%32%2E%39%32%31%37%34%2C%34%2E%35%36%35%31%38%38%32%20%31%32%2E%34%31%33%34%30%32%2C%33%2E%36%30%30%32%32%36%31%20%31%31%2E%34%32%37%38%35%2C%31%2E%36%36%30%33%35%39%35%20%39%2E%34%35%36%35%30%33%2C%30%2E%32%36%30%37%39%33%32%36%20%37%2E%32%36%35%34%39%33%31%2C%30%2E%30%36%33%30%31%32%39%35%20%68%20%2D%30%2E%30%30%37%39%31%20%43%20%37%2E%31%37%38%34%39%31%31%2C%30%2E%30%35%35%34%34%34%39%36%20%37%2E%30%39%37%39%30%31%33%2C%30%2E%30%35%39%38%33%33%32%33%20%37%2E%30%31%38%37%35%36%35%2C%30%2E%30%35%35%31%31%37%33%38%20%56%20%30%2E%30%33%33%34%30%34%35%36%20%68%20%2D%30%2E%34%39%39%33%39%35%20%63%20%2D%30%2E%30%30%34%39%37%2C%36%2E%31%30%38%65%2D%35%20%2D%30%2E%30%31%30%38%31%2C%2D%37%2E%31%32%65%2D%35%20%2D%30%2E%30%31%35%37%37%35%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%31%2C%31%2E%30%30%36%36%38%34%36%34%20%68%20%30%2E%30%30%37%39%31%20%63%20%30%2E%32%31%35%39%36%36%36%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%36%30%39%30%39%2C%30%2E%30%30%38%39%35%20%30%2E%36%34%39%34%31%31%32%2C%30%2E%30%32%39%36%30%37%20%31%2E%38%31%35%33%33%37%33%2C%30%2E%31%36%31%38%37%30%36%20%33%2E%35%31%34%30%33%31%34%2C%31%2E%33%36%35%35%30%35%34%20%34%2E%33%34%30%35%38%35%34%2C%32%2E%39%39%32%34%31%39%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%32%33%34%34%36%2C%30%2E%38%30%31%32%37%34%32%20%30%2E%36%32%31%35%35%33%2C%31%2E%37%32%33%34%37%37%31%20%30%2E%35%39%30%31%39%33%2C%32%2E%36%34%31%30%36%36%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%32%20%76%20%30%2E%30%30%37%39%31%20%43%20%31%32%2E%31%30%30%30%39%32%2C%37%2E%32%39%39%35%30%39%39%20%31%31%2E%37%30%38%33%32%2C%37%2E%37%39%34%35%39%32%35%20%31%31%2E%35%30%39%33%35%39%2C%38%2E%33%34%33%34%38%37%31%20%31%31%2E%39%37%31%30%37%39%2C%37%2E%30%35%38%38%34%31%36%20%31%31%2E%39%36%37%35%38%34%2C%35%2E%36%31%37%35%36%34%32%20%31%31%2E%33%39%30%39%32%36%2C%34%2E%33%37%35%39%36%35%34%20%31%30%2E%35%37%37%37%30%36%2C%32%2E%35%35%39%35%33%35%20%38%2E%37%31%30%33%30%31%35%2C%31%2E%32%38%38%37%30%35%32%20%36%2E%36%39%38%39%38%36%31%2C%31%2E%32%38%36%38%32%35%36%20%63%20%2D%30%2E%30%31%36%34%32%35%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%36%38%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%35%30%39%2C%30%20%43%20%35%2E%36%39%31%30%38%37%36%2C%31%2E%32%34%38%33%37%34%39%20%34%2E%38%31%32%33%30%38%34%2C%31%2E%36%39%30%37%35%33%35%20%33%2E%39%39%30%38%30%37%2C%32%2E%31%37%35%30%37%36%38%20%34%2E%38%31%32%30%36%30%39%2C%31%2E%36%39%34%36%38%30%39%20%35%2E%35%36%37%32%37%35%31%2C%31%2E%30%33%33%34%35%37%39%20%36%2E%35%31%31%34%36%36%35%2C%31%2E%30%34%30%30%38%39%32%20%5A%20%6D%20%2D%30%2E%30%37%33%30%33%33%2C%31%2E%32%35%31%34%34%37%31%20%63%20%30%2E%30%35%39%30%30%33%2C%2D%35%2E%35%33%36%65%2D%34%20%30%2E%31%31%38%37%31%36%37%2C%2D%33%2E%36%31%32%65%2D%34%20%30%2E%31%37%37%36%35%31%2C%30%2E%30%30%31%39%37%20%68%20%30%2E%30%31%35%37%37%35%20%30%2E%30%30%35%39%32%20%63%20%30%2E%30%32%35%39%37%34%2C%30%20%30%2E%30%34%37%34%30%33%2C%2D%37%2E%36%65%2D%36%20%30%2E%30%36%31%31%39%32%2C%30%20%31%2E%35%37%39%34%30%31%33%2C%30%2E%30%30%31%34%38%20%33%2E%31%32%39%34%38%30%39%2C%31%2E%30%35%34%30%33%33%38%20%33%2E%37%37%34%30%38%30%36%2C%32%2E%34%39%38%39%34%36%35%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%37%35%37%34%39%2C%31%2E%30%32%34%33%34%33%39%20%30%2E%35%30%39%33%36%33%2C%32%2E%32%36%37%39%30%35%37%20%30%2E%30%39%36%37%32%2C%33%2E%33%32%30%30%38%35%33%20%2D%30%2E%35%35%34%37%36%2C%31%2E%34%32%31%35%35%34%20%2D%31%2E%39%33%33%39%34%31%33%2C%32%2E%35%32%33%32%31%30%39%20%2D%33%2E%34%34%36%34%31%33%32%2C%32%2E%36%39%32%33%38%37%39%20%2D%30%2E%36%37%38%38%30%31%32%2C%30%2E%30%37%36%34%31%20%2D%31%2E%33%36%34%37%30%32%35%2C%30%2E%30%32%38%30%37%20%2D%31%2E%39%36%39%39%34%33%37%2C%2D%30%2E%32%30%37%32%35%38%20%68%20%2D%30%2E%30%30%37%39%31%20%6C%20%2D%30%2E%30%31%33%38%32%37%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%32%34%36%35%39%38%2C%31%30%2E%30%35%30%38%32%35%20%32%2E%33%32%30%32%30%30%32%2C%38%2E%33%39%32%32%33%35%38%20%32%2E%33%30%33%31%32%39%36%2C%36%2E%36%39%35%32%38%37%38%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%35%39%32%20%43%20%32%2E%32%34%35%31%34%36%36%2C%35%2E%33%35%33%35%32%38%35%20%32%2E%39%30%31%37%38%36%38%2C%34%2E%30%30%32%32%39%30%31%20%33%2E%39%35%39%32%32%34%34%2C%33%2E%31%38%39%36%35%36%39%20%76%20%2D%30%2E%30%30%37%39%20%43%20%34%2E%36%36%36%32%36%34%2C%32%2E%36%32%39%35%37%38%36%20%35%2E%35%35%33%33%39%32%2C%32%2E%32%39%39%38%33%39%31%20%36%2E%34%33%38%34%33%32%31%2C%32%2E%32%39%31%35%33%36%33%20%5A%20%4D%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%43%20%32%2E%30%32%35%34%35%30%33%2C%33%2E%35%30%35%36%31%33%32%20%31%2E%32%33%36%33%38%34%39%2C%35%2E%30%38%30%30%37%34%38%20%31%2E%33%30%34%33%34%30%38%2C%36%2E%37%31%37%30%30%30%36%20%31%2E%33%32%39%39%33%33%31%2C%38%2E%37%38%37%38%31%37%32%20%32%2E%37%36%30%36%36%39%32%2C%31%30%2E%36%31%34%38%33%34%20%34%2E%36%37%35%37%34%38%2C%31%31%2E%33%37%33%34%31%20%34%2E%31%37%37%36%36%38%38%2C%31%31%2E%31%37%39%34%37%36%20%33%2E%35%39%33%37%33%33%34%2C%31%31%2E%32%36%33%35%38%32%20%33%2E%31%37%37%35%36%34%31%2C%31%30%2E%39%33%33%32%33%32%20%31%2E%39%32%35%32%38%36%35%2C%39%2E%39%35%39%39%32%38%36%20%31%2E%31%30%36%36%37%32%32%2C%38%2E%34%31%33%31%32%35%35%20%31%2E%30%35%37%36%30%34%2C%36%2E%38%33%37%34%30%37%39%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%43%20%30%2E%39%37%39%31%34%37%36%34%2C%35%2E%33%38%34%34%33%39%31%20%31%2E%35%30%31%30%39%39%38%2C%33%2E%39%30%35%35%39%36%20%32%2E%34%39%30%36%34%39%34%2C%32%2E%38%35%34%30%39%35%34%20%6C%20%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%43%20%32%2E%36%39%36%38%36%34%32%2C%32%2E%36%32%34%33%33%36%36%20%33%2E%30%35%34%38%30%30%39%2C%32%2E%36%37%32%39%33%31%38%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%5A%20%6D%20%30%2E%30%37%35%30%30%37%2C%32%2E%39%39%30%34%34%35%32%20%76%20%30%2E%35%30%37%32%39%20%31%2E%36%35%36%30%39%35%20%48%20%39%2E%38%31%35%37%36%30%34%20%56%20%35%2E%34%37%37%33%39%36%38%20%5A%20%4D%20%34%2E%33%37%37%36%39%2C%36%2E%34%39%31%39%37%37%31%20%48%20%38%2E%38%30%31%31%38%30%35%20%56%20%36%2E%36%33%34%30%39%37%32%20%48%20%34%2E%33%37%37%36%39%20%5A%20%6D%20%37%2E%30%35%36%36%36%32%2C%32%2E%30%35%32%38%34%37%31%20%68%20%30%2E%30%30%32%20%63%20%2D%30%2E%32%30%37%39%34%36%2C%30%2E%35%31%32%30%39%39%20%2D%30%2E%32%31%35%34%34%34%2C%31%2E%30%38%33%34%34%39%37%20%2D%30%2E%35%35%32%36%39%2C%31%2E%35%32%39%37%36%35%38%20%6C%20%2D%30%2E%32%36%30%35%35%34%2C%30%2E%33%35%31%33%35%32%20%30%2E%33%30%35%39%35%35%2C%30%2E%33%31%33%38%34%37%20%63%20%31%2E%32%30%33%32%31%34%2C%31%2E%32%31%36%34%33%37%20%32%2E%34%32%36%37%37%34%2C%32%2E%33%39%38%34%34%33%20%33%2E%36%30%32%33%35%32%2C%33%2E%36%31%38%31%34%33%20%30%2E%31%34%34%31%39%34%2C%30%2E%31%36%33%38%36%39%20%30%2E%32%38%32%39%38%2C%30%2E%32%38%34%32%35%39%20%30%2E%33%35%31%33%35%32%2C%30%2E%33%36%35%31%36%38%20%30%2E%30%37%32%36%35%2C%30%2E%30%38%35%39%37%20%30%2E%30%36%31%38%35%2C%30%2E%30%38%30%35%31%20%30%2E%30%35%39%32%32%2C%30%2E%31%30%34%36%31%38%20%76%20%30%2E%30%31%33%38%33%20%30%2E%30%31%35%37%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%37%20%2D%30%2E%31%33%31%35%33%39%2C%30%2E%30%37%34%31%31%20%2D%30%2E%31%34%32%31%32%2C%30%2E%30%36%37%31%31%20%2D%31%2E%32%31%32%34%32%35%2C%2D%31%2E%31%32%35%37%38%37%20%2D%32%2E%37%37%30%37%36%36%2C%2D%32%2E%37%34%39%36%38%31%20%2D%34%2E%31%34%31%32%32%36%2C%2D%33%2E%39%36%39%34%38%38%20%6C%20%2D%30%2E%33%30%35%39%35%32%2C%2D%30%2E%32%36%38%34%35%20%2D%30%2E%33%32%37%36%36%36%2C%30%2E%32%33%38%38%33%39%20%63%20%2D%30%2E%38%37%37%31%36%33%35%2C%30%2E%36%33%32%35%30%34%20%2D%31%2E%38%38%36%39%34%32%38%2C%31%2E%30%37%38%37%35%39%20%2D%32%2E%39%32%33%33%33%34%35%2C%31%2E%31%34%38%38%30%37%20%68%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%63%20%2D%30%2E%35%33%30%33%35%35%33%2C%30%2E%30%35%33%39%39%20%2D%30%2E%39%37%39%37%31%38%39%2C%2D%30%2E%33%33%34%33%37%20%2D%31%2E%35%30%36%30%35%36%33%2C%2D%30%2E%34%34%30%31%37%38%20%30%2E%35%35%33%39%30%38%34%2C%30%2E%31%30%35%38%34%31%20%31%2E%31%31%32%30%34%31%35%2C%30%2E%32%34%38%37%36%35%20%31%2E%36%35%36%30%39%35%2C%30%2E%31%38%37%35%32%20%31%2E%38%38%33%30%33%34%39%2C%2D%30%2E%32%31%30%36%32%37%20%33%2E%34%38%32%30%33%38%38%2C%2D%31%2E%35%34%37%39%30%32%20%34%2E%31%39%38%34%36%37%38%2C%2D%33%2E%32%37%36%36%35%39%38%20%7A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%43%20%34%2E%38%35%30%34%32%37%33%2C%30%2E%35%32%39%37%30%35%39%38%20%33%2E%32%31%37%30%32%38%2C%31%2E%32%38%31%36%31%34%32%20%32%2E%31%31%34%33%34%36%32%2C%32%2E%35%31%35%32%33%39%38%20%31%2E%30%32%34%37%39%35%35%2C%33%2E%36%37%33%30%30%31%39%20%30%2E%34%35%39%30%33%36%34%32%2C%35%2E%32%37%39%34%30%38%35%20%30%2E%35%34%35%31%30%31%38%39%2C%36%2E%38%35%35%38%32%36%39%20%30%2E%35%39%39%32%32%37%33%2C%38%2E%35%39%33%38%33%39%31%20%31%2E%34%38%39%32%31%39%35%2C%31%30%2E%32%37%30%37%38%32%20%32%2E%38%36%30%34%37%36%38%2C%31%31%2E%33%33%36%35%36%31%20%63%20%31%2E%31%39%31%35%34%37%39%2C%30%2E%39%34%35%38%33%32%20%32%2E%37%36%30%34%36%38%37%2C%31%2E%34%30%31%33%32%35%20%34%2E%32%37%31%35%30%31%33%2C%31%2E%32%34%37%34%39%39%20%31%2E%31%35%37%35%30%32%35%2C%2D%30%2E%30%37%38%32%33%20%32%2E%32%34%39%39%32%38%36%2C%2D%30%2E%35%37%30%30%39%34%20%33%2E%31%38%33%38%38%35%39%2C%2D%31%2E%32%34%33%35%35%32%20%31%2E%33%36%35%32%34%36%2C%31%2E%32%31%35%31%36%37%20%32%2E%39%35%38%34%31%2C%32%2E%38%36%37%39%37%34%20%34%2E%31%39%36%34%39%34%2C%34%2E%30%31%32%39%32%31%20%30%2E%33%35%37%38%33%2C%30%2E%32%33%36%37%32%37%20%30%2E%39%30%39%31%32%33%2C%2D%30%2E%30%33%34%35%35%20%30%2E%39%32%35%37%35%35%2C%2D%30%2E%34%36%39%37%38%36%20%30%2E%30%34%32%37%34%2C%2D%30%2E%33%38%38%36%35%31%20%2D%30%2E%33%33%32%31%33%37%2C%2D%30%2E%36%31%33%36%30%34%20%2D%30%2E%35%35%30%37%31%36%2C%2D%30%2E%38%37%30%34%38%36%20%2D%31%2E%31%38%33%30%34%32%2C%2D%31%2E%32%32%37%34%34%33%20%2D%32%2E%34%30%33%36%33%2C%2D%32%2E%34%31%36%31%31%38%20%2D%33%2E%36%30%32%33%35%32%2C%2D%33%2E%36%32%38%30%31%33%20%30%2E%37%39%33%33%30%35%2C%2D%31%2E%30%34%39%38%38%37%31%20%31%2E%33%31%39%38%32%34%2C%2D%32%2E%33%33%30%37%31%31%20%31%2E%33%31%38%35%36%2C%2D%33%2E%36%35%33%36%37%32%34%20%30%2E%30%33%34%2C%2D%31%2E%30%30%30%30%34%38%32%20%2D%30%2E%31%37%37%32%30%31%2C%2D%32%2E%30%30%39%35%38%32%37%20%2D%30%2E%36%34%35%34%36%33%2C%2D%32%2E%38%39%35%36%39%38%34%20%43%20%31%31%2E%30%35%31%36%30%32%2C%32%2E%30%35%31%34%32%35%35%20%39%2E%32%31%33%34%33%30%33%2C%30%2E%37%34%39%36%39%32%30%34%20%37%2E%32%30%38%39%35%39%31%2C%30%2E%35%37%30%39%35%36%38%32%20%36%2E%39%37%36%31%38%35%38%2C%30%2E%35%34%38%34%32%30%35%31%20%36%2E%37%34%32%30%34%33%39%2C%30%2E%35%33%37%39%37%33%36%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%5A%20%4D%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%63%20%30%2E%30%36%37%30%37%34%2C%2D%35%2E%39%35%32%65%2D%34%20%30%2E%31%33%34%31%37%35%31%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%33%33%37%31%2C%30%2E%30%30%33%39%35%20%30%2E%30%31%39%38%36%33%2C%30%20%30%2E%30%33%39%32%30%32%2C%2D%31%2E%31%32%65%2D%35%20%30%2E%30%35%39%32%31%37%2C%30%20%31%2E%37%39%36%34%37%36%2C%30%2E%30%30%31%36%38%20%33%2E%35%30%35%38%30%37%35%2C%31%2E%31%36%30%37%36%36%35%20%34%2E%32%33%33%39%39%36%35%2C%32%2E%37%39%33%30%35%36%32%20%43%20%31%31%2E%34%36%34%32%38%31%2C%35%2E%37%34%34%39%36%31%32%20%31%31%2E%35%30%33%30%31%35%2C%37%2E%31%32%31%37%20%31%31%2E%30%33%38%33%31%2C%38%2E%33%30%36%36%33%39%35%20%31%30%2E%34%31%33%39%35%37%2C%39%2E%39%30%36%35%31%30%36%20%38%2E%38%38%39%31%31%34%35%2C%31%31%2E%31%33%32%38%31%20%37%2E%31%37%33%34%32%39%33%2C%31%31%2E%33%32%34%37%31%37%20%36%2E%34%33%32%31%31%31%32%2C%31%31%2E%34%30%38%31%37%20%35%2E%36%36%36%35%36%32%34%2C%31%31%2E%33%35%34%30%37%35%20%34%2E%39%36%36%36%31%38%37%2C%31%31%2E%30%38%31%39%32%39%20%33%2E%31%34%34%32%34%39%33%2C%31%30%2E%34%36%31%37%34%37%20%31%2E%38%31%33%39%35%36%39%2C%38%2E%36%33%34%31%33%32%31%20%31%2E%37%39%34%35%37%36%2C%36%2E%37%30%37%37%38%35%32%20%31%2E%37%32%38%38%37%36%38%2C%35%2E%32%30%33%30%38%37%39%20%32%2E%34%35%36%31%38%33%35%2C%33%2E%37%30%36%30%31%35%33%20%33%2E%36%34%36%30%38%35%38%2C%32%2E%37%39%31%35%38%34%36%20%34%2E%34%33%36%39%32%33%38%2C%32%2E%31%37%33%39%36%30%35%20%35%2E%34%32%37%30%39%36%32%2C%31%2E%38%30%31%37%32%35%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%5A%20%4D%20%33%2E%38%36%35%31%38%38%31%2C%35%2E%39%38%37%33%31%34%37%20%56%20%37%2E%31%34%32%30%34%31%31%20%48%20%39%2E%33%30%33%32%35%38%34%20%56%20%35%2E%39%38%37%33%31%34%37%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto");
$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"resize-ew",$app$main$ui$cursors$resize_ew$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"resize-nesw",$app$main$ui$cursors$resize_nesw$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,
"resize-ns",$app$main$ui$cursors$resize_ns$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"resize-nwse",$app$main$ui$cursors$resize_nwse$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"rotate",$app$main$ui$cursors$rotate$$);
$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"text",$app$main$ui$cursors$text$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"scale-ew",$app$main$ui$cursors$scale_ew$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,
"scale-nesw",$app$main$ui$cursors$scale_nesw$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"scale-ns",$app$main$ui$cursors$scale_ns$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"scale-nwse",$app$main$ui$cursors$scale_nwse$$);
$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"resize-ew-2",$app$main$ui$cursors$resize_ew_2$$);$app$main$ui$css_cursors$init_dynamic_cursor_style$$($G__93468_93474_element$jscomp$inline_14299_options$jscomp$653_style$jscomp$inline_10900_style$jscomp$inline_14300_worker$jscomp$inline_10897$$,"resize-ns-2",$app$main$ui$cursors$resize_ns_2$$);$rumext$v2$render_BANG_$$();
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$initialize$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$initialize$$()]))},$app$main$ui$cursors$default$0$$={Picker:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%36%30%37%20%31%33%2E%30%37%36%76%32%2E%34%30%31%6C%32%2E%32%32%34%2E%30%32%35%20%37%2E%38%36%2D%37%2E%34%30%35%73%2D%2E%30%35%2D%2E%38%38%35%2D%2E%32%35%33%2D%31%2E%30%38%37%63%2D%2E%32%30%32%2D%2E%32%30%32%2D%32%2E%32%35%2D%31%2E%37%34%34%2D%32%2E%32%35%2D%31%2E%37%34%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%2E%33%34%33%20%31%35%2E%39%37%34%61%2E%35%31%34%2E%35%31%34%20%30%20%30%31%2D%2E%33%31%37%2D%2E%33%32%31%63%2D%2E%30%32%33%2D%2E%30%37%2D%2E%30%32%36%2D%2E%32%33%2D%2E%30%32%36%2D%31%2E%34%33%20%30%2D%31%2E%34%36%38%2D%2E%30%30%31%2D%31%2E%34%34%35%2E%30%39%2D%31%2E%35%38%36%2E%30%32%2D%2E%30%33%32%20%31%2E%37%30%33%2D%31%2E%37%32%34%20%33%2E%37%34%2D%33%2E%37%35%39%61%35%39%36%2E%38%30%35%20%35%39%36%2E%38%30%35%20%30%20%30%30%33%2E%37%2D%33%2E%37%31%36%63%30%2D%2E%30%30%39%2D%2E%33%36%37%2D%2E%33%38%34%2D%2E%38%31%36%2D%2E%38%33%33%61%32%39%2E%39%20%32%39%2E%39%20%30%20%30%31%2D%2E%38%31%37%2D%2E%38%33%33%63%30%2D%2E%30%31%2E%34%37%34%2D%2E%34%39%20%31%2E%30%35%34%2D%31%2E%30%37%6C%31%2E%30%35%33%2D%31%2E%30%35%33%2E%39%34%38%2E%39%34%36%2E%39%34%37%2E%39%34%37%20%31%2E%34%31%37%2D%31%2E%34%31%33%43%31%32%2E%33%36%36%2E%38%30%36%20%31%32%2E%37%36%35%2E%34%31%38%20%31%32%2E%38%35%36%2E%33%35%37%63%2E%32%33%38%2D%2E%31%36%31%2E%35%32%2D%2E%32%38%2E%37%39%32%2D%2E%33%33%34%2E%31%37%2D%2E%30%33%34%2E%35%38%36%2D%2E%30%33%2E%37%36%2E%30%30%38%2E%38%30%31%2E%31%37%33%20%31%2E%34%31%2E%37%39%34%20%31%2E%35%37%20%31%2E%36%30%33%2E%30%33%2E%31%35%2E%30%33%2E%35%36%39%20%30%20%2E%37%31%38%61%32%2E%32%32%37%20%32%2E%32%32%37%20%30%20%30%31%2D%2E%33%33%34%2E%37%39%33%63%2D%2E%30%36%31%2E%30%39%2D%2E%34%35%2E%34%39%2D%31%2E%34%39%36%20%31%2E%35%34%4C%31%32%2E%37%33%34%20%36%2E%31%6C%2E%39%34%37%2E%39%34%38%2E%39%34%37%2E%39%34%37%2D%31%2E%30%35%33%20%31%2E%30%35%34%63%2D%2E%35%38%2E%35%38%2D%31%2E%30%36%31%20%31%2E%30%35%34%2D%31%2E%30%37%20%31%2E%30%35%34%2D%2E%30%31%20%30%2D%2E%33%38%34%2D%2E%33%36%38%2D%2E%38%33%33%2D%2E%38%31%37%2D%2E%34%35%2D%2E%34%35%2D%2E%38%32%34%2D%2E%38%31%37%2D%2E%38%33%34%2D%2E%38%31%37%2D%2E%30%30%39%20%30%2D%31%2E%36%38%20%31%2E%36%36%36%2D%33%2E%37%31%36%20%33%2E%37%30%31%61%34%39%33%2E%30%39%33%20%34%39%33%2E%30%39%33%20%30%20%30%31%2D%33%2E%37%35%39%20%33%2E%37%34%63%2D%2E%31%34%2E%30%39%31%2D%2E%31%31%37%2E%30%39%2D%31%2E%35%39%2E%30%38%39%2D%31%2E%31%38%37%20%30%2D%31%2E%33%36%36%2D%2E%30%30%34%2D%31%2E%34%33%2D%2E%30%32%37%7A%6D%36%2E%30%32%34%2D%34%2E%36%33%33%61%35%39%32%2E%37%32%33%20%35%39%32%2E%37%32%33%20%30%20%30%30%33%2E%36%36%33%2D%33%2E%36%38%63%30%2D%2E%30%32%2D%31%2E%36%37%2D%31%2E%36%39%2D%31%2E%36%39%2D%31%2E%36%39%2D%2E%30%31%20%30%2D%31%2E%36%36%36%20%31%2E%36%34%38%2D%33%2E%36%38%20%33%2E%36%36%33%4C%2E%39%39%36%20%31%33%2E%32%39%37%76%2E%38%33%34%63%30%20%2E%36%32%37%2E%30%30%35%2E%38%33%39%2E%30%32%2E%38%35%34%2E%30%31%35%2E%30%31%34%2E%32%32%37%2E%30%32%2E%38%35%34%2E%30%32%68%2E%38%33%33%6C%33%2E%36%36%34%2D%33%2E%36%36%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto",
Pencil:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%31%31%2E%34%2E%34%4C%30%20%31%31%2E%38%76%34%2E%36%68%34%2E%36%4C%31%36%20%35%20%31%31%2E%34%2E%34%7A%6D%30%20%31%2E%35%4C%31%32%2E%35%20%33%20%32%2E%36%20%31%33%6C%2D%31%2E%31%2D%31%2E%32%20%39%2E%39%2D%31%30%7A%6D%32%20%32%4C%31%34%2E%35%20%35%20%34%2E%36%20%31%35%6C%2D%31%2E%32%2D%31%2E%32%20%31%30%2D%31%30%7A%4D%31%20%31%32%2E%39%6C%32%2E%34%20%32%2E%33%48%31%76%2D%32%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 24, auto",
ResizeNs:$app$main$ui$cursors$resize_ns$$,CreateShape:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%37%20%37%56%31%68%31%76%36%68%36%76%31%48%38%76%36%48%37%56%38%48%31%56%37%68%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%36%2E%35%2E%35%68%32%76%36%68%36%76%32%68%2D%36%76%36%68%2D%32%76%2D%36%68%2D%36%76%2D%32%68%36%76%2D%36%7A%4D%37%20%37%48%31%76%31%68%36%76%36%68%31%56%38%68%36%56%37%48%38%56%31%48%37%76%36%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
Comments:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%6D%36%2E%39%20%31%32%2E%35%31%39%2D%32%2E%35%33%34%39%20%32%2E%30%32%32%32%2D%30%2E%31%37%30%33%39%2D%32%2E%38%30%32%31%63%2D%30%2E%39%34%31%37%38%2D%30%2E%35%35%39%39%36%2D%32%2E%39%33%33%2D%32%2E%32%39%34%38%2D%33%2E%33%36%32%31%2D%34%2E%37%35%31%35%2D%30%2E%34%32%39%30%37%2D%32%2E%34%35%35%31%20%32%2E%36%36%34%32%2D%34%2E%37%37%35%35%20%34%2E%32%36%33%36%2D%35%2E%36%32%38%32%20%33%2E%37%30%33%36%2D%30%2E%34%39%35%36%37%20%31%30%2E%38%36%32%2D%30%2E%31%32%31%35%39%20%39%2E%38%36%38%35%20%35%2E%33%33%36%32%2D%30%2E%39%39%34%34%34%20%35%2E%34%35%37%38%2D%35%2E%37%39%30%38%20%36%2E%31%35%36%34%2D%38%2E%30%36%35%35%20%35%2E%38%32%33%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%6D%37%2E%38%36%34%32%20%30%2E%33%38%36%39%38%63%2D%32%2E%32%36%20%30%2E%30%32%37%38%38%32%2D%34%2E%35%36%38%37%20%30%2E%38%38%36%37%39%2D%36%2E%31%30%31%34%20%32%2E%35%38%36%2D%31%2E%30%31%34%36%20%31%2E%31%30%35%32%2D%31%2E%36%31%34%38%20%32%2E%36%32%30%31%2D%31%2E%34%38%31%36%20%34%2E%31%32%39%36%20%30%2E%31%30%35%33%33%20%31%2E%37%34%38%38%20%31%2E%31%32%39%32%20%33%2E%33%33%39%36%20%32%2E%34%39%33%39%20%34%2E%33%39%32%39%20%30%2E%32%35%30%39%33%20%30%2E%31%39%38%32%37%20%30%2E%35%31%32%37%31%20%30%2E%33%38%32%36%20%30%2E%37%37%39%39%31%20%30%2E%35%35%38%34%31%20%30%2E%30%32%39%34%33%31%20%30%2E%39%38%39%30%32%2D%30%2E%30%32%36%33%33%33%20%31%2E%39%38%35%38%20%30%2E%30%37%32%38%30%32%20%32%2E%39%36%39%34%20%30%2E%31%36%33%34%32%20%30%2E%33%39%37%33%31%20%30%2E%37%33%37%33%31%20%30%2E%34%39%35%36%37%20%31%2E%30%34%33%32%20%30%2E%32%30%33%36%39%20%30%2E%38%31%32%34%34%2D%30%2E%36%36%39%39%33%20%31%2E%36%33%33%34%2D%31%2E%33%33%30%36%20%32%2E%34%34%36%36%2D%32%2E%30%30%31%33%20%30%2E%37%36%30%35%35%20%30%2E%30%37%37%34%35%20%31%2E%35%33%31%39%20%30%2E%30%33%34%38%36%20%32%2E%32%38%37%38%2D%30%2E%30%36%38%31%35%20%32%2E%31%32%38%33%2D%30%2E%33%34%36%32%20%34%2E%31%38%30%37%2D%31%2E%34%39%39%34%20%35%2E%33%37%34%39%2D%33%2E%33%32%35%37%20%30%2E%38%31%30%38%39%2D%31%2E%32%32%31%34%20%31%2E%31%37%37%32%2D%32%2E%37%36%31%38%20%30%2E%38%35%35%38%31%2D%34%2E%32%30%35%35%2D%30%2E%33%31%32%31%32%2D%31%2E%34%38%34%37%2D%31%2E%32%37%36%34%2D%32%2E%37%37%31%31%2D%32%2E%34%39%36%32%2D%33%2E%36%34%34%37%2D%31%2E%35%31%36%34%2D%31%2E%31%30%33%36%2D%33%2E%34%31%30%31%2D%31%2E%36%33%30%33%2D%35%2E%32%37%35%38%2D%31%2E%35%39%34%37%7A%6D%30%2E%31%37%34%32%36%20%31%2E%33%30%38%39%63%31%2E%38%36%39%36%20%30%2E%30%30%36%39%37%20%33%2E%38%30%32%37%20%30%2E%36%35%36%37%37%20%35%2E%31%32%31%37%20%32%2E%30%33%30%37%20%30%2E%38%30%33%39%32%20%30%2E%38%32%32%35%31%20%31%2E%33%32%38%32%20%31%2E%39%35%33%33%20%31%2E%32%36%38%36%20%33%2E%31%30%37%32%2D%30%2E%30%32%34%37%38%20%31%2E%33%30%38%39%2D%30%2E%37%32%36%34%37%20%32%2E%35%33%36%34%2D%31%2E%36%39%36%31%20%33%2E%33%38%39%32%2D%31%2E%33%38%34%38%20%31%2E%32%33%31%34%2D%33%2E%32%37%39%32%20%31%2E%38%32%31%36%2D%35%2E%31%31%30%31%20%31%2E%37%32%30%39%2D%30%2E%33%31%35%39%39%20%30%2E%30%31%30%38%34%2D%30%2E%36%33%39%37%33%2D%30%2E%30%38%38%32%39%2D%30%2E%39%34%36%34%32%2D%30%2E%30%34%39%35%37%2D%30%2E%35%39%38%36%38%20%30%2E%34%38%37%31%35%2D%31%2E%31%39%36%36%20%30%2E%39%37%34%33%31%2D%31%2E%37%39%33%37%20%31%2E%34%36%32%32%2D%30%2E%30%31%35%34%39%2D%30%2E%36%38%39%33%2D%30%2E%30%31%32%33%39%32%2D%31%2E%33%37%39%34%2D%30%2E%30%32%30%31%33%37%2D%32%2E%30%36%39%34%2D%31%2E%33%36%37%37%2D%30%2E%36%38%39%32%39%2D%32%2E%36%30%39%33%2D%31%2E%38%30%34%36%2D%33%2E%30%38%37%31%2D%33%2E%32%39%33%39%2D%30%2E%34%31%32%30%33%2D%31%2E%32%35%34%37%2D%30%2E%31%37%35%30%33%2D%32%2E%37%30%36%38%20%30%2E%36%34%35%31%35%2D%33%2E%37%35%36%33%20%31%2E%32%39%31%31%2D%31%2E%37%33%37%32%20%33%2E%35%31%2D%32%2E%35%35%31%39%20%35%2E%36%31%38%31%2D%32%2E%35%34%30%33%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 2 20, auto",
ScaleEw:$app$main$ui$cursors$scale_ew$$,CreatePolygon:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%73%74%72%6F%6B%65%3D%27%23%66%66%66%27%20%73%74%72%6F%6B%65%2D%77%69%64%74%68%3D%27%2E%35%27%20%64%3D%27%4D%31%32%2E%32%2E%39%4C%31%32%20%2E%35%6C%2D%2E%33%2E%34%2D%33%2E%34%20%36%2D%2E%32%2E%33%48%31%35%2E%39%6C%2D%2E%33%2D%2E%33%2D%33%2E%34%2D%36%7A%6D%31%20%34%2E%38%68%2D%32%2E%35%4C%31%32%20%33%2E%35%6C%31%2E%33%20%32%2E%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
PointerMove:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'42px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%31%37%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%20%31%2E%32%36%33%20%31%2E%32%36%33%2E%35%32%36%2D%2E%35%32%36%76%31%2E%32%36%33%68%2D%2E%39%34%37%6C%2E%35%32%36%2D%2E%35%32%37%4C%36%2E%32%20%31%37%2E%32%32%32%6C%2D%32%2E%38%34%32%20%32%2E%38%34%32%4C%36%2E%32%20%32%32%2E%39%30%37%6C%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%36%2D%2E%35%32%36%68%2E%39%34%37%76%31%2E%34%37%34%6C%2D%2E%35%32%36%2D%2E%36%33%32%2D%31%2E%32%36%33%20%31%2E%33%36%39%20%32%2E%38%34%32%20%32%2E%38%34%32%20%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%33%2D%31%2E%32%36%34%2D%2E%35%32%37%2E%35%32%37%76%2D%31%2E%34%37%34%68%2E%39%34%38%6C%2D%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%34%20%31%2E%32%36%34%20%32%2E%38%34%32%2D%32%2E%38%34%33%2D%32%2E%38%34%32%2D%32%2E%38%34%32%2D%31%2E%32%36%34%20%31%2E%32%36%33%2E%35%32%37%2E%35%32%37%68%2D%2E%39%34%38%76%2D%31%2E%32%36%33%6C%2E%35%32%37%2E%35%32%36%20%31%2E%32%36%33%2D%31%2E%32%36%33%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%38%2E%39%33%37%20%31%34%2E%39%30%37%6C%2D%32%2E%31%30%35%20%32%2E%31%30%35%2E%35%32%36%2E%35%32%36%20%31%2E%30%35%32%2D%31%2E%30%35%33%76%33%2E%30%35%33%48%35%2E%36%37%34%6C%31%2E%30%35%32%2D%31%2E%30%35%33%2D%2E%35%32%36%2D%2E%35%32%36%2D%32%2E%31%30%35%20%32%2E%31%30%35%4C%36%2E%32%20%32%32%2E%31%37%6C%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%32%2D%31%2E%30%35%32%48%38%2E%34%31%76%33%2E%32%36%33%4C%37%2E%33%35%38%20%32%32%2E%38%6C%2D%2E%35%32%36%2E%35%32%37%20%32%2E%31%30%35%20%32%2E%31%30%35%20%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%36%2D%2E%35%32%37%2D%31%2E%30%35%33%20%31%2E%30%35%33%56%32%30%2E%35%39%48%31%32%2E%32%6C%2D%31%2E%30%35%33%20%31%2E%30%35%32%2E%35%32%37%2E%35%32%37%20%32%2E%31%30%35%2D%32%2E%31%30%36%2D%32%2E%31%30%35%2D%32%2E%31%30%35%2D%2E%35%32%37%2E%35%32%36%20%31%2E%30%35%33%20%31%2E%30%35%33%48%39%2E%34%36%33%76%2D%33%2E%30%35%33%6C%31%2E%30%35%33%20%31%2E%30%35%33%2E%35%32%36%2D%2E%35%32%36%7A%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto",
ResizeEw:$app$main$ui$cursors$resize_ew$$,Pen:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%63%2D%2E%37%2E%32%20%30%20%2E%33%2D%2E%37%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%6C%2D%2E%33%2E%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%32%2E%37%20%38%2E%36%6C%33%20%33%2D%34%20%34%2E%31%2D%33%2D%33%20%2E%37%2D%2E%37%20%32%2E%33%20%32%2E%33%20%32%2E%36%2D%32%2E%36%4C%31%32%20%39%2E%34%6C%2E%37%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%32%2E%33%20%31%61%31%37%2E%34%20%31%37%2E%34%20%30%20%30%30%31%2E%33%2E%34%4C%37%20%32%63%31%2E%37%2E%32%20%33%2E%32%2E%38%20%34%2E%32%20%31%2E%39%43%31%32%2E%34%20%34%2E%39%20%31%33%20%36%2E%33%20%31%33%20%38%63%30%20%2E%38%20%30%20%31%2E%35%2D%2E%33%20%32%2E%31%6C%2D%2E%38%2D%2E%38%4C%31%32%20%38%63%30%2D%32%2E%39%2D%32%2D%34%2E%36%2D%35%2D%35%61%34%36%2E%34%20%34%36%2E%34%20%30%20%30%31%2D%35%2D%31%6C%2E%33%20%31%2E%31%63%2E%32%2E%39%2E%35%20%32%2E%32%2E%37%20%33%2E%39%2E%34%20%33%20%32%2E%31%20%35%20%35%20%35%68%31%2E%33%6C%2E%38%2E%37%63%2D%2E%36%2E%32%2D%31%2E%33%2E%33%2D%32%2E%31%2E%33%2D%31%2E%37%20%30%2D%33%2E%31%2D%2E%36%2D%34%2E%31%2D%31%2E%37%2D%31%2D%31%2D%31%2E%37%2D%32%2E%35%2D%31%2E%39%2D%34%2E%32%61%34%36%20%34%36%20%30%20%30%30%2D%31%2D%34%2E%37%76%2D%2E%31%4C%2E%35%2E%35%6C%31%2E%38%2E%35%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%2E%36%20%31%2E%36%63%2E%32%2D%2E%31%2E%36%2D%2E%31%2E%38%20%30%6C%35%20%35%61%2E%35%2E%35%20%30%20%31%31%2D%2E%38%2E%38%6C%2D%35%2D%35%61%2E%35%2E%35%20%30%20%30%31%30%2D%2E%38%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%37%2E%35%20%39%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto",
ScaleNs:$app$main$ui$cursors$scale_ns$$,PointerNode:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'32px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%33%2E%36%56%32%2E%34%6C%38%2E%32%20%38%2E%32%48%34%7A%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%30%20%31%36%56%30%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%32%2E%34%76%31%31%2E%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%32%33%31%66%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%39%2E%31%34%33%20%31%39%2E%34%32%39%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%30%30%2D%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%30%30%20%33%2E%32%34%38%7A%6D%33%2E%34%38%39%2D%31%2E%36%32%34%61%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%31%31%2D%36%2E%39%37%38%20%30%20%33%2E%34%38%39%20%33%2E%34%38%39%20%30%20%30%31%36%2E%39%37%38%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C%70%61%74%68%20%64%3D%27%4D%31%32%2E%32%31%20%31%37%2E%38%30%35%61%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%31%31%2D%36%2E%31%33%35%20%30%20%33%2E%30%36%38%20%33%2E%30%36%38%20%30%20%30%31%36%2E%31%33%35%20%30%7A%6D%2D%31%2E%30%32%32%20%30%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%2D%34%2E%30%39%20%30%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%34%2E%30%39%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto",
Hand:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%33%2E%35%20%35%2E%33%38%76%2D%33%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%2D%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%35%2D%31%20%32%2E%35%2D%31%20%33%20%30%76%31%63%2E%38%2D%2E%32%34%20%31%2E%32%34%2D%2E%31%35%20%32%20%2E%35%76%37%2E%35%63%30%20%33%2D%33%20%34%2D%33%20%34%68%2D%37%73%2D%33%2D%31%2E%31%35%2D%33%2D%34%76%2D%35%2E%35%63%2E%38%32%2D%2E%38%36%20%31%2E%32%35%2D%2E%39%20%32%2D%2E%35%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%30%63%2D%2E%37%33%20%30%2D%31%2E%36%2E%32%39%2D%31%2E%39%38%20%31%2E%30%34%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2E%31%37%63%2D%2E%33%33%2D%2E%31%33%2D%2E%36%39%2D%2E%32%2D%31%2E%30%32%2D%2E%32%2D%2E%37%33%20%30%2D%31%2E%36%2E%33%2D%31%2E%39%38%20%31%2E%30%35%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2E%32%33%56%34%2E%36%61%31%2E%34%39%20%31%2E%34%39%20%30%20%30%30%2D%2E%35%39%20%30%63%2D%2E%34%37%2E%31%2D%2E%38%37%2E%34%33%2D%31%2E%33%2E%38%38%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%31%34%2E%33%35%76%35%2E%35%39%63%30%20%31%2E%36%35%2E%38%37%20%32%2E%38%20%31%2E%37%20%33%2E%35%61%36%2E%35%34%20%36%2E%35%34%20%30%20%30%30%31%2E%35%32%2E%39%37%6C%2E%31%2E%30%35%2E%30%34%2E%30%31%68%2E%30%31%61%2E%35%2E%35%20%30%20%30%30%2E%31%38%2E%30%34%68%37%2E%31%31%63%2E%30%36%20%30%20%2E%31%31%20%30%20%2E%31%37%2D%2E%30%33%68%2E%30%31%6C%2E%30%33%2D%2E%30%31%2E%31%32%2D%2E%30%35%41%35%2E%34%20%35%2E%34%20%30%20%30%30%31%33%2E%34%20%31%35%63%2E%38%34%2D%2E%37%20%31%2E%37%31%2D%31%2E%38%34%20%31%2E%37%31%2D%33%2E%35%36%56%33%2E%38%61%2E%35%2E%35%20%30%20%30%30%2D%2E%31%38%2D%2E%33%39%20%33%20%33%20%30%20%30%30%2D%31%2E%32%2D%2E%37%20%31%2E%39%35%20%31%2E%39%35%20%30%20%30%30%2D%2E%36%35%2D%2E%30%34%76%2D%2E%34%61%2E%35%2E%35%20%30%20%30%30%2D%2E%30%35%2D%2E%32%32%63%2D%2E%33%38%2D%2E%37%35%2D%31%2E%32%35%2D%31%2E%30%34%2D%31%2E%39%38%2D%31%2E%30%34%2D%2E%33%33%20%30%2D%2E%37%2E%30%36%2D%31%2E%30%32%2E%32%61%2E%35%31%2E%35%31%20%30%20%30%30%2D%2E%30%35%2D%2E%31%38%43%39%2E%36%2E%33%20%38%2E%37%33%20%30%20%38%20%30%7A%6D%30%20%31%2E%30%32%63%2E%34%38%20%30%20%2E%38%35%2E%31%37%20%31%2E%30%32%2E%33%39%76%33%2E%39%32%68%31%2E%30%31%56%32%2E%34%35%63%2E%31%36%2D%2E%32%33%2E%35%32%2D%2E%34%32%20%31%2E%30%32%2D%2E%34%32%2E%34%38%20%30%20%2E%38%34%2E%31%38%20%31%2E%30%31%2E%34%76%32%2E%39%68%31%2E%30%32%56%33%2E%37%31%63%2E%31%36%2D%2E%30%32%2E%33%2D%2E%30%32%2E%34%20%30%20%2E%31%37%2E%30%34%2E%33%35%2E%31%34%2E%36%32%2E%33%34%76%37%2E%33%38%63%30%20%31%2E%33%33%2D%2E%36%36%20%32%2E%32%31%2D%31%2E%33%35%20%32%2E%37%38%61%34%2E%39%38%20%34%2E%39%38%20%30%20%30%31%2D%31%2E%32%35%2E%37%36%6C%2D%2E%30%34%2E%30%31%48%34%2E%35%32%61%34%2E%37%35%20%34%2E%37%35%20%30%20%30%31%2D%31%2E%32%37%2D%2E%38%32%20%33%2E%35%35%20%33%2E%35%35%20%30%20%30%31%2D%31%2E%33%35%2D%32%2E%37%33%56%36%2E%30%35%63%2E%33%32%2D%2E%33%31%2E%35%31%2D%2E%34%31%2E%36%35%2D%2E%34%34%2E%30%38%2D%2E%30%32%2E%32%20%30%20%2E%33%37%2E%30%36%76%32%2E%37%31%68%31%2E%30%32%56%32%2E%34%33%63%2E%31%36%2D%2E%32%32%2E%35%33%2D%2E%34%20%31%2E%30%31%2D%2E%34%2E%35%20%30%20%2E%38%36%2E%31%39%20%31%2E%30%32%2E%34%32%76%32%2E%38%38%68%31%2E%30%31%56%31%2E%34%31%63%2E%31%37%2D%2E%32%32%2E%35%34%2D%2E%34%20%31%2E%30%32%2D%2E%34%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
PointerInner:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%31%20%31%34%2E%36%56%33%2E%34%6C%38%2E%32%20%38%2E%32%48%34%6C%2D%33%20%33%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%30%20%31%37%56%31%6C%31%31%2E%36%20%31%31%2E%36%48%34%2E%34%4C%30%20%31%37%7A%6D%34%2D%35%2E%34%68%35%2E%32%4C%31%20%33%2E%34%76%31%31%2E%32%6C%33%2D%33%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto",
ScaleNwse:$app$main$ui$cursors$scale_nwse$$,ResizeNesw:$app$main$ui$cursors$resize_nesw$$,Zoom:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%34%39%36%34%39%30%35%2C%30%2E%30%33%33%32%31%39%31%31%20%30%2E%30%30%37%34%34%2C%30%2E%30%30%37%34%35%33%34%20%43%20%34%2E%36%39%39%39%39%32%37%2C%30%2E%30%33%31%30%39%32%20%32%2E%39%34%35%30%35%32%32%2C%30%2E%38%33%30%37%34%37%36%34%20%31%2E%37%34%38%36%31%39%36%2C%32%2E%31%36%34%39%31%36%33%20%30%2E%35%36%31%38%32%38%38%38%2C%33%2E%34%32%36%30%30%33%39%20%2D%30%2E%30%34%39%37%31%31%33%35%2C%35%2E%31%35%36%33%33%38%20%30%2E%30%34%31%37%37%31%31%35%2C%36%2E%38%36%38%30%36%36%31%20%30%2E%31%30%32%38%38%36%37%39%2C%38%2E%37%36%30%35%39%39%37%20%31%2E%30%36%33%37%35%33%39%2C%31%30%2E%35%35%36%38%31%34%20%32%2E%35%34%36%31%34%32%36%2C%31%31%2E%37%31%32%38%33%33%20%63%20%30%2E%30%30%31%39%32%2C%30%2E%30%30%31%35%20%30%2E%30%30%35%35%33%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%34%35%2C%30%20%31%2E%32%39%32%32%33%36%35%2C%31%2E%30%32%33%32%35%34%20%32%2E%39%37%36%36%34%30%37%2C%31%2E%35%31%31%32%35%34%20%34%2E%36%31%33%37%30%38%35%2C%31%2E%33%34%39%30%38%31%20%31%2E%31%31%36%31%30%39%34%2C%2D%30%2E%30%37%37%35%33%20%32%2E%31%30%37%31%37%31%35%2C%2D%30%2E%35%38%30%35%31%39%20%33%2E%30%31%31%32%30%38%39%2C%2D%31%2E%31%36%32%37%34%34%20%31%2E%32%39%36%38%37%33%2C%31%2E%31%37%34%38%34%36%20%32%2E%37%38%34%35%35%2C%32%2E%37%30%33%30%36%31%20%33%2E%39%38%30%31%36%32%2C%33%2E%38%30%38%37%33%31%20%6C%20%30%2E%30%32%39%38%2C%30%2E%30%32%32%33%36%20%30%2E%30%33%37%32%38%2C%30%2E%30%32%32%33%36%20%63%20%30%2E%37%30%30%37%31%35%2C%30%2E%34%36%33%35%38%38%20%31%2E%36%35%37%32%34%33%2C%2D%30%2E%30%31%33%30%34%20%31%2E%36%39%39%33%38%38%2C%2D%30%2E%38%35%37%31%35%36%20%30%2E%30%32%38%33%38%2C%2D%30%2E%33%35%32%32%31%37%20%2D%30%2E%31%33%36%30%33%32%2C%2D%30%2E%36%35%39%31%39%39%20%2D%30%2E%32%39%30%36%38%36%2C%2D%30%2E%38%34%32%32%34%33%20%2D%30%2E%31%35%38%37%34%35%2C%2D%30%2E%31%38%37%38%38%38%20%2D%30%2E%33%30%38%36%35%31%2C%2D%30%2E%33%31%32%33%34%31%20%2D%30%2E%33%37%32%36%37%34%2C%2D%30%2E%33%38%37%35%38%32%20%6C%20%2D%30%2E%30%30%37%34%2C%2D%30%2E%30%30%37%34%20%2D%30%2E%30%31%34%39%32%2C%2D%30%2E%30%31%34%39%32%20%43%20%31%34%2E%31%31%36%32%34%2C%31%32%2E%34%37%37%39%34%20%31%32%2E%39%37%30%32%32%35%2C%31%31%2E%33%35%32%31%39%36%20%31%31%2E%38%34%30%36%34%2C%31%30%2E%32%31%34%36%38%32%20%31%32%2E%35%32%37%35%39%35%2C%39%2E%31%37%36%30%30%33%37%20%31%33%2E%30%39%39%38%31%36%2C%38%2E%30%31%30%31%30%38%37%20%31%33%2E%31%30%30%32%38%2C%36%2E%37%32%36%34%35%30%31%20%31%33%2E%31%33%34%36%33%31%2C%35%2E%36%35%32%31%33%37%32%20%31%32%2E%39%30%37%35%31%39%2C%34%2E%35%36%30%30%35%36%20%31%32%2E%33%39%39%36%35%32%2C%33%2E%35%39%35%39%38%35%37%20%31%31%2E%34%31%35%30%31%31%2C%31%2E%36%35%37%39%31%30%34%20%39%2E%34%34%35%37%33%33%38%2C%30%2E%32%36%30%36%33%30%36%39%20%37%2E%32%35%36%37%34%35%39%2C%30%2E%30%36%33%30%33%33%30%35%20%68%20%2D%30%2E%30%30%37%34%34%20%43%20%37%2E%31%37%30%32%35%31%2C%30%2E%30%35%35%34%37%31%39%37%20%37%2E%30%38%39%38%36%30%34%2C%30%2E%30%36%30%32%39%31%31%36%20%37%2E%30%31%30%37%38%31%2C%30%2E%30%35%35%35%37%39%35%38%20%56%20%30%2E%30%33%33%32%31%39%31%31%20%48%20%36%2E%35%31%31%33%39%37%33%20%63%20%2D%30%2E%30%30%34%39%32%2C%36%2E%30%39%38%65%2D%35%20%2D%30%2E%30%31%2C%2D%37%2E%31%31%34%65%2D%35%20%2D%30%2E%30%31%34%39%32%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%34%34%2C%31%2E%30%30%36%32%32%30%36%39%20%68%20%30%2E%30%30%37%34%34%20%63%20%30%2E%32%31%35%37%36%33%33%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%35%33%32%39%34%2C%30%2E%30%30%39%31%38%20%30%2E%36%34%38%34%35%33%35%2C%30%2E%30%32%39%38%31%36%20%31%2E%38%31%33%36%36%31%34%2C%30%2E%31%36%31%37%32%31%31%20%33%2E%35%31%32%31%33%38%2C%31%2E%33%36%33%34%33%36%39%20%34%2E%33%33%37%39%32%39%2C%32%2E%39%38%38%38%34%38%20%68%20%30%2E%30%30%37%34%20%76%20%30%2E%30%30%37%34%34%20%63%20%30%2E%34%32%33%30%35%35%2C%30%2E%38%30%30%35%33%34%32%20%30%2E%36%32%30%31%39%32%2C%31%2E%37%32%31%38%30%32%35%20%30%2E%35%38%38%38%36%31%2C%32%2E%36%33%38%35%34%34%34%20%6C%20%2D%30%2E%30%30%37%34%2C%30%2E%30%30%37%34%34%20%76%20%30%2E%30%30%37%34%34%20%43%20%31%32%2E%30%38%37%31%35%35%2C%37%2E%32%39%33%30%35%35%36%20%31%31%2E%36%39%36%35%35%36%2C%37%2E%37%38%38%30%31%35%35%20%31%31%2E%34%39%37%37%38%2C%38%2E%33%33%36%34%30%33%32%20%31%31%2E%39%35%39%30%37%33%2C%37%2E%30%35%32%39%34%34%32%20%31%31%2E%39%35%34%36%34%38%2C%35%2E%36%31%31%36%30%30%35%20%31%31%2E%33%37%38%35%32%34%2C%34%2E%33%37%31%31%34%38%34%20%31%30%2E%35%36%36%30%35%32%2C%32%2E%35%35%36%33%39%35%35%20%38%2E%36%39%39%37%34%30%39%2C%31%2E%32%38%37%32%38%32%38%20%36%2E%36%39%30%32%38%31%2C%31%2E%32%38%35%34%30%34%39%20%63%20%2D%30%2E%30%31%36%34%34%38%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%34%35%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%32%38%34%2C%30%20%43%20%35%2E%36%38%33%35%30%30%36%2C%31%2E%32%34%36%39%38%39%39%20%34%2E%38%30%35%34%30%36%37%2C%31%2E%36%38%38%34%39%33%39%20%33%2E%39%38%34%36%36%35%38%2C%32%2E%31%37%32%33%36%39%38%20%34%2E%38%30%35%31%35%39%38%2C%31%2E%36%39%32%34%31%37%36%20%35%2E%35%36%30%36%32%34%2C%31%2E%30%33%32%38%31%34%37%20%36%2E%35%30%33%39%34%34%31%2C%31%2E%30%33%39%34%33%39%38%20%5A%20%6D%20%30%2E%31%30%34%33%36%30%38%2C%31%2E%32%35%32%31%38%35%37%20%68%20%30%2E%30%31%34%39%32%31%20%30%2E%30%30%37%34%34%20%63%20%30%2E%30%32%35%39%38%38%2C%30%20%30%2E%30%34%35%38%38%36%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%35%39%36%32%38%2C%30%20%31%2E%35%37%37%39%34%32%36%2C%30%2E%30%30%31%34%37%20%33%2E%31%32%37%34%36%30%37%2C%31%2E%30%35%33%33%34%20%33%2E%37%37%31%34%36%34%37%2C%32%2E%34%39%36%39%31%38%31%20%76%20%30%2E%30%30%37%34%35%20%63%20%30%2E%34%37%35%33%31%31%2C%31%2E%30%32%33%33%39%37%38%20%30%2E%35%30%39%31%35%36%2C%32%2E%32%36%35%35%39%33%36%20%30%2E%30%39%36%38%39%2C%33%2E%33%31%36%38%30%31%35%20%43%20%31%30%2E%30%30%34%33%39%37%2C%39%2E%35%33%33%30%32%37%36%20%38%2E%36%32%36%32%30%35%37%2C%31%30%2E%36%33%34%34%38%37%20%37%2E%31%31%35%31%33%2C%31%30%2E%38%30%33%35%30%37%20%36%2E%34%33%36%39%35%36%31%2C%31%30%2E%38%37%39%38%35%32%20%35%2E%37%35%32%30%39%34%34%2C%31%30%2E%38%32%39%39%31%38%20%35%2E%31%34%37%34%30%39%35%2C%31%30%2E%35%39%34%38%31%20%68%20%2D%30%2E%30%30%37%34%34%20%6C%20%2D%30%2E%30%31%34%39%32%31%2C%2D%30%2E%30%30%37%34%20%43%20%33%2E%35%31%39%36%39%36%39%2C%31%30%2E%30%34%31%30%32%39%20%32%2E%33%31%37%32%33%33%39%2C%38%2E%33%38%34%35%36%33%31%20%32%2E%33%30%30%31%37%37%36%2C%36%2E%36%38%39%31%38%32%34%20%76%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%43%20%32%2E%32%34%32%32%35%39%35%2C%35%2E%33%34%37%35%38%33%35%20%32%2E%38%39%38%33%39%31%39%2C%33%2E%39%39%37%39%32%36%36%20%33%2E%39%35%34%38%35%31%37%2C%33%2E%31%38%36%30%34%33%39%20%76%20%2D%30%2E%30%30%37%34%35%20%43%20%34%2E%37%30%38%33%33%32%36%2C%32%2E%35%39%30%31%34%20%35%2E%36%36%36%32%34%32%38%2C%32%2E%32%35%34%32%39%38%35%20%36%2E%36%30%38%32%39%32%39%2C%32%2E%32%39%31%36%32%35%35%20%5A%20%4D%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%43%20%32%2E%30%32%32%37%35%31%32%2C%33%2E%35%30%33%31%33%37%32%20%31%2E%32%33%33%35%31%35%36%2C%35%2E%30%37%36%31%32%39%31%20%31%2E%33%30%31%34%31%30%34%2C%36%2E%37%31%31%35%34%33%20%63%20%30%2E%30%32%35%36%31%2C%32%2E%30%36%38%39%30%33%39%20%31%2E%34%35%35%36%36%38%36%2C%33%2E%38%39%33%31%20%33%2E%33%36%38%39%37%36%2C%34%2E%36%35%30%39%37%36%20%43%20%34%2E%31%37%32%37%36%37%37%2C%31%31%2E%31%36%38%37%36%33%20%33%2E%35%38%38%30%32%31%2C%31%31%2E%32%35%32%38%30%37%20%33%2E%31%37%32%32%33%35%35%2C%31%30%2E%39%32%32%37%36%33%20%31%2E%39%32%31%31%31%36%2C%39%2E%39%35%30%33%35%38%34%20%31%2E%31%30%34%34%36%37%34%2C%38%2E%34%30%35%30%36%31%20%31%2E%30%35%35%34%34%35%33%2C%36%2E%38%33%30%37%39%38%38%20%76%20%2D%30%2E%30%30%37%34%35%20%2D%30%2E%30%30%37%34%35%20%43%20%30%2E%39%37%37%30%35%35%31%36%2C%35%2E%33%38%30%30%34%31%36%20%31%2E%34%39%37%38%37%37%33%2C%33%2E%39%30%31%31%36%36%35%20%32%2E%34%38%36%35%31%34%37%2C%32%2E%38%35%30%36%33%37%20%6C%20%30%2E%30%30%37%34%35%2C%2D%30%2E%30%30%37%34%35%20%43%20%32%2E%36%39%32%30%39%38%2C%32%2E%36%32%31%35%32%35%35%20%33%2E%30%35%30%39%35%31%36%2C%32%2E%36%37%31%32%32%34%34%20%33%2E%32%38%34%30%33%37%38%2C%32%2E%34%38%35%34%31%36%32%20%5A%20%6D%20%38%2E%31%33%39%32%30%37%32%2C%36%2E%30%35%32%32%33%31%33%20%63%20%2D%30%2E%32%30%37%37%37%34%2C%30%2E%35%31%31%36%32%36%34%20%2D%30%2E%32%31%34%36%32%39%2C%31%2E%30%38%32%30%36%30%39%20%2D%30%2E%35%35%31%35%35%38%2C%31%2E%35%32%37%39%36%34%35%20%6C%20%2D%30%2E%32%36%30%38%37%2C%30%2E%33%35%30%33%31%34%20%30%2E%33%30%35%35%39%32%2C%30%2E%33%31%33%30%34%36%20%63%20%31%2E%32%30%32%31%30%35%2C%31%2E%32%31%35%33%31%33%20%32%2E%34%32%35%35%34%32%2C%32%2E%33%39%36%33%36%38%20%33%2E%36%30%30%30%33%34%2C%33%2E%36%31%34%39%34%31%20%30%2E%31%34%34%30%35%2C%30%2E%31%36%33%37%31%38%20%30%2E%32%38%32%30%31%32%2C%30%2E%32%38%34%33%38%32%20%30%2E%33%35%30%33%31%35%2C%30%2E%33%36%35%32%32%20%30%2E%30%37%32%35%37%2C%30%2E%30%38%35%38%39%20%30%2E%30%36%32%32%38%2C%30%2E%30%38%30%32%37%20%30%2E%30%35%39%36%33%2C%30%2E%31%30%34%33%35%20%76%20%30%2E%30%31%34%39%32%20%30%2E%30%31%34%39%32%20%63%20%2D%36%2E%35%39%65%2D%34%2C%30%2E%30%31%37%32%35%20%2D%30%2E%31%33%31%30%35%35%2C%30%2E%30%37%34%30%37%20%2D%30%2E%31%34%31%36%31%34%2C%30%2E%30%36%37%30%38%20%2D%31%2E%32%31%31%30%37%2C%2D%31%2E%31%32%34%37%35%34%20%2D%32%2E%37%36%37%34%39%34%2C%2D%32%2E%37%34%36%36%30%32%20%2D%34%2E%31%33%36%36%38%39%2C%2D%33%2E%39%36%35%32%38%33%20%4C%20%31%30%2E%33%34%32%34%39%2C%31%30%2E%36%37%36%38%20%31%30%2E%30%31%34%35%33%38%2C%31%30%2E%39%31%35%33%31%31%20%43%20%39%2E%31%33%38%31%38%34%34%2C%31%31%2E%35%34%37%32%33%20%38%2E%31%32%38%32%30%32%2C%31%31%2E%39%39%33%31%36%34%20%37%2E%30%39%32%37%36%39%34%2C%31%32%2E%30%36%33%31%34%37%20%68%20%2D%30%2E%30%30%37%34%34%20%2D%30%2E%30%30%37%34%34%20%63%20%2D%30%2E%35%32%39%38%39%31%38%2C%30%2E%30%35%33%39%34%20%2D%30%2E%39%37%39%37%37%37%37%2C%2D%30%2E%33%33%34%30%34%36%20%2D%31%2E%35%30%35%36%32%38%31%2C%2D%30%2E%34%33%39%37%35%36%20%30%2E%35%35%33%33%39%36%38%2C%30%2E%31%30%35%37%34%33%20%31%2E%31%31%31%31%32%35%2C%30%2E%32%34%37%35%32%37%20%31%2E%36%35%34%36%37%33%38%2C%30%2E%31%38%36%33%33%37%20%31%2E%38%38%31%32%39%35%37%2C%2D%30%2E%32%31%30%34%33%32%20%33%2E%34%38%30%35%34%35%39%2C%2D%31%2E%35%34%34%39%31%39%20%34%2E%31%39%36%33%31%32%39%2C%2D%33%2E%32%37%32%30%38%30%35%20%7A%27%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%36%39%30%36%33%31%20%43%20%34%2E%38%34%39%35%32%30%38%2C%30%2E%35%32%35%32%37%34%30%35%20%33%2E%32%31%38%34%36%38%36%2C%31%2E%32%37%35%31%39%38%31%20%32%2E%31%31%36%38%30%37%38%2C%32%2E%35%30%37%36%38%34%34%20%31%2E%30%32%38%32%36%31%36%2C%33%2E%36%36%34%33%37%37%33%20%30%2E%34%36%32%30%33%33%35%2C%35%2E%32%36%39%39%32%34%39%20%30%2E%35%34%38%30%31%38%33%37%2C%36%2E%38%34%34%38%38%37%34%20%30%2E%36%30%32%30%38%39%35%39%2C%38%2E%35%38%31%32%39%34%33%20%31%2E%34%39%31%39%38%33%32%2C%31%30%2E%32%35%35%39%35%37%20%32%2E%38%36%31%39%37%33%38%2C%31%31%2E%33%32%30%37%35%31%20%63%20%31%2E%31%39%30%34%34%38%36%2C%30%2E%39%34%34%39%35%39%20%32%2E%37%35%37%30%39%31%38%2C%31%2E%34%30%31%31%36%31%20%34%2E%32%36%36%37%32%35%38%2C%31%2E%32%34%37%34%37%37%20%31%2E%31%35%36%34%33%37%33%2C%2D%30%2E%30%37%38%31%36%20%32%2E%32%34%38%31%31%36%39%2C%2D%30%2E%35%37%30%35%36%36%20%33%2E%31%38%31%32%31%31%34%2C%2D%31%2E%32%34%33%34%30%32%20%31%2E%33%36%33%39%38%37%2C%31%2E%32%31%34%30%34%35%20%32%2E%39%35%36%32%32%2C%32%2E%38%36%35%38%30%31%20%34%2E%31%39%33%31%36%31%2C%34%2E%30%30%39%36%39%31%20%30%2E%33%35%37%34%38%35%2C%30%2E%32%33%36%35%31%20%30%2E%39%30%38%35%33%35%2C%2D%30%2E%30%33%34%31%35%20%30%2E%39%32%35%31%35%2C%2D%30%2E%34%36%38%39%38%36%20%30%2E%30%34%32%37%2C%2D%30%2E%33%38%38%32%39%32%20%2D%30%2E%33%33%32%30%38%32%2C%2D%30%2E%36%31%33%33%37%36%20%2D%30%2E%35%35%30%34%36%34%2C%2D%30%2E%38%37%30%30%32%32%20%43%20%31%33%2E%36%39%35%38%30%38%2C%31%32%2E%37%36%39%32%20%31%32%2E%34%37%35%31%36%31%2C%31%31%2E%35%38%31%30%38%31%20%31%31%2E%32%37%37%35%34%35%2C%31%30%2E%33%37%30%33%30%35%20%31%32%2E%30%37%30%31%31%38%2C%39%2E%33%32%31%33%38%37%33%20%31%32%2E%35%39%36%34%32%35%2C%38%2E%30%34%33%30%38%38%36%20%31%32%2E%35%39%35%31%36%31%2C%36%2E%37%32%31%33%34%39%20%31%32%2E%36%32%39%33%30%37%2C%35%2E%37%32%32%32%32%34%35%20%31%32%2E%34%31%38%38%30%31%2C%34%2E%37%31%33%33%32%31%37%20%31%31%2E%39%35%30%39%38%35%2C%33%2E%38%32%38%30%32%34%33%20%31%31%2E%30%34%35%32%38%33%2C%32%2E%30%34%35%33%32%34%38%20%39%2E%32%30%38%33%37%30%31%2C%30%2E%37%34%33%37%37%32%38%35%20%37%2E%32%30%35%37%35%30%33%2C%30%2E%35%36%35%32%30%32%37%31%20%36%2E%39%37%33%31%38%30%31%2C%30%2E%35%34%32%36%38%38%36%33%20%36%2E%37%33%39%33%39%30%37%2C%30%2E%35%33%33%36%38%33%30%35%20%36%2E%35%30%35%37%38%38%36%2C%30%2E%35%33%37%30%36%30%31%34%20%5A%20%4D%20%36%2E%36%39%31%35%36%38%32%2C%31%2E%37%38%39%39%33%36%37%20%43%20%38%2E%34%38%36%33%38%36%2C%31%2E%37%39%31%36%31%34%20%31%30%2E%31%39%33%39%35%32%2C%32%2E%39%34%39%37%34%34%20%31%30%2E%39%32%31%34%37%31%2C%34%2E%35%38%30%35%32%36%31%20%31%31%2E%34%35%37%34%38%35%2C%35%2E%37%33%34%36%31%38%37%20%31%31%2E%34%39%35%39%35%38%2C%37%2E%31%31%30%38%36%31%20%31%31%2E%30%33%31%36%37%37%2C%38%2E%32%39%34%37%30%35%37%20%31%30%2E%34%30%37%39%30%33%2C%39%2E%38%39%33%31%30%31%35%20%38%2E%38%38%33%36%36%31%32%2C%31%31%2E%31%31%37%30%32%39%20%37%2E%31%36%39%35%36%32%35%2C%31%31%2E%33%30%38%37%35%38%20%36%2E%34%32%38%39%32%35%37%2C%31%31%2E%33%39%32%31%33%35%20%35%2E%36%36%35%32%39%34%35%2C%31%31%2E%33%33%38%30%32%37%20%34%2E%39%36%35%39%39%37%33%2C%31%31%2E%30%36%36%31%33%32%20%33%2E%31%34%35%33%30%39%32%2C%31%30%2E%34%34%36%35%32%33%20%31%2E%38%31%36%32%30%34%32%2C%38%2E%36%32%31%32%31%39%33%20%31%2E%37%39%36%38%34%32%31%2C%36%2E%36%39%36%36%35%31%31%20%31%2E%37%33%31%32%31%33%37%2C%35%2E%31%39%33%33%34%33%36%20%32%2E%34%35%37%30%34%37%35%2C%33%2E%36%39%37%38%34%30%37%20%33%2E%36%34%35%38%34%38%37%2C%32%2E%37%38%34%32%35%34%35%20%34%2E%34%38%38%36%32%38%34%2C%32%2E%31%32%36%30%36%33%39%20%35%2E%35%35%37%39%30%36%33%2C%31%2E%37%34%37%37%34%39%31%20%36%2E%36%33%31%35%32%35%38%2C%31%2E%37%39%30%32%38%39%34%20%63%20%30%2E%30%31%39%38%38%32%2C%30%20%30%2E%30%34%30%30%33%39%2C%2D%33%2E%36%30%32%65%2D%34%20%30%2E%30%36%30%30%33%36%2C%2D%33%2E%34%38%39%65%2D%34%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
CreateEllipse:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%34%61%33%20%33%20%30%20%31%31%2D%36%20%30%20%33%20%33%20%30%20%30%31%36%20%30%7A%6D%2D%31%20%30%61%32%20%32%20%30%20%31%31%2D%34%20%30%20%32%20%32%20%30%20%30%31%34%20%30%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%2E%35%20%33%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%36%2D%33%2E%35%61%31%2E%35%20%31%2E%35%20%30%20%31%30%30%2D%33%20%31%2E%35%20%31%2E%35%20%30%20%30%30%30%20%33%7A%4D%31%35%2E%35%20%34%61%33%2E%35%20%33%2E%35%20%30%20%31%31%2D%37%20%30%20%33%2E%35%20%33%2E%35%20%30%20%30%31%37%20%30%7A%4D%31%32%20%37%61%33%20%33%20%30%20%31%30%30%2D%36%20%33%20%33%20%30%20%30%30%30%20%36%7A%6D%30%2D%31%61%32%20%32%20%30%20%31%30%30%2D%34%20%32%20%32%20%30%20%30%30%30%20%34%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
MovePointer:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%36%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%7A%4D%38%20%31%31%76%33%2E%32%7A%27%20%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%38%20%31%4C%36%20%33%6C%2E%35%2E%35%20%31%2D%31%56%37%68%2D%35%6C%31%2D%31%2D%2E%35%2D%2E%35%2D%32%20%32%20%32%20%32%20%2E%35%2D%2E%35%2D%31%2D%31%68%35%76%35%2E%35%6C%2D%31%2D%31%2D%2E%35%2E%35%20%32%20%32%20%32%2D%32%2D%2E%35%2D%2E%35%2D%31%20%31%56%38%68%35%6C%2D%31%20%31%20%2E%35%2E%35%20%32%2D%32%2D%32%2D%32%2D%2E%35%2E%35%20%31%20%31%68%2D%35%56%32%2E%35%6C%31%20%31%4C%31%30%20%33%20%38%20%31%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%38%20%2E%33%4C%35%2E%33%20%33%6C%31%2E%32%20%31%2E%32%2E%35%2D%2E%35%76%32%2E%38%48%33%2E%37%6C%2E%35%2D%2E%35%4C%33%20%34%2E%38%2E%33%20%37%2E%35%20%33%20%31%30%2E%32%20%34%2E%32%20%39%6C%2D%2E%35%2D%2E%35%48%37%76%33%2E%38%6C%2D%2E%35%2D%2E%35%4C%35%2E%33%20%31%33%20%38%20%31%35%2E%37%6C%32%2E%37%2D%32%2E%37%2D%31%2E%32%2D%31%2E%32%2D%2E%35%2E%35%56%38%2E%35%68%33%2E%33%6C%2D%2E%35%2E%35%20%31%2E%32%20%31%2E%32%20%32%2E%37%2D%32%2E%37%4C%31%33%20%34%2E%38%20%31%31%2E%38%20%36%6C%2E%35%2E%35%48%39%56%33%2E%37%6C%2E%35%2E%35%4C%31%30%2E%37%20%33%20%38%20%2E%33%7A%4D%38%20%31%6C%32%20%32%2D%2E%35%2E%35%2D%31%2D%31%56%37%68%35%6C%2D%31%2D%31%20%2E%35%2D%2E%35%20%32%20%32%2D%32%20%32%2D%2E%35%2D%2E%35%20%31%2D%31%68%2D%35%76%35%2E%35%6C%31%2D%31%20%2E%35%2E%35%2D%32%20%32%2D%32%2D%32%20%2E%35%2D%2E%35%20%31%20%31%56%38%68%2D%35%6C%31%20%31%2D%2E%35%2E%35%2D%32%2D%32%20%32%2D%32%20%2E%35%2E%35%2D%31%20%31%68%35%56%32%2E%35%6C%2D%31%20%31%4C%36%20%33%6C%32%2D%32%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ScaleNesw:$app$main$ui$cursors$scale_nesw$$,Rotate:$app$main$ui$cursors$rotate$$,PenNode:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'36px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%37%20%30%2D%2E%30%30%31%2D%2E%31%30%31%2E%36%39%39%2D%2E%33%30%31%6C%33%20%33%20%34%2D%34%2E%31%2D%33%2D%33%20%2E%33%2D%2E%36%63%30%2D%31%2E%37%2D%2E%36%2D%33%2E%30%39%39%2D%31%2E%38%2D%34%2E%30%39%39%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%33%2E%36%32%39%20%31%33%2E%38%30%38%61%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%20%36%2E%39%37%39%20%33%2E%34%39%20%33%2E%34%39%20%30%20%30%30%30%2D%36%2E%39%37%39%7A%6D%30%20%31%2E%38%36%36%61%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%31%31%2E%30%30%32%20%33%2E%32%34%38%20%31%2E%36%32%34%20%31%2E%36%32%34%20%30%20%30%31%2D%2E%30%30%32%2D%33%2E%32%34%38%7A%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%37%31%39%2E%37%31%39%6C%2E%35%20%31%2E%38%76%2E%31%61%34%35%2E%39%38%35%20%34%35%2E%39%38%35%20%30%20%30%31%31%20%34%2E%37%63%2E%32%20%31%2E%37%2E%39%20%33%2E%32%20%31%2E%39%20%34%2E%32%20%31%20%31%2E%31%20%32%2E%34%20%31%2E%37%20%34%2E%31%20%31%2E%37%2E%33%33%33%20%30%20%2E%36%33%39%2D%2E%30%32%38%2E%39%33%37%2D%2E%30%36%33%6C%32%2E%37%36%32%20%32%2E%37%36%32%20%34%2D%34%2E%31%2D%32%2E%37%32%39%2D%32%2E%37%32%38%63%2E%30%31%38%2D%2E%32%38%2E%30%33%2D%2E%35%36%32%2E%30%33%2D%2E%38%37%31%20%30%2D%31%2E%37%2D%2E%36%30%31%2D%33%2E%31%2D%31%2E%38%30%31%2D%34%2E%31%2D%31%2D%31%2E%31%2D%32%2E%35%2D%31%2E%37%2D%34%2E%32%2D%31%2E%39%6C%2D%33%2E%34%2D%2E%36%63%2D%2E%34%33%38%2D%2E%31%31%36%2D%2E%38%37%2D%2E%32%35%2D%31%2E%32%39%38%2D%2E%34%4C%2E%37%31%39%2E%37%31%39%7A%6D%32%2E%35%33%37%20%31%2E%37%33%36%63%31%2E%33%31%2E%33%30%36%20%32%2E%36%33%2E%35%37%33%20%33%2E%39%36%33%2E%37%36%34%20%33%20%2E%34%20%35%20%32%2E%31%20%35%20%35%6C%2D%2E%31%20%31%2E%33%2E%31%2E%31%2E%36%39%39%2E%37%20%31%2E%36%30%32%20%31%2E%35%39%39%2D%32%2E%36%30%32%20%32%2E%36%30%32%2D%31%2E%36%2D%31%2E%36%30%32%2D%2E%30%30%34%2D%2E%30%30%34%2D%2E%36%39%35%2D%2E%36%39%35%2D%2E%30%34%37%2E%30%34%37%2D%2E%30%35%32%2D%2E%30%34%37%48%38%2E%32%31%39%63%2D%32%2E%39%20%30%2D%34%2E%36%2D%32%2D%35%2D%35%2D%2E%32%2D%31%2E%37%2D%2E%35%2D%32%2E%39%39%39%2D%2E%37%2D%33%2E%38%39%39%4C%36%2E%33%33%20%37%2E%31%33%63%2D%2E%33%34%2E%38%38%34%2E%31%32%20%32%2E%30%38%39%20%31%2E%33%38%39%20%32%2E%30%38%39%20%32%20%30%20%32%2D%33%20%30%2D%33%2D%2E%32%32%34%20%30%2D%2E%34%31%39%2E%30%34%2D%2E%35%39%32%2E%31%30%37%6C%2D%33%2E%38%37%31%2D%33%2E%38%37%7A%4D%34%2E%33%34%38%20%31%34%2E%39%35%61%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%20%36%2E%31%33%35%20%33%2E%30%36%37%20%33%2E%30%36%37%20%30%20%31%30%30%2D%36%2E%31%33%35%7A%6D%30%20%31%2E%30%32%34%61%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%31%31%30%20%34%2E%30%39%20%32%2E%30%34%35%20%32%2E%30%34%35%20%30%20%30%31%30%2D%34%2E%30%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%63%6F%6C%6F%72%3D%27%23%30%30%30%27%20%66%6F%6E%74%2D%66%61%6D%69%6C%79%3D%27%73%61%6E%73%2D%73%65%72%69%66%27%20%66%6F%6E%74%2D%77%65%69%67%68%74%3D%27%34%30%30%27%20%6F%76%65%72%66%6C%6F%77%3D%27%76%69%73%69%62%6C%65%27%20%73%74%79%6C%65%3D%27%6C%69%6E%65%2D%68%65%69%67%68%74%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6C%69%67%61%74%75%72%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%70%6F%73%69%74%69%6F%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%63%61%70%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%6E%75%6D%65%72%69%63%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%61%6C%74%65%72%6E%61%74%65%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%6E%74%2D%65%61%73%74%2D%61%73%69%61%6E%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%66%65%61%74%75%72%65%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%66%6F%6E%74%2D%76%61%72%69%61%74%69%6F%6E%2D%73%65%74%74%69%6E%67%73%3A%6E%6F%72%6D%61%6C%3B%74%65%78%74%2D%69%6E%64%65%6E%74%3A%30%3B%74%65%78%74%2D%61%6C%69%67%6E%3A%73%74%61%72%74%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%6C%69%6E%65%3A%6E%6F%6E%65%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%73%74%79%6C%65%3A%73%6F%6C%69%64%3B%74%65%78%74%2D%64%65%63%6F%72%61%74%69%6F%6E%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%74%65%78%74%2D%74%72%61%6E%73%66%6F%72%6D%3A%6E%6F%6E%65%3B%74%65%78%74%2D%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%6D%69%78%65%64%3B%77%68%69%74%65%2D%73%70%61%63%65%3A%6E%6F%72%6D%61%6C%3B%73%68%61%70%65%2D%70%61%64%64%69%6E%67%3A%30%3B%73%68%61%70%65%2D%6D%61%72%67%69%6E%3A%30%3B%69%6E%6C%69%6E%65%2D%73%69%7A%65%3A%30%3B%69%73%6F%6C%61%74%69%6F%6E%3A%61%75%74%6F%3B%6D%69%78%2D%62%6C%65%6E%64%2D%6D%6F%64%65%3A%6E%6F%72%6D%61%6C%3B%73%6F%6C%69%64%2D%63%6F%6C%6F%72%3A%23%30%30%30%3B%73%6F%6C%69%64%2D%6F%70%61%63%69%74%79%3A%31%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 10, auto",
ZoomIn:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%31%33%36%34%30%32%2C%30%2E%30%33%33%34%30%32%37%38%20%30%2E%30%30%37%39%32%2C%30%2E%30%30%37%39%30%38%33%20%43%20%34%2E%37%31%33%30%35%39%36%2C%30%2E%30%33%31%37%30%36%33%20%32%2E%39%35%34%33%35%30%35%2C%30%2E%38%33%33%30%35%31%38%35%20%31%2E%37%35%34%39%30%30%31%2C%32%2E%31%37%30%35%38%35%35%20%30%2E%35%36%35%31%31%35%36%36%2C%33%2E%34%33%34%38%35%34%31%20%2D%30%2E%30%34%38%39%33%31%37%39%2C%35%2E%31%36%39%37%38%35%39%20%30%2E%30%34%32%37%38%30%36%39%2C%36%2E%38%38%35%38%33%31%37%20%30%2E%31%30%34%30%35%30%39%33%2C%38%2E%37%38%33%31%33%38%34%20%31%2E%30%36%37%34%39%37%33%2C%31%30%2E%35%38%34%34%39%20%32%2E%35%35%33%36%32%34%37%2C%31%31%2E%37%34%33%34%32%34%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%31%2C%30%20%31%2E%32%39%35%34%39%36%34%2C%31%2E%30%32%35%38%33%36%20%32%2E%39%38%35%30%38%33%34%2C%31%2E%35%31%34%38%38%31%20%34%2E%36%32%36%32%37%39%36%2C%31%2E%33%35%32%32%39%38%20%31%2E%31%31%38%39%32%34%34%2C%2D%30%2E%30%37%37%37%32%20%32%2E%31%31%32%36%32%35%36%2C%2D%30%2E%35%38%32%37%36%32%20%33%2E%30%31%38%39%34%33%37%2C%2D%31%2E%31%36%36%34%35%35%20%31%2E%33%30%30%31%34%35%2C%31%2E%31%37%37%38%30%39%20%32%2E%37%39%31%30%34%34%2C%32%2E%37%30%39%32%30%39%20%33%2E%39%38%39%36%37%31%2C%33%2E%38%31%37%36%36%39%20%6C%20%30%2E%30%32%39%36%35%2C%30%2E%30%32%33%37%32%20%30%2E%30%33%37%35%37%2C%30%2E%30%32%31%37%33%20%63%20%30%2E%37%30%32%34%39%34%2C%30%2E%34%36%34%37%37%39%20%31%2E%36%36%31%39%35%39%2C%2D%30%2E%30%31%33%37%33%20%31%2E%37%30%34%32%31%2C%2D%30%2E%38%35%39%39%39%32%20%30%2E%30%32%38%34%36%2C%2D%30%2E%33%35%33%31%30%37%20%2D%30%2E%31%33%37%35%35%37%2C%2D%30%2E%36%36%30%36%39%31%20%2D%30%2E%32%39%32%36%30%32%2C%2D%30%2E%38%34%34%31%39%37%20%2D%30%2E%31%35%39%31%34%36%2C%2D%30%2E%31%38%38%33%36%20%2D%30%2E%33%30%39%34%37%37%2C%2D%30%2E%33%31%32%30%36%38%20%2D%30%2E%33%37%33%36%36%33%2C%2D%30%2E%33%38%37%35%30%31%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%35%2C%2D%30%2E%30%31%35%38%20%43%20%31%34%2E%31%35%33%38%32%36%2C%31%32%2E%35%30%38%36%38%39%20%31%33%2E%30%30%33%38%36%2C%31%31%2E%33%38%31%32%35%36%20%31%31%2E%38%37%31%34%32%35%2C%31%30%2E%32%34%30%38%37%33%20%31%32%2E%35%36%30%31%31%33%2C%39%2E%31%39%39%35%37%34%34%20%31%33%2E%31%33%34%32%39%2C%38%2E%30%33%30%33%38%30%37%20%31%33%2E%31%33%34%37%35%35%2C%36%2E%37%34%33%34%38%34%34%20%31%33%2E%31%36%39%31%39%33%2C%35%2E%36%36%36%34%36%31%38%20%31%32%2E%39%34%32%30%35%33%2C%34%2E%35%37%32%34%32%30%37%20%31%32%2E%34%33%32%39%30%36%2C%33%2E%36%30%35%39%31%38%32%20%31%31%2E%34%34%35%37%38%31%2C%31%2E%36%36%32%39%35%34%39%20%39%2E%34%37%31%32%38%37%35%2C%30%2E%32%36%31%31%35%34%34%36%20%37%2E%32%37%36%37%37%39%32%2C%30%2E%30%36%33%30%35%38%34%33%20%68%20%2D%30%2E%30%30%37%39%32%20%43%20%37%2E%31%38%39%36%31%38%31%2C%30%2E%30%35%35%34%37%38%32%38%20%37%2E%31%30%38%39%32%37%39%2C%30%2E%30%35%39%38%37%33%37%31%20%37%2E%30%32%39%36%34%38%37%2C%30%2E%30%35%35%31%35%30%32%35%20%56%20%30%2E%30%33%33%34%30%32%37%38%20%48%20%36%2E%35%32%39%34%35%36%35%20%63%20%2D%30%2E%30%30%34%39%34%2C%36%2E%31%31%37%65%2D%35%20%2D%30%2E%30%31%30%38%36%35%2C%2D%37%2E%31%33%32%65%2D%35%20%2D%30%2E%30%31%35%38%30%31%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%32%2C%31%2E%30%30%38%32%39%31%36%32%20%68%20%30%2E%30%30%37%39%32%20%63%20%30%2E%32%31%36%33%30%37%35%2C%2D%30%2E%30%30%33%31%33%20%30%2E%34%33%36%37%38%36%33%2C%30%2E%30%30%38%39%37%20%30%2E%36%35%30%34%34%36%37%2C%30%2E%30%32%39%36%35%34%20%31%2E%38%31%38%32%33%36%34%2C%30%2E%31%36%32%31%32%39%20%33%2E%35%31%39%36%34%32%31%2C%31%2E%33%36%37%36%38%35%32%20%34%2E%33%34%37%35%31%36%31%2C%32%2E%39%39%37%31%39%36%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%32%34%31%32%31%2C%30%2E%38%30%32%35%35%33%33%20%30%2E%36%32%32%35%34%35%2C%31%2E%37%32%36%32%32%38%33%20%30%2E%35%39%31%31%33%35%2C%32%2E%36%34%35%32%38%32%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%33%20%76%20%30%2E%30%30%37%39%32%20%43%20%31%32%2E%31%31%39%30%39%36%2C%37%2E%33%31%31%31%30%38%36%20%31%31%2E%37%32%38%36%37%35%2C%37%2E%38%30%36%39%38%31%35%20%31%31%2E%35%32%39%33%39%39%2C%38%2E%33%35%36%37%35%32%34%20%31%31%2E%39%39%31%38%35%34%2C%37%2E%30%37%30%30%35%36%31%20%31%31%2E%39%38%36%33%37%35%2C%35%2E%36%32%36%34%37%38%20%31%31%2E%34%30%38%37%39%39%2C%34%2E%33%38%32%38%39%37%31%20%31%30%2E%35%39%34%32%37%36%2C%32%2E%35%36%33%35%36%35%37%20%38%2E%37%32%33%38%39%35%39%2C%31%2E%32%39%30%37%30%37%33%20%36%2E%37%30%39%33%36%37%39%2C%31%2E%32%38%38%38%32%34%37%20%63%20%2D%30%2E%30%31%36%34%38%39%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%39%30%31%2C%2D%31%2E%30%36%36%65%2D%34%20%2D%30%2E%30%33%37%35%37%2C%30%20%43%20%35%2E%36%39%39%38%36%32%34%2C%31%2E%32%35%30%33%31%32%35%20%34%2E%38%31%39%36%37%36%35%2C%31%2E%36%39%33%33%39%37%34%20%33%2E%39%39%36%38%36%35%36%2C%32%2E%31%37%38%34%39%33%38%20%34%2E%38%31%39%34%32%39%34%2C%31%2E%36%39%37%33%33%31%20%35%2E%35%37%35%38%34%39%31%2C%31%2E%30%33%35%30%35%32%36%20%36%2E%35%32%31%35%34%38%39%2C%31%2E%30%34%31%36%39%34%34%20%5A%20%6D%20%2D%30%2E%30%37%33%31%34%39%2C%31%2E%32%35%33%34%34%34%38%20%63%20%30%2E%30%35%39%30%39%37%2C%2D%35%2E%35%34%34%65%2D%34%20%30%2E%31%31%38%39%30%36%32%2C%2D%33%2E%36%31%37%65%2D%34%20%30%2E%31%37%37%39%33%34%36%2C%30%2E%30%30%31%39%38%20%68%20%30%2E%30%31%35%38%30%31%20%30%2E%30%30%35%39%33%20%63%20%30%2E%30%32%36%30%35%34%2C%30%20%30%2E%30%34%37%35%31%33%2C%2D%37%2E%37%65%2D%36%20%30%2E%30%36%31%32%38%39%2C%30%20%31%2E%35%38%31%39%32%32%36%2C%30%2E%30%30%31%34%38%20%33%2E%31%33%34%34%37%36%36%2C%31%2E%30%35%35%37%31%36%33%20%33%2E%37%38%30%31%30%35%32%2C%32%2E%35%30%32%39%33%35%37%20%76%20%30%2E%30%30%37%39%32%20%63%20%30%2E%34%37%36%35%31%2C%31%2E%30%32%35%39%37%39%31%20%30%2E%35%31%30%31%37%38%2C%32%2E%32%37%31%35%32%36%20%30%2E%30%39%36%38%37%2C%33%2E%33%32%35%33%38%35%33%20%2D%30%2E%35%35%35%36%34%2C%31%2E%34%32%33%38%31%39%36%20%2D%31%2E%39%33%37%30%32%37%2C%32%2E%35%32%37%32%33%35%38%20%2D%33%2E%34%35%31%39%31%33%33%2C%32%2E%36%39%36%36%38%32%38%20%2D%30%2E%36%37%39%38%38%34%38%2C%30%2E%30%37%36%35%33%20%2D%31%2E%33%36%36%38%37%38%37%2C%30%2E%30%32%38%31%32%20%2D%31%2E%39%37%33%30%38%38%37%2C%2D%30%2E%32%30%37%35%38%39%20%68%20%2D%30%2E%30%30%35%39%33%20%6C%20%2D%30%2E%30%31%35%38%30%31%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%33%30%31%39%36%39%2C%31%30%2E%30%36%36%38%31%36%20%32%2E%33%32%35%35%37%30%39%2C%38%2E%34%30%35%35%37%37%36%20%32%2E%33%30%38%34%37%31%2C%36%2E%37%30%35%39%32%30%37%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%35%39%33%20%43%20%32%2E%32%35%30%34%30%37%36%2C%35%2E%33%36%32%30%31%39%34%20%32%2E%39%30%38%30%38%34%38%2C%34%2E%30%30%38%36%32%34%31%20%33%2E%39%36%37%32%30%39%38%2C%33%2E%31%39%34%36%39%33%35%20%76%20%2D%30%2E%30%30%37%39%31%20%43%20%34%2E%36%37%35%33%37%39%39%2C%32%2E%36%33%33%37%32%31%31%20%35%2E%35%36%31%39%34%34%32%2C%32%2E%33%30%33%34%35%35%33%20%36%2E%34%34%38%33%39%37%39%2C%32%2E%32%39%35%31%33%39%32%20%5A%20%4D%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%43%20%32%2E%30%32%38%35%37%30%39%2C%33%2E%35%31%31%31%35%34%34%20%31%2E%32%33%38%30%34%35%35%2C%35%2E%30%38%38%31%32%39%33%20%31%2E%33%30%36%31%31%30%39%2C%36%2E%37%32%37%36%36%38%31%20%31%2E%33%33%31%37%38%35%35%2C%38%2E%38%30%31%37%39%30%34%20%32%2E%37%36%34%37%36%36%2C%31%30%2E%36%33%31%37%32%34%20%34%2E%36%38%32%38%39%39%36%2C%31%31%2E%33%39%31%35%31%31%20%34%2E%31%38%34%30%32%35%37%2C%31%31%2E%31%39%37%32%36%37%20%33%2E%35%39%39%31%35%38%31%2C%31%31%2E%32%38%31%35%30%37%20%33%2E%31%38%32%33%32%34%35%2C%31%30%2E%39%35%30%36%33%20%31%2E%39%32%38%30%34%38%38%2C%39%2E%39%37%35%37%37%32%39%20%31%2E%31%30%38%31%32%36%38%2C%38%2E%34%32%36%35%30%30%36%20%31%2E%30%35%38%39%38%31%32%2C%36%2E%38%34%38%32%36%37%36%20%76%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%30%2E%39%38%30%33%39%30%34%38%2C%35%2E%33%39%32%39%37%39%34%20%31%2E%35%30%33%31%38%33%2C%33%2E%39%31%31%37%37%35%36%20%32%2E%34%39%34%33%31%33%32%2C%32%2E%38%35%38%35%39%36%34%20%6C%20%30%2E%30%30%37%39%31%2C%2D%30%2E%30%30%37%39%31%20%43%20%32%2E%37%30%30%38%34%39%38%2C%32%2E%36%32%38%34%37%30%35%20%33%2E%30%35%39%33%36%35%2C%32%2E%36%37%37%31%34%33%32%20%33%2E%32%39%33%30%33%38%38%2C%32%2E%34%39%30%38%36%36%34%20%5A%20%4D%20%35%2E%35%31%33%32%35%36%39%2C%33%2E%33%34%32%39%37%31%37%20%56%20%33%2E%38%34%35%31%34%30%33%20%35%2E%34%38%38%30%36%32%37%20%48%20%33%2E%33%36%38%31%36%36%37%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%35%2E%35%31%33%32%35%36%39%20%56%20%39%2E%37%39%39%39%39%31%38%20%48%20%37%2E%36%38%38%30%30%34%31%20%56%20%37%2E%36%35%34%39%30%31%31%20%48%20%39%2E%38%33%33%30%39%34%34%20%56%20%35%2E%34%38%38%30%36%32%37%20%48%20%37%2E%36%38%38%30%30%34%31%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%20%6D%20%31%2E%30%31%36%31%39%39%36%2C%31%2E%30%31%30%32%36%38%34%20%68%20%30%2E%31%34%32%33%34%36%39%20%76%20%32%2E%31%34%33%31%31%34%32%20%68%20%32%2E%31%34%35%30%39%31%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%36%2E%36%37%31%38%30%33%38%20%56%20%38%2E%37%39%31%37%30%30%36%20%48%20%36%2E%35%32%39%34%35%36%35%20%56%20%36%2E%36%33%38%37%30%31%32%20%48%20%34%2E%33%38%34%33%36%36%32%20%56%20%36%2E%34%39%36%33%35%34%33%20%48%20%36%2E%35%32%39%34%35%36%35%20%5A%20%4D%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%43%20%31%31%2E%32%34%35%39%37%33%2C%39%2E%30%37%31%33%32%36%20%31%31%2E%32%33%38%34%37%35%2C%39%2E%36%34%33%35%38%38%38%20%31%30%2E%39%30%30%36%39%38%2C%31%30%2E%30%39%30%36%31%37%20%6C%20%2D%30%2E%32%36%30%39%37%2C%30%2E%33%35%31%39%31%34%20%30%2E%33%30%36%34%34%33%2C%30%2E%33%31%34%33%34%37%20%63%20%31%2E%32%30%35%31%33%37%2C%31%2E%32%31%38%33%37%39%20%32%2E%34%33%30%36%34%37%2C%32%2E%34%30%32%32%37%32%20%33%2E%36%30%38%31%30%32%2C%33%2E%36%32%33%39%31%39%20%30%2E%31%34%34%34%31%33%2C%30%2E%31%36%34%31%33%31%20%30%2E%32%38%33%34%33%39%2C%30%2E%32%38%34%37%31%33%20%30%2E%33%35%31%39%31%34%2C%30%2E%33%36%35%37%35%31%20%30%2E%30%37%32%37%35%2C%30%2E%30%38%36%31%20%30%2E%30%36%31%39%37%2C%30%2E%30%38%30%36%34%20%30%2E%30%35%39%33%31%2C%30%2E%31%30%34%37%38%35%20%76%20%30%2E%30%31%33%38%35%20%30%2E%30%31%35%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%39%20%2D%30%2E%31%33%31%37%36%31%2C%30%2E%30%37%34%32%33%20%2D%30%2E%31%34%32%33%34%37%2C%30%2E%30%36%37%32%32%20%2D%31%2E%32%31%34%31%32%35%2C%2D%31%2E%31%32%37%35%38%34%20%2D%32%2E%37%37%33%32%31%31%2C%2D%32%2E%37%35%34%30%37%20%2D%34%2E%31%34%35%38%35%39%2C%2D%33%2E%39%37%35%38%32%34%20%6C%20%2D%30%2E%33%30%36%34%34%33%2C%2D%30%2E%32%36%38%38%37%38%20%2D%30%2E%33%33%30%31%36%38%2C%30%2E%32%33%39%32%32%20%63%20%2D%30%2E%38%37%38%35%36%31%39%2C%30%2E%36%33%33%35%31%34%20%2D%31%2E%38%38%39%39%35%32%2C%31%2E%30%38%30%34%38%31%20%2D%32%2E%39%32%37%39%39%36%39%2C%31%2E%31%35%30%36%34%31%20%68%20%2D%30%2E%30%30%37%39%32%20%2D%30%2E%30%30%37%39%32%20%43%20%36%2E%35%36%35%36%33%39%35%2C%31%32%2E%31%34%37%34%33%39%20%36%2E%31%31%35%35%36%31%35%2C%31%31%2E%37%35%38%34%35%37%20%35%2E%35%38%38%33%38%34%37%2C%31%31%2E%36%35%32%34%38%31%20%36%2E%31%34%33%31%37%37%34%2C%31%31%2E%37%35%38%34%39%20%36%2E%37%30%32%32%30%33%33%2C%31%31%2E%39%30%31%36%34%35%20%37%2E%32%34%37%31%32%33%34%2C%31%31%2E%38%34%30%33%30%32%20%39%2E%31%33%33%31%36%33%39%2C%31%31%2E%36%32%39%33%33%39%20%31%30%2E%37%33%36%36%39%37%2C%31%30%2E%32%38%39%39%32%39%20%31%31%2E%34%35%34%32%37%2C%38%2E%35%35%38%34%30%39%35%20%5A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%43%20%34%2E%38%35%37%38%35%32%37%2C%30%2E%35%33%30%35%30%31%31%36%20%33%2E%32%32%33%38%31%38%31%2C%31%2E%32%38%33%36%31%30%32%20%32%2E%31%31%39%33%37%39%31%2C%32%2E%35%31%39%32%30%35%31%20%31%2E%30%32%38%30%38%37%32%2C%33%2E%36%37%38%38%31%35%34%20%30%2E%34%35%39%34%35%32%30%35%2C%35%2E%32%38%37%37%38%36%35%20%30%2E%35%34%35%36%35%32%38%38%2C%36%2E%38%36%36%37%32%31%34%20%30%2E%35%39%39%38%36%31%36%37%2C%38%2E%36%30%37%35%30%38%31%20%31%2E%34%39%31%32%37%37%36%2C%31%30%2E%32%38%37%31%32%38%20%32%2E%38%36%34%37%32%33%39%2C%31%31%2E%33%35%34%36%30%38%20%63%20%31%2E%31%39%33%34%35%31%2C%30%2E%39%34%37%33%34%32%20%32%2E%37%36%34%38%37%38%32%2C%31%2E%34%30%33%35%36%32%20%34%2E%32%37%38%33%31%39%31%2C%31%2E%32%34%39%34%39%31%20%31%2E%31%35%39%33%35%34%35%2C%2D%30%2E%30%37%38%33%36%20%32%2E%32%35%33%35%32%32%32%2C%2D%30%2E%35%37%31%30%30%34%20%33%2E%31%38%38%39%37%2C%2D%31%2E%32%34%35%35%33%37%20%31%2E%33%36%37%34%32%37%2C%31%2E%32%31%37%31%30%37%20%32%2E%39%36%33%31%33%32%2C%32%2E%38%37%32%35%35%32%20%34%2E%32%30%33%31%39%32%2C%34%2E%30%31%39%33%32%37%20%30%2E%33%35%38%33%38%37%2C%30%2E%32%33%37%31%30%34%20%30%2E%39%31%32%35%35%33%2C%2D%30%2E%30%33%34%35%38%20%30%2E%39%32%39%32%31%2C%2D%30%2E%34%37%30%35%33%37%20%30%2E%30%34%32%38%31%2C%2D%30%2E%33%38%39%32%37%31%20%2D%30%2E%33%33%34%36%33%39%2C%2D%30%2E%36%31%34%35%38%33%20%2D%30%2E%35%35%33%35%37%31%2C%2D%30%2E%38%37%31%38%37%35%20%43%20%31%33%2E%37%32%35%39%31%33%2C%31%32%2E%38%30%36%30%37%34%20%31%32%2E%35%30%33%33%37%37%2C%31%31%2E%36%31%35%35%30%32%20%31%31%2E%33%30%32%37%34%31%2C%31%30%2E%34%30%31%36%37%33%20%31%32%2E%30%39%37%33%31%33%2C%39%2E%33%35%30%31%30%39%34%20%31%32%2E%36%32%34%36%37%34%2C%38%2E%30%36%37%32%34%30%39%20%31%32%2E%36%32%33%34%30%35%2C%36%2E%37%34%32%31%36%37%36%20%31%32%2E%36%35%37%36%33%37%2C%35%2E%37%34%30%35%32%32%39%20%31%32%2E%34%34%35%39%30%38%2C%34%2E%37%32%39%33%37%36%39%20%31%31%2E%39%37%36%39%31%32%2C%33%2E%38%34%31%38%34%36%36%20%31%31%2E%30%36%38%39%32%36%2C%32%2E%30%35%34%36%35%30%34%20%39%2E%32%32%37%38%31%38%36%2C%30%2E%37%35%30%38%33%38%39%33%20%37%2E%32%32%30%31%34%38%2C%30%2E%35%37%31%38%31%38%33%39%20%36%2E%39%38%36%39%39%31%37%2C%30%2E%35%34%39%32%34%36%31%31%20%36%2E%37%35%32%34%38%39%34%2C%30%2E%35%33%38%37%38%32%35%31%20%36%2E%35%31%38%32%39%38%31%2C%30%2E%35%34%32%31%36%32%37%37%20%5A%20%4D%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%63%20%30%2E%30%36%37%31%38%31%2C%2D%35%2E%39%36%33%65%2D%34%20%30%2E%31%33%34%33%38%39%32%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%36%35%38%35%2C%30%2E%30%30%33%39%36%20%30%2E%30%31%39%39%33%32%2C%30%20%30%2E%30%33%39%32%36%34%2C%2D%31%2E%31%33%65%2D%35%20%30%2E%30%35%39%33%31%31%2C%30%20%31%2E%37%39%39%33%34%34%39%2C%30%2E%30%30%31%36%38%20%33%2E%35%31%31%34%30%33%32%2C%31%2E%31%36%32%36%31%39%34%20%34%2E%32%34%30%37%35%36%32%2C%32%2E%37%39%37%35%31%35%20%30%2E%35%33%37%33%36%36%2C%31%2E%31%35%37%30%30%33%35%20%30%2E%35%37%36%31%36%36%2C%32%2E%35%33%35%39%34%20%30%2E%31%31%30%37%31%35%2C%33%2E%37%32%32%37%37%31%31%20%43%20%31%30%2E%34%33%30%32%36%34%2C%39%2E%39%32%32%32%37%35%20%38%2E%39%30%32%39%38%34%2C%31%31%2E%31%35%30%35%33%32%20%37%2E%31%38%34%35%36%31%35%2C%31%31%2E%33%34%32%37%34%35%20%36%2E%34%34%32%30%35%37%2C%31%31%2E%34%32%36%33%33%33%20%35%2E%36%37%35%32%38%38%38%2C%31%31%2E%33%37%32%31%35%20%34%2E%39%37%34%32%32%37%38%2C%31%31%2E%30%39%39%35%37%20%33%2E%31%34%38%39%34%37%33%2C%31%30%2E%34%37%38%33%39%38%20%31%2E%38%31%36%35%33%32%34%2C%38%2E%36%34%37%38%36%35%34%20%31%2E%37%39%37%31%32%30%36%2C%36%2E%37%31%38%34%34%33%33%20%31%2E%37%33%31%33%32%37%36%2C%35%2E%32%31%31%33%34%34%31%20%32%2E%34%35%39%37%38%37%32%2C%33%2E%37%31%31%38%38%31%35%20%33%2E%36%35%31%35%38%37%31%2C%32%2E%37%39%35%39%39%31%31%20%34%2E%34%34%33%36%38%35%34%2C%32%2E%31%37%37%33%38%31%20%35%2E%34%33%35%34%33%39%32%2C%31%2E%38%30%34%35%35%31%33%20%36%2E%34%34%33%31%37%30%33%2C%31%2E%37%39%35%36%30%37%36%20%5A%20%4D%20%36%2E%30%31%36%31%32%39%31%2C%33%2E%38%35%31%37%33%31%38%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%33%2E%38%37%31%30%33%38%39%20%76%20%31%2E%31%35%36%35%36%39%37%20%68%20%32%2E%31%34%35%30%39%30%32%20%76%20%32%2E%31%34%35%30%39%31%20%48%20%37%2E%31%37%32%36%39%38%38%20%56%20%37%2E%31%35%33%33%39%32%35%20%48%20%39%2E%33%31%37%37%39%30%32%20%56%20%35%2E%39%39%36%38%32%32%38%20%48%20%37%2E%31%37%32%36%39%38%38%20%76%20%2D%32%2E%31%34%35%30%39%31%20%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ResizeNs2:$app$main$ui$cursors$resize_ns_2$$,Duplicate:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%35%2E%31%20%30%4C%31%36%20%31%30%2E%39%48%39%2E%32%4C%35%2E%31%20%31%35%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%35%2E%37%20%31%2E%35%6C%38%2E%37%20%38%2E%36%48%39%6C%2D%33%2E%33%20%33%2E%34%7A%6D%33%20%37%2E%39%68%34%4C%36%2E%35%20%33%2E%33%76%38%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%4D%30%20%30%76%31%35%6C%34%2E%31%2D%34%2E%31%68%32%2E%34%76%2E%38%6C%2E%38%2D%2E%38%68%33%2E%36%4C%39%2E%33%20%39%2E%35%68%33%2E%34%4C%36%2E%35%20%33%2E%33%76%33%2E%32%7A%6D%31%20%32%2E%33%6C%35%2E%34%20%35%2E%35%76%32%2E%31%48%33%2E%37%4C%31%20%31%32%2E%37%7A%6D%37%2E%34%20%37%2E%34%6C%2E%32%2E%32%68%2D%2E%34%7A%27%2F%3E%20%3C%70%61%74%68%20%64%3D%27%4D%31%20%31%32%2E%37%56%32%2E%33%6C%37%2E%37%20%37%2E%36%68%2D%35%7A%27%2F%3E%3C/g%3E%3C/svg%3E\") 0 0, auto",
Text:$app$main$ui$cursors$text$$,CreateArtboard:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%34%2D%31%76%35%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%2E%35%20%34%2E%35%68%34%76%2D%34%68%32%76%36%68%2D%36%76%2D%32%7A%4D%35%20%35%48%31%76%31%68%35%56%31%48%35%76%34%7A%6D%33%2E%35%2D%31%2E%35%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%39%20%39%48%34%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%68%2D%35%56%34%48%39%76%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ZoomOut:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%64%3D%27%6D%20%36%2E%35%30%33%35%37%30%34%2C%30%2E%30%33%33%34%30%34%35%36%20%30%2E%30%30%37%39%31%2C%30%2E%30%30%37%38%39%35%37%20%43%20%34%2E%37%30%35%38%36%31%34%2C%30%2E%30%33%31%37%31%30%37%35%20%32%2E%39%34%39%39%35%31%35%2C%30%2E%38%33%31%37%37%39%31%36%20%31%2E%37%35%32%34%31%33%38%2C%32%2E%31%36%37%31%38%31%31%20%30%2E%35%36%34%35%32%35%35%39%2C%33%2E%34%32%39%34%33%34%37%20%2D%30%2E%30%34%38%35%34%32%32%31%2C%35%2E%31%36%31%36%30%31%33%20%30%2E%30%34%33%30%32%34%31%31%2C%36%2E%38%37%34%39%31%32%31%20%30%2E%31%30%34%31%37%37%34%38%2C%38%2E%37%36%39%31%39%34%39%20%31%2E%30%36%36%31%30%36%35%2C%31%30%2E%35%36%37%36%37%35%20%32%2E%35%34%39%38%36%36%34%2C%31%31%2E%37%32%34%37%36%32%20%63%20%30%2E%30%30%31%39%33%2C%30%2E%30%30%31%35%20%30%2E%30%30%36%33%37%2C%2D%30%2E%30%30%31%35%20%30%2E%30%30%37%39%2C%30%20%31%2E%32%39%33%34%33%30%34%2C%31%2E%30%32%34%32%30%32%20%32%2E%39%37%38%33%34%36%37%2C%31%2E%35%31%32%34%36%37%20%34%2E%36%31%36%39%33%31%34%2C%31%2E%33%35%30%31%34%33%20%31%2E%31%31%37%31%34%2C%2D%30%2E%30%37%37%36%20%32%2E%31%30%39%32%36%31%36%2C%2D%30%2E%35%38%31%38%33%33%20%33%2E%30%31%34%31%33%33%32%2C%2D%31%2E%31%36%34%35%39%36%20%31%2E%32%39%38%30%37%31%2C%31%2E%31%37%35%39%33%32%20%32%2E%37%38%38%35%37%2C%32%2E%37%30%34%38%39%31%20%33%2E%39%38%35%32%38%36%2C%33%2E%38%31%31%35%38%34%20%6C%20%30%2E%30%32%39%36%2C%30%2E%30%32%33%36%38%20%30%2E%30%33%37%35%31%2C%30%2E%30%32%31%37%20%63%20%30%2E%37%30%31%33%37%32%2C%30%2E%34%36%34%30%31%37%20%31%2E%36%35%37%33%34%2C%2D%30%2E%30%31%33%37%35%20%31%2E%36%39%39%35%32%31%2C%2D%30%2E%38%35%38%36%34%33%20%30%2E%30%32%38%32%37%2C%2D%30%2E%33%35%32%35%34%34%20%2D%30%2E%31%33%35%33%38%36%2C%2D%30%2E%36%35%39%36%33%38%20%2D%30%2E%32%39%30%31%36%31%2C%2D%30%2E%38%34%32%38%35%31%20%2D%30%2E%31%35%38%39%2C%2D%30%2E%31%38%38%30%36%20%2D%30%2E%33%30%38%39%37%32%2C%2D%30%2E%33%31%31%35%37%20%2D%30%2E%33%37%33%30%36%37%2C%2D%30%2E%33%38%36%38%38%33%20%6C%20%2D%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%2D%30%2E%30%31%33%38%33%2C%2D%30%2E%30%31%35%37%38%20%43%20%31%34%2E%31%33%31%32%38%32%2C%31%32%2E%34%38%38%38%30%38%20%31%32%2E%39%38%33%34%34%34%2C%31%31%2E%33%36%33%31%37%32%20%31%31%2E%38%35%32%38%31%36%2C%31%30%2E%32%32%34%36%30%36%20%31%32%2E%35%34%30%34%30%37%2C%39%2E%31%38%34%39%36%37%32%20%31%33%2E%31%31%33%36%37%31%2C%38%2E%30%31%37%36%33%37%20%31%33%2E%31%31%34%31%33%33%2C%36%2E%37%33%32%37%39%31%37%20%31%33%2E%31%34%38%35%31%38%2C%35%2E%36%35%37%34%38%35%36%20%31%32%2E%39%32%31%37%34%2C%34%2E%35%36%35%31%38%38%32%20%31%32%2E%34%31%33%34%30%32%2C%33%2E%36%30%30%32%32%36%31%20%31%31%2E%34%32%37%38%35%2C%31%2E%36%36%30%33%35%39%35%20%39%2E%34%35%36%35%30%33%2C%30%2E%32%36%30%37%39%33%32%36%20%37%2E%32%36%35%34%39%33%31%2C%30%2E%30%36%33%30%31%32%39%35%20%68%20%2D%30%2E%30%30%37%39%31%20%43%20%37%2E%31%37%38%34%39%31%31%2C%30%2E%30%35%35%34%34%34%39%36%20%37%2E%30%39%37%39%30%31%33%2C%30%2E%30%35%39%38%33%33%32%33%20%37%2E%30%31%38%37%35%36%35%2C%30%2E%30%35%35%31%31%37%33%38%20%56%20%30%2E%30%33%33%34%30%34%35%36%20%68%20%2D%30%2E%34%39%39%33%39%35%20%63%20%2D%30%2E%30%30%34%39%37%2C%36%2E%31%30%38%65%2D%35%20%2D%30%2E%30%31%30%38%31%2C%2D%37%2E%31%32%65%2D%35%20%2D%30%2E%30%31%35%37%37%35%2C%30%20%7A%20%6D%20%30%2E%30%30%37%39%31%2C%31%2E%30%30%36%36%38%34%36%34%20%68%20%30%2E%30%30%37%39%31%20%63%20%30%2E%32%31%35%39%36%36%36%2C%2D%30%2E%30%30%33%31%32%20%30%2E%34%33%36%30%39%30%39%2C%30%2E%30%30%38%39%35%20%30%2E%36%34%39%34%31%31%32%2C%30%2E%30%32%39%36%30%37%20%31%2E%38%31%35%33%33%37%33%2C%30%2E%31%36%31%38%37%30%36%20%33%2E%35%31%34%30%33%31%34%2C%31%2E%33%36%35%35%30%35%34%20%34%2E%33%34%30%35%38%35%34%2C%32%2E%39%39%32%34%31%39%20%68%20%30%2E%30%30%37%39%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%32%33%34%34%36%2C%30%2E%38%30%31%32%37%34%32%20%30%2E%36%32%31%35%35%33%2C%31%2E%37%32%33%34%37%37%31%20%30%2E%35%39%30%31%39%33%2C%32%2E%36%34%31%30%36%36%35%20%6C%20%2D%30%2E%30%30%37%39%2C%30%2E%30%30%35%39%32%20%76%20%30%2E%30%30%37%39%31%20%43%20%31%32%2E%31%30%30%30%39%32%2C%37%2E%32%39%39%35%30%39%39%20%31%31%2E%37%30%38%33%32%2C%37%2E%37%39%34%35%39%32%35%20%31%31%2E%35%30%39%33%35%39%2C%38%2E%33%34%33%34%38%37%31%20%31%31%2E%39%37%31%30%37%39%2C%37%2E%30%35%38%38%34%31%36%20%31%31%2E%39%36%37%35%38%34%2C%35%2E%36%31%37%35%36%34%32%20%31%31%2E%33%39%30%39%32%36%2C%34%2E%33%37%35%39%36%35%34%20%31%30%2E%35%37%37%37%30%36%2C%32%2E%35%35%39%35%33%35%20%38%2E%37%31%30%33%30%31%35%2C%31%2E%32%38%38%37%30%35%32%20%36%2E%36%39%38%39%38%36%31%2C%31%2E%32%38%36%38%32%35%36%20%63%20%2D%30%2E%30%31%36%34%32%35%2C%2D%39%2E%33%65%2D%36%20%2D%30%2E%30%32%35%36%36%38%2C%2D%31%2E%30%36%34%65%2D%34%20%2D%30%2E%30%33%37%35%30%39%2C%30%20%43%20%35%2E%36%39%31%30%38%37%36%2C%31%2E%32%34%38%33%37%34%39%20%34%2E%38%31%32%33%30%38%34%2C%31%2E%36%39%30%37%35%33%35%20%33%2E%39%39%30%38%30%37%2C%32%2E%31%37%35%30%37%36%38%20%34%2E%38%31%32%30%36%30%39%2C%31%2E%36%39%34%36%38%30%39%20%35%2E%35%36%37%32%37%35%31%2C%31%2E%30%33%33%34%35%37%39%20%36%2E%35%31%31%34%36%36%35%2C%31%2E%30%34%30%30%38%39%32%20%5A%20%6D%20%2D%30%2E%30%37%33%30%33%33%2C%31%2E%32%35%31%34%34%37%31%20%63%20%30%2E%30%35%39%30%30%33%2C%2D%35%2E%35%33%36%65%2D%34%20%30%2E%31%31%38%37%31%36%37%2C%2D%33%2E%36%31%32%65%2D%34%20%30%2E%31%37%37%36%35%31%2C%30%2E%30%30%31%39%37%20%68%20%30%2E%30%31%35%37%37%35%20%30%2E%30%30%35%39%32%20%63%20%30%2E%30%32%35%39%37%34%2C%30%20%30%2E%30%34%37%34%30%33%2C%2D%37%2E%36%65%2D%36%20%30%2E%30%36%31%31%39%32%2C%30%20%31%2E%35%37%39%34%30%31%33%2C%30%2E%30%30%31%34%38%20%33%2E%31%32%39%34%38%30%39%2C%31%2E%30%35%34%30%33%33%38%20%33%2E%37%37%34%30%38%30%36%2C%32%2E%34%39%38%39%34%36%35%20%76%20%30%2E%30%30%37%39%31%20%63%20%30%2E%34%37%35%37%34%39%2C%31%2E%30%32%34%33%34%33%39%20%30%2E%35%30%39%33%36%33%2C%32%2E%32%36%37%39%30%35%37%20%30%2E%30%39%36%37%32%2C%33%2E%33%32%30%30%38%35%33%20%2D%30%2E%35%35%34%37%36%2C%31%2E%34%32%31%35%35%34%20%2D%31%2E%39%33%33%39%34%31%33%2C%32%2E%35%32%33%32%31%30%39%20%2D%33%2E%34%34%36%34%31%33%32%2C%32%2E%36%39%32%33%38%37%39%20%2D%30%2E%36%37%38%38%30%31%32%2C%30%2E%30%37%36%34%31%20%2D%31%2E%33%36%34%37%30%32%35%2C%30%2E%30%32%38%30%37%20%2D%31%2E%39%36%39%39%34%33%37%2C%2D%30%2E%32%30%37%32%35%38%20%68%20%2D%30%2E%30%30%37%39%31%20%6C%20%2D%30%2E%30%31%33%38%32%37%2C%2D%30%2E%30%30%37%39%20%43%20%33%2E%35%32%34%36%35%39%38%2C%31%30%2E%30%35%30%38%32%35%20%32%2E%33%32%30%32%30%30%32%2C%38%2E%33%39%32%32%33%35%38%20%32%2E%33%30%33%31%32%39%36%2C%36%2E%36%39%35%32%38%37%38%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%35%39%32%20%43%20%32%2E%32%34%35%31%34%36%36%2C%35%2E%33%35%33%35%32%38%35%20%32%2E%39%30%31%37%38%36%38%2C%34%2E%30%30%32%32%39%30%31%20%33%2E%39%35%39%32%32%34%34%2C%33%2E%31%38%39%36%35%36%39%20%76%20%2D%30%2E%30%30%37%39%20%43%20%34%2E%36%36%36%32%36%34%2C%32%2E%36%32%39%35%37%38%36%20%35%2E%35%35%33%33%39%32%2C%32%2E%32%39%39%38%33%39%31%20%36%2E%34%33%38%34%33%32%31%2C%32%2E%32%39%31%35%33%36%33%20%5A%20%4D%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%43%20%32%2E%30%32%35%34%35%30%33%2C%33%2E%35%30%35%36%31%33%32%20%31%2E%32%33%36%33%38%34%39%2C%35%2E%30%38%30%30%37%34%38%20%31%2E%33%30%34%33%34%30%38%2C%36%2E%37%31%37%30%30%30%36%20%31%2E%33%32%39%39%33%33%31%2C%38%2E%37%38%37%38%31%37%32%20%32%2E%37%36%30%36%36%39%32%2C%31%30%2E%36%31%34%38%33%34%20%34%2E%36%37%35%37%34%38%2C%31%31%2E%33%37%33%34%31%20%34%2E%31%37%37%36%36%38%38%2C%31%31%2E%31%37%39%34%37%36%20%33%2E%35%39%33%37%33%33%34%2C%31%31%2E%32%36%33%35%38%32%20%33%2E%31%37%37%35%36%34%31%2C%31%30%2E%39%33%33%32%33%32%20%31%2E%39%32%35%32%38%36%35%2C%39%2E%39%35%39%39%32%38%36%20%31%2E%31%30%36%36%37%32%32%2C%38%2E%34%31%33%31%32%35%35%20%31%2E%30%35%37%36%30%34%2C%36%2E%38%33%37%34%30%37%39%20%76%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%43%20%30%2E%39%37%39%31%34%37%36%34%2C%35%2E%33%38%34%34%33%39%31%20%31%2E%35%30%31%30%39%39%38%2C%33%2E%39%30%35%35%39%36%20%32%2E%34%39%30%36%34%39%34%2C%32%2E%38%35%34%30%39%35%34%20%6C%20%30%2E%30%30%37%39%2C%2D%30%2E%30%30%37%39%20%43%20%32%2E%36%39%36%38%36%34%32%2C%32%2E%36%32%34%33%33%36%36%20%33%2E%30%35%34%38%30%30%39%2C%32%2E%36%37%32%39%33%31%38%20%33%2E%32%38%38%31%30%32%2C%32%2E%34%38%36%39%35%31%36%20%5A%20%6D%20%30%2E%30%37%35%30%30%37%2C%32%2E%39%39%30%34%34%35%32%20%76%20%30%2E%35%30%37%32%39%20%31%2E%36%35%36%30%39%35%20%48%20%39%2E%38%31%35%37%36%30%34%20%56%20%35%2E%34%37%37%33%39%36%38%20%5A%20%4D%20%34%2E%33%37%37%36%39%2C%36%2E%34%39%31%39%37%37%31%20%48%20%38%2E%38%30%31%31%38%30%35%20%56%20%36%2E%36%33%34%30%39%37%32%20%48%20%34%2E%33%37%37%36%39%20%5A%20%6D%20%37%2E%30%35%36%36%36%32%2C%32%2E%30%35%32%38%34%37%31%20%68%20%30%2E%30%30%32%20%63%20%2D%30%2E%32%30%37%39%34%36%2C%30%2E%35%31%32%30%39%39%20%2D%30%2E%32%31%35%34%34%34%2C%31%2E%30%38%33%34%34%39%37%20%2D%30%2E%35%35%32%36%39%2C%31%2E%35%32%39%37%36%35%38%20%6C%20%2D%30%2E%32%36%30%35%35%34%2C%30%2E%33%35%31%33%35%32%20%30%2E%33%30%35%39%35%35%2C%30%2E%33%31%33%38%34%37%20%63%20%31%2E%32%30%33%32%31%34%2C%31%2E%32%31%36%34%33%37%20%32%2E%34%32%36%37%37%34%2C%32%2E%33%39%38%34%34%33%20%33%2E%36%30%32%33%35%32%2C%33%2E%36%31%38%31%34%33%20%30%2E%31%34%34%31%39%34%2C%30%2E%31%36%33%38%36%39%20%30%2E%32%38%32%39%38%2C%30%2E%32%38%34%32%35%39%20%30%2E%33%35%31%33%35%32%2C%30%2E%33%36%35%31%36%38%20%30%2E%30%37%32%36%35%2C%30%2E%30%38%35%39%37%20%30%2E%30%36%31%38%35%2C%30%2E%30%38%30%35%31%20%30%2E%30%35%39%32%32%2C%30%2E%31%30%34%36%31%38%20%76%20%30%2E%30%31%33%38%33%20%30%2E%30%31%35%37%38%20%63%20%2D%36%2E%36%65%2D%34%2C%30%2E%30%31%37%32%37%20%2D%30%2E%31%33%31%35%33%39%2C%30%2E%30%37%34%31%31%20%2D%30%2E%31%34%32%31%32%2C%30%2E%30%36%37%31%31%20%2D%31%2E%32%31%32%34%32%35%2C%2D%31%2E%31%32%35%37%38%37%20%2D%32%2E%37%37%30%37%36%36%2C%2D%32%2E%37%34%39%36%38%31%20%2D%34%2E%31%34%31%32%32%36%2C%2D%33%2E%39%36%39%34%38%38%20%6C%20%2D%30%2E%33%30%35%39%35%32%2C%2D%30%2E%32%36%38%34%35%20%2D%30%2E%33%32%37%36%36%36%2C%30%2E%32%33%38%38%33%39%20%63%20%2D%30%2E%38%37%37%31%36%33%35%2C%30%2E%36%33%32%35%30%34%20%2D%31%2E%38%38%36%39%34%32%38%2C%31%2E%30%37%38%37%35%39%20%2D%32%2E%39%32%33%33%33%34%35%2C%31%2E%31%34%38%38%30%37%20%68%20%2D%30%2E%30%30%37%39%31%20%2D%30%2E%30%30%37%39%31%20%63%20%2D%30%2E%35%33%30%33%35%35%33%2C%30%2E%30%35%33%39%39%20%2D%30%2E%39%37%39%37%31%38%39%2C%2D%30%2E%33%33%34%33%37%20%2D%31%2E%35%30%36%30%35%36%33%2C%2D%30%2E%34%34%30%31%37%38%20%30%2E%35%35%33%39%30%38%34%2C%30%2E%31%30%35%38%34%31%20%31%2E%31%31%32%30%34%31%35%2C%30%2E%32%34%38%37%36%35%20%31%2E%36%35%36%30%39%35%2C%30%2E%31%38%37%35%32%20%31%2E%38%38%33%30%33%34%39%2C%2D%30%2E%32%31%30%36%32%37%20%33%2E%34%38%32%30%33%38%38%2C%2D%31%2E%35%34%37%39%30%32%20%34%2E%31%39%38%34%36%37%38%2C%2D%33%2E%32%37%36%36%35%39%38%20%7A%27%20%2F%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%30%30%30%27%20%64%3D%27%4D%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%43%20%34%2E%38%35%30%34%32%37%33%2C%30%2E%35%32%39%37%30%35%39%38%20%33%2E%32%31%37%30%32%38%2C%31%2E%32%38%31%36%31%34%32%20%32%2E%31%31%34%33%34%36%32%2C%32%2E%35%31%35%32%33%39%38%20%31%2E%30%32%34%37%39%35%35%2C%33%2E%36%37%33%30%30%31%39%20%30%2E%34%35%39%30%33%36%34%32%2C%35%2E%32%37%39%34%30%38%35%20%30%2E%35%34%35%31%30%31%38%39%2C%36%2E%38%35%35%38%32%36%39%20%30%2E%35%39%39%32%32%37%33%2C%38%2E%35%39%33%38%33%39%31%20%31%2E%34%38%39%32%31%39%35%2C%31%30%2E%32%37%30%37%38%32%20%32%2E%38%36%30%34%37%36%38%2C%31%31%2E%33%33%36%35%36%31%20%63%20%31%2E%31%39%31%35%34%37%39%2C%30%2E%39%34%35%38%33%32%20%32%2E%37%36%30%34%36%38%37%2C%31%2E%34%30%31%33%32%35%20%34%2E%32%37%31%35%30%31%33%2C%31%2E%32%34%37%34%39%39%20%31%2E%31%35%37%35%30%32%35%2C%2D%30%2E%30%37%38%32%33%20%32%2E%32%34%39%39%32%38%36%2C%2D%30%2E%35%37%30%30%39%34%20%33%2E%31%38%33%38%38%35%39%2C%2D%31%2E%32%34%33%35%35%32%20%31%2E%33%36%35%32%34%36%2C%31%2E%32%31%35%31%36%37%20%32%2E%39%35%38%34%31%2C%32%2E%38%36%37%39%37%34%20%34%2E%31%39%36%34%39%34%2C%34%2E%30%31%32%39%32%31%20%30%2E%33%35%37%38%33%2C%30%2E%32%33%36%37%32%37%20%30%2E%39%30%39%31%32%33%2C%2D%30%2E%30%33%34%35%35%20%30%2E%39%32%35%37%35%35%2C%2D%30%2E%34%36%39%37%38%36%20%30%2E%30%34%32%37%34%2C%2D%30%2E%33%38%38%36%35%31%20%2D%30%2E%33%33%32%31%33%37%2C%2D%30%2E%36%31%33%36%30%34%20%2D%30%2E%35%35%30%37%31%36%2C%2D%30%2E%38%37%30%34%38%36%20%2D%31%2E%31%38%33%30%34%32%2C%2D%31%2E%32%32%37%34%34%33%20%2D%32%2E%34%30%33%36%33%2C%2D%32%2E%34%31%36%31%31%38%20%2D%33%2E%36%30%32%33%35%32%2C%2D%33%2E%36%32%38%30%31%33%20%30%2E%37%39%33%33%30%35%2C%2D%31%2E%30%34%39%38%38%37%31%20%31%2E%33%31%39%38%32%34%2C%2D%32%2E%33%33%30%37%31%31%20%31%2E%33%31%38%35%36%2C%2D%33%2E%36%35%33%36%37%32%34%20%30%2E%30%33%34%2C%2D%31%2E%30%30%30%30%34%38%32%20%2D%30%2E%31%37%37%32%30%31%2C%2D%32%2E%30%30%39%35%38%32%37%20%2D%30%2E%36%34%35%34%36%33%2C%2D%32%2E%38%39%35%36%39%38%34%20%43%20%31%31%2E%30%35%31%36%30%32%2C%32%2E%30%35%31%34%32%35%35%20%39%2E%32%31%33%34%33%30%33%2C%30%2E%37%34%39%36%39%32%30%34%20%37%2E%32%30%38%39%35%39%31%2C%30%2E%35%37%30%39%35%36%38%32%20%36%2E%39%37%36%31%38%35%38%2C%30%2E%35%34%38%34%32%30%35%31%20%36%2E%37%34%32%30%34%33%39%2C%30%2E%35%33%37%39%37%33%36%20%36%2E%35%30%38%32%32%38%32%2C%30%2E%35%34%31%33%34%38%34%37%20%5A%20%4D%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%63%20%30%2E%30%36%37%30%37%34%2C%2D%35%2E%39%35%32%65%2D%34%20%30%2E%31%33%34%31%37%35%31%2C%30%2E%30%30%31%32%39%20%30%2E%32%30%31%33%33%37%31%2C%30%2E%30%30%33%39%35%20%30%2E%30%31%39%38%36%33%2C%30%20%30%2E%30%33%39%32%30%32%2C%2D%31%2E%31%32%65%2D%35%20%30%2E%30%35%39%32%31%37%2C%30%20%31%2E%37%39%36%34%37%36%2C%30%2E%30%30%31%36%38%20%33%2E%35%30%35%38%30%37%35%2C%31%2E%31%36%30%37%36%36%35%20%34%2E%32%33%33%39%39%36%35%2C%32%2E%37%39%33%30%35%36%32%20%43%20%31%31%2E%34%36%34%32%38%31%2C%35%2E%37%34%34%39%36%31%32%20%31%31%2E%35%30%33%30%31%35%2C%37%2E%31%32%31%37%20%31%31%2E%30%33%38%33%31%2C%38%2E%33%30%36%36%33%39%35%20%31%30%2E%34%31%33%39%35%37%2C%39%2E%39%30%36%35%31%30%36%20%38%2E%38%38%39%31%31%34%35%2C%31%31%2E%31%33%32%38%31%20%37%2E%31%37%33%34%32%39%33%2C%31%31%2E%33%32%34%37%31%37%20%36%2E%34%33%32%31%31%31%32%2C%31%31%2E%34%30%38%31%37%20%35%2E%36%36%36%35%36%32%34%2C%31%31%2E%33%35%34%30%37%35%20%34%2E%39%36%36%36%31%38%37%2C%31%31%2E%30%38%31%39%32%39%20%33%2E%31%34%34%32%34%39%33%2C%31%30%2E%34%36%31%37%34%37%20%31%2E%38%31%33%39%35%36%39%2C%38%2E%36%33%34%31%33%32%31%20%31%2E%37%39%34%35%37%36%2C%36%2E%37%30%37%37%38%35%32%20%31%2E%37%32%38%38%37%36%38%2C%35%2E%32%30%33%30%38%37%39%20%32%2E%34%35%36%31%38%33%35%2C%33%2E%37%30%36%30%31%35%33%20%33%2E%36%34%36%30%38%35%38%2C%32%2E%37%39%31%35%38%34%36%20%34%2E%34%33%36%39%32%33%38%2C%32%2E%31%37%33%39%36%30%35%20%35%2E%34%32%37%30%39%36%32%2C%31%2E%38%30%31%37%32%35%20%36%2E%34%33%33%32%32%30%34%2C%31%2E%37%39%32%37%39%35%35%20%5A%20%4D%20%33%2E%38%36%35%31%38%38%31%2C%35%2E%39%38%37%33%31%34%37%20%56%20%37%2E%31%34%32%30%34%31%31%20%48%20%39%2E%33%30%33%32%35%38%34%20%56%20%35%2E%39%38%37%33%31%34%37%20%5A%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ResizeNwse:$app$main$ui$cursors$resize_nwse$$,ResizeEw2:$app$main$ui$cursors$resize_ew_2$$,CreateRectangle:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%39%20%37%56%31%68%36%76%36%48%39%7A%6D%31%2D%35%68%34%76%34%68%2D%34%56%32%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%64%3D%27%4D%36%20%34%76%35%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%7A%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%38%2E%35%2E%35%68%37%76%37%68%2D%37%76%2D%37%7A%6D%2D%33%20%33%68%32%76%35%68%35%76%32%68%2D%35%76%35%68%2D%32%76%2D%35%68%2D%35%76%2D%32%68%35%76%2D%35%7A%4D%36%20%39%48%31%76%31%68%35%76%35%68%31%76%2D%35%68%35%56%39%48%37%56%34%48%36%76%35%7A%6D%34%2D%37%68%34%76%34%68%2D%34%56%32%7A%6D%2E%35%20%33%2E%35%68%33%76%2D%33%68%2D%33%76%33%7A%4D%39%20%37%56%31%68%36%76%36%48%39%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto",
ResizeAlt:"url(\"data:image/svg+xml,%3Csvg xmlns\x3d'http://www.w3.org/2000/svg' viewBox\x3d'0 0 16 16' width\x3d'20px' height\x3d'20px' %3E%3Cg transform\x3d'rotate(0 8,8)'%3E%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%32%33%31%46%32%30%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%20%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%20%3C%70%61%74%68%20%66%69%6C%6C%3D%27%23%66%66%66%27%20%66%69%6C%6C%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%20%64%3D%27%4D%31%35%2E%35%2E%35%76%34%2E%39%68%2D%31%2E%38%56%33%2E%36%4C%39%2E%32%20%38%6C%34%2E%35%20%34%2E%34%76%2D%31%2E%38%68%31%2E%38%76%34%2E%39%68%2D%34%2E%39%76%2D%31%2E%38%68%31%2E%38%4C%38%20%39%2E%32%6C%2D%34%2E%34%20%34%2E%35%68%31%2E%38%76%31%2E%38%48%2E%35%76%2D%34%2E%39%68%31%2E%38%76%31%2E%38%4C%36%2E%38%20%38%20%32%2E%33%20%33%2E%35%76%32%48%2E%35%76%2D%35%68%34%2E%39%76%31%2E%38%48%33%2E%35%4C%38%20%36%2E%38%6C%34%2E%34%2D%34%2E%35%68%2D%31%2E%38%56%2E%35%68%34%2E%39%7A%6D%2D%31%2E%39%20%31%2E%33%4C%38%20%37%2E%35%20%32%2E%33%20%31%2E%38%48%35%56%31%48%31%76%34%68%2E%38%56%32%2E%33%4C%37%2E%35%20%38%6C%2D%35%2E%37%20%35%2E%36%76%2D%32%2E%35%48%31%56%31%35%68%33%2E%39%76%2D%2E%38%48%32%2E%34%4C%38%20%38%2E%35%6C%35%2E%36%20%35%2E%37%68%2D%32%2E%35%76%2E%38%48%31%35%76%2D%33%2E%39%68%2D%2E%38%76%32%2E%35%4C%38%2E%35%20%38%6C%35%2E%37%2D%35%2E%36%76%32%2E%35%68%2E%38%56%31%68%2D%33%2E%39%76%2E%38%68%32%2E%35%7A%27%20%63%6C%69%70%2D%72%75%6C%65%3D%27%65%76%65%6E%6F%64%64%27%2F%3E%3C/g%3E%3C/svg%3E\") 12 12, auto"},
$app$main$initialize_rasterizer_93456$$,$app$main$initialize_93462$$,$app$main$data$workspace$set_shape_index_71980$$,$app$main$data$workspace$reorder_children_71983$$,$app$main$data$event$snapshot_performance_info_50569$$,$app$main$data$event$store_performace_info_50594$$,$app$main$data$event$initialize_50633$$;$APP.$goog$inherits$$($goog$history$Event$$,$APP.$goog$events$Event$$);$APP.$goog$inherits$$($goog$history$Html5History$$,$APP.$goog$events$EventTarget$$);
$APP.$JSCompiler_prototypeAlias$$=$goog$history$Html5History$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$enabled_$=!1;$APP.$JSCompiler_prototypeAlias$$.$useFragment_$=!0;$APP.$JSCompiler_prototypeAlias$$.$pathPrefix_$="/";
$APP.$JSCompiler_prototypeAlias$$.getToken=function(){if(this.$useFragment_$)var $JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$=$JSCompiler_StaticMethods_getFragment_$$(this);else this.$transformer_$?($JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$=this.$window_$.location,$JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$=$JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$.pathname.substr(this.$pathPrefix_$.length)+
$JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$.search):$JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$=this.$window_$.location.pathname.slice(this.$pathPrefix_$.length);return $JSCompiler_temp$jscomp$2064_JSCompiler_temp$jscomp$2065_location$jscomp$inline_9841$$};
$APP.$JSCompiler_prototypeAlias$$.$setToken$=function($token$jscomp$59$$){$token$jscomp$59$$!=this.getToken()&&(this.$window_$.history.pushState(null,this.$window_$.document.title||"",$JSCompiler_StaticMethods_getUrl_$$(this,$token$jscomp$59$$)),this.dispatchEvent(new $goog$history$Event$$($token$jscomp$59$$,!1)))};
$APP.$JSCompiler_prototypeAlias$$.$replaceToken$=function($token$jscomp$60$$){this.$window_$.history.replaceState(null,this.$window_$.document.title||"",$JSCompiler_StaticMethods_getUrl_$$(this,$token$jscomp$60$$));this.dispatchEvent(new $goog$history$Event$$($token$jscomp$60$$,!1))};
$APP.$JSCompiler_prototypeAlias$$.$disposeInternal$=function(){$APP.$goog$events$unlisten$$(this.$window_$,"popstate",this.$onHistoryEvent_$,!1,this);this.$useFragment_$&&$APP.$goog$events$unlisten$$(this.$window_$,"hashchange",this.$onHistoryEvent_$,!1,this)};
$APP.$JSCompiler_prototypeAlias$$.$onHistoryEvent_$=function($e$jscomp$291$$){if(this.$enabled_$){const $fragment$jscomp$10$$=$JSCompiler_StaticMethods_getFragment_$$(this);if($e$jscomp$291$$.type=="popstate"||$fragment$jscomp$10$$!=this.$lastFragment_$)this.$lastFragment_$=$fragment$jscomp$10$$,this.dispatchEvent(new $goog$history$Event$$(this.getToken(),!0))}};
var $$jscomp$scope$m1810428007$0$TokenTransformer$$=class{},$app$main$router$initialize_router_52256$$,$app$main$router$navigated_52290$$,$app$main$router$initialize_history_52459$$,$app$main$data$common$create_team_access_request_52656$$,$app$main$features$toggle_feature_54893$$,$app$main$features$enable_feature_54904$$,$app$plugins$initialize_93449$$,$app$main$data$profile$mark_onboarding_as_viewed_55191$$,$app$main$data$profile$mark_questions_as_answered_55208$$,$app$main$data$team$team_initialized_55552$$,
$app$main$data$team$initialize_team_55555$$,$app$main$data$team$finalize_team_55560$$,$app$main$data$team$create_team_with_invitations_55627$$,$app$plugins$flags$set_flag_55299$$,$app$main$data$plugins$set_file_plugin_data_66437$$,$app$main$data$workspace$zoom$fit_to_shapes_66414$$,$app$main$data$workspace$media$create_svg_shape_67936$$,$app$main$data$workspace$media$create_svg_shape_with_images_67964$$,$app$main$data$workspace$libraries$update_color_data_69655$$,$app$main$data$workspace$texts$update_text_range_70318$$,
$app$main$data$workspace$interactions$add_interaction_70658$$,$app$main$data$workspace$tokens$library_edit$set_token_theme_active_73010$$,$app$main$data$workspace$tokens$library_edit$set_enabled_token_set_73100$$,$app$main$data$workspace$versions$create_version_from_plugins_73778$$,$app$main$data$workspace$versions$restore_version_from_plugins_73809$$;$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50248$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50250$$,$meta50249__$1$$){return new $reitit$trie$t_reitit$0trie50248$$(this.$meta50241$,this.$_$,this.params,this.data,this.match,$meta50249__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50249$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$824$$,$i$jscomp$500$$,$max$jscomp$71$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$500$$,$max$jscomp$71$$)?this.match:null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return 1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52163$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52165$$,$meta52164__$1$$){return new $reitit$core$t_reitit$0core52163$$(this.$non_conflicting$,this.names,this.$conflicting_paths$,this.$compiled_routes$,this.$conflicting$,this.$routes$,this.$conflicting_QMARK_$,this.$mixed_router$,this.$map__52162$,this.$linear_router$,this.$opts$,$meta52164__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52164$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1515_or__5025__auto__$jscomp$439$$,$path$jscomp$222$$){$_$jscomp$1515_or__5025__auto__$jscomp$439$$=$reitit$core$match_by_path$$(this.$mixed_router$,$path$jscomp$222$$);return $APP.$cljs$core$truth_$$($_$jscomp$1515_or__5025__auto__$jscomp$439$$)?$_$jscomp$1515_or__5025__auto__$jscomp$439$$:$reitit$core$match_by_path$$(this.$linear_router$,$path$jscomp$222$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1516_or__5025__auto__$jscomp$440$$,$name$jscomp$248$$){$_$jscomp$1516_or__5025__auto__$jscomp$440$$=$APP.$reitit$core$match_by_name$$(this.$mixed_router$,$name$jscomp$248$$);return $APP.$cljs$core$truth_$$($_$jscomp$1516_or__5025__auto__$jscomp$440$$)?$_$jscomp$1516_or__5025__auto__$jscomp$440$$:$APP.$reitit$core$match_by_name$$(this.$linear_router$,$name$jscomp$248$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1517_or__5025__auto__$jscomp$441$$,$name$jscomp$249$$,$path_params$jscomp$18$$){$_$jscomp$1517_or__5025__auto__$jscomp$441$$=$APP.$reitit$core$match_by_name$$(this.$mixed_router$,$name$jscomp$249$$,$path_params$jscomp$18$$);return $APP.$cljs$core$truth_$$($_$jscomp$1517_or__5025__auto__$jscomp$441$$)?$_$jscomp$1517_or__5025__auto__$jscomp$441$$:$APP.$reitit$core$match_by_name$$(this.$linear_router$,$name$jscomp$249$$,
$path_params$jscomp$18$$)};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52151$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52153$$,$meta52152__$1$$){return new $reitit$core$t_reitit$0core52151$$(this.names,this.$compiled_routes$,this.$map__52150$,this.$routes$,this.$__GT_static_router$,this.$lookup$,this.$wild$,this.$static_router$,this.$opts$,this.$wildcard_router$,$meta52152__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52152$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1507_or__5025__auto__$jscomp$436$$,$path$jscomp$221$$){$_$jscomp$1507_or__5025__auto__$jscomp$436$$=$reitit$core$match_by_path$$(this.$static_router$,$path$jscomp$221$$);return $APP.$cljs$core$truth_$$($_$jscomp$1507_or__5025__auto__$jscomp$436$$)?$_$jscomp$1507_or__5025__auto__$jscomp$436$$:$reitit$core$match_by_path$$(this.$wildcard_router$,$path$jscomp$221$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1508_or__5025__auto__$jscomp$437$$,$name$jscomp$246$$){$_$jscomp$1508_or__5025__auto__$jscomp$437$$=$APP.$reitit$core$match_by_name$$(this.$static_router$,$name$jscomp$246$$);return $APP.$cljs$core$truth_$$($_$jscomp$1508_or__5025__auto__$jscomp$437$$)?$_$jscomp$1508_or__5025__auto__$jscomp$437$$:$APP.$reitit$core$match_by_name$$(this.$wildcard_router$,$name$jscomp$246$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1509_or__5025__auto__$jscomp$438$$,$name$jscomp$247$$,$path_params$jscomp$17$$){$_$jscomp$1509_or__5025__auto__$jscomp$438$$=$APP.$reitit$core$match_by_name$$(this.$static_router$,$name$jscomp$247$$,$path_params$jscomp$17$$);return $APP.$cljs$core$truth_$$($_$jscomp$1509_or__5025__auto__$jscomp$438$$)?$_$jscomp$1509_or__5025__auto__$jscomp$438$$:$APP.$reitit$core$match_by_name$$(this.$wildcard_router$,
$name$jscomp$247$$,$path_params$jscomp$17$$)};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50315$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50317$$,$meta50316__$1$$){return new $reitit$trie$t_reitit$0trie50315$$(this.$meta50241$,this.$_$,this.key,this.params,this.data,this.match,$meta50316__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50316$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$836$$,$i$jscomp$503$$,$max$jscomp$74$$,$path$jscomp$200$$){return $i$jscomp$503$$<=$max$jscomp$74$$?$reitit$trie$assoc_param$$(this.match,this.key,$reitit$trie$decode$$($path$jscomp$200$$,$i$jscomp$503$$,$max$jscomp$74$$,!0)):null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return 1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50263$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50265$$,$meta50264__$1$$){return new $reitit$trie$t_reitit$0trie50263$$(this.$meta50241$,this.$_$,this.path,this.$matcher$,this.size,$meta50264__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50264$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$828_j$jscomp$112$$,$i$jscomp$501$$,$max$jscomp$72$$,$p$jscomp$212$$){if($max$jscomp$72$$<$i$jscomp$501$$+this.size)return null;for($___$1$jscomp$828_j$jscomp$112$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($___$1$jscomp$828_j$jscomp$112$$,this.size))return $reitit$trie$match$$(this.$matcher$,$i$jscomp$501$$+this.size,$max$jscomp$72$$,$p$jscomp$212$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$212$$,
$i$jscomp$501$$+$___$1$jscomp$828_j$jscomp$112$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.path,$___$1$jscomp$828_j$jscomp$112$$)))$___$1$jscomp$828_j$jscomp$112$$+=1;else return null}};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return $reitit$trie$depth$$(this.$matcher$)+1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return $APP.$cljs$core$count$$(this.path)};
var $reitit$impl$accumulate$$=function $reitit$impl$accumulate$$($var_args$jscomp$1041$$){switch(arguments.length){case 1:return $reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$1$=function($x$jscomp$1141$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2405$reitit_DOT_impl_SLASH_accumulator$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($x$jscomp$1141$$)))?$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1141$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2405$reitit_DOT_impl_SLASH_accumulator$$,!0],
null)):$x$jscomp$1141$$};$reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$2$=function($x$jscomp$1142$$,$y$jscomp$384$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($reitit$impl$accumulate$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$1142$$),$y$jscomp$384$$)};$reitit$impl$accumulate$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52137$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52139$$,$meta52138__$1$$){return new $reitit$core$t_reitit$0core52137$$(this.p,this.names,this.match,this.data,this.$compiled_routes$,this.$routes$,this.$vec__52133$,this.$vec__52130$,this.n,this.$vec__52127$,this.result,this.$opts$,$meta52138__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52138$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1499$$,$path$jscomp$220$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.p,$path$jscomp$220$$)?this.match:null};$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1500$$,$name$jscomp$244$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.n,$name$jscomp$244$$)?this.match:null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1501_a$jscomp$inline_9904$$,$name$jscomp$245$$,$JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.n,$name$jscomp$245$$)?($_$jscomp$1501_a$jscomp$inline_9904$$=this.match,$JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$=$reitit$impl$path_params$$($JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$),
$JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$1501_a$jscomp$inline_9904$$,$APP.$cljs$cst$2406$path_params$$,$JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$)):$JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$=null;return $JSCompiler_temp$jscomp$2078_path_params$jscomp$16_v$jscomp$inline_9906$$};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52101$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52103$$,$meta52102__$1$$){return new $reitit$core$t_reitit$0core52101$$(this.$matcher$,this.names,this.$compiled_routes$,this.$routes$,this.$lookup$,this.pl,this.nl,this.$match_by_path$,this.$compiler$,this.$opts$,this.$vec__52069$,$meta52102__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52102$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$,$path$jscomp$218$$){$_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$=this.$match_by_path$;$_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$=$APP.$cljs$core$truth_$$($_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$)?this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$?
this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$218$$):this.$match_by_path$($path$jscomp$218$$):$_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$;return $APP.$cljs$core$truth_$$($_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$),
$APP.$cljs$cst$2406$path_params$$,$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1491_and__5023__auto__$jscomp$inline_9908_temp__5823__auto__$jscomp$141$$)),$APP.$cljs$cst$296$path$$,$path$jscomp$218$$):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1492_temp__5823__auto__$jscomp$142$$,$name$jscomp$241$$){$_$jscomp$1492_temp__5823__auto__$jscomp$142$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$241$$);return $APP.$cljs$core$truth_$$($_$jscomp$1492_temp__5823__auto__$jscomp$142$$)?$_$jscomp$1492_temp__5823__auto__$jscomp$142$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$1492_temp__5823__auto__$jscomp$142$$.$cljs$core$IFn$_invoke$arity$1$(null):
$_$jscomp$1492_temp__5823__auto__$jscomp$142$$(null):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1493_temp__5823__auto__$jscomp$143$$,$name$jscomp$242$$,$G__52123_path_params$jscomp$14$$){$_$jscomp$1493_temp__5823__auto__$jscomp$143$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$242$$);return $APP.$cljs$core$truth_$$($_$jscomp$1493_temp__5823__auto__$jscomp$143$$)?($G__52123_path_params$jscomp$14$$=$reitit$impl$path_params$$($G__52123_path_params$jscomp$14$$),$_$jscomp$1493_temp__5823__auto__$jscomp$143$$.$cljs$core$IFn$_invoke$arity$1$?
$_$jscomp$1493_temp__5823__auto__$jscomp$143$$.$cljs$core$IFn$_invoke$arity$1$($G__52123_path_params$jscomp$14$$):$_$jscomp$1493_temp__5823__auto__$jscomp$143$$($G__52123_path_params$jscomp$14$$)):null};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core52015$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52017$$,$meta52016__$1$$){return new $reitit$core$t_reitit$0core52015$$(this.names,this.data,this.$compiled_routes$,this.$routes$,this.$vec__51994$,this.$lookup$,this.pl,this.nl,this.$opts$,$meta52016__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52016$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1483$$,$path$jscomp$217$$){return $reitit$impl$fast_get$$(this.data,$path$jscomp$217$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1484_temp__5823__auto__$jscomp$139$$,$name$jscomp$238$$){$_$jscomp$1484_temp__5823__auto__$jscomp$139$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$238$$);return $APP.$cljs$core$truth_$$($_$jscomp$1484_temp__5823__auto__$jscomp$139$$)?$_$jscomp$1484_temp__5823__auto__$jscomp$139$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$1484_temp__5823__auto__$jscomp$139$$.$cljs$core$IFn$_invoke$arity$1$(null):
$_$jscomp$1484_temp__5823__auto__$jscomp$139$$(null):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1485_temp__5823__auto__$jscomp$140$$,$name$jscomp$239$$,$G__52042_path_params$jscomp$13$$){$_$jscomp$1485_temp__5823__auto__$jscomp$140$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$239$$);return $APP.$cljs$core$truth_$$($_$jscomp$1485_temp__5823__auto__$jscomp$140$$)?($G__52042_path_params$jscomp$13$$=$reitit$impl$path_params$$($G__52042_path_params$jscomp$13$$),$_$jscomp$1485_temp__5823__auto__$jscomp$140$$.$cljs$core$IFn$_invoke$arity$1$?
$_$jscomp$1485_temp__5823__auto__$jscomp$140$$.$cljs$core$IFn$_invoke$arity$1$($G__52042_path_params$jscomp$13$$):$_$jscomp$1485_temp__5823__auto__$jscomp$140$$($G__52042_path_params$jscomp$13$$)):null};$APP.$JSCompiler_prototypeAlias$$=$reitit$core$t_reitit$0core51961$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51963$$,$meta51962__$1$$){return new $reitit$core$t_reitit$0core51961$$(this.$matcher$,this.names,this.$compiled_routes$,this.$routes$,this.$lookup$,this.pl,this.nl,this.$vec__51938$,this.$match_by_path$,this.$compiler$,this.$opts$,$meta51962__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta51962$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_path$arity$2$=function($_$jscomp$1475_temp__5823__auto__$jscomp$135$$,$path$jscomp$215$$){$_$jscomp$1475_temp__5823__auto__$jscomp$135$$=this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$?this.$match_by_path$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$215$$):this.$match_by_path$($path$jscomp$215$$);return $APP.$cljs$core$truth_$$($_$jscomp$1475_temp__5823__auto__$jscomp$135$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1475_temp__5823__auto__$jscomp$135$$),
$APP.$cljs$cst$2406$path_params$$,$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1475_temp__5823__auto__$jscomp$135$$)),$APP.$cljs$cst$296$path$$,$path$jscomp$215$$):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$2$=function($_$jscomp$1476_temp__5823__auto__$jscomp$136$$,$name$jscomp$235$$){$_$jscomp$1476_temp__5823__auto__$jscomp$136$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$235$$);return $APP.$cljs$core$truth_$$($_$jscomp$1476_temp__5823__auto__$jscomp$136$$)?$_$jscomp$1476_temp__5823__auto__$jscomp$136$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$1476_temp__5823__auto__$jscomp$136$$.$cljs$core$IFn$_invoke$arity$1$(null):
$_$jscomp$1476_temp__5823__auto__$jscomp$136$$(null):null};
$APP.$JSCompiler_prototypeAlias$$.$reitit$core$Router$match_by_name$arity$3$=function($_$jscomp$1477_temp__5823__auto__$jscomp$137$$,$name$jscomp$236$$,$G__51972_path_params$jscomp$11$$){$_$jscomp$1477_temp__5823__auto__$jscomp$137$$=$reitit$impl$fast_get$$(this.$lookup$,$name$jscomp$236$$);return $APP.$cljs$core$truth_$$($_$jscomp$1477_temp__5823__auto__$jscomp$137$$)?($G__51972_path_params$jscomp$11$$=$reitit$impl$path_params$$($G__51972_path_params$jscomp$11$$),$_$jscomp$1477_temp__5823__auto__$jscomp$137$$.$cljs$core$IFn$_invoke$arity$1$?
$_$jscomp$1477_temp__5823__auto__$jscomp$137$$.$cljs$core$IFn$_invoke$arity$1$($G__51972_path_params$jscomp$11$$):$_$jscomp$1477_temp__5823__auto__$jscomp$137$$($G__51972_path_params$jscomp$11$$)):null};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50277$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50279$$,$meta50278__$1$$){return new $reitit$trie$t_reitit$0trie50277$$(this.$meta50241$,this.$_$,this.key,this.end,this.$matcher$,$meta50278__$1$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50278$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$832_percent_QMARK_$jscomp$1$$,$i$jscomp$502$$,$max$jscomp$73$$,$path$jscomp$199$$){if($i$jscomp$502$$<$max$jscomp$73$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$199$$,$i$jscomp$502$$),this.end)){$___$1$jscomp$832_percent_QMARK_$jscomp$1$$=!1;for(var $G__50705_j$jscomp$113$$=$i$jscomp$502$$;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($max$jscomp$73$$,
$G__50705_j$jscomp$113$$)){var $JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$=$reitit$trie$match$$(this.$matcher$,$max$jscomp$73$$,$max$jscomp$73$$,$path$jscomp$199$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$)?$reitit$trie$assoc_param$$($JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$,this.key,$reitit$trie$decode$$($path$jscomp$199$$,
$i$jscomp$502$$,$max$jscomp$73$$,$___$1$jscomp$832_percent_QMARK_$jscomp$1$$)):null}var $G__50305$jscomp$inline_9912_c$jscomp$281_expr__50301$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$199$$,$G__50705_j$jscomp$113$$);$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$=$APP.$cljs$core$_EQ_$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$?
$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$(this.end,$G__50305$jscomp$inline_9912_c$jscomp$281_expr__50301$$):$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$(this.end,$G__50305$jscomp$inline_9912_c$jscomp$281_expr__50301$$)))return $JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$=$reitit$trie$match$$(this.$matcher$,
$G__50705_j$jscomp$113$$,$max$jscomp$73$$,$path$jscomp$199$$),$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$)?$reitit$trie$assoc_param$$($JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$,this.key,$reitit$trie$decode$$($path$jscomp$199$$,$i$jscomp$502$$,$G__50705_j$jscomp$113$$,$___$1$jscomp$832_percent_QMARK_$jscomp$1$$)):null;$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$=
$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$?$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$.$cljs$core$IFn$_invoke$arity$2$("%",$G__50305$jscomp$inline_9912_c$jscomp$281_expr__50301$$):$JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$("%",$G__50305$jscomp$inline_9912_c$jscomp$281_expr__50301$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2082_match$jscomp$30_pred__50300_temp__5823__auto__$jscomp$130$$)?
($G__50705_j$jscomp$113$$+=1,$___$1$jscomp$832_percent_QMARK_$jscomp$1$$=!0):$G__50705_j$jscomp$113$$+=1}}else return null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return $reitit$trie$depth$$(this.$matcher$)+1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50328$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50330$$,$meta50329__$1$$){return new $reitit$trie$t_reitit$0trie50328$$(this.$meta50241$,this.$_$,this.$matchers$,this.$ordered_QMARK_$,this.size,$meta50329__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50329$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$match$arity$4$=function($___$1$jscomp$840_j$jscomp$114$$,$i$jscomp$504$$,$max$jscomp$75$$,$path$jscomp$201$$){for($___$1$jscomp$840_j$jscomp$114$$=0;;)if($___$1$jscomp$840_j$jscomp$114$$<this.size){var $or__5025__auto__$jscomp$430$$=$reitit$trie$match$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.$matchers$,$___$1$jscomp$840_j$jscomp$114$$),$i$jscomp$504$$,$max$jscomp$75$$,$path$jscomp$201$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$430$$))return $or__5025__auto__$jscomp$430$$;
$___$1$jscomp$840_j$jscomp$114$$+=1}else return null};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$depth$arity$1$=function(){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$max$$,0,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($reitit$trie$depth$$,this.$matchers$))+1};$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$Matcher$length$arity$1$=function(){return null};
var $app$main$data$workspace$texts$count_node_chars$$=function $app$main$data$workspace$texts$count_node_chars$$($var_args$jscomp$1291$$){switch(arguments.length){case 1:return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$1$=function($node$jscomp$315$$){return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$315$$,!1)};
$app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$=function($node$jscomp$316$$,$last_QMARK_$jscomp$3$$){switch($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$316$$)){case "root":case "paragraph-set":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$texts$count_node_chars$$,
$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$316$$))),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70296_SHARP_$$){return $app$main$data$workspace$texts$count_node_chars$$.$cljs$core$IFn$_invoke$arity$2$($p1__70296_SHARP_$$,!0)},$cljs$core$take_last$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$316$$)))));case "paragraph":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_PLUS_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$texts$count_node_chars$$,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$316$$)))+($APP.$cljs$core$truth_$$($last_QMARK_$jscomp$3$$)?0:1);default:return $APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$316$$))}};$app$main$data$workspace$texts$count_node_chars$$.$cljs$lang$maxFixedArity$=2;
var $app$main$data$event$make_event$$=function $app$main$data$event$make_event$$($var_args$jscomp$1026$$){switch(arguments.length){case 1:return $app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$1$=function($result$jscomp$218$$){return $app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$218$$[1],$result$jscomp$218$$[0])};
$app$main$data$event$make_event$$.$cljs$core$IFn$_invoke$arity$2$=function($profile_id$jscomp$3$$,$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$){if($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$!=null?$APP.$cljs$core$PROTOCOL_SENTINEL$$===$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$.$app$main$data$event$Event$$||($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$.$cljs$lang$protocol_mask$partition$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$Event$$,
$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($app$main$data$event$Event$$,$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$)){var $JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$=$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$event$_data$$($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$),
$APP.$cljs$core$meta$$($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$));var $context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$=$APP.$potok$v2$core$type$$($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$);$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$=$APP.$cljs$core$name$$($context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$);$context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$=
$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$2314$app_DOT_main_DOT_data_DOT_event_SLASH_context$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$),$APP.$cljs$cst$2315$event_origin$$,
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$)),$APP.$cljs$cst$2316$event_namespace$$,$APP.$cljs$core$namespace$$($context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$)),$APP.$cljs$cst$2317$event_symbol$$,$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$));var $data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$=
$app$main$data$event$simplify_props$$($APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$));$JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2318$app_DOT_main_DOT_data_DOT_event_SLASH_type$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$,
"action"),$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$,$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$),$APP.$cljs$cst$2320$context$$,$context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$,$APP.$cljs$cst$575$props$$,$data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$],
null)}else $ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$ instanceof $APP.$potok$v2$core$DataEvent$$?($data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$=$APP.$cljs$core$_deref$$($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$),$JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$=$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$),
typeof $JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$==="string"?($ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$=$APP.$cljs$cst$2318$app_DOT_main_DOT_data_DOT_event_SLASH_type$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$,"action"),$context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$2314$app_DOT_main_DOT_data_DOT_event_SLASH_context$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$),
$APP.$cljs$cst$2315$event_origin$$,$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$))),$data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$=$app$main$data$event$simplify_props$$($APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$)),$JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$ev_name$jscomp$inline_9948_event$jscomp$65_type$jscomp$inline_9955$$,$APP.$cljs$cst$725$name$$,$JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$,$APP.$cljs$cst$2320$context$$,$context$jscomp$inline_9949_context$jscomp$inline_9956_type$jscomp$inline_9947$$,$APP.$cljs$cst$575$props$$,$data$jscomp$inline_9953_props$jscomp$inline_9950_props$jscomp$inline_9957$$],
null)):$JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$=null):$JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$=null;return $APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$2094_JSCompiler_temp$jscomp$2095_data$jscomp$inline_9946_name$jscomp$inline_9954_temp__5825__auto__$jscomp$139$$,
$APP.$cljs$cst$2321$profile_id$$,$profile_id$jscomp$3$$):null};$app$main$data$event$make_event$$.$cljs$lang$maxFixedArity$=2;
var $app$main$data$event$make_performance_event$$=function $app$main$data$event$make_performance_event$$($var_args$jscomp$1027$$){switch(arguments.length){case 1:return $app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$1$=function($result$jscomp$219$$){return $app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$219$$[1],$result$jscomp$219$$[0])};
$app$main$data$event$make_performance_event$$.$cljs$core$IFn$_invoke$arity$2$=function($profile_id$jscomp$5$$,$props$jscomp$80$$){var $perf_info$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$2322$performance_info$$),$name$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$80$$,$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,"trigger",$APP.$cljs$cst$725$name$$,["performance-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$226$$)].join(""),$APP.$cljs$cst$2320$context$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2323$file_stats$$,$APP.$cljs$cst$2324$counters$$.$cljs$core$IFn$_invoke$arity$1$($perf_info$$)],null),$APP.$cljs$cst$575$props$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$80$$,
$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$),$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($perf_info$$)),$APP.$cljs$cst$2321$profile_id$$,$profile_id$jscomp$5$$],null)};$app$main$data$event$make_performance_event$$.$cljs$lang$maxFixedArity$=2;$APP.$JSCompiler_prototypeAlias$$=$app$util$worker$Worker$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$34$$,$k__5324__auto__$jscomp$34$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$34$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$34$$,$k53787$$,$else__5326__auto__$jscomp$34$$){switch($k53787$$ instanceof $APP.$cljs$core$Keyword$$?$k53787$$.$fqn$:null){case "instance":return this.instance;case "stream":return this.stream;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k53787$$,$else__5326__auto__$jscomp$34$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$34$$,$f__5344__auto__$jscomp$34$$,$init__5345__auto__$jscomp$34$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$34$$,$p__53798_v__5348__auto__$jscomp$34$$){var $k__5347__auto__$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53798_v__5348__auto__$jscomp$34$$,0,null);$p__53798_v__5348__auto__$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53798_v__5348__auto__$jscomp$34$$,
1,null);return $f__5344__auto__$jscomp$34$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$34$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$34$$,$k__5347__auto__$jscomp$34$$,$p__53798_v__5348__auto__$jscomp$34$$):$f__5344__auto__$jscomp$34$$($ret__5346__auto__$jscomp$34$$,$k__5347__auto__$jscomp$34$$,$p__53798_v__5348__auto__$jscomp$34$$)},$init__5345__auto__$jscomp$34$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$34$$,$writer__5339__auto__$jscomp$34$$,$opts__5340__auto__$jscomp$34$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$34$$,function($keyval__5342__auto__$jscomp$34$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$34$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$34$$,$keyval__5342__auto__$jscomp$34$$)},"#app.util.worker.Worker{",
", ","}",$opts__5340__auto__$jscomp$34$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3142$instance$$,this.instance],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1421$stream$$,this.stream],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3142$instance$$,$APP.$cljs$cst$1421$stream$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $app$util$worker$Worker$$(this.instance,this.stream,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$=this.$__hash$;return $h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$!=null?$h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$:this.$__hash$=$h__5134__auto__$jscomp$64_h__5134__auto____$1$jscomp$64$$=-2074835673^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this53788$$,$other53789$$){return $other53789$$!=null&&this.constructor===$other53789$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.instance,$other53789$$.instance)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.stream,$other53789$$.stream)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other53789$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$34$$,$k__5334__auto__$jscomp$34$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3142$instance$$,null,$APP.$cljs$cst$1421$stream$$,null],null),null),$k__5334__auto__$jscomp$34$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$34$$):new $app$util$worker$Worker$$(this.instance,this.stream,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$34$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$34$$,$k53787$jscomp$1$$){switch($k53787$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k53787$jscomp$1$$.$fqn$:null){case "instance":case "stream":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k53787$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$34$$,$k__5332__auto__$jscomp$34$$,$G__53786$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3142$instance$$,$k__5332__auto__$jscomp$34$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$3142$instance$$,$k__5332__auto__$jscomp$34$$))?
new $app$util$worker$Worker$$($G__53786$jscomp$1$$,this.stream,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1421$stream$$,$k__5332__auto__$jscomp$34$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1421$stream$$,$k__5332__auto__$jscomp$34$$))?new $app$util$worker$Worker$$(this.instance,$G__53786$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $app$util$worker$Worker$$(this.instance,this.stream,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$34$$,$G__53786$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$3142$instance$$,this.instance,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1421$stream$$,this.stream,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$34$$,$G__53786$jscomp$2$$){return new $app$util$worker$Worker$$(this.instance,this.stream,$G__53786$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$34$$,$entry__5329__auto__$jscomp$34$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$34$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$34$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$34$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$34$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$core$PartialMatch$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$32$$,$k__5324__auto__$jscomp$32$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$32$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$32$$,$k51835$$,$else__5326__auto__$jscomp$32$$){switch($k51835$$ instanceof $APP.$cljs$core$Keyword$$?$k51835$$.$fqn$:null){case "template":return this.template;case "data":return this.data;case "result":return this.result;case "path-params":return this.$path_params$;case "required":return this.required;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k51835$$,
$else__5326__auto__$jscomp$32$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$32$$,$f__5344__auto__$jscomp$32$$,$init__5345__auto__$jscomp$32$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$32$$,$p__51844_v__5348__auto__$jscomp$32$$){var $k__5347__auto__$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51844_v__5348__auto__$jscomp$32$$,0,null);$p__51844_v__5348__auto__$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51844_v__5348__auto__$jscomp$32$$,
1,null);return $f__5344__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$32$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$32$$,$k__5347__auto__$jscomp$32$$,$p__51844_v__5348__auto__$jscomp$32$$):$f__5344__auto__$jscomp$32$$($ret__5346__auto__$jscomp$32$$,$k__5347__auto__$jscomp$32$$,$p__51844_v__5348__auto__$jscomp$32$$)},$init__5345__auto__$jscomp$32$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$32$$,$writer__5339__auto__$jscomp$32$$,$opts__5340__auto__$jscomp$32$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$32$$,function($keyval__5342__auto__$jscomp$32$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$32$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$32$$,$keyval__5342__auto__$jscomp$32$$)},"#reitit.core.PartialMatch{",
", ","}",$opts__5340__auto__$jscomp$32$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2414$template$$,this.template],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$828$result$$,this.result],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2406$path_params$$,this.$path_params$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1839$required$$,this.required],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2414$template$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$828$result$$,$APP.$cljs$cst$2406$path_params$$,$APP.$cljs$cst$1839$required$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$=this.$__hash$;return $h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$!=null?$h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$:this.$__hash$=$h__5134__auto__$jscomp$62_h__5134__auto____$1$jscomp$62$$=492095938^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this51836$$,$other51837$$){return $other51837$$!=null&&this.constructor===$other51837$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.template,$other51837$$.template)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other51837$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.result,$other51837$$.result)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$path_params$,
$other51837$$.$path_params$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.required,$other51837$$.required)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other51837$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$32$$,$k__5334__auto__$jscomp$32$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2414$template$$,null,$APP.$cljs$cst$828$result$$,null,$APP.$cljs$cst$2406$path_params$$,null,$APP.$cljs$cst$1839$required$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$32$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$32$$):new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$32$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$32$$,$k51835$jscomp$1$$){switch($k51835$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k51835$jscomp$1$$.$fqn$:null){case "template":case "data":case "result":case "path-params":case "required":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k51835$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$32$$,$k__5332__auto__$jscomp$32$$,$G__51834$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2414$template$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2414$template$$,$k__5332__auto__$jscomp$32$$))?
new $reitit$core$PartialMatch$$($G__51834$jscomp$1$$,this.data,this.result,this.$path_params$,this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,
$G__51834$jscomp$1$$,this.result,this.$path_params$,this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,this.data,$G__51834$jscomp$1$$,
this.$path_params$,this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2406$path_params$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2406$path_params$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,this.data,this.result,$G__51834$jscomp$1$$,
this.required,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1839$required$$,$k__5332__auto__$jscomp$32$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1839$required$$,$k__5332__auto__$jscomp$32$$))?new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,$G__51834$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$32$$,$G__51834$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2414$template$$,this.template,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$828$result$$,this.result,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2406$path_params$$,
this.$path_params$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1839$required$$,this.required,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$32$$,$G__51834$jscomp$2$$){return new $reitit$core$PartialMatch$$(this.template,this.data,this.result,this.$path_params$,this.required,$G__51834$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$32$$,$entry__5329__auto__$jscomp$32$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$32$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$32$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$32$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$32$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$core$Match$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$31$$,$k__5324__auto__$jscomp$31$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$31$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$31$$,$k51800$$,$else__5326__auto__$jscomp$31$$){switch($k51800$$ instanceof $APP.$cljs$core$Keyword$$?$k51800$$.$fqn$:null){case "template":return this.template;case "data":return this.data;case "result":return this.result;case "path-params":return this.$path_params$;case "path":return this.path;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k51800$$,$else__5326__auto__$jscomp$31$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$31$$,$f__5344__auto__$jscomp$31$$,$init__5345__auto__$jscomp$31$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$31$$,$p__51805_v__5348__auto__$jscomp$31$$){var $k__5347__auto__$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51805_v__5348__auto__$jscomp$31$$,0,null);$p__51805_v__5348__auto__$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51805_v__5348__auto__$jscomp$31$$,
1,null);return $f__5344__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$31$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$31$$,$k__5347__auto__$jscomp$31$$,$p__51805_v__5348__auto__$jscomp$31$$):$f__5344__auto__$jscomp$31$$($ret__5346__auto__$jscomp$31$$,$k__5347__auto__$jscomp$31$$,$p__51805_v__5348__auto__$jscomp$31$$)},$init__5345__auto__$jscomp$31$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$31$$,$writer__5339__auto__$jscomp$31$$,$opts__5340__auto__$jscomp$31$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$31$$,function($keyval__5342__auto__$jscomp$31$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$31$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$31$$,$keyval__5342__auto__$jscomp$31$$)},"#reitit.core.Match{",
", ","}",$opts__5340__auto__$jscomp$31$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2414$template$$,this.template],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$828$result$$,this.result],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2406$path_params$$,this.$path_params$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$296$path$$,this.path],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2414$template$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$828$result$$,$APP.$cljs$cst$2406$path_params$$,$APP.$cljs$cst$296$path$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$=this.$__hash$;return $h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$!=null?$h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$:this.$__hash$=$h__5134__auto__$jscomp$61_h__5134__auto____$1$jscomp$61$$=687105853^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this51801$$,$other51802$$){return $other51802$$!=null&&this.constructor===$other51802$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.template,$other51802$$.template)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other51802$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.result,$other51802$$.result)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$path_params$,
$other51802$$.$path_params$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.path,$other51802$$.path)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other51802$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$31$$,$k__5334__auto__$jscomp$31$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2414$template$$,null,$APP.$cljs$cst$828$result$$,null,$APP.$cljs$cst$2406$path_params$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$31$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$31$$):new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$31$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$31$$,$k51800$jscomp$1$$){switch($k51800$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k51800$jscomp$1$$.$fqn$:null){case "template":case "data":case "result":case "path-params":case "path":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k51800$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$31$$,$k__5332__auto__$jscomp$31$$,$G__51799$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2414$template$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2414$template$$,$k__5332__auto__$jscomp$31$$))?
new $reitit$core$Match$$($G__51799$jscomp$1$$,this.data,this.result,this.$path_params$,this.path,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,
$G__51799$jscomp$1$$,this.result,this.$path_params$,this.path,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$828$result$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,this.data,$G__51799$jscomp$1$$,
this.$path_params$,this.path,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2406$path_params$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2406$path_params$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,this.data,this.result,$G__51799$jscomp$1$$,this.path,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$k__5332__auto__$jscomp$31$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$296$path$$,$k__5332__auto__$jscomp$31$$))?new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,$G__51799$jscomp$1$$,this.$__meta$,this.$__extmap$,null):
new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$31$$,$G__51799$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2414$template$$,this.template,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$828$result$$,this.result,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2406$path_params$$,
this.$path_params$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$296$path$$,this.path,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$31$$,$G__51799$jscomp$2$$){return new $reitit$core$Match$$(this.template,this.data,this.result,this.$path_params$,this.path,$G__51799$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$31$$,$entry__5329__auto__$jscomp$31$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$31$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$31$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$31$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$31$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$Node$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$30$$,$k__5324__auto__$jscomp$30$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$30$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$30$$,$k50066$$,$else__5326__auto__$jscomp$30$$){switch($k50066$$ instanceof $APP.$cljs$core$Keyword$$?$k50066$$.$fqn$:null){case "children":return this.children;case "wilds":return this.$wilds$;case "catch-all":return this.$catch_all$;case "params":return this.params;case "data":return this.data;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k50066$$,$else__5326__auto__$jscomp$30$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$30$$,$f__5344__auto__$jscomp$30$$,$init__5345__auto__$jscomp$30$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$30$$,$p__50073_v__5348__auto__$jscomp$30$$){var $k__5347__auto__$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50073_v__5348__auto__$jscomp$30$$,0,null);$p__50073_v__5348__auto__$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50073_v__5348__auto__$jscomp$30$$,
1,null);return $f__5344__auto__$jscomp$30$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$30$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$30$$,$k__5347__auto__$jscomp$30$$,$p__50073_v__5348__auto__$jscomp$30$$):$f__5344__auto__$jscomp$30$$($ret__5346__auto__$jscomp$30$$,$k__5347__auto__$jscomp$30$$,$p__50073_v__5348__auto__$jscomp$30$$)},$init__5345__auto__$jscomp$30$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$30$$,$writer__5339__auto__$jscomp$30$$,$opts__5340__auto__$jscomp$30$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$30$$,function($keyval__5342__auto__$jscomp$30$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$30$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$30$$,$keyval__5342__auto__$jscomp$30$$)},"#reitit.trie.Node{",
", ","}",$opts__5340__auto__$jscomp$30$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,this.children],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2382$wilds$$,this.$wilds$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2383$catch_all$$,this.$catch_all$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,this.params],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,5,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$2382$wilds$$,$APP.$cljs$cst$2383$catch_all$$,$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 5+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$=this.$__hash$;return $h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$!=null?$h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$:this.$__hash$=$h__5134__auto__$jscomp$60_h__5134__auto____$1$jscomp$60$$=33004208^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this50067$$,$other50068$$){return $other50068$$!=null&&this.constructor===$other50068$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.children,$other50068$$.children)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$wilds$,$other50068$$.$wilds$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$catch_all$,$other50068$$.$catch_all$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.params,
$other50068$$.params)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other50068$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other50068$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$30$$,$k__5334__auto__$jscomp$30$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$342$children$$,null,$APP.$cljs$cst$1435$params$$,null,$APP.$cljs$cst$2382$wilds$$,null,$APP.$cljs$cst$2383$catch_all$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$30$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$30$$):new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$30$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$30$$,$k50066$jscomp$1$$){switch($k50066$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k50066$jscomp$1$$.$fqn$:null){case "children":case "wilds":case "catch-all":case "params":case "data":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k50066$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$30$$,$k__5332__auto__$jscomp$30$$,$G__50065$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$342$children$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$342$children$$,$k__5332__auto__$jscomp$30$$))?
new $reitit$trie$Node$$($G__50065$jscomp$1$$,this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2382$wilds$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2382$wilds$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,
$G__50065$jscomp$1$$,this.$catch_all$,this.params,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2383$catch_all$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2383$catch_all$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,this.$wilds$,$G__50065$jscomp$1$$,
this.params,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1435$params$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1435$params$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,$G__50065$jscomp$1$$,this.data,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$30$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$30$$))?new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,$G__50065$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $reitit$trie$Node$$(this.children,
this.$wilds$,this.$catch_all$,this.params,this.data,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$30$$,$G__50065$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$342$children$$,this.children,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2382$wilds$$,this.$wilds$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2383$catch_all$$,this.$catch_all$,null),
new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1435$params$$,this.params,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$30$$,$G__50065$jscomp$2$$){return new $reitit$trie$Node$$(this.children,this.$wilds$,this.$catch_all$,this.params,this.data,$G__50065$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$30$$,$entry__5329__auto__$jscomp$30$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$30$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$30$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$30$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$30$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$Match$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$29$$,$k__5324__auto__$jscomp$29$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$29$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$29$$,$k50045$$,$else__5326__auto__$jscomp$29$$){switch($k50045$$ instanceof $APP.$cljs$core$Keyword$$?$k50045$$.$fqn$:null){case "params":return this.params;case "data":return this.data;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k50045$$,$else__5326__auto__$jscomp$29$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$29$$,$f__5344__auto__$jscomp$29$$,$init__5345__auto__$jscomp$29$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$29$$,$p__50052_v__5348__auto__$jscomp$29$$){var $k__5347__auto__$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50052_v__5348__auto__$jscomp$29$$,0,null);$p__50052_v__5348__auto__$jscomp$29$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50052_v__5348__auto__$jscomp$29$$,
1,null);return $f__5344__auto__$jscomp$29$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$29$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$29$$,$k__5347__auto__$jscomp$29$$,$p__50052_v__5348__auto__$jscomp$29$$):$f__5344__auto__$jscomp$29$$($ret__5346__auto__$jscomp$29$$,$k__5347__auto__$jscomp$29$$,$p__50052_v__5348__auto__$jscomp$29$$)},$init__5345__auto__$jscomp$29$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$29$$,$writer__5339__auto__$jscomp$29$$,$opts__5340__auto__$jscomp$29$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$29$$,function($keyval__5342__auto__$jscomp$29$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$29$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$29$$,$keyval__5342__auto__$jscomp$29$$)},"#reitit.trie.Match{",
", ","}",$opts__5340__auto__$jscomp$29$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,this.params],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,this.data],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$Match$$(this.params,this.data,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$=this.$__hash$;return $h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$!=null?$h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$:this.$__hash$=$h__5134__auto__$jscomp$59_h__5134__auto____$1$jscomp$59$$=-1117628764^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this50046$$,$other50047$$){return $other50047$$!=null&&this.constructor===$other50047$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.params,$other50047$$.params)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.data,$other50047$$.data)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other50047$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$29$$,$k__5334__auto__$jscomp$29$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1435$params$$,null,$APP.$cljs$cst$142$data$$,null],null),null),$k__5334__auto__$jscomp$29$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$29$$):new $reitit$trie$Match$$(this.params,this.data,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$29$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$29$$,$k50045$jscomp$1$$){switch($k50045$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k50045$jscomp$1$$.$fqn$:null){case "params":case "data":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k50045$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$29$$,$k__5332__auto__$jscomp$29$$,$G__50044$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1435$params$$,$k__5332__auto__$jscomp$29$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1435$params$$,$k__5332__auto__$jscomp$29$$))?
new $reitit$trie$Match$$($G__50044$jscomp$1$$,this.data,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$29$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$142$data$$,$k__5332__auto__$jscomp$29$$))?new $reitit$trie$Match$$(this.params,$G__50044$jscomp$1$$,this.$__meta$,this.$__extmap$,
null):new $reitit$trie$Match$$(this.params,this.data,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$29$$,$G__50044$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1435$params$$,this.params,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$142$data$$,this.data,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$29$$,$G__50044$jscomp$2$$){return new $reitit$trie$Match$$(this.params,this.data,$G__50044$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$29$$,$entry__5329__auto__$jscomp$29$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$29$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$29$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$29$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$29$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$t_reitit$0trie50240$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_50242$$,$meta50241__$1$$){return new $reitit$trie$t_reitit$0trie50240$$($meta50241__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta50241$};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$data_matcher$arity$3$=function($_$jscomp$1450$$,$params$jscomp$130$$,$data$jscomp$170$$){return new $reitit$trie$t_reitit$0trie50248$$(this.$meta50241$,this,$params$jscomp$130$$,$data$jscomp$170$$,new $reitit$trie$Match$$($params$jscomp$130$$,$data$jscomp$170$$,null,null,null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$static_matcher$arity$3$=function($_$jscomp$1451_size$jscomp$101$$,$path$jscomp$202$$,$matcher$jscomp$13$$){$_$jscomp$1451_size$jscomp$101$$=$APP.$cljs$core$count$$($path$jscomp$202$$);return new $reitit$trie$t_reitit$0trie50263$$(this.$meta50241$,this,$path$jscomp$202$$,$matcher$jscomp$13$$,$_$jscomp$1451_size$jscomp$101$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$wild_matcher$arity$4$=function($_$jscomp$1452$$,$key$jscomp$326$$,$end$jscomp$80$$,$matcher$jscomp$14$$){return new $reitit$trie$t_reitit$0trie50277$$(this.$meta50241$,this,$key$jscomp$326$$,$end$jscomp$80$$,$matcher$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$catch_all_matcher$arity$4$=function($_$jscomp$1453$$,$key$jscomp$327$$,$params$jscomp$131$$,$data$jscomp$171$$){return new $reitit$trie$t_reitit$0trie50315$$(this.$meta50241$,this,$key$jscomp$327$$,$params$jscomp$131$$,$data$jscomp$171$$,new $reitit$trie$Match$$($params$jscomp$131$$,$data$jscomp$171$$,null,null,null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$linear_matcher$arity$3$=function($_$jscomp$1454_matchers__$1$$,$matchers$jscomp$4_size$jscomp$102$$,$ordered_QMARK_$jscomp$5$$){$_$jscomp$1454_matchers__$1$$=$APP.$cljs$core$vec$$($APP.$cljs$core$truth_$$($ordered_QMARK_$jscomp$5$$)?$matchers$jscomp$4_size$jscomp$102$$:$APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($reitit$trie$depth$$,$reitit$trie$length$$),
$matchers$jscomp$4_size$jscomp$102$$)));$matchers$jscomp$4_size$jscomp$102$$=$APP.$cljs$core$count$$($_$jscomp$1454_matchers__$1$$);return new $reitit$trie$t_reitit$0trie50328$$(this.$meta50241$,this,$_$jscomp$1454_matchers__$1$$,$ordered_QMARK_$jscomp$5$$,$matchers$jscomp$4_size$jscomp$102$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$.$reitit$trie$TrieCompiler$_path_matcher$arity$2$=function($_$jscomp$1456$$,$matcher$jscomp$16$$){return function($JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$){var $data$jscomp$inline_9977_temp__5823__auto__$jscomp$131$$=$reitit$trie$match$$($matcher$jscomp$16$$,0,$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$),$JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$);$APP.$cljs$core$truth_$$($data$jscomp$inline_9977_temp__5823__auto__$jscomp$131$$)?
($JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$=$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9977_temp__5823__auto__$jscomp$131$$),$data$jscomp$inline_9977_temp__5823__auto__$jscomp$131$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$inline_9977_temp__5823__auto__$jscomp$131$$),$JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$=new $reitit$trie$Match$$($JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$,
$data$jscomp$inline_9977_temp__5823__auto__$jscomp$131$$,null,null,null)):$JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$=null;return $JSCompiler_temp$jscomp$2102_params$jscomp$inline_9976_path$jscomp$203$$}};$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$CatchAll$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$28$$,$k__5324__auto__$jscomp$28$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$28$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$28$$,$k50001$$,$else__5326__auto__$jscomp$28$$){switch($k50001$$ instanceof $APP.$cljs$core$Keyword$$?$k50001$$.$fqn$:null){case "value":return this.value;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k50001$$,$else__5326__auto__$jscomp$28$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$28$$,$f__5344__auto__$jscomp$28$$,$init__5345__auto__$jscomp$28$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$28$$,$p__50019_v__5348__auto__$jscomp$28$$){var $k__5347__auto__$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50019_v__5348__auto__$jscomp$28$$,0,null);$p__50019_v__5348__auto__$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50019_v__5348__auto__$jscomp$28$$,
1,null);return $f__5344__auto__$jscomp$28$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$28$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$28$$,$k__5347__auto__$jscomp$28$$,$p__50019_v__5348__auto__$jscomp$28$$):$f__5344__auto__$jscomp$28$$($ret__5346__auto__$jscomp$28$$,$k__5347__auto__$jscomp$28$$,$p__50019_v__5348__auto__$jscomp$28$$)},$init__5345__auto__$jscomp$28$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$28$$,$writer__5339__auto__$jscomp$28$$,$opts__5340__auto__$jscomp$28$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$28$$,function($keyval__5342__auto__$jscomp$28$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$28$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$28$$,$keyval__5342__auto__$jscomp$28$$)},"#reitit.trie.CatchAll{",
", ","}",$opts__5340__auto__$jscomp$28$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$CatchAll$$(this.value,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$=this.$__hash$;return $h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$!=null?$h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$:this.$__hash$=$h__5134__auto__$jscomp$58_h__5134__auto____$1$jscomp$58$$=-987265038^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this50002$$,$other50003$$){return $other50003$$!=null&&this.constructor===$other50003$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other50003$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other50003$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$28$$,$k__5334__auto__$jscomp$28$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,null],null),null),$k__5334__auto__$jscomp$28$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$28$$):new $reitit$trie$CatchAll$$(this.value,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$28$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$28$$,$k50001$jscomp$1$$){switch($k50001$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k50001$jscomp$1$$.$fqn$:null){case "value":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k50001$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$28$$,$k__5332__auto__$jscomp$28$$,$G__50000$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$28$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$28$$))?
new $reitit$trie$CatchAll$$($G__50000$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $reitit$trie$CatchAll$$(this.value,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$28$$,$G__50000$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$28$$,$G__50000$jscomp$2$$){return new $reitit$trie$CatchAll$$(this.value,$G__50000$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$28$$,$entry__5329__auto__$jscomp$28$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$28$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$28$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$28$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$28$$)};
$APP.$JSCompiler_prototypeAlias$$=$reitit$trie$Wild$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$27$$,$k__5324__auto__$jscomp$27$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$27$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$27$$,$k49970$$,$else__5326__auto__$jscomp$27$$){switch($k49970$$ instanceof $APP.$cljs$core$Keyword$$?$k49970$$.$fqn$:null){case "value":return this.value;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k49970$$,$else__5326__auto__$jscomp$27$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$27$$,$f__5344__auto__$jscomp$27$$,$init__5345__auto__$jscomp$27$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$27$$,$p__49977_v__5348__auto__$jscomp$27$$){var $k__5347__auto__$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49977_v__5348__auto__$jscomp$27$$,0,null);$p__49977_v__5348__auto__$jscomp$27$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49977_v__5348__auto__$jscomp$27$$,
1,null);return $f__5344__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$27$$,$k__5347__auto__$jscomp$27$$,$p__49977_v__5348__auto__$jscomp$27$$):$f__5344__auto__$jscomp$27$$($ret__5346__auto__$jscomp$27$$,$k__5347__auto__$jscomp$27$$,$p__49977_v__5348__auto__$jscomp$27$$)},$init__5345__auto__$jscomp$27$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$27$$,$writer__5339__auto__$jscomp$27$$,$opts__5340__auto__$jscomp$27$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$27$$,function($keyval__5342__auto__$jscomp$27$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$27$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$27$$,$keyval__5342__auto__$jscomp$27$$)},"#reitit.trie.Wild{",
", ","}",$opts__5340__auto__$jscomp$27$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,this.value],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $reitit$trie$Wild$$(this.value,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 1+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$=this.$__hash$;return $h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$!=null?$h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$:this.$__hash$=$h__5134__auto__$jscomp$57_h__5134__auto____$1$jscomp$57$$=-1970880185^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this49971$$,$other49972$$){return $other49972$$!=null&&this.constructor===$other49972$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.value,$other49972$$.value)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other49972$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$27$$,$k__5334__auto__$jscomp$27$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,null],null),null),$k__5334__auto__$jscomp$27$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$27$$):new $reitit$trie$Wild$$(this.value,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$27$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$27$$,$k49970$jscomp$1$$){switch($k49970$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k49970$jscomp$1$$.$fqn$:null){case "value":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k49970$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$27$$,$k__5332__auto__$jscomp$27$$,$G__49969$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$27$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$260$value$$,$k__5332__auto__$jscomp$27$$))?
new $reitit$trie$Wild$$($G__49969$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $reitit$trie$Wild$$(this.value,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$27$$,$G__49969$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$260$value$$,this.value,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$27$$,$G__49969$jscomp$2$$){return new $reitit$trie$Wild$$(this.value,$G__49969$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$27$$,$entry__5329__auto__$jscomp$27$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$27$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$27$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$27$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$27$$)};
var $reitit$trie$_insert$$=function $reitit$trie$_insert$$($node$jscomp$256$$,$node_SINGLEQUOTE__p__50191_seq__50194$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$){$node_SINGLEQUOTE__p__50191_seq__50194$$=$APP.$cljs$core$seq$$($node_SINGLEQUOTE__p__50191_seq__50194$$);var $first__50195$$=$APP.$cljs$core$first$$($node_SINGLEQUOTE__p__50191_seq__50194$$),$seq__50194__$1$$=$APP.$cljs$core$next$$($node_SINGLEQUOTE__p__50191_seq__50194$$);$node_SINGLEQUOTE__p__50191_seq__50194$$=$first__50195$$==null?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($node$jscomp$256$$,$APP.$cljs$cst$142$data$$,$data$jscomp$165$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1435$params$$,$params$jscomp$125$$])):$first__50195$$ instanceof $reitit$trie$Wild$$?function(){var $next$jscomp$9$$=$APP.$cljs$core$first$$($seq__50194__$1$$);return $next$jscomp$9$$ instanceof $reitit$trie$Wild$$||$next$jscomp$9$$ instanceof $reitit$trie$CatchAll$$?$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2389$reitit_DOT_trie_SLASH_following_parameters$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$fp$$,$APP.$cljs$cst$2390$parameters$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$first__50195$$,$next$jscomp$9$$],null))],null)):$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$256$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2382$wilds$$,$first__50195$$],null),function($G__50199_n$jscomp$279$$){$G__50199_n$jscomp$279$$=$APP.$cljs$core$truth_$$($G__50199_n$jscomp$279$$)?$G__50199_n$jscomp$279$$:$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50199_n$jscomp$279$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($G__50199_n$jscomp$279$$,
$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)})}():$first__50195$$ instanceof $reitit$trie$CatchAll$$?$APP.$cljs$core$assoc_in$$($node$jscomp$256$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2383$catch_all$$,$first__50195$$],null),$reitit$trie$_node$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1435$params$$,$params$jscomp$125$$,$APP.$cljs$cst$142$data$$,$data$jscomp$165$$],null))):$APP.$cljs$core$empty_QMARK_$$($first__50195$$)?
$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$256$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($node$jscomp$256$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):function(){var $or__5025__auto__$jscomp$429$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($_$jscomp$1439$$,$p__50204$$){var $p$jscomp$211$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50204$$,
0,null),$n$jscomp$280$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__50204$$,1,null),$temp__5823__auto__$jscomp$129$$=$reitit$trie$common_prefix$$($p$jscomp$211$$,$first__50195$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$129$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$129$$,$p$jscomp$211$$)){var $n_SINGLEQUOTE_$$=function(){var $G__50211$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($seq__50194__$1$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($first__50195$$,
$APP.$cljs$core$count$$($p$jscomp$211$$)));return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($n$jscomp$280$$,$G__50211$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($n$jscomp$280$$,$G__50211$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)}();return $APP.$cljs$core$reduced$$($APP.$cljs$core$assoc_in$$($node$jscomp$256$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$342$children$$,$p$jscomp$211$$],null),$n_SINGLEQUOTE_$$))}var $rp$jscomp$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$211$$,$temp__5823__auto__$jscomp$129$$.length),$rp_SINGLEQUOTE_$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($first__50195$$,$temp__5823__auto__$jscomp$129$$.length);$n_SINGLEQUOTE_$$=function(){var $G__50216$$=$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?
$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50216$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($G__50216$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)}();var $n_SINGLEQUOTE__SINGLEQUOTE_$$=function(){var $G__50221$$=$reitit$trie$_node$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$rp$jscomp$1$$,$n$jscomp$280$$,$rp_SINGLEQUOTE_$$,
$n_SINGLEQUOTE_$$])],null));return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50221$$,null,null,null,null):$reitit$trie$_insert$$($G__50221$$,null,null,null,null)}();return $APP.$cljs$core$reduced$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$256$$,$APP.$cljs$cst$342$children$$,function($children$jscomp$172$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$172$$,
$p$jscomp$211$$),$temp__5823__auto__$jscomp$129$$,$n_SINGLEQUOTE__SINGLEQUOTE_$$)}))}return null},null,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$256$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$429$$)?$or__5025__auto__$jscomp$429$$:$APP.$cljs$core$assoc_in$$($node$jscomp$256$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,$first__50195$$],null),function(){var $G__50226$$=
$reitit$trie$_node$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$?$reitit$trie$_insert$$.$cljs$core$IFn$_invoke$arity$5$($G__50226$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$):$reitit$trie$_insert$$($G__50226$$,$seq__50194__$1$$,$fp$$,$params$jscomp$125$$,$data$jscomp$165$$)}())}();var $temp__5823__auto__$jscomp$128$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($node_SINGLEQUOTE__p__50191_seq__50194$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,""],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$128$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($node_SINGLEQUOTE__p__50191_seq__50194$$,
$APP.$cljs$cst$142$data$$),$temp__5823__auto__$jscomp$128$$])),$APP.$cljs$cst$342$children$$,$APP.$cljs$core$dissoc$$,""):$node_SINGLEQUOTE__p__50191_seq__50194$$},$app$common$types$text$change_text$$=function $app$common$types$text$change_text$$($var_args$jscomp$925$$){for(var $args__5755__auto__$jscomp$148$$=[],$len__5749__auto___46075$$=arguments.length,$i__5750__auto___46076$$=0;;)if($i__5750__auto___46076$$<$len__5749__auto___46075$$)$args__5755__auto__$jscomp$148$$.push(arguments[$i__5750__auto___46076$$]),
$i__5750__auto___46076$$+=1;else break;return $app$common$types$text$change_text$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$148$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$148$$.slice(2),0,null):null)};
$app$common$types$text$change_text$$.$cljs$core$IFn$_invoke$arity$variadic$=function($content$jscomp$21_paragraph_texts_paragraphs$$,$text$jscomp$22$$,$p__45981_root_styles$$){var $styles$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($p__45981_root_styles$$);$p__45981_root_styles$$=$APP.$cljs$core$select_keys$$($content$jscomp$21_paragraph_texts_paragraphs$$,$APP.$app$common$types$text$text_valign_attrs$$);var $paragraph_style$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_text_attrs$$,
$styles$jscomp$1$$,$APP.$cljs$core$select_keys$$($APP.$cljs$core$first$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$content$jscomp$21_paragraph_texts_paragraphs$$)),$APP.$app$common$types$text$text_all_attrs$$)])),$text_style$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_text_attrs$$,$styles$jscomp$1$$,
$APP.$cljs$core$select_keys$$($APP.$cljs$core$first$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$content$jscomp$21_paragraph_texts_paragraphs$$)),$APP.$app$common$types$text$text_all_attrs$$)]));$content$jscomp$21_paragraph_texts_paragraphs$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($text$jscomp$22$$,"\n");$content$jscomp$21_paragraph_texts_paragraphs$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($pt$jscomp$17$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$paragraph_style$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1593$text$$,$pt$jscomp$17$$],null),$text_style$$]))],null)],null)]))},$content$jscomp$21_paragraph_texts_paragraphs$$);
return $APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,$content$jscomp$21_paragraph_texts_paragraphs$$],null)],null)],null),$p__45981_root_styles$$)};
$app$common$types$text$change_text$$.$cljs$lang$maxFixedArity$=2;
$app$common$types$text$change_text$$.$cljs$lang$applyTo$=function($G__45976_seq45974$$){var $G__45975$$=$APP.$cljs$core$first$$($G__45976_seq45974$$),$seq45974__$1_seq45974__$2$$=$APP.$cljs$core$next$$($G__45976_seq45974$$);$G__45976_seq45974$$=$APP.$cljs$core$first$$($seq45974__$1_seq45974__$2$$);$seq45974__$1_seq45974__$2$$=$APP.$cljs$core$next$$($seq45974__$1_seq45974__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__45975$$,$G__45976_seq45974$$,$seq45974__$1_seq45974__$2$$)};
var $meta_merge$core$meta_merge$$=function $meta_merge$core$meta_merge$$($var_args$jscomp$1036$$){switch(arguments.length){case 0:return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:for(var $args_arr__5774__auto__$jscomp$100$$=[],$len__5749__auto___50008$$=arguments.length,$i__5750__auto___50009$$=
0;;)if($i__5750__auto___50009$$<$len__5749__auto___50008$$)$args_arr__5774__auto__$jscomp$100$$.push(arguments[$i__5750__auto___50009$$]),$i__5750__auto___50009$$+=1;else break;return $meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args_arr__5774__auto__$jscomp$100$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$100$$.slice(2),0,null):null)}};$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$cljs$core$PersistentArrayMap$EMPTY$$};
$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$1$=function($left$jscomp$21$$){return $left$jscomp$21$$};
$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$2$=function($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$,$right$jscomp$18$$){var $JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$=$APP.$cljs$core$some$$($cljs$core$some_fn$cljs$0core$0IFn$0_invoke$0arity$03$$(),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$,$right$jscomp$18$$],null));$JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$)?
$JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$:$APP.$cljs$cst$2380$top_displace$$.$cljs$core$IFn$_invoke$arity$1$($meta_merge$core$meta_STAR_$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$));$APP.$cljs$core$boolean$0$$($JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$)?
$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$=$meta_merge$core$pick_prioritized$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$,$right$jscomp$18$$):$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$)&&$APP.$cljs$core$map_QMARK_$$($right$jscomp$18$$)?
$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$=$APP.$cljs$core$merge_with$$.$cljs$core$IFn$_invoke$arity$variadic$($meta_merge$core$meta_merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$,$right$jscomp$18$$])):$APP.$cljs$core$set_QMARK_$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$)&&
$APP.$cljs$core$set_QMARK_$$($right$jscomp$18$$)?$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($right$jscomp$18$$,$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$):$APP.$cljs$core$coll_QMARK_$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$)&&
$APP.$cljs$core$coll_QMARK_$$($right$jscomp$18$$)?($JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$=$APP.$cljs$cst$2381$prepend$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$)),$JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$)?$JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$:$APP.$cljs$cst$2381$prepend$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($right$jscomp$18$$)),$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2115_JSCompiler_inline_result$jscomp$inline_14169_or__5025__auto__$jscomp$inline_10008_or__5025__auto__$jscomp$inline_14170$$)?$APP.$cljs$core$with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$),$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($right$jscomp$18$$,$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$)),
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$),$APP.$cljs$core$select_keys$$($APP.$cljs$core$meta$$($right$jscomp$18$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2378$displace$$],null))]))):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$),
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$,$right$jscomp$18$$))):$JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$=$right$jscomp$18$$;return $JSCompiler_temp$jscomp$2111_JSCompiler_temp$jscomp$2112_JSCompiler_temp$jscomp$2113_JSCompiler_temp$jscomp$2114_left$jscomp$22$$};
$meta_merge$core$meta_merge$$.$cljs$core$IFn$_invoke$arity$variadic$=function($left$jscomp$23$$,$right$jscomp$19$$,$more$jscomp$49$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($meta_merge$core$meta_merge$$,$left$jscomp$23$$,$APP.$cljs$core$cons$$($right$jscomp$19$$,$more$jscomp$49$$))};
$meta_merge$core$meta_merge$$.$cljs$lang$applyTo$=function($G__49986_seq49984$$){var $G__49985$$=$APP.$cljs$core$first$$($G__49986_seq49984$$),$seq49984__$1_seq49984__$2$$=$APP.$cljs$core$next$$($G__49986_seq49984$$);$G__49986_seq49984$$=$APP.$cljs$core$first$$($seq49984__$1_seq49984__$2$$);$seq49984__$1_seq49984__$2$$=$APP.$cljs$core$next$$($seq49984__$1_seq49984__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__49985$$,$G__49986_seq49984$$,$seq49984__$1_seq49984__$2$$)};
$meta_merge$core$meta_merge$$.$cljs$lang$maxFixedArity$=2;var $reitit$core$trie_router$$=function $reitit$core$trie_router$$($var_args$jscomp$1047$$){switch(arguments.length){case 1:return $reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$10$$){return $reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$11$$,$opts$jscomp$281$$){var $compiler$jscomp$9$$=$APP.$cljs$cst$2429$reitit_DOT_trie_SLASH_trie_compiler$$.$cljs$core$IFn$_invoke$arity$2$($opts$jscomp$281$$,new $reitit$trie$t_reitit$0trie50240$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)),$names$jscomp$11$$=$reitit$impl$find_names$$($compiled_routes$jscomp$11$$),$vec__52069$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($nl$jscomp$15_p__52073$$,
$map__52085_p__52074$$){function $f$jscomp$798$$($JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$){var $temp__5823__auto__$jscomp$144$$=$reitit$impl$path_for$$($map__52085__$1$$,$JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$);$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$144$$)?$JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$=$reitit$core$__GT_Match$$($p$jscomp$232$$,$map__52084__$1$$,$result$jscomp$227$$,
$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$),$temp__5823__auto__$jscomp$144$$):($JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$=$reitit$impl$maybe_map_values$$($reitit$impl$maybe_url_decode$$,$JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$),$JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$=new $reitit$core$PartialMatch$$($p$jscomp$232$$,
$map__52084__$1$$,$result$jscomp$227$$,$JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$,$path_params$jscomp$15$$,null,null,null));return $JSCompiler_temp$jscomp$2100_p1__52063_SHARP__path_params$jscomp$inline_10028$$}var $pl$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$15_p__52073$$,0,null);$nl$jscomp$15_p__52073$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$15_p__52073$$,1,null);var $p$jscomp$232$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52085_p__52074$$,
0,null),$map__52084_name$jscomp$243$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52085_p__52074$$,1,null),$map__52084__$1$$=$APP.$cljs$core$__destructure_map$$($map__52084_name$jscomp$243$$);$map__52084_name$jscomp$243$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52084__$1$$,$APP.$cljs$cst$725$name$$);var $result$jscomp$227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__52085_p__52074$$,2,null);$map__52085_p__52074$$=$reitit$impl$parse$$($p$jscomp$232$$,
$opts$jscomp$281$$);var $map__52085__$1$$=$APP.$cljs$core$__destructure_map$$($map__52085_p__52074$$),$path_params$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52085__$1$$,$APP.$cljs$cst$2406$path_params$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$reitit$trie$insert$cljs$0core$0IFn$0_invoke$0arity$04$$($pl$jscomp$11$$,$p$jscomp$232$$,$reitit$core$__GT_Match$$($p$jscomp$232$$,$map__52084__$1$$,$result$jscomp$227$$,
null,null),$opts$jscomp$281$$),$APP.$cljs$core$truth_$$($map__52084_name$jscomp$243$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nl$jscomp$15_p__52073$$,$map__52084_name$jscomp$243$$,$f$jscomp$798$$):$nl$jscomp$15_p__52073$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$compiled_routes$jscomp$11$$),$pl$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52069$jscomp$2$$,
0,null),$nl$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52069$jscomp$2$$,1,null),$matcher$jscomp$22$$=$reitit$trie$compile$cljs$0core$0IFn$0_invoke$0arity$03$$($pl$jscomp$10$$,$compiler$jscomp$9$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$match_by_path$jscomp$5$$=$APP.$cljs$core$truth_$$($matcher$jscomp$22$$)?$reitit$trie$_path_matcher$$($compiler$jscomp$9$$,$matcher$jscomp$22$$):null,$routes$jscomp$17$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$11$$);
return new $reitit$core$t_reitit$0core52101$$($matcher$jscomp$22$$,$names$jscomp$11$$,$compiled_routes$jscomp$11$$,$routes$jscomp$17$$,$nl$jscomp$14$$,$pl$jscomp$10$$,$nl$jscomp$14$$,$match_by_path$jscomp$5$$,$compiler$jscomp$9$$,$opts$jscomp$281$$,$vec__52069$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2430$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$trie_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$single_static_path_router$$=function $reitit$core$single_static_path_router$$($var_args$jscomp$1048$$){switch(arguments.length){case 1:return $reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$14$$){return $reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$single_static_path_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$15$$,$opts$jscomp$284$$){var $JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$=($JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($compiled_routes$jscomp$15$$),1))?$JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$:
$APP.$cljs$core$some$$($reitit$impl$__GT_wild_route_QMARK_$$($opts$jscomp$284$$),$compiled_routes$jscomp$15$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$)&&$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$([":single-static-path-router requires exactly 1 static route: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($compiled_routes$jscomp$15$$)].join(""),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2408$routes$$,$compiled_routes$jscomp$15$$],null));$JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$=$reitit$impl$find_names$$($compiled_routes$jscomp$15$$);var $n$jscomp$283$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$,0,null),$vec__52133$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($compiled_routes$jscomp$15$$,
0,null),$p$jscomp$235$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52133$jscomp$2$$,0,null),$data$jscomp$188$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52133$jscomp$2$$,1,null),$result$jscomp$230$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52133$jscomp$2$$,2,null),$match$jscomp$50$$=$reitit$core$__GT_Match$$($p$jscomp$235$$,$data$jscomp$188$$,$result$jscomp$230$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p$jscomp$235$$),$routes$jscomp$20$$=
$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$15$$);return new $reitit$core$t_reitit$0core52137$$($p$jscomp$235$$,$JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$,$match$jscomp$50$$,$data$jscomp$188$$,$compiled_routes$jscomp$15$$,$routes$jscomp$20$$,$vec__52133$jscomp$2$$,$compiled_routes$jscomp$15$$,$n$jscomp$283$$,$JSCompiler_inline_result$jscomp$2117_or__5025__auto__$jscomp$inline_10037_vec__52127$jscomp$2$$,$result$jscomp$230$$,$opts$jscomp$284$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2430$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$single_static_path_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$lookup_router$$=function $reitit$core$lookup_router$$($var_args$jscomp$1046$$){switch(arguments.length){case 1:return $reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$6$$){return $reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$lookup_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$7$$,$opts$jscomp$278$$){var $names$jscomp$8_temp__5825__auto___52394$$=$APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($reitit$impl$__GT_wild_route_QMARK_$$($opts$jscomp$278$$),$compiled_routes$jscomp$7$$));$names$jscomp$8_temp__5825__auto___52394$$&&$reitit$exception$fail_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(["can't create :lookup-router with wildcard routes: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($names$jscomp$8_temp__5825__auto___52394$$)].join(""),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2382$wilds$$,$names$jscomp$8_temp__5825__auto___52394$$,$APP.$cljs$cst$2408$routes$$,$compiled_routes$jscomp$7$$],null));$names$jscomp$8_temp__5825__auto___52394$$=$reitit$impl$find_names$$($compiled_routes$jscomp$7$$);var $vec__51994$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($nl$jscomp$11_p__51997$$,$p__51998$$){var $pl$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$11_p__51997$$,
0,null);$nl$jscomp$11_p__51997$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nl$jscomp$11_p__51997$$,1,null);var $p$jscomp$231$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51998$$,0,null),$map__52006_name$jscomp$240$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51998$$,1,null),$map__52006__$1$$=$APP.$cljs$core$__destructure_map$$($map__52006_name$jscomp$240$$);$map__52006_name$jscomp$240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52006__$1$$,
$APP.$cljs$cst$725$name$$);var $result$jscomp$226$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__51998$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($pl$jscomp$7$$,$p$jscomp$231$$,$reitit$core$__GT_Match$$($p$jscomp$231$$,$map__52006__$1$$,$result$jscomp$226$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$p$jscomp$231$$)),$APP.$cljs$core$truth_$$($map__52006_name$jscomp$240$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nl$jscomp$11_p__51997$$,$map__52006_name$jscomp$240$$,function($p1__51980_SHARP_$$){return $reitit$core$__GT_Match$$($p$jscomp$231$$,$map__52006__$1$$,$result$jscomp$226$$,$p1__51980_SHARP_$$,$p$jscomp$231$$)}):$nl$jscomp$11_p__51997$$],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$compiled_routes$jscomp$7$$),
$pl$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51994$jscomp$2$$,0,null),$nl$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__51994$jscomp$2$$,1,null),$routes$jscomp$14$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$7$$);return new $reitit$core$t_reitit$0core52015$$($names$jscomp$8_temp__5825__auto___52394$$,$pl$jscomp$6$$,$compiled_routes$jscomp$7$$,$routes$jscomp$14$$,$vec__51994$jscomp$2$$,$nl$jscomp$10$$,$pl$jscomp$6$$,$nl$jscomp$10$$,
$opts$jscomp$278$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2430$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$lookup_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$mixed_router$$=function $reitit$core$mixed_router$$($var_args$jscomp$1049$$){switch(arguments.length){case 1:return $reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$18$$){return $reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$19$$,$opts$jscomp$287$$){var $map__52150$jscomp$2_map__52150__$1$$=$APP.$cljs$core$group_by$$($reitit$impl$__GT_wild_route_QMARK_$$($opts$jscomp$287$$),$compiled_routes$jscomp$19$$);$map__52150$jscomp$2_map__52150__$1$$=$APP.$cljs$core$__destructure_map$$($map__52150$jscomp$2_map__52150__$1$$);var $wild$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52150$jscomp$2_map__52150__$1$$,
!0),$lookup$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52150$jscomp$2_map__52150__$1$$,!1),$__GT_static_router$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($lookup$jscomp$14$$))?$reitit$core$single_static_path_router$$:$reitit$core$lookup_router$$,$wildcard_router$jscomp$2$$=$reitit$core$trie_router$$.$cljs$core$IFn$_invoke$arity$2$($wild$jscomp$2$$,$opts$jscomp$287$$),$static_router$jscomp$2$$=$__GT_static_router$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?
$__GT_static_router$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($lookup$jscomp$14$$,$opts$jscomp$287$$):$__GT_static_router$jscomp$2$$($lookup$jscomp$14$$,$opts$jscomp$287$$),$names$jscomp$17$$=$reitit$impl$find_names$$($compiled_routes$jscomp$19$$),$routes$jscomp$23$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$19$$);return new $reitit$core$t_reitit$0core52151$$($names$jscomp$17$$,$compiled_routes$jscomp$19$$,$map__52150$jscomp$2_map__52150__$1$$,$routes$jscomp$23$$,$__GT_static_router$jscomp$2$$,
$lookup$jscomp$14$$,$wild$jscomp$2$$,$static_router$jscomp$2$$,$opts$jscomp$287$$,$wildcard_router$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2430$reitit_DOT_core_SLASH_router$$],null))};$reitit$core$mixed_router$$.$cljs$lang$maxFixedArity$=2;
var $reitit$core$quarantine_router$$=function $reitit$core$quarantine_router$$($var_args$jscomp$1050$$){switch(arguments.length){case 1:return $reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$1$=function($compiled_routes$jscomp$22$$){return $reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$2$($compiled_routes$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$reitit$core$quarantine_router$$.$cljs$core$IFn$_invoke$arity$2$=function($compiled_routes$jscomp$23$$,$opts$jscomp$290$$){function $conflicting_QMARK_$jscomp$2$$($p1__52159_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($conflicting_paths$jscomp$2$$,$APP.$cljs$core$first$$($p1__52159_SHARP_$$))}var $conflicting_paths$jscomp$2$$=$reitit$impl$conflicting_paths$$(function(){var $or__5025__auto__$jscomp$442$$=$APP.$cljs$cst$2460$reitit_DOT_core_SLASH_path_conflicting$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$290$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$442$$)?$or__5025__auto__$jscomp$442$$:$reitit$impl$path_conflicting_routes$$($compiled_routes$jscomp$23$$,$opts$jscomp$290$$)}()),$map__52162$jscomp$2_map__52162__$1$$=$APP.$cljs$core$group_by$$($conflicting_QMARK_$jscomp$2$$,$compiled_routes$jscomp$23$$);$map__52162$jscomp$2_map__52162__$1$$=$APP.$cljs$core$__destructure_map$$($map__52162$jscomp$2_map__52162__$1$$);var $conflicting$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52162$jscomp$2_map__52162__$1$$,
!0),$non_conflicting$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52162$jscomp$2_map__52162__$1$$,!1),$linear_router$jscomp$2$$=$reitit$core$linear_router$cljs$0core$0IFn$0_invoke$0arity$02$$($conflicting$jscomp$2$$,$opts$jscomp$290$$),$mixed_router$jscomp$2$$=$reitit$core$mixed_router$$.$cljs$core$IFn$_invoke$arity$2$($non_conflicting$jscomp$2$$,$opts$jscomp$290$$),$names$jscomp$20$$=$reitit$impl$find_names$$($compiled_routes$jscomp$23$$),$routes$jscomp$26$$=$reitit$impl$uncompile_routes$$($compiled_routes$jscomp$23$$);
return new $reitit$core$t_reitit$0core52163$$($non_conflicting$jscomp$2$$,$names$jscomp$20$$,$conflicting_paths$jscomp$2$$,$compiled_routes$jscomp$23$$,$conflicting$jscomp$2$$,$routes$jscomp$26$$,$conflicting_QMARK_$jscomp$2$$,$mixed_router$jscomp$2$$,$map__52162$jscomp$2_map__52162__$1$$,$linear_router$jscomp$2$$,$opts$jscomp$290$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2430$reitit_DOT_core_SLASH_router$$],null))};
$reitit$core$quarantine_router$$.$cljs$lang$maxFixedArity$=2;var $app$main$worker$on_error$$=null;$app$main$worker$on_error$$=$APP.$app$main$errors$on_error$$;
var $cljs$cst$6440$exporting$$=new $APP.$cljs$core$Keyword$$(null,"exporting","exporting",-2019585981),$cljs$cst$6478$dashboard_legacy_team_settings$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-settings","dashboard-legacy-team-settings",1266059192),$cljs$cst$6621$getSharedPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginData-key","getSharedPluginData-key",1393856585),$cljs$cst$6638$applyTypography_typography$$=new $APP.$cljs$core$Keyword$$(null,"applyTypography-typography",
"applyTypography-typography",2055995230),$cljs$cst$6676$saveVersion$$=new $APP.$cljs$core$Keyword$$(null,"saveVersion","saveVersion",1295710756),$cljs$cst$6482$dashboard_legacy_font_providers$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-font-providers","dashboard-legacy-font-providers",192867763),$cljs$cst$6511$verticalMargin$$=new $APP.$cljs$core$Keyword$$(null,"verticalMargin","verticalMargin",2098722016),$cljs$cst$6689$font_height$$=new $APP.$cljs$core$Keyword$$(null,"font-height","font-height",
49078273),$cljs$cst$6458$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.viewer","viewer-page*","app.main.ui.viewer/viewer-page*",2102384267,null),$cljs$cst$6483$dashboard_legacy_libraries$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-libraries","dashboard-legacy-libraries",-1600130587),$cljs$cst$6613$rotate_angle$$=new $APP.$cljs$core$Keyword$$(null,"rotate-angle","rotate-angle",-1896437128),$cljs$cst$6645$removeInteraction$$=new $APP.$cljs$core$Keyword$$(null,
"removeInteraction","removeInteraction",1218317317),$cljs$cst$6587$border_radius_top_right$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-top-right","border-radius-top-right",-2056556020),$cljs$cst$6486$app_DOT_main_DOT_ui_DOT_routes_SLASH_teams$$=new $APP.$cljs$core$Keyword$$("app.main.ui.routes","teams","app.main.ui.routes/teams",-1977218830),$cljs$cst$6643$resetOverrides$$=new $APP.$cljs$core$Keyword$$(null,"resetOverrides","resetOverrides",-1399555246),$cljs$cst$6629$insertChild_child$$=
new $APP.$cljs$core$Keyword$$(null,"insertChild-child","insertChild-child",1653590456),$cljs$cst$6518$minWidth$$=new $APP.$cljs$core$Keyword$$(null,"minWidth","minWidth",-204293526),$cljs$cst$6617$setPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData-key","setPluginData-key",437211756),$cljs$cst$6455$finish$$=new $APP.$cljs$core$Keyword$$(null,"finish","finish",-586688046),$cljs$cst$6694$createColor$$=new $APP.$cljs$core$Keyword$$(null,"createColor","createColor",-414553580),$cljs$cst$6573$fontWeight$$=
new $APP.$cljs$core$Keyword$$(null,"fontWeight","fontWeight",166450581),$cljs$cst$6540$setColumn$$=new $APP.$cljs$core$Keyword$$(null,"setColumn","setColumn",1194844473),$cljs$cst$6502$topPadding$$=new $APP.$cljs$core$Keyword$$(null,"topPadding","topPadding",453548852),$cljs$cst$6572$fontSize$$=new $APP.$cljs$core$Keyword$$(null,"fontSize","fontSize",919623033),$cljs$cst$6492$plugin_name$$=new $APP.$cljs$core$Keyword$$(null,"plugin-name","plugin-name",1482210260),$cljs$cst$6555$columnSpan_value$$=
new $APP.$cljs$core$Keyword$$(null,"columnSpan-value","columnSpan-value",2076747203),$cljs$cst$6627$getChildren$$=new $APP.$cljs$core$Keyword$$(null,"getChildren","getChildren",-446203521),$cljs$cst$6548$row_value$$=new $APP.$cljs$core$Keyword$$(null,"row-value","row-value",-1067843622),$cljs$cst$6724$generateStyle_includeChildren$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-includeChildren","generateStyle-includeChildren",-441924583),$cljs$cst$6489$x_axis_rotation$$=new $APP.$cljs$core$Keyword$$(null,
"x-axis-rotation","x-axis-rotation",-637606609),$cljs$cst$6723$generateStyle_withPrelude$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-withPrelude","generateStyle-withPrelude",-551214991),$cljs$cst$6654$reply$$=new $APP.$cljs$core$Keyword$$(null,"reply","reply",1144328671),$cljs$cst$6710$replaceColor_newColor$$=new $APP.$cljs$core$Keyword$$(null,"replaceColor-newColor","replaceColor-newColor",-1427541529),$cljs$cst$6599$constraintsVertical$$=new $APP.$cljs$core$Keyword$$(null,"constraintsVertical",
"constraintsVertical",250879495),$cljs$cst$6528$lex$$=new $APP.$cljs$core$Keyword$$(null,"lex","lex",1572323917),$cljs$cst$6646$addRulerGuide$$=new $APP.$cljs$core$Keyword$$(null,"addRulerGuide","addRulerGuide",1837252654),$cljs$cst$6542$setRow_type$$=new $APP.$cljs$core$Keyword$$(null,"setRow-type","setRow-type",1456587126),$cljs$cst$6658$page_plugin_data_namespace$$=new $APP.$cljs$core$Keyword$$(null,"page-plugin-data-namespace","page-plugin-data-namespace",-699256157),$cljs$cst$6714$createText$$=
new $APP.$cljs$core$Keyword$$(null,"createText","createText",256547428),$cljs$cst$6706$selection$$=new $APP.$cljs$core$Keyword$$(null,"selection","selection",975998651),$cljs$cst$6506$appendChild$$=new $APP.$cljs$core$Keyword$$(null,"appendChild","appendChild",1287125270),$cljs$cst$6709$replaceColor_oldColor$$=new $APP.$cljs$core$Keyword$$(null,"replaceColor-oldColor","replaceColor-oldColor",807960134),$cljs$cst$6662$removeFlow_flow$$=new $APP.$cljs$core$Keyword$$(null,"removeFlow-flow","removeFlow-flow",
1839197888),$cljs$cst$6495$alignContent$$=new $APP.$cljs$core$Keyword$$(null,"alignContent","alignContent",403294922),$cljs$cst$6660$createFlow_name$$=new $APP.$cljs$core$Keyword$$(null,"createFlow-name","createFlow-name",88270356),$cljs$cst$6549$row_cell$$=new $APP.$cljs$core$Keyword$$(null,"row-cell","row-cell",1612632022),$cljs$cst$6592$margin_right$$=new $APP.$cljs$core$Keyword$$(null,"margin-right","margin-right",809689658),$cljs$cst$6479$dashboard_legacy_projects$$=new $APP.$cljs$core$Keyword$$(null,
"dashboard-legacy-projects","dashboard-legacy-projects",-834288049),$cljs$cst$6624$setSharedPluginData_value$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-value","setSharedPluginData-value",1942190613),$cljs$cst$6567$justifySelf$$=new $APP.$cljs$core$Keyword$$(null,"justifySelf","justifySelf",-894439176),$cljs$cst$6683$findAllById$$=new $APP.$cljs$core$Keyword$$(null,"findAllById","findAllById",-633206720),$cljs$cst$6481$dashboard_legacy_fonts$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-fonts",
"dashboard-legacy-fonts",-1082225854),$cljs$cst$6640$applyTypography$$=new $APP.$cljs$core$Keyword$$(null,"applyTypography","applyTypography",-1953840408),$cljs$cst$6614$rotate_center$$=new $APP.$cljs$core$Keyword$$(null,"rotate-center","rotate-center",6610822),$cljs$cst$6657$page_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"page-plugin-data-key","page-plugin-data-key",936190759),$cljs$cst$6609$frameX$$=new $APP.$cljs$core$Keyword$$(null,"frameX","frameX",1123372234),$cljs$cst$6610$frameY$$=
new $APP.$cljs$core$Keyword$$(null,"frameY","frameY",86132734),$cljs$cst$6472$debug_icons_preview$$=new $APP.$cljs$core$Keyword$$(null,"debug-icons-preview","debug-icons-preview",-444662807),$cljs$cst$6639$applyTypography_shape$$=new $APP.$cljs$core$Keyword$$(null,"applyTypography-shape","applyTypography-shape",1275019073),$cljs$cst$6615$clone$$=new $APP.$cljs$core$Keyword$$(null,"clone","clone",711747572),$cljs$cst$6460$app_DOT_main_DOT_ui_DOT_settings_SLASH_settings_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.settings",
"settings-page*","app.main.ui.settings/settings-page*",-117972938,null),$cljs$cst$6498$rowGap$$=new $APP.$cljs$core$Keyword$$(null,"rowGap","rowGap",1869424743),$cljs$cst$6636$getRange_start$$=new $APP.$cljs$core$Keyword$$(null,"getRange-start","getRange-start",243941450),$cljs$cst$6736$app_DOT_main_SLASH_initialize_rasterizer$$=new $APP.$cljs$core$Keyword$$("app.main","initialize-rasterizer","app.main/initialize-rasterizer",-823615130),$cljs$cst$6500$verticalPadding$$=new $APP.$cljs$core$Keyword$$(null,
"verticalPadding","verticalPadding",-116062864),$cljs$cst$6726$alignHorizontal_shapes$$=new $APP.$cljs$core$Keyword$$(null,"alignHorizontal-shapes","alignHorizontal-shapes",1742786132),$cljs$cst$6520$addRow_type$$=new $APP.$cljs$core$Keyword$$(null,"addRow-type","addRow-type",1581806272),$cljs$cst$6484$dashboard_legacy_files$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-files","dashboard-legacy-files",-547738017),$cljs$cst$6527$addColumn_type$$=new $APP.$cljs$core$Keyword$$(null,"addColumn-type",
"addColumn-type",369510652),$cljs$cst$6560$areaName$$=new $APP.$cljs$core$Keyword$$(null,"areaName","areaName",-785186640),$cljs$cst$6438$export_success_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"export-success?","export-success?",1913775048),$cljs$cst$6441$expected_use$$=new $APP.$cljs$core$Keyword$$(null,"expected-use","expected-use",133731615),$cljs$cst$6691$typography_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"typography-plugin-data-key","typography-plugin-data-key",1398110804),$cljs$cst$6491$name_like$$=
new $APP.$cljs$core$Keyword$$(null,"name-like","name-like",244303068),$cljs$cst$6488$large_arc_flag$$=new $APP.$cljs$core$Keyword$$(null,"large-arc-flag","large-arc-flag",396724034),$cljs$cst$6561$position_value$$=new $APP.$cljs$core$Keyword$$(null,"position-value","position-value",-1598412318),$cljs$cst$6517$maxWidth$$=new $APP.$cljs$core$Keyword$$(null,"maxWidth","maxWidth",-1375124795),$cljs$cst$6569$fontId$$=new $APP.$cljs$core$Keyword$$(null,"fontId","fontId",-474874285),$cljs$cst$6727$alignVertical_direction$$=
new $APP.$cljs$core$Keyword$$(null,"alignVertical-direction","alignVertical-direction",-2037964308),$cljs$cst$6601$borderRadius$$=new $APP.$cljs$core$Keyword$$(null,"borderRadius","borderRadius",-1505621083),$cljs$cst$6707$shapesColors_shapes$$=new $APP.$cljs$core$Keyword$$(null,"shapesColors-shapes","shapesColors-shapes",1999445904),$cljs$cst$6730$distributeVertical_shapes$$=new $APP.$cljs$core$Keyword$$(null,"distributeVertical-shapes","distributeVertical-shapes",404282144),$cljs$cst$6570$fontFamily$$=
new $APP.$cljs$core$Keyword$$(null,"fontFamily","fontFamily",1493518353),$cljs$cst$6682$findByName$$=new $APP.$cljs$core$Keyword$$(null,"findByName","findByName",-1135437361),$cljs$cst$6507$horizontalSizing$$=new $APP.$cljs$core$Keyword$$(null,"horizontalSizing","horizontalSizing",1922240218),$cljs$cst$6687$setSharedPluginData_non_local_library$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-non-local-library","setSharedPluginData-non-local-library",331868634),$cljs$cst$6453$invites$$=new $APP.$cljs$core$Keyword$$(null,
"invites","invites",1962160761),$cljs$cst$6508$verticalSizing$$=new $APP.$cljs$core$Keyword$$(null,"verticalSizing","verticalSizing",911089716),$cljs$cst$6600$fixedWhenScrolling$$=new $APP.$cljs$core$Keyword$$(null,"fixedWhenScrolling","fixedWhenScrolling",-38587213),$cljs$cst$6594$margin_top$$=new $APP.$cljs$core$Keyword$$(null,"margin-top","margin-top",392161226),$cljs$cst$6670$createPage$$=new $APP.$cljs$core$Keyword$$(null,"createPage","createPage",1663482836),$cljs$cst$6475$dashboard_legacy_team_members$$=
new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-members","dashboard-legacy-team-members",-659515913),$cljs$cst$6616$getPluginData$$=new $APP.$cljs$core$Keyword$$(null,"getPluginData","getPluginData",190301887),$cljs$cst$6503$rightPadding$$=new $APP.$cljs$core$Keyword$$(null,"rightPadding","rightPadding",553025942),$cljs$cst$6590$border_radius_bottom_right$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-bottom-right","border-radius-bottom-right",-186894172),$cljs$cst$6598$constraintsHorizontal$$=
new $APP.$cljs$core$Keyword$$(null,"constraintsHorizontal","constraintsHorizontal",1307569455),$cljs$cst$6490$sweep_flag$$=new $APP.$cljs$core$Keyword$$(null,"sweep-flag","sweep-flag",1319872435),$cljs$cst$6456$app_DOT_main_DOT_ui_DOT_auth_SLASH_auth_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.auth","auth-page*","app.main.ui.auth/auth-page*",63279394,null),$cljs$cst$6439$prepare$$=new $APP.$cljs$core$Keyword$$(null,"prepare","prepare",-1449654665),$cljs$cst$6557$columnSpan$$=new $APP.$cljs$core$Keyword$$(null,
"columnSpan","columnSpan",-1065100091),$cljs$cst$6474$render_sprite$$=new $APP.$cljs$core$Keyword$$(null,"render-sprite","render-sprite",463778943),$cljs$cst$6539$setColumn_value$$=new $APP.$cljs$core$Keyword$$(null,"setColumn-value","setColumn-value",748250994),$cljs$cst$6597$proportionLock$$=new $APP.$cljs$core$Keyword$$(null,"proportionLock","proportionLock",90792392),$cljs$cst$6655$startingBoard$$=new $APP.$cljs$core$Keyword$$(null,"startingBoard","startingBoard",979547215),$cljs$cst$6536$removeColumn$$=
new $APP.$cljs$core$Keyword$$(null,"removeColumn","removeColumn",-1624774294),$cljs$cst$6522$addRow$$=new $APP.$cljs$core$Keyword$$(null,"addRow","addRow",-1526940876),$cljs$cst$6732$centerShapes$$=new $APP.$cljs$core$Keyword$$(null,"centerShapes","centerShapes",-1359078552),$cljs$cst$6552$rowSpan$$=new $APP.$cljs$core$Keyword$$(null,"rowSpan","rowSpan",826884002),$cljs$cst$6699$connectLibrary$$=new $APP.$cljs$core$Keyword$$(null,"connectLibrary","connectLibrary",606055059),$cljs$cst$6586$padding_bottom$$=
new $APP.$cljs$core$Keyword$$(null,"padding-bottom","padding-bottom",-1899795591),$cljs$cst$6718$createBoolean$$=new $APP.$cljs$core$Keyword$$(null,"createBoolean","createBoolean",-1102545242),$cljs$cst$6510$alignSelf$$=new $APP.$cljs$core$Keyword$$(null,"alignSelf","alignSelf",-1666557725),$cljs$cst$6667$pin$$=new $APP.$cljs$core$Keyword$$(null,"pin","pin",-2111774834),$cljs$cst$6719$generateMarkup_shapes$$=new $APP.$cljs$core$Keyword$$(null,"generateMarkup-shapes","generateMarkup-shapes",-1635320333),
$cljs$cst$6606$blendMode$$=new $APP.$cljs$core$Keyword$$(null,"blendMode","blendMode",2057676269),$cljs$cst$6448$start_with$$=new $APP.$cljs$core$Keyword$$(null,"start-with","start-with",1292915726),$cljs$cst$6596$addToken$$=new $APP.$cljs$core$Keyword$$(null,"addToken","addToken",-646732290),$cljs$cst$6473$debug_playground$$=new $APP.$cljs$core$Keyword$$(null,"debug-playground","debug-playground",371173136),$cljs$cst$6516$leftMargin$$=new $APP.$cljs$core$Keyword$$(null,"leftMargin","leftMargin",
-427217148),$cljs$cst$6562$position_cell$$=new $APP.$cljs$core$Keyword$$(null,"position-cell","position-cell",-608152505),$cljs$cst$6715$createShapeFromSvg$$=new $APP.$cljs$core$Keyword$$(null,"createShapeFromSvg","createShapeFromSvg",1744668068),$cljs$cst$6665$findCommentThreads$$=new $APP.$cljs$core$Keyword$$(null,"findCommentThreads","findCommentThreads",1948881022),$cljs$cst$6603$borderRadiusTopRight$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusTopRight","borderRadiusTopRight",223982879),
$cljs$cst$6515$bottomMargin$$=new $APP.$cljs$core$Keyword$$(null,"bottomMargin","bottomMargin",459661842),$cljs$cst$6686$setPluginData_non_local_library$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData-non-local-library","setPluginData-non-local-library",-839915494),$cljs$cst$6577$textTransform$$=new $APP.$cljs$core$Keyword$$(null,"textTransform","textTransform",-1959669529),$cljs$cst$6612$flipY$$=new $APP.$cljs$core$Keyword$$(null,"flipY","flipY",624880256),$cljs$cst$6611$flipX$$=new $APP.$cljs$core$Keyword$$(null,
"flipX","flipX",-1853365),$cljs$cst$6578$textDecoration$$=new $APP.$cljs$core$Keyword$$(null,"textDecoration","textDecoration",418180221),$cljs$cst$6563$alignSelf_value$$=new $APP.$cljs$core$Keyword$$(null,"alignSelf-value","alignSelf-value",1581687155),$cljs$cst$6728$alignVertical_shapes$$=new $APP.$cljs$core$Keyword$$(null,"alignVertical-shapes","alignVertical-shapes",53178325),$cljs$cst$6529$addColumn_value$$=new $APP.$cljs$core$Keyword$$(null,"addColumn-value","addColumn-value",-154426043),$cljs$cst$6711$uploadMedia_name$$=
new $APP.$cljs$core$Keyword$$(null,"uploadMedia-name","uploadMedia-name",-1741554770),$cljs$cst$6672$export_file$$=new $APP.$cljs$core$Keyword$$(null,"export-file","export-file",-1808912864),$cljs$cst$6526$addRowAtIndex$$=new $APP.$cljs$core$Keyword$$(null,"addRowAtIndex","addRowAtIndex",-909836310),$cljs$cst$6647$removeRulerGuide$$=new $APP.$cljs$core$Keyword$$(null,"removeRulerGuide","removeRulerGuide",-1323808559),$cljs$cst$6499$columnGap$$=new $APP.$cljs$core$Keyword$$(null,"columnGap","columnGap",
-376837767),$cljs$cst$6690$setFont$$=new $APP.$cljs$core$Keyword$$(null,"setFont","setFont",-510963166),$cljs$cst$6644$addInteraction$$=new $APP.$cljs$core$Keyword$$(null,"addInteraction","addInteraction",1571848503),$cljs$cst$6450$onboarding_team_id$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-team-id","onboarding-team-id",1539385036),$cljs$cst$6716$createBoolean_boolType$$=new $APP.$cljs$core$Keyword$$(null,"createBoolean-boolType","createBoolean-boolType",1854310447),$cljs$cst$6512$horizontalMargin$$=
new $APP.$cljs$core$Keyword$$(null,"horizontalMargin","horizontalMargin",606533049),$cljs$cst$6725$alignHorizontal_direction$$=new $APP.$cljs$core$Keyword$$(null,"alignHorizontal-direction","alignHorizontal-direction",-378078007),$cljs$cst$6485$workspace_legacy$$=new $APP.$cljs$core$Keyword$$(null,"workspace-legacy","workspace-legacy",104522706),$cljs$cst$6680$applyToRange$$=new $APP.$cljs$core$Keyword$$(null,"applyToRange","applyToRange",1653614162),$cljs$cst$6523$addRowAtIndex_index$$=new $APP.$cljs$core$Keyword$$(null,
"addRowAtIndex-index","addRowAtIndex-index",-1679866381),$cljs$cst$6585$margin_bottom$$=new $APP.$cljs$core$Keyword$$(null,"margin-bottom","margin-bottom",388334941),$cljs$cst$6623$setSharedPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-key","setSharedPluginData-key",-1257676988),$cljs$cst$6591$border_radius_top_left$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-top-left","border-radius-top-left",-1945583265),$cljs$cst$6581$textDirection$$=new $APP.$cljs$core$Keyword$$(null,
"textDirection","textDirection",-486409590),$cljs$cst$6720$generateMarkup_type$$=new $APP.$cljs$core$Keyword$$(null,"generateMarkup-type","generateMarkup-type",-177562878),$cljs$cst$6580$growType$$=new $APP.$cljs$core$Keyword$$(null,"growType","growType",-2038406868),$cljs$cst$6618$setPluginData_value$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData-value","setPluginData-value",281004073),$cljs$cst$6535$removeRow$$=new $APP.$cljs$core$Keyword$$(null,"removeRow","removeRow",453086520),$cljs$cst$6447$team_size$$=
new $APP.$cljs$core$Keyword$$(null,"team-size","team-size",2116636517),$cljs$cst$6722$generateStyle_type$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-type","generateStyle-type",196722442),$cljs$cst$6674$findVersions$$=new $APP.$cljs$core$Keyword$$(null,"findVersions","findVersions",1578584464),$cljs$cst$6604$borderRadiusBottomRight$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusBottomRight","borderRadiusBottomRight",-1210449538),$cljs$cst$6553$column_value$$=new $APP.$cljs$core$Keyword$$(null,
"column-value","column-value",1145304215),$cljs$cst$6695$createTypography$$=new $APP.$cljs$core$Keyword$$(null,"createTypography","createTypography",1413714480),$cljs$cst$6571$fontVariantId$$=new $APP.$cljs$core$Keyword$$(null,"fontVariantId","fontVariantId",-598111105),$cljs$cst$6496$justifyItems$$=new $APP.$cljs$core$Keyword$$(null,"justifyItems","justifyItems",710685366),$cljs$cst$6501$horizontalPadding$$=new $APP.$cljs$core$Keyword$$(null,"horizontalPadding","horizontalPadding",513951974),$cljs$cst$6668$get_team_users$$=
new $APP.$cljs$core$Keyword$$(null,"get-team-users","get-team-users",796041692),$cljs$cst$6556$columnSpan_cell$$=new $APP.$cljs$core$Keyword$$(null,"columnSpan-cell","columnSpan-cell",-149218441),$cljs$cst$6497$justifyContent$$=new $APP.$cljs$core$Keyword$$(null,"justifyContent","justifyContent",885406515),$cljs$cst$6669$getPluginData_key$$=new $APP.$cljs$core$Keyword$$(null,"getPluginData-key","getPluginData-key",-1372143031),$cljs$cst$6713$group_shapes$$=new $APP.$cljs$core$Keyword$$(null,"group-shapes",
"group-shapes",1902987914),$cljs$cst$6605$borderRadiusBottomLeft$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusBottomLeft","borderRadiusBottomLeft",-81645913),$cljs$cst$6700$getItem$$=new $APP.$cljs$core$Keyword$$(null,"getItem","getItem",-1850161217),$cljs$cst$6463$get_library_file_references$$=new $APP.$cljs$core$Keyword$$(null,"get-library-file-references","get-library-file-references",383296011),$cljs$cst$6565$justifySelf_value$$=new $APP.$cljs$core$Keyword$$(null,"justifySelf-value","justifySelf-value",
131913092),$cljs$cst$6588$padding_top$$=new $APP.$cljs$core$Keyword$$(null,"padding-top","padding-top",1929675955),$cljs$cst$6593$border_radius_bottom_left$$=new $APP.$cljs$core$Keyword$$(null,"border-radius-bottom-left","border-radius-bottom-left",-1697288612),$cljs$cst$6446$img_height$$=new $APP.$cljs$core$Keyword$$(null,"img-height","img-height",1572702026),$cljs$cst$6465$nitrate_entry$$=new $APP.$cljs$core$Keyword$$(null,"nitrate-entry","nitrate-entry",1711495687),$cljs$cst$6688$getSharedPluginDataKeys_namespace$$=
new $APP.$cljs$core$Keyword$$(null,"getSharedPluginDataKeys-namespace","getSharedPluginDataKeys-namespace",207404581),$cljs$cst$6487$app_DOT_main_DOT_ui_DOT_routes_SLASH_init_routes$$=new $APP.$cljs$core$Keyword$$("app.main.ui.routes","init-routes","app.main.ui.routes/init-routes",601316191),$cljs$cst$6547$appendChild_column$$=new $APP.$cljs$core$Keyword$$(null,"appendChild-column","appendChild-column",-2018830626),$cljs$cst$6505$leftPadding$$=new $APP.$cljs$core$Keyword$$(null,"leftPadding","leftPadding",
-550857795),$cljs$cst$6566$justifySelf_cell$$=new $APP.$cljs$core$Keyword$$(null,"justifySelf-cell","justifySelf-cell",1644610466),$cljs$cst$6675$findVersions_user$$=new $APP.$cljs$core$Keyword$$(null,"findVersions-user","findVersions-user",836091189),$cljs$cst$6696$createComponent$$=new $APP.$cljs$core$Keyword$$(null,"createComponent","createComponent",-2141156902),$cljs$cst$6681$findbyId$$=new $APP.$cljs$core$Keyword$$(null,"findbyId","findbyId",681438060),$cljs$cst$6631$addGridLayout$$=new $APP.$cljs$core$Keyword$$(null,
"addGridLayout","addGridLayout",-2084589424),$cljs$cst$6656$getShapeById$$=new $APP.$cljs$core$Keyword$$(null,"getShapeById","getShapeById",1762718316),$cljs$cst$6684$findAllByName$$=new $APP.$cljs$core$Keyword$$(null,"findAllByName","findAllByName",1530295653),$cljs$cst$6705$zoomIntoView$$=new $APP.$cljs$core$Keyword$$(null,"zoomIntoView","zoomIntoView",-898042566),$cljs$cst$6673$export_files$$=new $APP.$cljs$core$Keyword$$(null,"export-files","export-files",1120929044),$cljs$cst$6717$createBoolean_shapes$$=
new $APP.$cljs$core$Keyword$$(null,"createBoolean-shapes","createBoolean-shapes",-1009255477),$cljs$cst$6679$applyToText$$=new $APP.$cljs$core$Keyword$$(null,"applyToText","applyToText",-2123120633),$cljs$cst$6436$hash$$=new $APP.$cljs$core$Keyword$$(null,"hash","hash",-13781596),$cljs$cst$6685$undoBlockFinish$$=new $APP.$cljs$core$Keyword$$(null,"undoBlockFinish","undoBlockFinish",223635385),$cljs$cst$6634$toD$$=new $APP.$cljs$core$Keyword$$(null,"toD","toD",-167929600),$cljs$cst$6731$flatten_shapes$$=
new $APP.$cljs$core$Keyword$$(null,"flatten-shapes","flatten-shapes",489189922),$cljs$cst$6622$setSharedPluginData_namespace$$=new $APP.$cljs$core$Keyword$$(null,"setSharedPluginData-namespace","setSharedPluginData-namespace",807971852),$cljs$cst$6513$topMargin$$=new $APP.$cljs$core$Keyword$$(null,"topMargin","topMargin",1454522636),$cljs$cst$6461$app_DOT_main_DOT_ui_DOT_workspace_SLASH_workspace_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.workspace","workspace-page*","app.main.ui.workspace/workspace-page*",
1318295057,null),$cljs$cst$6671$export_file_v3$$=new $APP.$cljs$core$Keyword$$(null,"export-file-v3","export-file-v3",-1949378869),$cljs$cst$6541$setRow_index$$=new $APP.$cljs$core$Keyword$$(null,"setRow-index","setRow-index",1430875983),$cljs$cst$6533$addColumnAtIndex_value$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex-value","addColumnAtIndex-value",-1084618681),$cljs$cst$6693$component_plugin_data_namespace$$=new $APP.$cljs$core$Keyword$$(null,"component-plugin-data-namespace","component-plugin-data-namespace",
-953872153),$cljs$cst$6701$setItem$$=new $APP.$cljs$core$Keyword$$(null,"setItem","setItem",1848393972),$cljs$cst$6559$areaName_cell$$=new $APP.$cljs$core$Keyword$$(null,"areaName-cell","areaName-cell",303279412),$cljs$cst$6524$addRowAtIndex_type$$=new $APP.$cljs$core$Keyword$$(null,"addRowAtIndex-type","addRowAtIndex-type",1831710979),$cljs$cst$6661$createFlow_frame$$=new $APP.$cljs$core$Keyword$$(null,"createFlow-frame","createFlow-frame",-1759152297),$cljs$cst$6628$insertChild$$=new $APP.$cljs$core$Keyword$$(null,
"insertChild","insertChild",649742086),$cljs$cst$6642$swapComponent$$=new $APP.$cljs$core$Keyword$$(null,"swapComponent","swapComponent",-1074850438),$cljs$cst$6659$openPage$$=new $APP.$cljs$core$Keyword$$(null,"openPage","openPage",136412439),$cljs$cst$6451$onboarding_without_invitations$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-without-invitations","onboarding-without-invitations",-677171434),$cljs$cst$6619$setPluginData$$=new $APP.$cljs$core$Keyword$$(null,"setPluginData","setPluginData",
2049380387),$cljs$cst$6452$onboarding_with_invitations$$=new $APP.$cljs$core$Keyword$$(null,"onboarding-with-invitations","onboarding-with-invitations",1108924654),$cljs$cst$6477$dashboard_legacy_team_webhooks$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-webhooks","dashboard-legacy-team-webhooks",-1694314662),$cljs$cst$6480$dashboard_legacy_search$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-search","dashboard-legacy-search",1431918022),$cljs$cst$6583$padding_right$$=new $APP.$cljs$core$Keyword$$(null,
"padding-right","padding-right",-1250249681),$cljs$cst$6633$removeMask$$=new $APP.$cljs$core$Keyword$$(null,"removeMask","removeMask",1636150276),$cljs$cst$6550$rowSpan_value$$=new $APP.$cljs$core$Keyword$$(null,"rowSpan-value","rowSpan-value",-2081956858),$cljs$cst$6493$dir$$=new $APP.$cljs$core$Keyword$$(null,"dir","dir",1734754661),$cljs$cst$6584$padding_left$$=new $APP.$cljs$core$Keyword$$(null,"padding-left","padding-left",-1180879053),$cljs$cst$6625$setSharedPluginData$$=new $APP.$cljs$core$Keyword$$(null,
"setSharedPluginData","setSharedPluginData",-324251591),$cljs$cst$6476$dashboard_legacy_team_invitations$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-legacy-team-invitations","dashboard-legacy-team-invitations",464259896),$cljs$cst$6708$replaceColor_shapes$$=new $APP.$cljs$core$Keyword$$(null,"replaceColor-shapes","replaceColor-shapes",61687483),$cljs$cst$6620$getSharedPluginData_namespace$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginData-namespace","getSharedPluginData-namespace",823864288),
$cljs$cst$6544$setRow$$=new $APP.$cljs$core$Keyword$$(null,"setRow","setRow",959178877),$cljs$cst$6443$experience_design_tool$$=new $APP.$cljs$core$Keyword$$(null,"experience-design-tool","experience-design-tool",1120701429),$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$=new $APP.$cljs$core$Keyword$$("app.plugins.events","not-changed","app.plugins.events/not-changed",1296884509),$cljs$cst$6444$experience_design_tool_other$$=new $APP.$cljs$core$Keyword$$(null,"experience-design-tool-other",
"experience-design-tool-other",-1840227460),$cljs$cst$6651$content_type$$=new $APP.$cljs$core$Keyword$$(null,"content-type","content-type",-508222634),$cljs$cst$6449$start_with_other$$=new $APP.$cljs$core$Keyword$$(null,"start-with-other","start-with-other",-1627779046),$cljs$cst$6564$alignSelf_cell$$=new $APP.$cljs$core$Keyword$$(null,"alignSelf-cell","alignSelf-cell",702748092),$cljs$cst$6521$addRow_value$$=new $APP.$cljs$core$Keyword$$(null,"addRow-value","addRow-value",-1889184769),$cljs$cst$6504$bottomPadding$$=
new $APP.$cljs$core$Keyword$$(null,"bottomPadding","bottomPadding",-646451636),$cljs$cst$6698$file_plugin_data_namespace$$=new $APP.$cljs$core$Keyword$$(null,"file-plugin-data-namespace","file-plugin-data-namespace",1778425062),$cljs$cst$6733$app_DOT_plugins_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.plugins","initialize","app.plugins/initialize",-280898138),$cljs$cst$6692$component_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"component-plugin-data-key","component-plugin-data-key",
-1960216489),$cljs$cst$6702$removeItem$$=new $APP.$cljs$core$Keyword$$(null,"removeItem","removeItem",-1184844686),$cljs$cst$6664$removeCommentThread$$=new $APP.$cljs$core$Keyword$$(null,"removeCommentThread","removeCommentThread",-1296576721),$cljs$cst$6626$getSharedPluginDataKeys$$=new $APP.$cljs$core$Keyword$$(null,"getSharedPluginDataKeys","getSharedPluginDataKeys",1605636461),$cljs$cst$6607$parentX$$=new $APP.$cljs$core$Keyword$$(null,"parentX","parentX",283353021),$cljs$cst$6608$parentY$$=new $APP.$cljs$core$Keyword$$(null,
"parentY","parentY",485277499),$cljs$cst$6582$verticalAlign$$=new $APP.$cljs$core$Keyword$$(null,"verticalAlign","verticalAlign",465597462),$cljs$cst$6543$setRow_value$$=new $APP.$cljs$core$Keyword$$(null,"setRow-value","setRow-value",-11319580),$cljs$cst$6531$addColumnAtIndex_index$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex-index","addColumnAtIndex-index",1508798879),$cljs$cst$6602$borderRadiusTopLeft$$=new $APP.$cljs$core$Keyword$$(null,"borderRadiusTopLeft","borderRadiusTopLeft",1495282142),
$cljs$cst$6653$findComments$$=new $APP.$cljs$core$Keyword$$(null,"findComments","findComments",1317965565),$cljs$cst$6729$distributeHorizontal_shapes$$=new $APP.$cljs$core$Keyword$$(null,"distributeHorizontal-shapes","distributeHorizontal-shapes",-995314595),$cljs$cst$6579$characters$$=new $APP.$cljs$core$Keyword$$(null,"characters","characters",-163867197),$cljs$cst$6454$klass$$=new $APP.$cljs$core$Keyword$$(null,"klass","klass",-1386752349),$cljs$cst$6514$rightMargin$$=new $APP.$cljs$core$Keyword$$(null,
"rightMargin","rightMargin",1199553501),$cljs$cst$6546$appendChild_row$$=new $APP.$cljs$core$Keyword$$(null,"appendChild-row","appendChild-row",420578043),$cljs$cst$6737$app_DOT_main_SLASH_initialize$$=new $APP.$cljs$core$Keyword$$("app.main","initialize","app.main/initialize",1664955691),$cljs$cst$6637$getRange_end$$=new $APP.$cljs$core$Keyword$$(null,"getRange-end","getRange-end",-1693867629),$cljs$cst$6538$setColumn_type$$=new $APP.$cljs$core$Keyword$$(null,"setColumn-type","setColumn-type",373633885),
$cljs$cst$6532$addColumnAtIndex_type$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex-type","addColumnAtIndex-type",-990488622),$cljs$cst$6470$frame_preview$$=new $APP.$cljs$core$Keyword$$(null,"frame-preview","frame-preview",1876875008),$cljs$cst$6534$addColumnAtIndex$$=new $APP.$cljs$core$Keyword$$(null,"addColumnAtIndex","addColumnAtIndex",316866004),$cljs$cst$6445$img_width$$=new $APP.$cljs$core$Keyword$$(null,"img-width","img-width",1169865415),$cljs$cst$6525$addRowAtIndex_value$$=new $APP.$cljs$core$Keyword$$(null,
"addRowAtIndex-value","addRowAtIndex-value",-515836114),$cljs$cst$6471$viewer_legacy$$=new $APP.$cljs$core$Keyword$$(null,"viewer-legacy","viewer-legacy",-1892502654),$cljs$cst$6575$lineHeight$$=new $APP.$cljs$core$Keyword$$(null,"lineHeight","lineHeight",-1729831016),$cljs$cst$6734$asserts$$=new $APP.$cljs$core$Keyword$$(null,"asserts","asserts",359548304),$cljs$cst$6554$column_cell$$=new $APP.$cljs$core$Keyword$$(null,"column-cell","column-cell",-497688888),$cljs$cst$6595$applyToSelected$$=new $APP.$cljs$core$Keyword$$(null,
"applyToSelected","applyToSelected",577942880),$cljs$cst$6435$modified$$=new $APP.$cljs$core$Keyword$$(null,"modified","modified",-2134587826),$cljs$cst$6632$makeMask$$=new $APP.$cljs$core$Keyword$$(null,"makeMask","makeMask",1937012005),$cljs$cst$6442$role_other$$=new $APP.$cljs$core$Keyword$$(null,"role-other","role-other",-933264397),$cljs$cst$6574$fontStyle$$=new $APP.$cljs$core$Keyword$$(null,"fontStyle","fontStyle",1246842165),$cljs$cst$6519$minHeight$$=new $APP.$cljs$core$Keyword$$(null,"minHeight",
"minHeight",-1635998980),$cljs$cst$6635$getRange_shape$$=new $APP.$cljs$core$Keyword$$(null,"getRange-shape","getRange-shape",1197987177),$cljs$cst$6551$rowSpan_cell$$=new $APP.$cljs$core$Keyword$$(null,"rowSpan-cell","rowSpan-cell",-2040199739),$cljs$cst$6630$addFlexLayout$$=new $APP.$cljs$core$Keyword$$(null,"addFlexLayout","addFlexLayout",222594497),$cljs$cst$6530$addColumn$$=new $APP.$cljs$core$Keyword$$(null,"addColumn","addColumn",-1515461232),$cljs$cst$6650$showInViewMode$$=new $APP.$cljs$core$Keyword$$(null,
"showInViewMode","showInViewMode",-445923934),$cljs$cst$6462$dashboard_font_providers$$=new $APP.$cljs$core$Keyword$$(null,"dashboard-font-providers","dashboard-font-providers",-593422352),$cljs$cst$6537$setColumn_index$$=new $APP.$cljs$core$Keyword$$(null,"setColumn-index","setColumn-index",-1846647314),$cljs$cst$6568$board$$=new $APP.$cljs$core$Keyword$$(null,"board","board",-1907017633),$cljs$cst$6434$cache$$=new $APP.$cljs$core$Keyword$$(null,"cache","cache",-1237023054),$cljs$cst$6663$addCommentThread$$=
new $APP.$cljs$core$Keyword$$(null,"addCommentThread","addCommentThread",11455178),$cljs$cst$6697$file_plugin_data_key$$=new $APP.$cljs$core$Keyword$$(null,"file-plugin-data-key","file-plugin-data-key",-1008870444),$cljs$cst$6509$zIndex$$=new $APP.$cljs$core$Keyword$$(null,"zIndex","zIndex",-1588341609),$cljs$cst$6576$letterSpacing$$=new $APP.$cljs$core$Keyword$$(null,"letterSpacing","letterSpacing",-1331934989),$cljs$cst$6494$alignItems$$=new $APP.$cljs$core$Keyword$$(null,"alignItems","alignItems",
410331199),$cljs$cst$6641$setParentIndex$$=new $APP.$cljs$core$Keyword$$(null,"setParentIndex","setParentIndex",1845372782),$cljs$cst$6704$center_y$$=new $APP.$cljs$core$Keyword$$(null,"center-y","center-y",-233780987),$cljs$cst$6703$center_x$$=new $APP.$cljs$core$Keyword$$(null,"center-x","center-x",2109659472),$cljs$cst$6678$app_DOT_plugins_DOT_events_SLASH_void$$=new $APP.$cljs$core$Keyword$$("app.plugins.events","void","app.plugins.events/void",1229710245),$cljs$cst$6545$appendChild_child$$=new $APP.$cljs$core$Keyword$$(null,
"appendChild-child","appendChild-child",-568841985),$cljs$cst$6712$uploadMedia_url$$=new $APP.$cljs$core$Keyword$$(null,"uploadMedia-url","uploadMedia-url",-675246750),$cljs$cst$6459$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard_page_STAR_$$=new $APP.$cljs$core$Symbol$$("app.main.ui.dashboard","dashboard-page*","app.main.ui.dashboard/dashboard-page*",-1237983004,null),$cljs$cst$6649$clipContent$$=new $APP.$cljs$core$Keyword$$(null,"clipContent","clipContent",249671651),$cljs$cst$6589$margin_left$$=
new $APP.$cljs$core$Keyword$$(null,"margin-left","margin-left",2015598377),$cljs$cst$6666$restore$$=new $APP.$cljs$core$Keyword$$(null,"restore","restore",267172424),$cljs$cst$6558$areaName_value$$=new $APP.$cljs$core$Keyword$$(null,"areaName-value","areaName-value",982496147),$cljs$cst$6648$applyToken$$=new $APP.$cljs$core$Keyword$$(null,"applyToken","applyToken",-109067546),$cljs$cst$6735$build_date$$=new $APP.$cljs$core$Keyword$$(null,"build-date","build-date",-325850528),$cljs$cst$6457$app_DOT_main_DOT_ui_DOT_auth_DOT_verify_token_SLASH_verify_token_page_STAR_$$=
new $APP.$cljs$core$Symbol$$("app.main.ui.auth.verify-token","verify-token-page*","app.main.ui.auth.verify-token/verify-token-page*",426832199,null),$cljs$cst$6464$auth_recovery$$=new $APP.$cljs$core$Keyword$$(null,"auth-recovery","auth-recovery",-1821305124),$cljs$cst$6721$generateStyle_shapes$$=new $APP.$cljs$core$Keyword$$(null,"generateStyle-shapes","generateStyle-shapes",-2048142893);$APP.$JSCompiler_prototypeAlias$$=$app$common$types$objects_map$ObjectsMapEntry$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$891$$,$writer$jscomp$177$$,$opts$jscomp$314$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$177$$,function($item$jscomp$153$$,$w$jscomp$47$$){return $APP.$cljs$core$_write$$($w$jscomp$47$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$item$jscomp$153$$])))},"[",", ","]",$opts$jscomp$314$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($node$jscomp$483$$,$k$jscomp$720$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$720$$,null)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($node$jscomp$484$$,$k$jscomp$721$$,$not_found$jscomp$88$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$721$$,$not_found$jscomp$88$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_key$arity$1$=function(){return this.key};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMapEntry$_val$arity$1$=function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(this.$omap$,this.key)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return $app$common$types$objects_map$_hash_for_key$$(this.$omap$,this.key)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$892$$,$other$jscomp$204$$){return $APP.$cljs$core$map_entry_QMARK_$$($other$jscomp$204$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.key.$cljs$core$IFn$_invoke$arity$1$?this.key.$cljs$core$IFn$_invoke$arity$1$(this):this.key(this),this.key.$cljs$core$IFn$_invoke$arity$1$?this.key.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$204$$):this.key($other$jscomp$204$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_val$$(this),
$APP.$cljs$core$_val$$($other$jscomp$204$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($node$jscomp$485$$,$n$jscomp$320$$){if($n$jscomp$320$$===0)return this.key;if($n$jscomp$320$$===1)return this.$cljs$core$IMapEntry$_val$arity$1$(null);throw Error("Index out of bounds");};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($node$jscomp$486$$,$n$jscomp$321$$,$not_found$jscomp$89$$){return $n$jscomp$321$$===0?this.key:$n$jscomp$321$$===1?this.$cljs$core$IMapEntry$_val$arity$1$(null):$not_found$jscomp$89$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $this$__$1$jscomp$450$$=this;return $APP.$cljs$core$cons$$(this.key,new $APP.$cljs$core$LazySeq$$(null,function(){return $APP.$cljs$core$cons$$($this$__$1$jscomp$450$$.$cljs$core$IMapEntry$_val$arity$1$(null),null)},null,null))};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14279__auto__$jscomp$35$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7675$$,$args83481$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args83481$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$722$$){return this.$cljs$core$IIndexed$_nth$arity$2$(null,$k$jscomp$722$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$723$$,$not_found$jscomp$90$$){return this.$cljs$core$IIndexed$_nth$arity$3$(null,$k$jscomp$723$$,$not_found$jscomp$90$$)};$APP.$JSCompiler_prototypeAlias$$=$app$common$types$objects_map$ObjectsMap$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this$$jscomp$894$$,$writer$jscomp$178$$,$opts$jscomp$315$$){return $APP.$cljs$core$pr_sequential_writer$$($writer$jscomp$178$$,function($item$jscomp$154$$,$w$jscomp$48$$){$APP.$cljs$core$_write$$($w$jscomp$48$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_key$$($item$jscomp$154$$)])));$APP.$cljs$core$_write$$($w$jscomp$48$$,
" ");return $APP.$cljs$core$_write$$($w$jscomp$48$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$_val$$($item$jscomp$154$$)])))},"#penpot/objects-map {",", ","}",$opts$jscomp$315$$,$APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$SeqIter$$(this)};$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};
$APP.$JSCompiler_prototypeAlias$$.equiv=function($other$jscomp$205$$){return this.$cljs$core$IEquiv$_equiv$arity$2$(null,$other$jscomp$205$$)};$APP.$JSCompiler_prototypeAlias$$.keys=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$keys$$(this))};$APP.$JSCompiler_prototypeAlias$$.entries=function(){return $APP.$cljs$core$es6_entries_iterator$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.values=function(){return $APP.$cljs$core$es6_iterator$$($APP.$cljs$core$vals$$(this))};
$APP.$JSCompiler_prototypeAlias$$.has=function($k$jscomp$724$$){return $APP.$cljs$core$contains_QMARK_$$(this,$k$jscomp$724$$)};$APP.$JSCompiler_prototypeAlias$$.get=function($k$jscomp$725$$,$not_found$jscomp$91$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$725$$,$not_found$jscomp$91$$)};
$APP.$JSCompiler_prototypeAlias$$.forEach=function($f$jscomp$894$$){return $APP.$cljs$core$run_BANG_$$(function($p__83502_v$jscomp$699$$){var $k$jscomp$726$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83502_v$jscomp$699$$,0,null);$p__83502_v$jscomp$699$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83502_v$jscomp$699$$,1,null);return $f$jscomp$894$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$894$$.$cljs$core$IFn$_invoke$arity$2$($p__83502_v$jscomp$699$$,$k$jscomp$726$$):
$f$jscomp$894$$($p__83502_v$jscomp$699$$,$k$jscomp$726$$)},this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFind$_find$arity$2$=function($this$$jscomp$904$$,$k$jscomp$727$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.data,$k$jscomp$727$$)?new $app$common$types$objects_map$ObjectsMapEntry$$($k$jscomp$727$$,this):null};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this$$jscomp$905$$,$new_meta$jscomp$36$$){return $new_meta$jscomp$36$$===$APP.$cljs$core$meta$$?this:new $app$common$types$objects_map$ObjectsMap$$($new_meta$jscomp$36$$,this.cache,this.data,this.$modified$,this.hash)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$,$k$jscomp$728$$){$or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$=$APP.$cljs$core$_lookup$$(this.cache,$k$jscomp$728$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$))return $or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$;if($APP.$cljs$core$_contains_key_QMARK_$$(this.data,
$k$jscomp$728$$))return $or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$=$APP.$cljs$core$_lookup$$(this.data,$k$jscomp$728$$),$or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$),this.cache=$APP.$cljs$core$_assoc$$(this.cache,$k$jscomp$728$$,$or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$),
$or__5025__auto__$jscomp$1482_this$$jscomp$906_v$jscomp$700_v__$1$jscomp$35$$;this.cache=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.cache,$k$jscomp$728$$,null);return null};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$907$$,$k$jscomp$729$$,$not_found$jscomp$92$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.data,$k$jscomp$729$$)?this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$729$$):$not_found$jscomp$92$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.metadata};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$$(this);return new $app$common$types$objects_map$ObjectsMap$$(this.metadata,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,this.data,!1,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this$$jscomp$909$$,$f$jscomp$895$$,$init$jscomp$61$$){var $this$__$1$jscomp$458$$=this;return $APP.$cljs$core$_kv_reduce$$(this.data,function($init__$1$jscomp$12$$,$k$jscomp$730$$){var $G__83516$$=$this$__$1$jscomp$458$$.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$730$$);return $f$jscomp$895$$.$cljs$core$IFn$_invoke$arity$3$?$f$jscomp$895$$.$cljs$core$IFn$_invoke$arity$3$($init__$1$jscomp$12$$,$k$jscomp$730$$,
$G__83516$$):$f$jscomp$895$$($init__$1$jscomp$12$$,$k$jscomp$730$$,$G__83516$$)},$init$jscomp$61$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){$APP.$cljs$core$truth_$$(this.hash)||(this.hash=$APP.$cljs$core$hash_unordered_coll$$(this));return this.hash};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$911$$,$other$jscomp$206$$){return $APP.$cljs$core$equiv_map$$(this,$other$jscomp$206$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$?$app$common$types$objects_map$create$cljs$0core$0IFn$0_invoke$0arity$00$$():$app$common$types$objects_map$create$$()};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($_$jscomp$3214$$,$k$jscomp$731$$,$v$jscomp$701$$){return new $app$common$types$objects_map$ObjectsMap$$(this.metadata,$APP.$cljs$core$_assoc$$(this.cache,$k$jscomp$731$$,$v$jscomp$701$$),$APP.$cljs$core$_assoc$$(this.data,$k$jscomp$731$$,null),!0,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($_$jscomp$3215$$,$k$jscomp$732$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.data,$k$jscomp$732$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return $APP.$cljs$core$_count$$(this.data)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($_$jscomp$3217$$,$k$jscomp$733$$){return new $app$common$types$objects_map$ObjectsMap$$(this.metadata,$APP.$cljs$core$_dissoc$$(this.cache,$k$jscomp$733$$),$APP.$cljs$core$_dissoc$$(this.data,$k$jscomp$733$$),!0,null)};$APP.$JSCompiler_prototypeAlias$$.$app$common$types$objects_map$IObjectsMap$get_data$arity$1$=function(){$JSCompiler_StaticMethods_app$common$types$objects_map$IObjectsMap$compact$arity$1$$(this);return this.data};
$APP.$JSCompiler_prototypeAlias$$.$app$common$types$objects_map$IObjectsMap$_hash_for_key$arity$2$=function($this$$jscomp$914$$,$key$jscomp$437$$){return $APP.$cljs$core$_contains_key_QMARK_$$(this.cache,$key$jscomp$437$$)?$APP.$cljs$core$_hash$$($APP.$cljs$core$_lookup$$(this.cache,$key$jscomp$437$$)):$APP.$cljs$core$_hash$$(this.$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$437$$))};
$APP.$JSCompiler_prototypeAlias$$.$clojure$core$protocols$Datafiable$datafy$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$142$data$$,this.data,$cljs$cst$6434$cache$$,this.cache,$cljs$cst$6435$modified$$,this.$modified$,$cljs$cst$6436$hash$$,this.hash],null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){var $this$__$1$jscomp$464$$=this;return $APP.$cljs$core$seq$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$1086$$){return new $app$common$types$objects_map$ObjectsMapEntry$$($id$jscomp$1086$$,$this$__$1$jscomp$464$$)},$APP.$cljs$core$keys$$(this.data)))};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14279__auto__$jscomp$36$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7711$$,$args83495$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args83495$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($k$jscomp$734$$){return this.$cljs$core$ILookup$_lookup$arity$2$(null,$k$jscomp$734$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($k$jscomp$735$$,$not_found$jscomp$93$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k$jscomp$735$$,$not_found$jscomp$93$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($G__83538_ret$jscomp$148_this$$jscomp$918$$,$G__83539_entry$jscomp$87_es$jscomp$12$$){if($APP.$cljs$core$map_entry_QMARK_$$($G__83539_entry$jscomp$87_es$jscomp$12$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,$G__83539_entry$jscomp$87_es$jscomp$12$$.key,$G__83539_entry$jscomp$87_es$jscomp$12$$.$cljs$core$IMapEntry$_val$arity$1$(null));if($APP.$cljs$core$vector_QMARK_$$($G__83539_entry$jscomp$87_es$jscomp$12$$))return this.$cljs$core$IAssociative$_assoc$arity$3$(null,
$APP.$cljs$core$_nth$$($G__83539_entry$jscomp$87_es$jscomp$12$$,0),$APP.$cljs$core$_nth$$($G__83539_entry$jscomp$87_es$jscomp$12$$,1));$G__83538_ret$jscomp$148_this$$jscomp$918$$=this;for($G__83539_entry$jscomp$87_es$jscomp$12$$=$APP.$cljs$core$seq$$($G__83539_entry$jscomp$87_es$jscomp$12$$);;){if($G__83539_entry$jscomp$87_es$jscomp$12$$==null)return $G__83538_ret$jscomp$148_this$$jscomp$918$$;var $e$jscomp$418$$=$APP.$cljs$core$first$$($G__83539_entry$jscomp$87_es$jscomp$12$$);if($APP.$cljs$core$vector_QMARK_$$($e$jscomp$418$$))$G__83538_ret$jscomp$148_this$$jscomp$918$$=
$APP.$cljs$core$_assoc$$($G__83538_ret$jscomp$148_this$$jscomp$918$$,$APP.$cljs$core$_nth$$($e$jscomp$418$$,0),$APP.$cljs$core$_nth$$($e$jscomp$418$$,1)),$G__83539_entry$jscomp$87_es$jscomp$12$$=$APP.$cljs$core$next$$($G__83539_entry$jscomp$87_es$jscomp$12$$);else throw Error("conj on a map takes map entries or seqables of map entries");}};$app$common$types$objects_map$ObjectsMap$$.prototype[$APP.$cljs$core$ITER_SYMBOL$$]=function(){return $APP.$cljs$core$es6_iterator$$(this)};
$APP.$app$common$transit$add_handlers_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"penpot/objects-map/v2",$APP.$cljs$cst$1296$class$$,$app$common$types$objects_map$ObjectsMap$$,$APP.$cljs$cst$1319$wfn$$,$app$common$types$objects_map$get_data$$,$APP.$cljs$cst$1320$rfn$$,$app$common$types$objects_map$from_data$$],null)]));var $shadow$js$shim$module$0react_error_boundary$$=shadow$bridge("react-error-boundary");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$56$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$56$$,$APP.$cljs$cst$5129$app_DOT_main_DOT_data_DOT_exports_DOT_files_SLASH_export_files$$,$app$main$ui$exports$files$export_dialog$$)});var $app$main$ui$frame_preview$frame_preview_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $iframe_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_data_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$zoom_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$zoom_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(1),$zoom$jscomp$193$$=$APP.$cljs$core$_deref$$($zoom_STAR_$$),$handle_load$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$528$$,
$width$jscomp$259$$,$height$jscomp$224$$){$APP.$cljs$core$reset_BANG_$$($last_data_STAR_$$,$data$jscomp$528$$);var $iframe_dom$$=$APP.$rumext$v2$ref_val$$($iframe_ref$$);return $APP.$cljs$core$truth_$$($iframe_dom$$)?($iframe_dom$$.width=$width$jscomp$259$$+64,$iframe_dom$$.height=$height$jscomp$224$$+64,$iframe_dom$$.contentWindow.document.open(),$iframe_dom$$.contentWindow.document.write($data$jscomp$528$$),$iframe_dom$$.contentWindow.document.close()):null}),$load_ref$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($iframe_dom$jscomp$1$$){$APP.$rumext$v2$set_ref_val_BANG_$$($iframe_ref$$,
$iframe_dom$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($iframe_dom$jscomp$1$$)?$APP.$cljs$core$_deref$$($last_data_STAR_$$):$iframe_dom$jscomp$1$$)?($iframe_dom$jscomp$1$$.contentWindow.document.open(),$iframe_dom$jscomp$1$$.contentWindow.document.write($APP.$cljs$core$_deref$$($last_data_STAR_$$)),$iframe_dom$jscomp$1$$.contentWindow.document.close()):null}),$change_zoom$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($zoom_STAR_$$,
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$rumext$v2$ref_val$$($zoom_ref$jscomp$3$$).value)/100)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){window.load=$handle_load$$;return function(){return delete window.load}});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{display:"flex",width:"100%",height:"100%",flexDirection:"column",overflow:"auto",alignItems:"center"},children:[(0,$APP.$rumext$v2$jsx$$)("input",{id:"zoom-input",ref:$zoom_ref$jscomp$3$$,
type:"range",min:1,max:400,defaultValue:100,onChange:$change_zoom$$,style:{maxWidth:"500px"}}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{width:"100%",height:"100%",overflow:"auto"},children:(0,$APP.$rumext$v2$jsx$$)("iframe",{ref:$load_ref$$,frameBorder:"0",scrolling:"no",style:{transformOrigin:"top left",transform:["scale(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$193$$),")"].join("")}})})]})});var $app$main$ui$notifications$ref_COLON_notification$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2370$notification$$,$APP.$app$main$store$state$$);var $app$main$ui$onboarding$questions$schema_COLON_questions_form_1$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep1"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$cljs$cst$6441$expected_use$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"work","education","personal"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2501$role$$,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"ux","developer","student-teacher","designer","marketing","manager",
"other"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6442$role_other$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,512],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3441$error_SLASH_field$$,$cljs$cst$6442$role_other$$],null),function($p__83695_role$jscomp$18$$){var $map__83696__$1_role_other$$=$APP.$cljs$core$__destructure_map$$($p__83695_role$jscomp$18$$);$p__83695_role$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83696__$1_role_other$$,$APP.$cljs$cst$2501$role$$);$map__83696__$1_role_other$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83696__$1_role_other$$,
$cljs$cst$6442$role_other$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83695_role$jscomp$18$$,"other")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83695_role$jscomp$18$$,"other")&&!$APP.$cuerdas$core$blank_QMARK_$$($map__83696__$1_role_other$$)}],null)],null),$app$main$ui$onboarding$questions$schema_COLON_questions_form_2$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep2"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6443$experience_design_tool$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"figma","sketch","adobe-xd","canva","invision","other"],null)],null),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6444$experience_design_tool_other$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,512],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3441$error_SLASH_field$$,$cljs$cst$6444$experience_design_tool_other$$],null),function($data$jscomp$529_experience_other$$){var $experience$$=$cljs$cst$6443$experience_design_tool$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$529_experience_other$$);$data$jscomp$529_experience_other$$=$cljs$cst$6444$experience_design_tool_other$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$529_experience_other$$);
return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($experience$$,"other")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($experience$$,"other")&&!$APP.$cuerdas$core$blank_QMARK_$$($data$jscomp$529_experience_other$$)}],null)],null),$app$main$ui$onboarding$questions$schema_COLON_questions_form_3$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep3"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6447$team_size$$,new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"1","2-100","101-500","501-1000","1001-5000","5001+"],null)],null)],null)],null),$app$main$ui$onboarding$questions$schema_COLON_questions_form_4$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"QuestionsFormStep4"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6448$start_with$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$499$enum$$,"ui","wireframing","prototyping","ds","code","other"],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6449$start_with_other$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,512],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3441$error_SLASH_field$$,$cljs$cst$6449$start_with_other$$],null),function($p__83711_start_with$$){var $map__83712__$1_start_with_other$$=$APP.$cljs$core$__destructure_map$$($p__83711_start_with$$);$p__83711_start_with$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83712__$1_start_with_other$$,$cljs$cst$6448$start_with$$);$map__83712__$1_start_with_other$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83712__$1_start_with_other$$,$cljs$cst$6449$start_with_other$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83711_start_with$$,"other")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__83711_start_with$$,"other")&&!$APP.$cuerdas$core$blank_QMARK_$$($map__83712__$1_start_with_other$$)}],
null)],null);var $app$main$ui$onboarding$team_choice$schema_COLON_team_form$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"TeamForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$APP.$app$common$types$team$schema_COLON_team_name$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2501$role$$,$APP.$cljs$cst$221$keyword$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3346$emails$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,$APP.$cljs$cst$944$app_DOT_common_DOT_schema_SLASH_email$$],
null)],null)],null);var $app$main$ui$releases$common$render_release_notes$$,$method_table__5622__auto__$jscomp$inline_14194$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$inline_14195$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$inline_14196$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$cached_hierarchy__5625__auto__$jscomp$inline_14197$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$inline_14198$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());
$app$main$ui$releases$common$render_release_notes$$=new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.main.ui.releases.common","render-release-notes"),$APP.$cljs$cst$1726$version$$,$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$inline_14198$$,$method_table__5622__auto__$jscomp$inline_14194$$,$prefer_table__5623__auto__$jscomp$inline_14195$$,$method_cache__5624__auto__$jscomp$inline_14196$$,$cached_hierarchy__5625__auto__$jscomp$inline_14197$$);$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.10",function($klass$jscomp$5_p__83734$$){var $map__83735__$1_version$jscomp$27$$=$APP.$cljs$core$__destructure_map$$($klass$jscomp$5_p__83734$$);$klass$jscomp$5_p__83734$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83735__$1_version$jscomp$27$$,$cljs$cst$6454$klass$$);var $finish$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83735__$1_version$jscomp$27$$,$cljs$cst$6455$finish$$);
$map__83735__$1_version$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83735__$1_version$jscomp$27$$,$APP.$cljs$cst$1726$version$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$5_p__83734$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/beta-on.jpg",border:"0",alt:"Penpot is now BETA"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Penpot is now BETA"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83735__$1_version$jscomp$27$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot’s officially beta!"}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We carefully analyzed everything important to us before taking this step. And now we’re ready to move forward onto the beta version.  Have a play around if you haven’t yet."}),(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://penpot.app/why-beta",target:"_blank",children:"Learn why we made this decision."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$4$$,
children:"Explore Penpot Beta 1.10"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",border:"0"})]})})})});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.11",function($p__83736_slide$jscomp$1$$){var $map__83737__$1_version$jscomp$28$$=$APP.$cljs$core$__destructure_map$$($p__83736_slide$jscomp$1$$);$p__83736_slide$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83737__$1_version$jscomp$28$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83737__$1_version$jscomp$28$$,
$cljs$cst$6454$klass$$),$next$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83737__$1_version$jscomp$28$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83737__$1_version$jscomp$28$$,$cljs$cst$6455$finish$$),$navigate$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83737__$1_version$jscomp$28$$,$APP.$cljs$cst$1957$navigate$$);$map__83737__$1_version$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83737__$1_version$jscomp$28$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83736_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.11"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83737__$1_version$jscomp$28$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.11 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$13$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83736_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.11-animations.gif",
border:"0",alt:"Animations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Prototype animations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Bring your prototypes to life with animations! With animations now you can define the transition between artboards when an interaction is triggered."}),(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Use dissolve, slide and push animations to fade screens and imitate gestures like swipe."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$13$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83736_slide$jscomp$1$$,navigate:$navigate$jscomp$6$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83736_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.11-bg-export.gif",border:"0",alt:"Ignore background on export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Ignore artboard background on export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Sometimes you don’t need the artboards to be part of your designs, but only their support to work on them."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can decide to include their backgrounds on your exports or leave them out."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$13$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83736_slide$jscomp$1$$,navigate:$navigate$jscomp$6$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83736_slide$jscomp$1$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$6$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.11-zoom-widget.gif",border:"0",alt:"New zoom widget"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"New zoom widget"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve redesigned zooming menus to improve their usability and the consistency between zooming in the design workspace and in the view mode."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve also added two new options to scale your designs at the view mode that might help you to make your presentations look better."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$5$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83736_slide$jscomp$1$$,navigate:$navigate$jscomp$6$$,total:3})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83736_slide$jscomp$1$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.12",function($p__83739_slide$jscomp$2$$){var $map__83740__$1_version$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($p__83739_slide$jscomp$2$$);$p__83739_slide$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83740__$1_version$jscomp$29$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83740__$1_version$jscomp$29$$,
$cljs$cst$6454$klass$$),$next$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83740__$1_version$jscomp$29$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83740__$1_version$jscomp$29$$,$cljs$cst$6455$finish$$),$navigate$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83740__$1_version$jscomp$29$$,$APP.$cljs$cst$1957$navigate$$);$map__83740__$1_version$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83740__$1_version$jscomp$29$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83739_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.12"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83740__$1_version$jscomp$29$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.12 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83739_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-ui.gif",border:"0",
alt:"Adjustable UI"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Adjustable UI"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Adjust the workspace interface to your unique experience. Resize the sidebar, the layers panel  or hide the whole UI to have maximum space."}),(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Along with a better organization of panels (say hello to typography toolbar!) and new shortcuts that will speed your workflow."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83739_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83739_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-guides.gif",border:"0",alt:"Guides"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Guides"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"One of our most requested features! It’s hard to believe how far Penpot has come without guides, but they are here at last."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"And they don’t come alone, but with some nice improvements to the rulers."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83739_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83739_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-scrollbars.gif",border:"0",alt:"Scrollbars"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Scrollbars"})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-content",children:(0,$APP.$rumext$v2$jsx$$)("p",{children:"Scrollbars at the design workspace will make it more obvious how to navigate it and easier for some users, for instance those who love using graphic tablets, from now on, will feel just as comfortable as those who use a mouseAnd they don’t come alone, but with some nice improvements to the rulers."})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$14$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83739_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83739_slide$jscomp$2$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$7$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.12-nudge.gif",border:"0",alt:"Nudge amount"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Nudge amount"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Set your desired distance to move objects using the keyboard."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is a must if you’re working with grids (if you’re not, you should ;)), being able to adjust the movement to your baseline grid (8px? 5px?) is a huge timesaver that will improve your quality of life while designing."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$6$$,
children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83739_slide$jscomp$2$$,navigate:$navigate$jscomp$7$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83739_slide$jscomp$2$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.13",function($p__83742_slide$jscomp$3$$){var $map__83743__$1_version$jscomp$30$$=$APP.$cljs$core$__destructure_map$$($p__83742_slide$jscomp$3$$);$p__83742_slide$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83743__$1_version$jscomp$30$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83743__$1_version$jscomp$30$$,
$cljs$cst$6454$klass$$),$next$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83743__$1_version$jscomp$30$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83743__$1_version$jscomp$30$$,$cljs$cst$6455$finish$$),$navigate$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83743__$1_version$jscomp$30$$,$APP.$cljs$cst$1957$navigate$$);$map__83743__$1_version$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83743__$1_version$jscomp$30$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83742_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.13"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83743__$1_version$jscomp$30$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.13 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83742_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-multi-export.gif",
border:"0",alt:"Multiple exports"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Multiple exports"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Speed up your workflow exporting multiple elements simultaneously."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Use the export window to manage your multiple exports and be informed about the download progress. Big exports will happen in the background so you can keep designing in the meantime ;)"})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83742_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83742_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-multiple-fills.gif",border:"0",alt:"Multiple fills and strokes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",
children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Multiple fills and strokes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can add multiple color fills and strokes to a single element, including shapes and texts."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This opens endless graphic possibilities such as combining gradients and blending modes in the same element to create sophisticated visual effects."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83742_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83742_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"animated "+($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-members.gif",border:"0",alt:"Members area redesign"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Members area redesign"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot is meant for teams, that’s why we decided to give some love to the members area."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"A refreshed interface and two new features! The Invitations section allows you to check the status of current team invites plus you now have the ability to invite multiple members at the same time."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$15$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83742_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83742_slide$jscomp$3$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$8$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.13-focus.gif",border:"0",alt:"Focus mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Focus mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Enjoy a distraction-less design mode by selecting the elements of a page that matter to you and temporarily hiding the rest."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"As a side effect, this can give you a performance boost in massive designs."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$7$$,children:"Start!"}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83742_slide$jscomp$3$$,navigate:$navigate$jscomp$8$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83742_slide$jscomp$3$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.14",function($p__83745_slide$jscomp$4$$){var $map__83746__$1_version$jscomp$31$$=$APP.$cljs$core$__destructure_map$$($p__83745_slide$jscomp$4$$);$p__83745_slide$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83746__$1_version$jscomp$31$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83746__$1_version$jscomp$31$$,
$cljs$cst$6454$klass$$),$next$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83746__$1_version$jscomp$31$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83746__$1_version$jscomp$31$$,$cljs$cst$6455$finish$$),$navigate$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83746__$1_version$jscomp$31$$,$APP.$cljs$cst$1957$navigate$$);$map__83746__$1_version$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83746__$1_version$jscomp$31$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83745_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.14"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83746__$1_version$jscomp$31$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.14 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$16$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83745_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-shortcuts.gif",border:"0",
alt:"Shortcuts panel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Shortcuts panel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Shortcuts boost your productivity but are not easy to find and learn. A handy panel at your workspace will help you with that."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Categories and filters will help you to find the shortcut you need. One of the most requested features by the community!"})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$16$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83745_slide$jscomp$4$$,navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83745_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-color-group.gif",border:"0",alt:"Colors selection"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Colors selection"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"All of the colors that are contained within a selection of objects are showcased at the sidebar."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Play with the colors of a group without the hassles of individual selection!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$next$jscomp$16$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83745_slide$jscomp$4$$,navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83745_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-fix-on-scroll.gif",border:"0",alt:"Fix elements at scroll"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Fix elements at scroll"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"A new option that allows you to fix the position of an object when scrolling at the presentation view."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Ideal for prototyping fixed headers, navbars and floating buttons."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$16$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83745_slide$jscomp$4$$,
navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83745_slide$jscomp$4$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$9$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.14-group-assets.gif",
border:"0",alt:"Group library assets with drag \x26 drop"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Group library assets with drag \x26 drop"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We have improved the way to manage asset groups at libraries."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Until now you could only do it by renaming the groups, now with drag \x26 drop it is much more user friendly."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$8$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83745_slide$jscomp$4$$,navigate:$navigate$jscomp$9$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83745_slide$jscomp$4$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.15",function($p__83748_slide$jscomp$5$$){var $map__83749__$1_version$jscomp$32$$=$APP.$cljs$core$__destructure_map$$($p__83748_slide$jscomp$5$$);$p__83748_slide$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83749__$1_version$jscomp$32$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83749__$1_version$jscomp$32$$,
$cljs$cst$6454$klass$$),$next$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83749__$1_version$jscomp$32$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83749__$1_version$jscomp$32$$,$cljs$cst$6455$finish$$),$navigate$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83749__$1_version$jscomp$32$$,$APP.$cljs$cst$1957$navigate$$);$map__83749__$1_version$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83749__$1_version$jscomp$32$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83748_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.15"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83749__$1_version$jscomp$32$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.15 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83748_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-nested-boards.gif",
border:"0",alt:"Nested boards"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Nested boards"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Unlike its predecessors (the artboards) boards can contain other boards and offer the options to clip content and show them or not at the View Mode, opening up a ton of possibilities when creating and organizing your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Say goodbye to Artboards and hello to Boards!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83748_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83748_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-share.gif",border:"0",alt:"Share prototype options"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Share prototype options"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Have you ever wanted to share a Penpot file and get feedback from people that are not in your Penpot team?"}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can thanks to new permissions that allow you to decide who can comment and/or inspect the code at a shared prototype link."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83748_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83748_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-comments.gif",border:"0",alt:"Comments positioning"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Comments positioning"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"They live! Now you can move existing comments wherever you want by dragging them."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Also, comments inside boards will be associated with it, so that if you move a board its comments will maintain its place inside it."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$17$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83748_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83748_slide$jscomp$5$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$10$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.15-view-mode.gif",border:"0",alt:"View Mode improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"View Mode improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"The View Mode, used for presenting designs, is now easier to use thanks to new navigation buttons and microinteractions."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve also made some adjustments to ensure the access to the options from  small screens."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$9$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83748_slide$jscomp$5$$,navigate:$navigate$jscomp$10$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83748_slide$jscomp$5$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.16",function($p__83751_slide$jscomp$6$$){var $map__83752__$1_version$jscomp$33$$=$APP.$cljs$core$__destructure_map$$($p__83751_slide$jscomp$6$$);$p__83751_slide$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83752__$1_version$jscomp$33$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83752__$1_version$jscomp$33$$,
$cljs$cst$6454$klass$$),$next$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83752__$1_version$jscomp$33$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83752__$1_version$jscomp$33$$,$cljs$cst$6455$finish$$),$navigate$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83752__$1_version$jscomp$33$$,$APP.$cljs$cst$1957$navigate$$);$map__83752__$1_version$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83752__$1_version$jscomp$33$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83751_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Beta release 1.16"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Beta version ",$map__83752__$1_version$jscomp$33$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues to grow with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Beta 1.16 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83751_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-dashboard.gif",
border:"0",alt:"Dashboard refreshed look \x26 feel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Dashboard refreshed look \x26 feel"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"It’s been some time since we designed the project's dashboard and we felt that we could improve it in terms of accessibility, content hierarchy and aesthetics."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We heard the users before refreshing the interface, simplifying it to give prominence to the content. And yes, now that you ask, the dark theme is coming soon."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83751_slide$jscomp$6$$,
navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83751_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-slider.gif",
border:"0",alt:"Libraries \x26 templates module"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Libraries \x26 templates module"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"This new module will allow you to import a curated selection of the files that are available at the Libraries \x26 Templates page directly from your projects dashboard."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"You no longer need to to download most of them to the computer before importing."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83751_slide$jscomp$6$$,navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$p__83751_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-onboarding.gif",border:"0",alt:"Improved onboarding"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Improved onboarding"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve done a ton of improvements to the onboarding experience."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"More relevant info and better explanations, a refined new team and invitation flow, a beginners tutorial and a walkthrough file that will help newcomers learn how to use and start designing with Penpot faster."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$18$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83751_slide$jscomp$6$$,navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83751_slide$jscomp$6$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$11$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.16-click-zoom.gif",border:"0",alt:"Zoom to shape with double click"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",
children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Zoom to shape with double click"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"The devil is in the details. At the layers panel, double clicking to the icon of a layer will zoom to it, making the layers navigation and selection easier."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This was a contribution by our community member @andrewzhurov \x3c3"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$10$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83751_slide$jscomp$6$$,navigate:$navigate$jscomp$11$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83751_slide$jscomp$6$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.17",function($p__83754_slide$jscomp$7$$){var $map__83755__$1_version$jscomp$34$$=$APP.$cljs$core$__destructure_map$$($p__83754_slide$jscomp$7$$);$p__83754_slide$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83755__$1_version$jscomp$34$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83755__$1_version$jscomp$34$$,
$cljs$cst$6454$klass$$),$next$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83755__$1_version$jscomp$34$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83755__$1_version$jscomp$34$$,$cljs$cst$6455$finish$$),$navigate$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83755__$1_version$jscomp$34$$,$APP.$cljs$cst$1957$navigate$$);$map__83755__$1_version$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83755__$1_version$jscomp$34$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83754_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/onboarding-version.jpg",
border:"0",alt:"What's new release 1.17"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Version ",$map__83755__$1_version$jscomp$34$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is the first release in which Penpot is no longer Beta (hooray!) and it comes with very special features, starring the long awaited Flex Layout."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"On this 1.17 release, you’ll also be able to inspect the code and properties of your designs right from the workspace and to manage webhooks. We’ve also implemented a lot of accessibility improvements."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",
border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83754_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",
children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.17-flex-layout.gif",border:"0",alt:"Flex-Layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Flex-Layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"The Flex Layout allows you to automatically adapt your designs. Resize, fit, and fill content and containers without the need to do it manually."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot brings a layout system like no other. As described by one of our beta testers: 'I love the fact that Penpot is following the CSS FlexBox, which is making UI Design a step closer to the logic and behavior behind how things will be actually built after design.'"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83754_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83754_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/1.17-inspect.gif",border:"0",alt:"Inspect at the workspace"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Inspect at the workspace"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can inspect designs to get measures, properties and production-ready code right at the workspace, so designers and developers can share the same space while working."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Also, inspect mode provides a safer view-only mode and other improvements."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83754_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$p__83754_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.17-webhook.gif",border:"0",alt:"Webhooks"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Webhooks"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Webhooks allow other websites and apps to be notified when certain events happen at Penpot, ensuring to create integrations with other services."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"While we are still working on a plugin system, this is a great and simple way to create integrations with other services."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$19$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83754_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83754_slide$jscomp$7$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$12$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.17-ally.gif",border:"0",alt:"Accessibility improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Accessibility improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We're working to ensure that people with visual or physical impairments can use Penpot in the same conditions."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This release comes with improvements on color contrasts, alt texts, semantic labels, focusable items and keyboard navigation at login and dashboard, but more will come."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$11$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83754_slide$jscomp$7$$,navigate:$navigate$jscomp$12$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83754_slide$jscomp$7$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.18",function($p__83758_slide$jscomp$8$$){var $map__83760__$1_version$jscomp$35$$=$APP.$cljs$core$__destructure_map$$($p__83758_slide$jscomp$8$$);$p__83758_slide$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_version$jscomp$35$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_version$jscomp$35$$,
$cljs$cst$6454$klass$$),$next$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_version$jscomp$35$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_version$jscomp$35$$,$cljs$cst$6455$finish$$),$navigate$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_version$jscomp$35$$,$APP.$cljs$cst$1957$navigate$$);$map__83760__$1_version$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83760__$1_version$jscomp$35$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83758_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/onboarding-version.jpg",
border:"0",alt:"What's new release 1.18"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Version ",$map__83760__$1_version$jscomp$35$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"On this 1.18 release we make Flex Layout even more powerful with smart spacing, absolute position and z-index management."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We also continued implementing accessibility improvements to make Penpot more inclusive and published stability and performance enhancements."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",
src:"images/deco-right.png",border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83758_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-spacing.gif",
border:"0",alt:"Spacing management"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Spacing management for Flex layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Managing Flex Layout spacing is much more intuitive now. Visualize paddings, margins and gaps and drag to resize them."}),(0,$APP.$rumext$v2$jsx$$)("p",
{children:"And not only that, when creating Flex layouts, the spacing is predicted, helping you to maintain your design composition."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83758_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83758_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-absolute.gif",border:"0",alt:"Position absolute feature"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Absolute position elements in Flex layout"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Sometimes you need to freely position an element in a specific place regardless of the size of the layout where it belongs."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can exclude elements from the Flex layout flow using absolute position."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83758_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83758_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-z-index.gif",border:"0",alt:"Z-index feature"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"More on Flex layout: z-index"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"With the new z-index option you can decide the order of overlapping elements while maintaining the layers order."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is another capability that brings Penpot Flex layout even closer to the power of CSS standards."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$20$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83758_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83758_slide$jscomp$8$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$13$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.18-scale.gif",border:"0",alt:"Scale content proportionally"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Scale content proportionally affects strokes, shadows, blurs and corners"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can resize your layers and groups preserving their aspect ratio while scaling their properties proportionally, including strokes, shadows, blurs and corners."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Activate the scale tool by pressing K and scale your elements, maintaining their visual aspect."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$finish$jscomp$12$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83758_slide$jscomp$8$$,navigate:$navigate$jscomp$13$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83758_slide$jscomp$8$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.19",function($p__83757_slide$jscomp$9$$){var $map__83759__$1_version$jscomp$36$$=$APP.$cljs$core$__destructure_map$$($p__83757_slide$jscomp$9$$);$p__83757_slide$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83759__$1_version$jscomp$36$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83759__$1_version$jscomp$36$$,
$cljs$cst$6454$klass$$),$next$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83759__$1_version$jscomp$36$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83759__$1_version$jscomp$36$$,$cljs$cst$6455$finish$$),$navigate$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83759__$1_version$jscomp$36$$,$APP.$cljs$cst$1957$navigate$$);$map__83759__$1_version$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83759__$1_version$jscomp$36$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83757_slide$jscomp$9$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$14$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/onboarding-version.jpg",
border:"0",alt:"What's new release 1.19"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Version ",$map__83759__$1_version$jscomp$36$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["On this 1.19 release, we bring Access Tokens, which ",
"will enable Penpot to connect with other services, ","another gateway to community creativity!"]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["We’ve also published performance improvements and tons ","of enhancements, a lot of them from our beloved community ","contributors \x3c3"]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$21$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",
{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83757_slide$jscomp$9$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$14$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.19-contributions.png",border:"0",alt:"Community code contributions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Community code contributions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["By far, this is the Penpot release that has the most ",
"code contributions. We cannot emphasize enough how happy ","we are to see how Penpot is more and more  a product of ","the community."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Let’s give kudos to ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/astudentinearth",target:"_blank",rel:"noopener noreferrer",children:"@astudentinearth"}),", ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/dfelinto",target:"_blank",rel:"noopener noreferrer",children:"@dfelinto"}),", ",(0,$APP.$rumext$v2$jsx$$)("a",
{href:"https://github.com/akshay-gupta7",target:"_blank",rel:"noopener noreferrer",children:"@akshay-gupta7"}),", ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/ondrejkonec",target:"_blank",rel:"noopener noreferrer",children:"@ondrejkonec"})," and ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://github.com/ryanbreen",target:"_blank",rel:"noopener noreferrer",children:"@ryanbreen"})," in particular and the Penpot community as a whole!"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$21$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83757_slide$jscomp$9$$,navigate:$navigate$jscomp$14$$,total:2})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83757_slide$jscomp$9$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$14$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/1.19-tokens.gif",border:"0",alt:"Access Tokens"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Access Tokens"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Personal access tokens function like an alternative to ","our login/password authentication system and can be used ","to allow an application to access the internal Penpot API."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["This opens up a wide range of possibilities in terms of ","integrations and is an important step on the critical path ","to the Penpot’s plugins system."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$13$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83757_slide$jscomp$9$$,navigate:$navigate$jscomp$14$$,total:2})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83757_slide$jscomp$9$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.4",function($p__83763_slide$jscomp$10$$){var $map__83764__$1_version$jscomp$37$$=$APP.$cljs$core$__destructure_map$$($p__83763_slide$jscomp$10$$);$p__83763_slide$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_version$jscomp$37$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_version$jscomp$37$$,
$cljs$cst$6454$klass$$),$next$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_version$jscomp$37$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_version$jscomp$37$$,$cljs$cst$6455$finish$$),$navigate$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_version$jscomp$37$$,$APP.$cljs$cst$1957$navigate$$);$map__83764__$1_version$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83764__$1_version$jscomp$37$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83763_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.4.0"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83764__$1_version$jscomp$37$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.4.0 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83763_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/select-files.gif",border:"0",
alt:"New file selection"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"New file selection and open files"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can select files with left click and make multi-selections holding down the shift + left click."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"To open a file you just have to double click it. You can also open a file in a new tab with right click."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83763_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83763_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/manage-files.gif",border:"0",alt:"Manage files"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"New files/projects management"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot now allows to duplicate and move files and projects."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Also, now you have an easy way to manage files and projects between teams."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,
children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83763_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83763_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/rtl.gif",border:"0",alt:"RTL support"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"RTL support is now available!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Diversity and inclusion is one major Penpot concern and that's why we love to give support to RTL languages, unlike in most of design tools."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"If you write in arabic, hebrew or other RTL language text direction will be automatically detected in text layers."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$22$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83763_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83763_slide$jscomp$10$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$15$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/blend-modes.gif",border:"0",alt:"Blend modes"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"New layer opacity and blend modes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Combining elements visually is an important part of the design process."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"This is why the standard blend modes and opacity level are now available for each element."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$14$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83763_slide$jscomp$10$$,navigate:$navigate$jscomp$15$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83763_slide$jscomp$10$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.5",function($p__83765_slide$jscomp$11$$){var $map__83766__$1_version$jscomp$38$$=$APP.$cljs$core$__destructure_map$$($p__83765_slide$jscomp$11$$);$p__83765_slide$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83766__$1_version$jscomp$38$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83766__$1_version$jscomp$38$$,
$cljs$cst$6454$klass$$),$next$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83766__$1_version$jscomp$38$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83766__$1_version$jscomp$38$$,$cljs$cst$6455$finish$$),$navigate$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83766__$1_version$jscomp$38$$,$APP.$cljs$cst$1957$navigate$$);$map__83766__$1_version$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83766__$1_version$jscomp$38$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83765_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.5.0"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83766__$1_version$jscomp$38$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.5.0 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$23$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83765_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/path-tool.gif",border:"0",
alt:"New path tool"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"New features for paths"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can select snap points on edition, add/remove nodes, merge/join/split nodes."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"The usability and performance of the paths tool has been improved too."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$23$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83765_slide$jscomp$11$$,navigate:$navigate$jscomp$16$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83765_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/assets-organiz.gif",border:"0",alt:"Manage libraries"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"New libraries organization"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot now allows to group, multiselect and bulk edition of assets (components and graphics)."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"It is time to have all the libraries well organized and work more efficiently."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$next$jscomp$23$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83765_slide$jscomp$11$$,navigate:$navigate$jscomp$16$$,total:3})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83765_slide$jscomp$11$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$16$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/smart-inputs.gif",border:"0",alt:"Smart inputs"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Smart inputs"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Now you can have more precision in your designs with basic math operations in inputs."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"It's easier to specify by how much you want to change a value and work with measures and distances."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$15$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83765_slide$jscomp$11$$,navigate:$navigate$jscomp$16$$,total:3})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83765_slide$jscomp$11$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.6",function($p__83769_slide$jscomp$12$$){var $map__83770__$1_version$jscomp$39$$=$APP.$cljs$core$__destructure_map$$($p__83769_slide$jscomp$12$$);$p__83769_slide$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83770__$1_version$jscomp$39$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83770__$1_version$jscomp$39$$,
$cljs$cst$6454$klass$$),$next$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83770__$1_version$jscomp$39$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83770__$1_version$jscomp$39$$,$cljs$cst$6455$finish$$),$navigate$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83770__$1_version$jscomp$39$$,$APP.$cljs$cst$1957$navigate$$);$map__83770__$1_version$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83770__$1_version$jscomp$39$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83769_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.6.0"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83770__$1_version$jscomp$39$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.6.0 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$24$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83769_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/custom-fonts.gif",border:"0",
alt:"Upload/use custom fonts"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Upload/use custom fonts"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"From now on you can upload fonts to a Penpot team and use them across its files. This is one of the most requested features since our first release (we listen!)"}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We hope you enjoy having more typography options and our brand new font selector."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$24$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83769_slide$jscomp$12$$,navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,
$p__83769_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/scale-text.gif",border:"0",alt:"Interactively scale text"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Scale text layers at resizing"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"New main menu option “Scale text (K)” to enable scale text mode."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Disabled by default, this tool is disabled back after being used."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$24$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83769_slide$jscomp$12$$,navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83769_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/performance.gif",border:"0",alt:"Performance improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Performance improvements"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot brings important improvements handling large files. The performance in managing files in the dashboard has also been improved."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You should have the feeling that files and layers show up a bit faster :)"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",
onClick:$next$jscomp$24$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83769_slide$jscomp$12$$,navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83769_slide$jscomp$12$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$17$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/shapes-to-path.gif",border:"0",alt:"Shapes to path"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Shapes to path"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Now you can edit basic shapes like rectangles, circles and image containers by double clicking."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"An easy way to increase speed by working with vectors!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$16$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83769_slide$jscomp$12$$,
navigate:$navigate$jscomp$17$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83769_slide$jscomp$12$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.7",function($p__83772_slide$jscomp$13$$){var $map__83773__$1_version$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($p__83772_slide$jscomp$13$$);$p__83772_slide$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83773__$1_version$jscomp$40$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83773__$1_version$jscomp$40$$,
$cljs$cst$6454$klass$$),$next$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83773__$1_version$jscomp$40$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83773__$1_version$jscomp$40$$,$cljs$cst$6455$finish$$),$navigate$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83773__$1_version$jscomp$40$$,$APP.$cljs$cst$1957$navigate$$);$map__83773__$1_version$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83773__$1_version$jscomp$40$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83772_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.7"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83773__$1_version$jscomp$40$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.7 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83772_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/export.gif",border:"0",
alt:"Export \x26 Import"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Export and import Penpot files"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:[(0,$APP.$rumext$v2$jsx$$)("strong",{children:"Export files from the dashboard to your computer and import them from your computer to your projects."}),
" This means that Penpot users can freely save and share Penpot files."]}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Exported files linked to shared libraries provide\n          different ways to export their assets. Choose the one that\n          suits you better!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83772_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83772_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/constraints.gif",border:"0",alt:"Resizing constraints"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Resizing constraints"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Constraints allow you to ",(0,$APP.$rumext$v2$jsx$$)("strong",{children:"decide how layers will behave when resizing its container"}),
" being a group or an artboard."]}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You can manually set horizontal and vertical\n          constraints for every layer. This is especially useful to\n          control how your designs look when working with responsive\n          components."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83772_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83772_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/group-components.gif",border:"0",alt:"Library assets management improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Library assets management"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{children:[(0,$APP.$rumext$v2$jsx$$)("strong",{children:"Collapse/expand groups"})," at any nesting level, so you don’t have to manage their visibility individually."]}),
(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Penpot ",(0,$APP.$rumext$v2$jsx$$)("strong",{children:"remembers the last library state"}),", so you don’t have to collapse a group you want hidden every time."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{children:["Easily ",(0,$APP.$rumext$v2$jsx$$)("strong",{children:"rename and ungroup"})," asset groups."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$25$$,
children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83772_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83772_slide$jscomp$13$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$18$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/copy-paste.gif",border:"0",alt:"Paste components from file to file"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Paste components from file to file"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-content",children:(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Do you sometimes copy and paste component copies that belong to a library already shared by the original and destination files? From now on, those component copies are aware of this and will retain their linkage to the library."})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$17$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83772_slide$jscomp$13$$,navigate:$navigate$jscomp$18$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83772_slide$jscomp$13$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.8",function($p__83775_slide$jscomp$14$$){var $map__83776__$1_version$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($p__83775_slide$jscomp$14$$);$p__83775_slide$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83776__$1_version$jscomp$41$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83776__$1_version$jscomp$41$$,
$cljs$cst$6454$klass$$),$next$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83776__$1_version$jscomp$41$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83776__$1_version$jscomp$41$$,$cljs$cst$6455$finish$$),$navigate$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83776__$1_version$jscomp$41$$,$APP.$cljs$cst$1957$navigate$$);$map__83776__$1_version$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83776__$1_version$jscomp$41$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83775_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.8"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83776__$1_version$jscomp$41$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.8 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83775_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/share-viewer.gif",border:"0",
alt:"Share options and pages at view mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Share options and pages at view mode"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can navigate through prototype pages of the same file at the view mode."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You can also create a shareable link deciding which pages will be available for the visitors. Sharing is caring!"})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83775_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83775_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/stroke-caps.gif",border:"0",alt:"Path stroke caps"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Path stroke caps"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Ever needed an arrow to point something? Style the ends of any open paths."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"You can select different styles for each end of an open path: arrows, square, circle, diamond or just a round ending are the available options."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83775_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83775_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/navigate-history.gif",border:"0",alt:"Navigable history"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Navigable history"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{children:"Click on a change of the history of a file to get the file to this very point without ctrl+z all the way."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Quick and easy :)"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$26$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83775_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,
total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83775_slide$jscomp$14$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$19$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/export-artboards.gif",
border:"0",alt:"Export artboards PDF"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Export artboards PDF"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"If you have a presentation made at Penpot you might want to create a document that can be shared with anyone, regardless of having a Penpot account, or just to be able to use your presentation offline (essential for talks and classes)."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now you can easily export all the artboards of a page to a single pdf file."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$18$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83775_slide$jscomp$14$$,navigate:$navigate$jscomp$19$$,total:4})]})]})]})})});throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83775_slide$jscomp$14$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"1.9",function($p__83777_slide$jscomp$15$$){var $map__83778__$1_version$jscomp$42$$=$APP.$cljs$core$__destructure_map$$($p__83777_slide$jscomp$15$$);$p__83777_slide$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83778__$1_version$jscomp$42$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83778__$1_version$jscomp$42$$,
$cljs$cst$6454$klass$$),$next$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83778__$1_version$jscomp$42$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83778__$1_version$jscomp$42$$,$cljs$cst$6455$finish$$),$navigate$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83778__$1_version$jscomp$42$$,$APP.$cljs$cst$1957$navigate$$);$map__83778__$1_version$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83778__$1_version$jscomp$42$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83777_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/login-on.jpg",
border:"0",alt:"What's new Alpha release 1.9"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"What's new?"})}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"release",children:["Alpha version ",$map__83778__$1_version$jscomp$42$$]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Penpot continues growing with new features that improve performance, user experience and visual design."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"We are happy to show you a sneak peek of the most important stuff that the Alpha 1.9 version brings."})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"})})]}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco",src:"images/deco-left.png",border:"0"}),(0,$APP.$rumext$v2$jsx$$)("img",{className:"deco right",src:"images/deco-right.png",
border:"0"})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83777_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/advanced-proto.gif",
border:"0",alt:"Advanced interactions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Prototyping triggers and actions"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Prototyping options at last! Different triggers (like mouse events or time delays) and actions allow you to add complexity to the interactions of your prototypes."}),
(0,$APP.$rumext$v2$jsx$$)("p",{children:"Create overlays, back buttons or links to URLs to mimic the behavior of the product you’re designing."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83777_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83777_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/flows-proto.gif",border:"0",alt:"Multiple flows"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Multiple flows"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Design projects usually need to define multiple casuistics for different devices and user journeys."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Flows allow you to define multiple starting points within the same page so you can better organize and present your prototypes."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83777_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83777_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/booleans.gif",border:"0",alt:"Boolean shapes"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",
{children:"Boolean operations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"Now in Penpot you can combine shapes in different ways. There are five options: Union, difference, intersection, exclusion and flatten."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:"Using boolean operations will lead to countless graphic possibilities for your designs."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{className:"btn-secondary",onClick:$next$jscomp$27$$,children:"Continue"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83777_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83777_slide$jscomp$15$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$20$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-container onboarding feature",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-left",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/libraries-feature.gif",border:"0",alt:"Libraries \x26 templates"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"modal-title",children:(0,$APP.$rumext$v2$jsx$$)("h2",{children:"Libraries \x26 templates"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{children:"We’ve created a new space on Penpot where you can share your libraries and templates and download the ones you like.   Material Design, Cocomaterial or Penpot’s Design System are among them (and a lot more to come!)."}),(0,$APP.$rumext$v2$jsx$$)("p",{children:(0,$APP.$rumext$v2$jsx$$)("a",{alt:"Explore libraries \x26 templates",target:"_blank",href:"https://penpot.app/libraries-templates",children:"Explore libraries \x26 templates"})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"modal-navigation",children:[(0,$APP.$rumext$v2$jsx$$)("button",{className:"btn-secondary",onClick:$finish$jscomp$19$$,children:"Start!"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83777_slide$jscomp$15$$,navigate:$navigate$jscomp$20$$,total:4})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83777_slide$jscomp$15$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.0",function($p__83780_slide$jscomp$16$$){var $map__83781__$1_version$jscomp$43$$=$APP.$cljs$core$__destructure_map$$($p__83780_slide$jscomp$16$$);$p__83780_slide$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83781__$1_version$jscomp$43$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83781__$1_version$jscomp$43$$,
$cljs$cst$6454$klass$$),$next$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83781__$1_version$jscomp$43$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83781__$1_version$jscomp$43$$,$cljs$cst$6455$finish$$),$navigate$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83781__$1_version$jscomp$43$$,$APP.$cljs$cst$1957$navigate$$);$map__83781__$1_version$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83781__$1_version$jscomp$43$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83780_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-intro-image.png",
border:"0",alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"Welcome to Penpot 2.0! "}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__version-tag",children:"Version "+
($map__83781__$1_version$jscomp$43$$??"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__features-block",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:[(0,$APP.$rumext$v2$jsx$$)("spam",{className:"main_ui_releases_v2_0__feature-title",children:"CSS Grid Layout: "}),"Bring your designs to life, knowing that what you create is what developers code."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",
children:[(0,$APP.$rumext$v2$jsx$$)("spam",{className:"main_ui_releases_v2_0__feature-title",children:"Sleeker UI: "}),"We’ve polished Penpot to make your experience smoother and more enjoyable."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:[(0,$APP.$rumext$v2$jsx$$)("spam",{className:"main_ui_releases_v2_0__feature-title",children:"New Components System: "}),"Managing and using your design components got a whole lot better."]}),(0,$APP.$rumext$v2$jsxs$$)("p",
{className:"main_ui_releases_v2_0__feature-content",children:["And that’s not all - we’ve fined tuned performance and ","accessibility to give you a better and more fluid design experience."]}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:" Ready to dive in? Let 's get started!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",
children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83780_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-css-grid.gif",border:"0",alt:"Penpot's CSS Grid Layout",
className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"CSS Grid Layout - Design Meets Development"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",
children:["The much-awaited Grid Layout introduces 2-dimensional"," layout capabilities to Penpot, allowing for the creation"," of adaptive layouts by leveraging the power of CSS properties."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["It’s a host of new features, including columns and"," rows management, flexible units such as FR (fractions),"," the ability to create and name areas, and tons of new ","and unique possibilities within a design tool."]}),
(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["Designers will learn CSS basics while working, ","and as always with Penpot, developers can pick"," up the design as code to take it from there."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83780_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83780_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.0-new-ui.gif",border:"0",alt:"Penpot's UI Makeover",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"UI Makeover -  Smoother, Sharper, and Simply More Fun"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",
children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["We've completely overhauled Penpot's user interface. ","The improvements in consistency, the introduction of ","new microinteractions, and attention to countless details"," will significantly enhance the productivity and enjoyment of using Penpot."]}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["Furthermore, we’ve made several accessibility improvements, ",
"with better color contrast, keyboard navigation,"," and adherence to other best practices."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83780_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$p__83780_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-components.gif",border:"0",alt:"Penpot's new components system",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"New Components System"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:"The new Penpot components system improves; control over instances, including their ;inheritances and properties overrides. ;Main components are now accessible as design; elements, allowing a better updating ;workflow through instant changes synchronization.".split(";")}),
(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:["And that’s not all, there are new capabilities ","such as component swapping and annotations ","that will help you to better manage your design systems."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83780_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$28$$,className:"main_ui_releases_v2_0__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83780_slide$jscomp$16$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$21$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-html.gif",border:"0",alt:" Penpot's  HTML code generator",className:"main_ui_releases_v2_0__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_0__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_0__modal-title",children:"And much more"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_0__feature-content",children:"In addition to all of this, we’ve included several other requested improvements:"}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_releases_v2_0__feature-list",children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:"Access HTML markup code directly in inspect mode"}),(0,$APP.$rumext$v2$jsx$$)("li",{children:"Images are now treated as element fills, maintaining their aspect ratio on resize, ideal for flexible designs"}),
(0,$APP.$rumext$v2$jsx$$)("li",{children:"Enjoy new color themes with options for both dark and light modes"}),(0,$APP.$rumext$v2$jsx$$)("li",{children:"Feel the speed boost! Enjoy a smoother experience with a bunch of performance improvements"})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_0__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83780_slide$jscomp$16$$,navigate:$navigate$jscomp$21$$,total:4}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$20$$,className:"main_ui_releases_v2_0__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83780_slide$jscomp$16$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.1",function($klass$jscomp$22_p__83784$$){var $map__83785__$1_version$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($klass$jscomp$22_p__83784$$),$G__83789__$1_slide$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83785__$1_version$jscomp$44$$,$APP.$cljs$cst$1974$slide$$);$klass$jscomp$22_p__83784$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83785__$1_version$jscomp$44$$,
$cljs$cst$6454$klass$$);var $finish$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83785__$1_version$jscomp$44$$,$cljs$cst$6455$finish$$);$map__83785__$1_version$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83785__$1_version$jscomp$44$$,$APP.$cljs$cst$1726$version$$);$G__83789__$1_slide$jscomp$17$$=$G__83789__$1_slide$jscomp$17$$ instanceof $APP.$cljs$core$Keyword$$?$G__83789__$1_slide$jscomp$17$$.$fqn$:null;switch($G__83789__$1_slide$jscomp$17$$){case "start":return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_1__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$22_p__83784$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-intro-image.png",border:"0",alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_1__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_1__modal-title",children:"What's new in Penpot? "}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_1__version-tag",children:"Version "+($map__83785__$1_version$jscomp$44$$??"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_1__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_1__feature-content",
children:"Penpot 2.1 brings improvements to the authentication system, path editing, real-time persistence, and comments system among other enhancements. We’ve improved the stability of the platform by fixing a bunch of bugs, a lot of them raised by our amazing community \x3c3."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_1__feature-content",children:"This minor release comes shortly after our amazing Penpot 2.0 and it shows the way to long-expected capabilities like the incoming new plugin system!"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_1__feature-content",children:" Ready to dive in? Let 's get started!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_1__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$21$$,className:"main_ui_releases_v2_1__next-btn",children:"Let's go"})})]})]})})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83789__$1_slide$jscomp$17$$)].join(""));
}});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.10",function($p__83786_slide$jscomp$18$$){var $map__83787__$1_version$jscomp$45$$=$APP.$cljs$core$__destructure_map$$($p__83786_slide$jscomp$18$$);$p__83786_slide$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83787__$1_version$jscomp$45$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83787__$1_version$jscomp$45$$,
$cljs$cst$6454$klass$$),$next$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83787__$1_version$jscomp$45$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83787__$1_version$jscomp$45$$,$cljs$cst$6455$finish$$),$navigate$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83787__$1_version$jscomp$45$$,$APP.$cljs$cst$1957$navigate$$);$map__83787__$1_version$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83787__$1_version$jscomp$45$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83786_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-slide-0.jpg",
border:"0",alt:"Penpot 2.10 is here!",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__version-tag",children:"Version "+($map__83787__$1_version$jscomp$45$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_10__feature-title",children:"Variants have arrived in Penpot!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"We’re excited to introduce what’s (probably) the top community request. Variants are a powerful way to bring order and flexibility to your design system in Penpot."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_10__feature-content",children:"This release also brings major progress on design tokens—including several new token types to help you manage typography at an entirely new level—plus a bunch of quality-of-life improvements that make the Penpot experience even more enjoyable."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__navigation",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83786_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-variants.gif",border:"0",alt:"Variants have arrived in Penpot!",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"Variants have arrived in Penpot!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"With Variants, you can group similar components—like buttons, icons, or toggles—into a single, customizable component. Instead of juggling multiple versions for every state, size, or style, you’ll manage them all in one unified place with clear, intuitive properties."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",
children:"Imagine a single button component that seamlessly switches between primary and secondary styles, active and disabled states, and small to large sizes—all without leaving your flow. That’s the power of Variants."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This release has been shaped by our amazing community. A huge thank-you to everyone who shared ideas, feedback, and insights to make Penpot Variants possible \x3c3"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83786_slide$jscomp$18$$,navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83786_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-penpotfest.jpg",border:"0",alt:"Road to Penpot 3.0… Join us at Penpot Fest next month!",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"Road to Penpot 3.0… Join us at Penpot Fest next month!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This year’s Penpot Fest theme is: Better, together: Refining the designer-developer workflow."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_10__feature-content",children:"Catch industry experts from GitHub, Blender, Wikimedia Foundation and more. Join workshops and our panel discussion for practical and visionary thoughts."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"And one more thing…Tune into our product showcase to see future plans and help us shape Penpot. Come for the insights, stay for the community…"}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_10__feature-content",
children:[(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://penpot.app/penpotfest",target:"_blank",children:"Get your tickets"})," now to join us 8-10 October, in Madrid!"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83786_slide$jscomp$18$$,navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",
children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83786_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-font-tokens.gif",border:"0",alt:"New typography token types",
className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"New typography token types"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",
children:"We're continually building on Penpot's native Design Tokens support, and this time, we introduce an expanded range of token types, giving you greater options for your design systems."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This latest update brings—no more no less than—six new token types, significantly boosting your ability to manage design decisions, particularly in typography: Font Family, Font Weight, Text Case, Text Decoration, Letter Spacing token, and Number token (for unitless values)."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83786_slide$jscomp$18$$,navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$29$$,className:"main_ui_releases_v2_10__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83786_slide$jscomp$18$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_10__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$23$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.10-preset.gif",border:"0",alt:"Select artboard defaults before their creation",className:"main_ui_releases_v2_10__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_10__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_10__modal-title",children:"Select artboard defaults before their creation"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"Starting a new design in Penpot just got easier. You can now choose from preset artboard sizes before creating an artboard. This will help you begin your designs with the right dimensions from the very first click."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_10__feature-content",children:"This feature was born from community proposals. Several Penpot users helped us understand the different workflows around creating artboards, and their feedback shaped the simple, effective solution we’re announcing today."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_10__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83786_slide$jscomp$18$$,
navigate:$navigate$jscomp$22$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$22$$,className:"main_ui_releases_v2_10__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83786_slide$jscomp$18$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.11",function($p__83791_slide$jscomp$19$$){var $map__83792__$1_version$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($p__83791_slide$jscomp$19$$);$p__83791_slide$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_version$jscomp$46$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_version$jscomp$46$$,
$cljs$cst$6454$klass$$),$next$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_version$jscomp$46$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_version$jscomp$46$$,$cljs$cst$6455$finish$$),$navigate$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_version$jscomp$46$$,$APP.$cljs$cst$1957$navigate$$);$map__83792__$1_version$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83792__$1_version$jscomp$46$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83791_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-slide-0.jpg",
border:"0",alt:"Penpot 2.11 is here!",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__version-tag",children:"Version "+($map__83792__$1_version$jscomp$46$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_11__feature-title",children:"Typography tokens take the stage!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"This release brings one of our most anticipated design system upgrades yet: Typography tokens."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",
children:"But that’s not all. Variants get a nice boost with multi-switching, new creation shortcuts, and draggable property reordering. Invitations are now easier to manage and the user menu has been reorganized. Now showing your current Penpot version and direct access to release info."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"And as always, you’ll notice performance improvements throughout. Faster, smoother, and just a bit more magical every time."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83791_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-typography-token.gif",border:"0",alt:"Typography token: one token to rule your text",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"Typography token: one token to rule your text"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Imagine having just one token to manage all your typography. With the new Typography token, you can create presets that bundle all your text styles (font, weight, size, line height, spacing, and more) into a single reusable definition. Just one clean, flexible token to keep your type consistent across your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"The Typography token also marks a big step forward for Penpot: it’s our first composite token! Composite tokens are special because they can hold multiple properties within one token. Shadow token will be the next composite token coming your way."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83791_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83791_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-variants.gif",border:"0",alt:"Variants get a power-up",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"Variants get a power-up"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Variants just got published and they already got a serious quality-of-life boost!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"- Switch several variant copies at once: No more clicking through each one individually when you want to update a property. Just select multiple copies and change their values in one go — fast, smooth, and efficient."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"- New ways to create variants, right from the design viewport: No need to dig through menus. The new buttons make it super quick to spin up variant sets directly where you’re working."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"- Reorder your component properties by drag \x26 drop: Because organization matters, now you can arrange your properties however makes the most sense to you, so you can keep the ones you use most often right where you want them."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83791_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83791_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-invitations.gif",border:"0",alt:"A smoother way to manage invitations",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"A smoother way to manage invitations"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"The Invitations section just got a big usability upgrade for admins. Here’s what’s new:"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Sorting - Organize invitations by role type or status to keep track of who’s in and who’s pending."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Quicker actions - Main actions (resend and delete) are now visible upfront for quicker access."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Bulk management - Select multiple invitations to resend or delete them all at once."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"Invited users will also get clearer emails, including a reminder sent one day before the invite expires (after seven days). Simple, clean, and much more efficient."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83791_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,
total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$30$$,className:"main_ui_releases_v2_11__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83791_slide$jscomp$19$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$24$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.11-menu.gif",border:"0",alt:"User menu makeover",className:"main_ui_releases_v2_11__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_11__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_11__modal-title",children:"User menu makeover"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"The user menu got a well-deserved cleanup. Options are now grouped into clear sections like Help \x26 Learning and Community \x26 Contributions, making navigation faster and easier."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_11__feature-content",children:"You’ll also notice a handy new detail: the menu now shows your current Penpot version and gives you quick access to changelog information. This is especially useful for self-hosted setups that want to stay in sync with the latest updates. Simple, organized, and more informative."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_11__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83791_slide$jscomp$19$$,navigate:$navigate$jscomp$23$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$23$$,className:"main_ui_releases_v2_11__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83791_slide$jscomp$19$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.12",function($p__83794_slide$jscomp$20$$){var $map__83795__$1_version$jscomp$47$$=$APP.$cljs$core$__destructure_map$$($p__83794_slide$jscomp$20$$);$p__83794_slide$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83795__$1_version$jscomp$47$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83795__$1_version$jscomp$47$$,
$cljs$cst$6454$klass$$),$next$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83795__$1_version$jscomp$47$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83795__$1_version$jscomp$47$$,$cljs$cst$6455$finish$$),$navigate$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83795__$1_version$jscomp$47$$,$APP.$cljs$cst$1957$navigate$$);$map__83795__$1_version$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83795__$1_version$jscomp$47$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83794_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-slide-0.jpg",
border:"0",alt:"Penpot 2.12 is here!",className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__version-tag",children:"Version "+($map__83795__$1_version$jscomp$47$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"Better tokens visibility and more!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"This release focuses on making your everyday workflow feel clearer, faster and more intuitive. Tokens are now easier to see and apply, appearing directly where you work and giving the designs better context during code inspection. Variants gain a more natural flow thanks to simple boolean toggles that remove friction when switching states. And PDF export becomes more flexible, letting you choose exactly which boards to share so your files match the story you want to tell."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Together, these enhancements bring greater control and fluidity to your entire design process."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$31$$,className:"main_ui_releases_v2_12__next-btn",
children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83794_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-tokens-sidebar.gif",border:"0",alt:"Better tokens visibility",
className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_12__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"Better tokens visibility"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",
children:"Design systems should be both powerful and effortless to use. This release brings tokens closer to where you work, making them easier to apply and easier to understand."}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"Apply color tokens right from the sidebar"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Your color tokens now appear directly in the properties sidebar, making it faster to apply or unapply tokens from the design tab. No more digging: now you can use tokens within your design flow."}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"See token names in the Inspect panel"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Developers now get a clearer context during handoff. The Inspect panel shows the actual token used in your design, in a similar way to how styles are displayed. This small detail reduces ambiguity, aligns everyone on the same language, and strengthens collaboration across the team."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83794_slide$jscomp$20$$,navigate:$navigate$jscomp$24$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$31$$,className:"main_ui_releases_v2_12__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83794_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-variants.gif",border:"0",alt:"Simpler boolean variants",className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"Simpler boolean variants"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Variants are central to building flexible, scalable components. With this release, boolean properties become far easier to work with."}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_releases_v2_12__feature-title",children:"A simple toggle for boolean values"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Binary states now use a clean toggle, to be able to switch visually,  instead of a dropdown. This makes adjusting component states more intuitive and speeds up working with multiple instances."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"It’s a subtle improvement, but it removes friction you feel hundreds of times a week, and makes component work flow more naturally."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83794_slide$jscomp$20$$,navigate:$navigate$jscomp$24$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$31$$,className:"main_ui_releases_v2_12__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83794_slide$jscomp$20$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$25$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.12-export-pdf.gif",border:"0",alt:"Smarter PDF export",className:"main_ui_releases_v2_12__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_12__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_12__modal-title",children:"Smarter PDF export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"Exporting your work is now more precise and flexible."}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_12__feature-title",children:"Select specific boards when exporting"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_12__feature-content",children:"You’re now in control of which boards make it into your PDF. Share just the final screens, just a flow, just the workshop materials. This streamlined export flow adapts to the way real teams work: share the story you want to tell, with exactly the boards you need."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_12__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83794_slide$jscomp$20$$,navigate:$navigate$jscomp$24$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$24$$,className:"main_ui_releases_v2_12__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83794_slide$jscomp$20$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.13",function($p__83797_slide$jscomp$21$$){var $map__83798__$1_version$jscomp$48$$=$APP.$cljs$core$__destructure_map$$($p__83797_slide$jscomp$21$$);$p__83797_slide$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83798__$1_version$jscomp$48$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83798__$1_version$jscomp$48$$,
$cljs$cst$6454$klass$$),$next$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83798__$1_version$jscomp$48$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83798__$1_version$jscomp$48$$,$cljs$cst$6455$finish$$),$navigate$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83798__$1_version$jscomp$48$$,$APP.$cljs$cst$1957$navigate$$);$map__83798__$1_version$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83798__$1_version$jscomp$48$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83797_slide$jscomp$21$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$26$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.13-slide-0.jpg",
border:"0",alt:"Penpot 2.13 is here!",className:"main_ui_releases_v2_13__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_13__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__version-tag",children:"Version "+($map__83798__$1_version$jscomp$48$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_13__feature-title",children:"The first release of the year, and we’re just getting started \ud83d\ude80"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"This is our first release of the year, and it sets the tone for what’s coming next. We’re kicking off an exciting year where we’ll take Penpot to a whole new level, with improved performance, stronger design system foundations, long-requested features, and new capabilities that unlock better workflows for teams."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"This release brings two highlights the community has been asking for, along with solid improvements under the hood to keep everything fast and smooth."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$32$$,
className:"main_ui_releases_v2_13__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83797_slide$jscomp$21$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$26$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.13-trash.gif",
border:"0",alt:"The Trash",className:"main_ui_releases_v2_13__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_13__modal-title",children:"The Trash"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",
children:"Deleting a file no longer means it’s gone forever. Introducing The Trash, a dedicated space in the dashboard where deleted files and projects live before being permanently removed."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"From here, you can recover content deleted by mistake or clean things up for good when you’re sure you don’t need them anymore. The Trash works for both files and projects, and items are automatically removed after a period of time depending on your Penpot plan."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Highly requested, long overdue, and now officially here."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83797_slide$jscomp$21$$,navigate:$navigate$jscomp$25$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$32$$,className:"main_ui_releases_v2_13__next-btn",
children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83797_slide$jscomp$21$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$26$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.13-shadow-tokens.gif",border:"0",alt:"Shadow tokens: Reusable shadows, at last!",
className:"main_ui_releases_v2_13__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_13__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_13__modal-title",children:"Shadow tokens: Reusable shadows, at last!"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",
children:"With Shadow tokens, we’re introducing our second composite token, right after Typography tokens. This is a big step forward for design systems in Penpot."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Until now, shadows couldn’t be defined as reusable styles the way colors could before color tokens existed. Shadow tokens change that. You can now create reusable, consistent shadows, made of one or multiple layers, fully tokenized and ready to scale across your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_13__feature-content",children:"Each shadow can reference existing tokens or use custom values, supports both Drop Shadow and Inner Shadow, and even allows shadow tokens to reference other shadow tokens. A brand-new capability, unlocked."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_13__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83797_slide$jscomp$21$$,
navigate:$navigate$jscomp$25$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$25$$,className:"main_ui_releases_v2_13__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83797_slide$jscomp$21$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.14",function($p__83799_slide$jscomp$22$$){var $map__83800__$1_version$jscomp$49$$=$APP.$cljs$core$__destructure_map$$($p__83799_slide$jscomp$22$$);$p__83799_slide$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83800__$1_version$jscomp$49$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83800__$1_version$jscomp$49$$,
$cljs$cst$6454$klass$$),$next$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83800__$1_version$jscomp$49$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83800__$1_version$jscomp$49$$,$cljs$cst$6455$finish$$),$navigate$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83800__$1_version$jscomp$49$$,$APP.$cljs$cst$1957$navigate$$);$map__83800__$1_version$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83800__$1_version$jscomp$49$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83799_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-slide-0.jpg",
border:"0",alt:"Penpot 2.14 is here!",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__version-tag",children:"Version "+($map__83800__$1_version$jscomp$49$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_14__feature-title",children:"Design tokens, but friendlier (and a bit faster, too)"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"This release keeps pushing Penpot’s design system foundations forward, with a big focus on design tokens. We’re making long token names easier to navigate, opening up tokens in the plugins API, and tackling one of the trickiest moments in token workflows: renaming (without breaking everything)."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"On top of that, you’ll find a handful of quality-of-life improvements and some performance work in the sidebar to keep things feeling smooth as your files grow. Let’s dive in."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$33$$,className:"main_ui_releases_v2_14__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83799_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.14-tokens-fold.gif",border:"0",alt:"Token groups: Navigating long names, finally",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Token groups: Navigating long names, finally"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_14__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Token names are rarely short and sweet. Most of the time they carry a lot of meaning (type, state, property, variant… and more), which is great for consistency, but not so great for browsing. In 2.14 we’re introducing token groups, a new way to navigate dotted token paths as nested, collapsible sections."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",
children:"Token segments before the final name are displayed as groups, and only the last segment stays as a pill (so you keep the familiar token “chip” where it matters). If you unfold a path, it stays open while you move around the app (it resets only when the page reloads). And when you create a new token, Penpot automatically unfolds the path needed to reveal it (even if it overrides a previously opened one)."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",
children:"One extra detail: if you edit the path and change group segments, the token is moved to its new group (creating it if needed), and empty groups are automatically cleaned up."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83799_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$33$$,
className:"main_ui_releases_v2_14__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83799_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-api.gif",
border:"0",alt:"Design tokens in the plugins API: Automation unlocked",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Design tokens in the plugins API: Automation unlocked"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Design tokens are now available in the Penpot plugins API. That means plugins (and external tools built around Penpot, like AI clients or Penpot MCP) can finally work with tokens programmatically and automate token workflows that used to be purely manual."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"If you’ve been waiting to generate tokens, sync them, or manipulate them from your own tools, this is the missing piece. And yes, this one has been requested a lot."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83799_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$33$$,className:"main_ui_releases_v2_14__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83799_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-remap.jpg",border:"0",alt:"Rename tokens without breaking everything",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Rename tokens without breaking everything"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Renaming tokens sounds simple until you remember the references. One change can ripple through aliases, applied tokens, tooltips, math operations… and suddenly you’re left with a broken chain. In 2.14, renaming a token can optionally remap its references, keeping connections intact and updating the design with the new token name."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Remapping is always optional, because sometimes you don’t want to keep the current connections. When enabled, it affects all tokens in the file and also takes libraries into account, so main components can propagate changes to child components, and applied tokens update on the elements using them."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83799_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$33$$,className:"main_ui_releases_v2_14__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83799_slide$jscomp$22$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$27$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_14__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.14-icons.gif",border:"0",alt:"Quality-of-life improvements",className:"main_ui_releases_v2_14__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_14__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_14__modal-title",children:"Quality-of-life improvements"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"Lock and hide controls in the layer panel are getting a usability boost. The lock and visibility icons stay fixed in a right-aligned column regardless of indentation, and scrolling won’t make them awkward to click (even in deeply nested files)."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",
children:"We’re also improving sidebar performance, with a focus on keeping interactions fluent. The goal is to lazy-load the shape list on-demand and avoid UI stalls when clicking or hovering around the sidebar."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_14__feature-content",children:"And one more: you can now use Shift/Alt arrow key stepping in color picker inputs (a community contribution by @eureka928. ❤️)"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_14__navigation",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83799_slide$jscomp$22$$,navigate:$navigate$jscomp$26$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$26$$,className:"main_ui_releases_v2_14__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83799_slide$jscomp$22$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.15",function($p__83802_slide$jscomp$23$$){var $map__83803__$1_version$jscomp$50$$=$APP.$cljs$core$__destructure_map$$($p__83802_slide$jscomp$23$$);$p__83802_slide$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83803__$1_version$jscomp$50$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83803__$1_version$jscomp$50$$,
$cljs$cst$6454$klass$$),$next$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83803__$1_version$jscomp$50$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83803__$1_version$jscomp$50$$,$cljs$cst$6455$finish$$),$navigate$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83803__$1_version$jscomp$50$$,$APP.$cljs$cst$1957$navigate$$);$map__83803__$1_version$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83803__$1_version$jscomp$50$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83802_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.15-slide-0.jpg",
border:"0",alt:"Penpot 2.15 is here!",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__version-tag",children:"Version "+($map__83803__$1_version$jscomp$50$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_15__feature-title",children:"One major feature: the Penpot MCP Server, with infinite workflow possibilities"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"This release marks a major MCP milestone: Penpot MCP moves from an early technical setup to an accessible in-app experience via hosted remote setup. Whether you already know MCP or are new to it, it's now zero-friction to connect your AI client and turn prompts into real actions on real design data."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"With 2.15, we are opening the door to truly multi-directional workflows between design and code, while staying faithful to Penpot values: openness, freedom of choice, and respect for your data."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$34$$,className:"main_ui_releases_v2_15__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83802_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.15-mcp-01.gif",border:"0",alt:"Penpot MCP Server: AI connected to real design context",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"Penpot MCP Server: AI connected to real design context"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_15__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"Penpot MCP Server is the bridge between your AI client and your Penpot file. You describe what you need in natural language, your agent picks the right operation, and MCP translates that into real actions through Penpot APIs."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"This is not a generic 'describe and generate' flow. It is context-aware work with components, tokens, pages, layers, and structure. In short: design expressed as code, now usable through your preferred AI assistant."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"You can run MCP in two ways. Remote MCP is hosted and simpler to set up. Local MCP runs on your machine and gives advanced teams extra control. Same vision, different operating model."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83802_slide$jscomp$23$$,navigate:$navigate$jscomp$27$$,
total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$34$$,className:"main_ui_releases_v2_15__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83802_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.15-mcp-02.gif",border:"0",alt:"Multi-directional workflows, from design to code and back",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"Multi-directional workflows, from design to code and back"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"The biggest unlock in 2.15 is multi-directionality. You can move from design to code, and from code back to design, without losing intent or structure in the process."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Generate semantic HTML/CSS from real layouts."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_15__feature-content",children:"• Translate tokens and styles into code variables."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Export only assets in use."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Validate design-code consistency."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"• Reorganize layers, apply naming rules, and automate repetitive design system maintenance."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"This is where MCP becomes workflow infrastructure. Less manual glue work, fewer handoff gaps, and faster iterations between designers and developers."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83802_slide$jscomp$23$$,navigate:$navigate$jscomp$27$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$34$$,className:"main_ui_releases_v2_15__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83802_slide$jscomp$23$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$28$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.15-mcp-03.gif",border:"0",alt:"Your stack, your model, your control",className:"main_ui_releases_v2_15__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_15__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_15__modal-title",children:"Your stack, your model, your control"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"With MCP, you connect Penpot to the AI client and model you already trust. Cursor, Claude, VS Code, Codex, or another MCP-compatible setup: the workflow adapts to your stack, not the other way around."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"You can run it hosted for a faster setup, or locally when you need tighter infrastructure control. The same applies to data boundaries: Penpot provides the bridge to your design context, while your team decides how and where AI runs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_15__feature-content",children:"In practice, this means teams can automate design and code workflows without giving up tool freedom, deployment control, or ownership of their process.\n"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_15__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83802_slide$jscomp$23$$,navigate:$navigate$jscomp$27$$,total:3}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$27$$,className:"main_ui_releases_v2_15__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83802_slide$jscomp$23$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.16",function($p__83805_slide$jscomp$24$$){var $map__83806__$1_version$jscomp$51$$=$APP.$cljs$core$__destructure_map$$($p__83805_slide$jscomp$24$$);$p__83805_slide$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83806__$1_version$jscomp$51$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83806__$1_version$jscomp$51$$,
$cljs$cst$6454$klass$$),$next$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83806__$1_version$jscomp$51$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83806__$1_version$jscomp$51$$,$cljs$cst$6455$finish$$),$navigate$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83806__$1_version$jscomp$51$$,$APP.$cljs$cst$1957$navigate$$);$map__83806__$1_version$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83806__$1_version$jscomp$51$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83805_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-slide-0.jpg",
border:"0",alt:"Penpot 2.16 is here!",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__version-tag",children:"Version "+($map__83806__$1_version$jscomp$51$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"2.16 brings design tokens into the Design sidebar next to the numbers you already tune for layout, so choosing and checking tokens stays in the same flow. It also introduces an optional WebGL path (beta) for a faster canvas when files grow heavy, plus a wide layer of fixes and polish so the app simply feels more dependable from session to session."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"This cycle ships on the order of fifty enhancements and sixty bug fixes, so the day-to-day gain is less about one headline and more about many small wins adding up. A large share of that work came from community contributors; we highlight a few names on a later slide, and we are grateful to everyone who helped move Penpot forward."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",
children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83805_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+
($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-tokens.gif",border:"0",alt:"Design tokens: visible and actionable from the Design tab",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",children:"Design tokens: visible and actionable from the Design tab"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"You can treat tokens as part of the Design sidebar: see what is bound, pick a token, or type a value with less jumping back to the tokens panel. The payoff is calmer work—fewer context switches when you are sizing, spacing, or tuning type and effects—and more confidence that what you see in the inspector matches what your system actually uses."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"This closes a long standing gap in the tokens roadmap: token picking and visibility belong in the Design panel itself. Token choices stay visible next to the controls you touch all day, so applying and checking design language feels like one continuous step instead of a detour."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83805_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83805_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-render.jpg",border:"0",alt:"WebGL rendering (beta): a faster canvas you can try now",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",
children:"WebGL rendering (beta): a faster canvas you can try now"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"WebGL is a genuine upgrade to how the canvas moves. On busy boards and heavy files, pan and zoom should feel quicker and more immediate—less friction between what you want to see and what appears on screen—so your attention stays on the design instead of on the viewport catching up."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"We are still hardening it with real work in the wild, so it ships as beta and stays off until you enable it in user settings. Turn it on for your toughest file, ride the speedup, and send feedback from the product if anything misbehaves so we can keep improving it together."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83805_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83805_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-find-replace.gif",border:"0",alt:"Community contributions: volume up, quality even higher",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",
children:"Community contributions: volume up, quality even higher"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"This release carried an unusually broad set of improvements with a community byline—not one or two patches at the edge, but a visible wave of quality-of-life work from people shipping Penpot alongside their own projects."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_16__feature-content",children:"That mix keeps the product grounded in how files actually behave in the wild, and we are glad to share the credit. In the long run, this is about ideas in motion: fresh workflows, clever affordances, and “why has nobody fixed this yet?” moments that expand what Penpot is."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83805_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83805_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_16__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-inputs-drag.gif",border:"0",alt:"Community contributions: volume up, quality even higher",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",
children:"Community contributions: volume up, quality even higher"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"A few highlights:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Drag to change on numeric inputs in the workspace sidebar — @RenzoMXD"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",
children:"• Loader feedback while importing and exporting files — @moorsecopers99"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Import tokens from a linked library — @dfelinto"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Find and replace for text content and layer names — @statxc"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Clickable links in comments — @eureka0928"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"• Read-only preview for saved versions — @wdeveloper16 "}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:" ... and many, many more."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83805_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,
total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$35$$,className:"main_ui_releases_v2_16__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(4,$p__83805_slide$jscomp$24$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$29$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.16-fixes.gif",border:"0",alt:"Stability, performance, and “everything else” (there is a lot)",className:"main_ui_releases_v2_16__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_16__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_16__modal-title",children:"Stability, performance, and “everything else” (there is a lot)"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"Alongside the visible features, 2.16 clears a lot of rough edges: regressions, corner cases, and small frictions that only register once they stop getting in your way."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_16__feature-content",children:"On the enhancement side, think on the order of ~50 quality of life improvements. Together with the fixes, you’re looking at more than a hundred tracked improvements in this cycle, which is why the release feels “radical” in day to day feel even when no single line item explains it."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_16__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83805_slide$jscomp$24$$,navigate:$navigate$jscomp$28$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$28$$,className:"main_ui_releases_v2_16__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83805_slide$jscomp$24$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.17",function($p__83809_slide$jscomp$25$$){var $map__83810__$1_version$jscomp$52$$=$APP.$cljs$core$__destructure_map$$($p__83809_slide$jscomp$25$$);$p__83809_slide$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83810__$1_version$jscomp$52$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83810__$1_version$jscomp$52$$,
$cljs$cst$6454$klass$$),$next$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83810__$1_version$jscomp$52$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83810__$1_version$jscomp$52$$,$cljs$cst$6455$finish$$),$navigate$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83810__$1_version$jscomp$52$$,$APP.$cljs$cst$1957$navigate$$);$map__83810__$1_version$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83810__$1_version$jscomp$52$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83809_slide$jscomp$25$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$30$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.17-slide-0.jpg",
border:"0",alt:"Penpot 2.17 is here!",className:"main_ui_releases_v2_17__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_17__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__version-tag",children:"Version "+($map__83810__$1_version$jscomp$52$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"Improvements across WebGL rendering, tokens, MCP, and quality-of-life design features."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"2.17 brings background blur to open up new graphic possibilities, without leaving the canvas, surfaces typography tokens directly in the Design sidebar, and lets you use comments while you design. WebGL rendering and MCP both keep getting stronger, backed by performance improvements, a wide round of bug fixes, and plenty of quality-of-life polish so every session feels smoother."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$36$$,className:"main_ui_releases_v2_17__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83809_slide$jscomp$25$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$30$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.17-render.jpg",border:"0",alt:"WebGL rendering: still beta, getting stronger",className:"main_ui_releases_v2_17__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_17__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_17__modal-title",children:"WebGL rendering: still beta, getting stronger"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"WebGL rendering keeps maturing. The prototype viewer now runs on the same engine, guides render in WebGL, and a wave of fixes makes heavy files more dependable."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"It is still beta and off by default, but we genuinely encourage you to turn it on from user settings: it is already a better, faster path and it is where Penpot is heading. And if you spot anything odd, give us a shout: all your feedback is hugely welcome."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83809_slide$jscomp$25$$,navigate:$navigate$jscomp$29$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$36$$,className:"main_ui_releases_v2_17__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83809_slide$jscomp$25$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$30$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_17__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.17-blur.gif",border:"0",alt:"Background blur is here",className:"main_ui_releases_v2_17__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_17__modal-title",children:"Background blur is here"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"A long-awaited effect lands: background blur. Blur whatever sits behind a layer to add depth, focus, and frosted-glass looks, expanding what you can create on the canvas."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"Find it in the Design sidebar alongside your other effects. More creative range, no workarounds."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83809_slide$jscomp$25$$,navigate:$navigate$jscomp$29$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$36$$,className:"main_ui_releases_v2_17__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83809_slide$jscomp$25$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_17__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$30$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.17-mcp.gif",border:"0",alt:"MCP: easier to connect, more reliable",className:"main_ui_releases_v2_17__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_17__modal-title",children:"MCP: easier to connect, more reliable"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"MCP feels more at home in Penpot. A status button gives you single-tab connection control, your API key is visible on the Integrations page, and sync between the server and plugins is much more reliable."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"Self-hosters get better multi-instance support and clearer proxy examples. If you connect AI to your files, this release is worth revisiting."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83809_slide$jscomp$25$$,navigate:$navigate$jscomp$29$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$36$$,className:"main_ui_releases_v2_17__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83809_slide$jscomp$25$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$30$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.17-tokens.gif",border:"0",alt:"Design tokens: more visible, more responsive",className:"main_ui_releases_v2_17__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_17__modal-title",children:"Design tokens: more visible, more responsive"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_17__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"Design-system work gets clearer and faster:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Typography tokens now appear when you multi-select text."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• The Design sidebar gains a composite typography input."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Autocomplete speeds up token creation forms."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Dropdowns surface more context at a glance."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Token propagation is faster, a nice performance boost."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__navigation",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83809_slide$jscomp$25$$,navigate:$navigate$jscomp$29$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$36$$,className:"main_ui_releases_v2_17__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(4,$p__83809_slide$jscomp$25$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"animated "+($klass$jscomp$30$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.17-comments.jpg",border:"0",alt:"Quality-of-life, fixes, and performance",className:"main_ui_releases_v2_17__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_17__modal-header",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_17__modal-title",children:"Quality-of-life, fixes, and performance"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"Lots of smaller wins add up this cycle. A few favorites:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Use comments while you design: read, reply, and resolve without switching out of design mode."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Color picker list view to scan swatches faster."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Import tokens from a linked library — @dfelinto"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"• Dashed strokes with dedicated dash and gap inputs (by @eureka0928)."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",
children:"• Selection size badge with color variants and positioning (by @bittoby)."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_17__feature-content",children:"On top of that, 2.17 ships performance improvements, a broad round of bug fixes, and many community-contributed enhancements (thanks to @FairyPigDev, @MilosM348, @Dexterity104, @RenzoMXD, and many more)."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_17__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83809_slide$jscomp$25$$,navigate:$navigate$jscomp$29$$,total:5}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$29$$,className:"main_ui_releases_v2_17__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83809_slide$jscomp$25$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.2",function($klass$jscomp$31_p__83812$$){var $map__83813__$1_version$jscomp$53$$=$APP.$cljs$core$__destructure_map$$($klass$jscomp$31_p__83812$$),$G__83816__$1_slide$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83813__$1_version$jscomp$53$$,$APP.$cljs$cst$1974$slide$$);$klass$jscomp$31_p__83812$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83813__$1_version$jscomp$53$$,
$cljs$cst$6454$klass$$);var $finish$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83813__$1_version$jscomp$53$$,$cljs$cst$6455$finish$$);$map__83813__$1_version$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83813__$1_version$jscomp$53$$,$APP.$cljs$cst$1726$version$$);$G__83816__$1_slide$jscomp$26$$=$G__83816__$1_slide$jscomp$26$$ instanceof $APP.$cljs$core$Keyword$$?$G__83816__$1_slide$jscomp$26$$.$fqn$:null;switch($G__83816__$1_slide$jscomp$26$$){case "start":return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_2__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$31_p__83812$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.0-intro-image.png",border:"0",alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_2__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_2__modal-title",children:"What's new in Penpot? "}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_2__version-tag",children:"Version "+($map__83813__$1_version$jscomp$53$$??"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_2__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",
children:"This Penpot 2.2 release focuses on internal changes that are laying out the ground for the upcoming plugin system and substantial performance improvements."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",children:"This version also adds full JSON API interoperability and the brand-new Penpot’s Storybook!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",children:"Self-hosted Penpot installations will benefit from better file data storage and Penpot admins can now use the improved automatic snapshotting process when recovering old files."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_2__feature-content",children:"Thanks again to our awesome community for their amazing contributions to this release!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_2__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$30$$,className:"main_ui_releases_v2_2__next-btn",children:"Let's go"})})]})]})})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83816__$1_slide$jscomp$26$$)].join(""));
}});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.3",function($p__83814_slide$jscomp$27$$){var $map__83815__$1_version$jscomp$54$$=$APP.$cljs$core$__destructure_map$$($p__83814_slide$jscomp$27$$);$p__83814_slide$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83815__$1_version$jscomp$54$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83815__$1_version$jscomp$54$$,
$cljs$cst$6454$klass$$),$next$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83815__$1_version$jscomp$54$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83815__$1_version$jscomp$54$$,$cljs$cst$6455$finish$$),$navigate$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83815__$1_version$jscomp$54$$,$APP.$cljs$cst$1957$navigate$$);$map__83815__$1_version$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83815__$1_version$jscomp$54$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83814_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.3-slide-0.png",border:"0",
alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_3__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_3__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__version-tag",children:"Version "+($map__83815__$1_version$jscomp$54$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_3__feature-title",children:"Penpot can now be extended by using Plugins!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"The introduction of our brand new Plugin system allows you to access even richer ecosystem of capabilities."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",
children:"We are beyond excited about how this will further involve the Penpot community in building the best design and prototyping platform."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$37$$,className:"main_ui_releases_v2_3__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$p__83814_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.3-img-slide-1.gif",border:"0",alt:"Build Plugins to enhance your workflow",className:"main_ui_releases_v2_3__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_3__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_3__modal-title",children:"Build Plugins and enhance your workflow"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Penpot Plugins encourage developers to easily customize and expand the platform using standard web technologies like JavaScript, CSS, and HTML."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Find everything you need in our full comprehensive documentation to start building your plugins now!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83814_slide$jscomp$27$$,navigate:$navigate$jscomp$30$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$37$$,
className:"main_ui_releases_v2_3__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83814_slide$jscomp$27$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$32$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.3-img-slide-2.gif",
border:"0",alt:"Plugins are safe and extremely easy to use",className:"main_ui_releases_v2_3__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_3__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_3__modal-title",children:"Plugins are safe and extremely easy to use"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:"Penpot plugins are quite easy to install."}),(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_releases_v2_3__feature-content",children:["Be sure to keep an eye on our evolving ",(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://penpot.app/penpothub",target:"_blank",children:"Penpot Hub"})," to pick the ones that are best suited to enhance your workflow."]}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_3__feature-content",
children:"This is just the beginning of a myriad of possibilities. Let’s build this community together ❤️."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_3__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83814_slide$jscomp$27$$,navigate:$navigate$jscomp$30$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$31$$,className:"main_ui_releases_v2_3__next-btn",children:"Let's go"})]})]})]})})});
throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83814_slide$jscomp$27$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.4",function($p__83819_slide$jscomp$28$$){var $map__83820__$1_version$jscomp$55$$=$APP.$cljs$core$__destructure_map$$($p__83819_slide$jscomp$28$$);$p__83819_slide$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83820__$1_version$jscomp$55$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83820__$1_version$jscomp$55$$,
$cljs$cst$6454$klass$$),$next$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83820__$1_version$jscomp$55$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83820__$1_version$jscomp$55$$,$cljs$cst$6455$finish$$),$navigate$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83820__$1_version$jscomp$55$$,$APP.$cljs$cst$1957$navigate$$);$map__83820__$1_version$jscomp$55$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83820__$1_version$jscomp$55$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83819_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.4-slide-0.jpg",border:"0",
alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__version-tag",children:"Version "+($map__83820__$1_version$jscomp$55$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_4__feature-title",children:"At Penpot we are at full speed!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"With the release of the long-awaited Plugins System still fresh, this 2.4 brings improvements in a wide range of areas that will serve a variety of use cases."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_4__feature-content",children:"This release combines some of the most requested features—such as versioning and the viewer-only role—with performance improvements and a new .penpot format that will streamline the export of files and assets."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_4__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83819_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.4-viewer.gif",border:"0",alt:"Viewer role, designed to enhance collaboration",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"Viewer role, designed to enhance collaboration"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_4__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Collaboration takes many forms, and sometimes the risk of making unwanted or accidental adjustments can be a barrier to engaging with a design file."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Now, you can invite members to your teams who only need to view and comment on files. Team members, stakeholders, developers… pick your case. Anyone who doesn't need to edit can participate confidently."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83819_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_4__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83819_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.4-history.gif",border:"0",alt:"A timeline for your design process",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_4__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"A timeline for your design process"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"Version History allows you to save different stages of your design process, so you can revisit them whenever needed."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_4__feature-content",children:"Some versions are saved automatically, serving as an invaluable emergency backup. Additionally, you can manually save versions, giving you full control over the timeline associated with a file. This way, you can always restore specific versions that you've intentionally saved."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83819_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$38$$,className:"main_ui_releases_v2_4__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83819_slide$jscomp$28$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$33$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_4__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.4-format.gif",border:"0",alt:"New export format: fast and open",className:"main_ui_releases_v2_4__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_4__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_4__modal-title",children:"New export format: fast and open"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"The new .penpot format will streamline the import and export of files and assets by being more efficient and interoperable."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_4__feature-content",children:"This format replaces the previous two—so no more choosing between them or accidentally picking the wrong one! It's better for both scenarios: if you just need to import or export files quickly, it’ll be a bit faster. And if you want to extract data (like a list of color assets), this new format is much easier to read."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_4__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83819_slide$jscomp$28$$,navigate:$navigate$jscomp$31$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$32$$,className:"main_ui_releases_v2_4__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83819_slide$jscomp$28$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.5",function($p__83821_slide$jscomp$29$$){var $map__83822__$1_version$jscomp$56$$=$APP.$cljs$core$__destructure_map$$($p__83821_slide$jscomp$29$$);$p__83821_slide$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83822__$1_version$jscomp$56$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83822__$1_version$jscomp$56$$,
$cljs$cst$6454$klass$$),$next$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83822__$1_version$jscomp$56$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83822__$1_version$jscomp$56$$,$cljs$cst$6455$finish$$),$navigate$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83822__$1_version$jscomp$56$$,$APP.$cljs$cst$1957$navigate$$);$map__83822__$1_version$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83822__$1_version$jscomp$56$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83821_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-slide-0.png",border:"0",
alt:"A graphic illustration with Penpot style",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__version-tag",children:"Version "+($map__83822__$1_version$jscomp$56$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_5__feature-title",children:"We’re thrilled to introduce Penpot 2.5"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Packed with powerful new features and little big details. This release brings multi-step gradients, along with comment notifications, making it easier than ever to communicate with your team members. Now you also can easily copy/paste groups of styles between layers and share direct links to specific boards, among other new capabilities considered true gems for designers and team collaboration."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"But that’s not all—we’ve also tackled numerous bug fixes and optimizations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83821_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-gradients.gif",border:"0",alt:"Multi-step gradients and more",className:"main_ui_releases_v2_5__start-image"}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Multi-step gradients and more"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"We’re so happy to bring you one of our most requested features—multi-step gradients! Now, you can create smooth, complex color transitions with multiple stops, giving you more creative options to customize your designs."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"And that’s not all. We’ve also added quick actions to flip and rotate gradients, plus now you can adjust the radius for radial gradients. More control, more flexibility, more fun."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83821_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,
total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83821_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-mention.gif",border:"0",alt:"Comment mentions and manage notifications",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Comment mentions and manage notifications"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"No more lost comments! You can now tag teammates in comments, and they’ll get a notification so they never miss direct feedback. Plus, now you can filter mentions—just select 'Only your mentions' to quickly find discussions that matter to you."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",
children:"We’ve also added a new section in your profile where you can customize your notifications, choosing what to receive on your dashboard and via email. On top of that, comments got a UI refresh, making everything clearer and better organized. And this is just the first batch of improvements—expect even more comment-related upgrades in the next Penpot release."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83821_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83821_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-copy.gif",border:"0",alt:"Copy/paste styles, CSS, and text",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Copy/paste styles, CSS, and text"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Easily copy and apply styles across your designs with just a few clicks. With the new Copy/Paste options, you can quickly transfer fills, strokes, shadows, and other properties from one layer to another—or multiple layers at once. Reusing styles is no longer a repetitive task."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",
children:"And we’ve also added more copy options:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"- 'Copy as CSS' to grab the code instantly."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"- 'Copy as text' if you just need the content."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"Less manual work for a faster workflow. We hope you find it as useful as we do."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83821_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$39$$,className:"main_ui_releases_v2_5__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83821_slide$jscomp$29$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_5__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$34$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.5-link.gif",border:"0",alt:"Links to specific boards",className:"main_ui_releases_v2_5__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_5__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_5__modal-title",children:"Links to specific boards"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"In a single Penpot file, it's common to have multiple individual screens or designs spread across different boards. Now, you can generate direct links to each board, making it easy to share them with team members or include direct links in documentation."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_5__feature-content",children:"No more navigating through the design workspace of a file to find a specific screen—just send a link and take your team straight to the intended board."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_5__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83821_slide$jscomp$29$$,navigate:$navigate$jscomp$32$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$finish$jscomp$33$$,className:"main_ui_releases_v2_5__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83821_slide$jscomp$29$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.6",function($p__83825_slide$jscomp$30$$){var $map__83826__$1_version$jscomp$57$$=$APP.$cljs$core$__destructure_map$$($p__83825_slide$jscomp$30$$);$p__83825_slide$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83826__$1_version$jscomp$57$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83826__$1_version$jscomp$57$$,
$cljs$cst$6454$klass$$),$next$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83826__$1_version$jscomp$57$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83826__$1_version$jscomp$57$$,$cljs$cst$6455$finish$$),$navigate$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83826__$1_version$jscomp$57$$,$APP.$cljs$cst$1957$navigate$$);$map__83826__$1_version$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83826__$1_version$jscomp$57$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83825_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-slide-0.png",border:"0",
alt:"Design Tokens make their debut in Penpot!",className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__version-tag",children:"Version "+($map__83826__$1_version$jscomp$57$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_6__feature-title",children:"Design Tokens make their debut in Penpot!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Penpot is the first design tool to integrate native design\n           tokens—a single source of truth to improve efficiency and\n           collaboration between product design and development."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"But that’s not all—we’ve also tackled improvements, bug fixes and optimizations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$40$$,className:"main_ui_releases_v2_6__next-btn",children:"Continue"})})]})]})})});
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83825_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-tokens-1.gif",border:"0",alt:"Manage brands and themes across your design systems",
className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"Manage brands and themes across your design systems"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",
children:"Create and manage different token types—Color, Opacity,\n           Border Radius, Dimension, Sizing, Spacing, Rotation, and\n           Stroke. And this is just the beginning—more token types are\n           on the way!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Add values to your tokens, including references to other\n           tokens (aliases) and even math operations to keep things\n           dynamic and flexible."}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_6__feature-content",children:"Use Themes and Sets for an efficient way to manage your\n           design system across multiple dimensions—whether it’s\n           brand, color schemes, devices, density, or anything else\n           your product needs."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83825_slide$jscomp$30$$,navigate:$navigate$jscomp$33$$,
total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$40$$,className:"main_ui_releases_v2_6__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83825_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-tokens-2.gif",border:"0",alt:"Open Source design tokens format",className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_6__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"Open Source design tokens format"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_6__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"Penpot adopts the W3C Design Tokens Community Group (DTCG)\n           standard, ensuring maximum compatibility with a wide range\n           of tools and technologies."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"With Penpot’s standardized design tokens format, you can\n           easily reuse and sync tokens across different platforms,\n           workflows, and disciplines. Import your existing tokens\n           into Penpot—or export them for use anywhere else. Seamless\n           interoperability by design through Open Source."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83825_slide$jscomp$30$$,navigate:$navigate$jscomp$33$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$40$$,className:"main_ui_releases_v2_6__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83825_slide$jscomp$30$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_6__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$35$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.6-bubbles.gif",border:"0",alt:"Comments grouped by zoom level",className:"main_ui_releases_v2_6__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_6__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_6__modal-title",children:"Comments grouped by zoom level"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"When collaborating on files, feedback can quickly become\n           dense and overwhelming, turning what should be information\n           into visual noise. Now, comments are grouped based on your\n           zoom level, giving the right level of visibility and making\n           navigating feedback easier."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_6__feature-content",children:"When you’re zoomed out, comments are grouped to reduce\n           clutter and keep your workspace clean. As you zoom in, the\n           groups expand, revealing individual comments in\n           context. This makes navigating feedback much smoother,\n           especially in complex designs with lots of discussion."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_6__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,
{slide:$p__83825_slide$jscomp$30$$,navigate:$navigate$jscomp$33$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$34$$,className:"main_ui_releases_v2_6__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83825_slide$jscomp$30$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.7",function($p__83828_slide$jscomp$31$$){var $map__83829__$1_version$jscomp$58$$=$APP.$cljs$core$__destructure_map$$($p__83828_slide$jscomp$31$$);$p__83828_slide$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83829__$1_version$jscomp$58$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83829__$1_version$jscomp$58$$,
$cljs$cst$6454$klass$$),$next$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83829__$1_version$jscomp$58$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83829__$1_version$jscomp$58$$,$cljs$cst$6455$finish$$),$navigate$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83829__$1_version$jscomp$58$$,$APP.$cljs$cst$1957$navigate$$);$map__83829__$1_version$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83829__$1_version$jscomp$58$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83828_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-slide-0.jpg",border:"0",
alt:"Design Tokens make their debut in Penpot!",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__version-tag",children:"Version "+($map__83829__$1_version$jscomp$58$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_7__feature-title",children:"Penpot 2.7 is out!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"After the huge excitement around our last release. The first-ever native Design Tokens support in a design tool (yay!), we’re keeping the momentum going with a fresh batch of new features and improvements."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"This update brings the first set of upgrades to our new Design Tokens system, a few of the many to come. We’ve also expanded who can create sharing prototype links and improved the invitations area. Last but not least, we fixed a bunch of bugs and optimizations that will make the experience more enjoyable for all."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"Let’s dive in!"})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_7__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83828_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_7__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-duplicate-set.gif",border:"0",alt:"Design Tokens improvements",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"Design Tokens improvements"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"It hasn’t been long since we launched Design Tokens in Penpot (the first native Design Tokens support in a design tool!), and we’re already rolling out the first set of improvements."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"The highlight: you can now duplicate token sets directly from a menu item. A huge time-saver, especially when working from existing sets. We’ve also made it easier to create themes by letting you select their set right away, and we’ve polished some info indicators to make everything a bit clearer. Plus, we’ve fixed a bunch of early-stage bugs to keep things running smoothly."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83828_slide$jscomp$31$$,navigate:$navigate$jscomp$34$$,total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_7__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83828_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-share.gif",border:"0",alt:"Editors and viewers can now create Share prototype links",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"Editors and viewers can now create Share prototype links"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"From now on, both editors and viewers can create Share Prototype links. Sharing prototypes is key for better team collaboration, no matter the role. It’s a common need, team members often have to share presentations without risking any accidental changes to the designs, which means they don’t necessarily need editing permissions. In the future, Penpot will introduce more fine-grained control over these permissions."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"This update gives editors and viewers the same ability to configure, create, copy, and delete sharing links. A capability that, until now, was limited to owners and admins."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83828_slide$jscomp$31$$,navigate:$navigate$jscomp$34$$,
total:3}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$41$$,className:"main_ui_releases_v2_7__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83828_slide$jscomp$31$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$36$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.7-invitations.gif",border:"0",alt:"A clearer way to invite your first team members",className:"main_ui_releases_v2_7__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_7__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_7__modal-title",children:"A clearer way to invite your first team members"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",children:"Penpot works perfectly for solo projects, but it’s always more fun with a team. That’s why we’ve updated the initial state of the invitations area. Instead of starting blank, it now offers clearer guidance to help you invite your first team members."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_7__feature-content",
children:"This improvement in design and UX writing comes from community member Prithvi Tharun (credit where it’s due!) Not all open source contributions are about code, and this is a fantastic example of how design and writing make a real difference too."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_7__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83828_slide$jscomp$31$$,navigate:$navigate$jscomp$34$$,total:3}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$35$$,className:"main_ui_releases_v2_7__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83828_slide$jscomp$31$$)].join(""));});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.8",function($p__83831_slide$jscomp$32$$){var $map__83832__$1_version$jscomp$59$$=$APP.$cljs$core$__destructure_map$$($p__83831_slide$jscomp$32$$);$p__83831_slide$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83832__$1_version$jscomp$59$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83832__$1_version$jscomp$59$$,
$cljs$cst$6454$klass$$),$next$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83832__$1_version$jscomp$59$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83832__$1_version$jscomp$59$$,$cljs$cst$6455$finish$$),$navigate$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83832__$1_version$jscomp$59$$,$APP.$cljs$cst$1957$navigate$$);$map__83832__$1_version$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83832__$1_version$jscomp$59$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83831_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-slide-0.jpg",border:"0",
alt:"Penpot 2.8 is here!",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__version-tag",children:"Version "+($map__83832__$1_version$jscomp$59$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_8__feature-title",children:"Penpot 2.8 is out!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"Keeping the momentum from our last releases, we're moving forward with a fresh batch of features and improvements."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"This update brings significant user experience optimizations, new capabilities for Design Token management, and an important performance enhancement, in addition to the usual bug fixes and general optimizations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$42$$,className:"main_ui_releases_v2_8__next-btn",
children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83831_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-selection.gif",border:"0",alt:"Quality-of-life improvements",
className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Quality-of-life improvements"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"The devil is in the details, and we've added many more improvements than we can list in this introduction, so we’ll list them here:"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- You can now deselect layers with Ctrl+Shift+Drag."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- Synchronize your color theme (light, dark) with your operating system theme."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"- Copy objects directly as SVG from the design workspace using the contextual menu."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- Your choice of ruler visibility settings now persists across files and reloads."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- We have introduced a new look and feel for tooltips."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",
children:"- Our fonts catalog has been updated, highlighting fonts like Atkinson Hyperlegible, developed specifically to increase legibility for readers with low vision."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- And we’ve a new language! Hi Serbians!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83831_slide$jscomp$32$$,
navigate:$navigate$jscomp$35$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$42$$,className:"main_ui_releases_v2_8__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83831_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-json-multi.gif",border:"0",alt:"Multi-file tokens import and export",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Multi-file tokens import and export"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_releases_v2_8__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"Continuing the development of our Design Tokens system, we keep launching new functionalities that will improve your workflow."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"It is now possible to perform multi-file token import. This is perfect for handling more complex setups like separate JSON files for themes or metadata. The same goes for exporting. Now you can export tokens choosing between single or multi-file (check your team preference!), being able to preview both options before you decide."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"This is just one more step in the evolution of Design Tokens in Penpot. And there's more to come: typography tokens are already in the works!"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83831_slide$jscomp$32$$,navigate:$navigate$jscomp$35$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$42$$,className:"main_ui_releases_v2_8__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$p__83831_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.8-ia-help.gif",border:"0",alt:"Better onboarding experience",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Better onboarding experience"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"We know Penpot works perfectly for solo projects, but it’s always more fun and productive to work as a team. That's why we have made significant optimizations to the onboarding process to make your team mates getting started easier and faster."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- We have reduced the number of onboarding steps so new users can start designing sooner. Only essential data will be collected to help you set up your profile more efficiently."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- We have integrated AI-powered help, which is trained on Penpot documentation, directly into the design workspace. Get assistance without switching context, so you can stay in the flow."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83831_slide$jscomp$32$$,navigate:$navigate$jscomp$35$$,
total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$42$$,className:"main_ui_releases_v2_8__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(3,$p__83831_slide$jscomp$32$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$37$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-container",
children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.8-svg-opt.gif",border:"0",alt:"Performance improvements related to SVG paths",className:"main_ui_releases_v2_8__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_8__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_8__modal-title",children:"Performance improvements related to SVG paths"})}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"We are putting a special focus on performance. This time, we've made improvements around handling paths, which typically make up icons and illustrations."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"We have carried out a refactoring of how Penpot deals with path data. This translates into perceptible performance improvements in SVG-heavily loaded files. This means that, in files with a significant presence of SVG icons and illustrations you can expect:"}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- Faster import/export."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"- A more fluid user experience."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_8__feature-content",children:"This is one of many performance improvements to come, including a new rendering engine that is already under development (this will be huge, please be patient!)."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_8__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83831_slide$jscomp$32$$,navigate:$navigate$jscomp$35$$,total:4}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$36$$,className:"main_ui_releases_v2_8__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83831_slide$jscomp$32$$)].join(""));
});$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"2.9",function($p__83833_slide$jscomp$33$$){var $map__83834__$1_version$jscomp$60$$=$APP.$cljs$core$__destructure_map$$($p__83833_slide$jscomp$33$$);$p__83833_slide$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83834__$1_version$jscomp$60$$,$APP.$cljs$cst$1974$slide$$);var $klass$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83834__$1_version$jscomp$60$$,
$cljs$cst$6454$klass$$),$next$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83834__$1_version$jscomp$60$$,$APP.$cljs$cst$1333$next$$),$finish$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83834__$1_version$jscomp$60$$,$cljs$cst$6455$finish$$),$navigate$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83834__$1_version$jscomp$60$$,$APP.$cljs$cst$1957$navigate$$);$map__83834__$1_version$jscomp$60$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83834__$1_version$jscomp$60$$,
$APP.$cljs$cst$1726$version$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1297$start$$,$p__83833_slide$jscomp$33$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$38$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.9-slide-0.jpg",border:"0",
alt:"Penpot 2.9 is here!",className:"main_ui_releases_v2_9__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_9__modal-title",children:"What’s new in Penpot?"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__version-tag",children:"Version "+($map__83834__$1_version$jscomp$60$$??
"")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__features-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_releases_v2_9__feature-title",children:"Penpot 2.9 is out!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"We're keeping the momentum going with another exciting round of improvements and features!"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"This release brings major progress in Design Token management (including our very first typography token!), smarter text overrides for components, and a rich collection of quality-of-life enhancements."}),
(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"Let’s dive in!"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__navigation",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$next$jscomp$43$$,className:"main_ui_releases_v2_9__next-btn",children:"Continue"})})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$p__83833_slide$jscomp$33$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-overlay",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$38$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/features/2.9-font-size.gif",border:"0",alt:"New typography token type",className:"main_ui_releases_v2_9__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-header",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_9__modal-title",children:"New typography token type"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__feature",children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"You can now define and manage font size tokens right from the Design Tokens panel. This is just the first of many typography token types to come. Font family token is next!"}),(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_releases_v2_9__feature-content",children:"And there’s more progress on Tokens, including support for importing multiple token files via .zip, and smarter token visibility, only showing the relevant tokens for each layer type."})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83833_slide$jscomp$33$$,navigate:$navigate$jscomp$36$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$next$jscomp$43$$,className:"main_ui_releases_v2_9__next-btn",children:"Continue"})]})]})]})})});if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$p__83833_slide$jscomp$33$$))return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-overlay",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"animated "+($klass$jscomp$38$$??""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-container",children:[(0,$APP.$rumext$v2$jsx$$)("img",
{src:"images/features/2.9-qol.gif",border:"0",alt:"Quality-of-life galore",className:"main_ui_releases_v2_9__start-image"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_releases_v2_9__modal-header",children:(0,$APP.$rumext$v2$jsx$$)("h1",{className:"main_ui_releases_v2_9__modal-title",children:"Quality-of-life galore"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__feature",
children:[(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"This release packs dozens of small yet impactful usability improvements, including enhanced UX writing (thanks to community contributions!), a new visual indicator for comments directly in the design space, a reorganized dashboard sidebar, improved text resizing behavior, and much more."}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_releases_v2_9__feature-content",children:"As always, we've squashed plenty of bugs and made underlying performance improvements to keep everything running smoothly."})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_releases_v2_9__navigation",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$releases$common$navigation_bullets_STAR_$$,{slide:$p__83833_slide$jscomp$33$$,navigate:$navigate$jscomp$36$$,total:2}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$finish$jscomp$37$$,className:"main_ui_releases_v2_9__next-btn",children:"Let's go"})]})]})]})})});throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__83833_slide$jscomp$33$$)].join(""));
});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$57$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$57$$,$APP.$cljs$cst$5476$release_notes$$,$app$main$ui$releases$release_notes_modal$$)});
$app$main$ui$releases$common$render_release_notes$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"0.0",function($params$jscomp$460$$){return $app$main$ui$releases$common$render_release_notes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$460$$,$APP.$cljs$cst$1726$version$$,"2.17"))});var $app$main$ui$auth_page$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6456$app_DOT_main_DOT_ui_DOT_auth_SLASH_auth_page_STAR_$$).then(function($f__49776__auto__$$){return{"default":$f__49776__auto__$$.$cljs$core$IFn$_invoke$arity$0$?$f__49776__auto__$$.$cljs$core$IFn$_invoke$arity$0$():$f__49776__auto__$$()}})}),$app$main$ui$verify_token_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6457$app_DOT_main_DOT_ui_DOT_auth_DOT_verify_token_SLASH_verify_token_page_STAR_$$).then(function($f__49776__auto__$jscomp$1$$){return{"default":$f__49776__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$f__49776__auto__$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$f__49776__auto__$jscomp$1$$()}})}),$app$main$ui$viewer_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6458$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer_page_STAR_$$).then(function($f__49776__auto__$jscomp$2$$){return{"default":$f__49776__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$f__49776__auto__$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$f__49776__auto__$jscomp$2$$()}})}),
$app$main$ui$dashboard_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6459$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard_page_STAR_$$).then(function($f__49776__auto__$jscomp$3$$){return{"default":$f__49776__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$f__49776__auto__$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$f__49776__auto__$jscomp$3$$()}})}),$app$main$ui$settings_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6460$app_DOT_main_DOT_ui_DOT_settings_SLASH_settings_page_STAR_$$).then(function($f__49776__auto__$jscomp$4$$){return{"default":$f__49776__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$f__49776__auto__$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$f__49776__auto__$jscomp$4$$()}})}),$app$main$ui$workspace_page_STAR_$$=(0,$APP.$rumext$v2$lazy$$)(function(){return $APP.$shadow$esm$load_by_name$$($cljs$cst$6461$app_DOT_main_DOT_ui_DOT_workspace_SLASH_workspace_page_STAR_$$).then(function($f__49776__auto__$jscomp$5$$){return{"default":$f__49776__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$f__49776__auto__$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$f__49776__auto__$jscomp$5$$()}})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$58$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$58$$,$APP.$cljs$cst$2484$confirm$$,$app$main$ui$confirm$confirm_dialog$$)});var $app$main$ui$delete_shared$noop$$=$APP.$cljs$core$constantly$$(null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$59$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$59$$,$APP.$cljs$cst$5721$delete_shared_libraries$$,$app$main$ui$delete_shared$delete_shared_dialog$$)});var $app$main$ui$routes$init_routes_83959$$,$app$main$ui$routes$routes$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/auth",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/login",$APP.$cljs$cst$3410$auth_login$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/register",$APP.$cljs$cst$5486$auth_register$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/register/validate",$APP.$cljs$cst$6400$auth_register_validate$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/register/success",$APP.$cljs$cst$5496$auth_register_success$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/recovery/request",
$APP.$cljs$cst$5485$auth_recovery_request$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/recovery",$cljs$cst$6464$auth_recovery$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/verify-token",$APP.$cljs$cst$3364$auth_verify_token$$],null)],null),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/subscribe-nitrate",$cljs$cst$6465$nitrate_entry$$],null):null,new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/settings",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/profile",$APP.$cljs$cst$5477$settings_profile$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/password",$APP.$cljs$cst$6466$settings_password$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/feedback",$APP.$cljs$cst$2520$settings_feedback$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/options",$APP.$cljs$cst$6467$settings_options$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/subscriptions",$APP.$cljs$cst$5225$settings_subscription$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/integrations",$APP.$cljs$cst$6468$settings_integrations$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/notifications",$APP.$cljs$cst$6469$settings_notifications$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/frame-preview",$cljs$cst$6470$frame_preview$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/view",$APP.$cljs$cst$1597$viewer$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/view/:file-id",$cljs$cst$6471$viewer_legacy$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/debug/icons-preview",$cljs$cst$6472$debug_icons_preview$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/debug/playground",$cljs$cst$6473$debug_playground$$],null):null,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/render-sprite/:file-id",$cljs$cst$6474$render_sprite$$],null),new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/dashboard",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/members",$APP.$cljs$cst$2535$dashboard_members$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/invitations",$APP.$cljs$cst$2537$dashboard_invitations$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/webhooks",$APP.$cljs$cst$2539$dashboard_webhooks$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/settings",$APP.$cljs$cst$2541$dashboard_settings$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/recent",$APP.$cljs$cst$2533$dashboard_recent$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/search",$APP.$cljs$cst$2526$dashboard_search$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts",$APP.$cljs$cst$2531$dashboard_fonts$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts/providers",$cljs$cst$6462$dashboard_font_providers$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/libraries",$APP.$cljs$cst$2529$dashboard_libraries$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/files",$APP.$cljs$cst$2523$dashboard_files$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/deleted",$APP.$cljs$cst$2547$dashboard_deleted$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/dashboard/team/:team-id",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/members",$cljs$cst$6475$dashboard_legacy_team_members$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/invitations",$cljs$cst$6476$dashboard_legacy_team_invitations$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
["/webhooks",$cljs$cst$6477$dashboard_legacy_team_webhooks$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/settings",$cljs$cst$6478$dashboard_legacy_team_settings$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/projects",$cljs$cst$6479$dashboard_legacy_projects$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/search",$cljs$cst$6480$dashboard_legacy_search$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts",$cljs$cst$6481$dashboard_legacy_fonts$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/fonts/providers",$cljs$cst$6482$dashboard_legacy_font_providers$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/libraries",$cljs$cst$6483$dashboard_legacy_libraries$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/projects/:project-id",$cljs$cst$6484$dashboard_legacy_files$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/workspace",$APP.$cljs$cst$2543$workspace$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["/workspace/:project-id/:file-id",$cljs$cst$6485$workspace_legacy$$],null)],null);var $shadow$js$shim$module$0$0penpot$0plugins_runtime$$=shadow$bridge("@penpot/plugins-runtime");var $app$plugins$format$shape_proxy$$=null;var $app$plugins$flex$shape_proxy_QMARK_$$=null;var $app$plugins$grid$shape_proxy_QMARK_$$=null;var $app$plugins$ruler_guides$shape_proxy$$=$APP.$cljs$core$identity$$,$app$plugins$ruler_guides$shape_proxy_QMARK_$$=$APP.$cljs$core$identity$$;var $app$plugins$text$font_size_re$$=/^\d*\.?\d*$/,$app$plugins$text$line_height_re$$=/^\d*\.?\d*$/,$app$plugins$text$letter_spacing_re$$=/^\d*\.?\d*$/,$app$plugins$text$text_transform_re$$=/uppercase|capitalize|lowercase|none/,$app$plugins$text$text_decoration_re$$=/underline|line-through|none/,$app$plugins$text$text_direction_re$$=/ltr|rtl/,$app$plugins$text$text_align_re$$=/left|center|right|justify/,$app$plugins$text$vertical_align_re$$=/top|center|bottom/;var $app$plugins$tokens$map_COLON_token_attr__GT_token_attr_plugin$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1693$p4$$,$APP.$cljs$cst$1707$m3$$,$APP.$cljs$cst$1692$p3$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1708$m4$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1706$m2$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1705$m1$$],[$cljs$cst$6583$padding_right$$,$cljs$cst$6584$padding_left$$,$cljs$cst$6585$margin_bottom$$,
$cljs$cst$6586$padding_bottom$$,$cljs$cst$6587$border_radius_top_right$$,$cljs$cst$6588$padding_top$$,$cljs$cst$6589$margin_left$$,$cljs$cst$6590$border_radius_bottom_right$$,$cljs$cst$6591$border_radius_top_left$$,$cljs$cst$6592$margin_right$$,$cljs$cst$6593$border_radius_bottom_left$$,$cljs$cst$6594$margin_top$$]),$app$plugins$tokens$map_COLON_token_attr_plugin__GT_token_attr$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$clojure$set$map_invert$$($app$plugins$tokens$map_COLON_token_attr__GT_token_attr_plugin$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$cljs$cst$6588$padding_top$$,$APP.$cljs$cst$1093$p1$$,$cljs$cst$6583$padding_right$$,$APP.$cljs$cst$1091$p2$$,$cljs$cst$6586$padding_bottom$$,$APP.$cljs$cst$1692$p3$$,$cljs$cst$6584$padding_left$$,$APP.$cljs$cst$1693$p4$$,$cljs$cst$6594$margin_top$$,$APP.$cljs$cst$1705$m1$$,$cljs$cst$6592$margin_right$$,$APP.$cljs$cst$1706$m2$$,$cljs$cst$6585$margin_bottom$$,$APP.$cljs$cst$1707$m3$$,$cljs$cst$6589$margin_left$$,$APP.$cljs$cst$1708$m4$$],null)])),$app$plugins$tokens$token_proxy$$=
function $app$plugins$tokens$token_proxy$$($plugin_id$jscomp$27$$,$file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$){var $obj_86394$$=new $APP.$app$util$object$Proxy$$,$schema_name_86452_87600$$=$APP.$app$common$files$tokens$make_token_name_schema$$(function(){var $G__86760$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$);return $G__86760$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens$$($G__86760$$,$set_id$jscomp$47$$)}()),$coercer_fn_name_86450_87601$$=$schema_name_86452_87600$$==
null||$APP.$cljs$core$fn_QMARK_$$($schema_name_86452_87600$$)?null:$APP.$app$common$schema$coercer$$($schema_name_86452_87600$$),$schema_value_86467_87606$$=function(){var $token$jscomp$220$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$),$base$jscomp$45$$=$APP.$app$common$files$tokens$make_token_value_schema$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$220$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1764$font_family$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$220$$))?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,$APP.$cljs$cst$198$string$$,$base$jscomp$45$$],null):$base$jscomp$45$$}(),$coercer_fn_value_86465_87607$$=$schema_value_86467_87606$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_value_86467_87606$$)?null:$APP.$app$common$schema$coercer$$($schema_value_86467_87606$$),$coercer_fn_description_86489_87614$$=
$APP.$app$common$files$tokens$schema_COLON_token_description$$==null||$APP.$cljs$core$fn_QMARK_$$($APP.$app$common$files$tokens$schema_COLON_token_description$$)?null:$APP.$app$common$schema$coercer$$($APP.$app$common$files$tokens$schema_COLON_token_description$$),$schema_applytoshapes_86513_87625$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$shape_proxy_QMARK_$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_attr_QMARK_$$],null)],null)],null)],null)],null),$coercer_fn_applytoshapes_86511_87626$$=$schema_applytoshapes_86513_87625$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_applytoshapes_86513_87625$$)?null:$APP.$app$common$schema$coercer$$($schema_applytoshapes_86513_87625$$),
$schema_applytoselected_86520_87629$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_attr_QMARK_$$],null)],null)],null)],null)],null),$coercer_fn_applytoselected_86518_87630$$=$schema_applytoselected_86520_87629$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_applytoselected_86520_87629$$)?null:$APP.$app$common$schema$coercer$$($schema_applytoselected_86520_87629$$);
Object.defineProperty($obj_86394$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TokenProxy"}});Object.defineProperty($obj_86394$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokenProxy"}});Object.defineProperty($obj_86394$$,"$plugin",{enumerable:!1,get:function(){var $internal_fn_plugin_86414$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$27$$);try{return $internal_fn_plugin_86414$$.call(this)}catch($e86528$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86528$$)}}});
Object.defineProperty($obj_86394$$,"$file-id",{enumerable:!1,get:function(){var $internal_fn_fileid_86421$$=$APP.$cljs$core$constantly$$($file_id$jscomp$477$$);try{return $internal_fn_fileid_86421$$.call(this)}catch($e86533$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86533$$)}}});Object.defineProperty($obj_86394$$,"$set-id",{enumerable:!1,get:function(){var $internal_fn_setid_86428$$=$APP.$cljs$core$constantly$$($set_id$jscomp$47$$);try{return $internal_fn_setid_86428$$.call(this)}catch($e86592$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86592$$)}}});
Object.defineProperty($obj_86394$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_86435$$=$APP.$cljs$core$constantly$$($id$jscomp$1118$$);try{return $internal_fn_id_86435$$.call(this)}catch($e86593$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86593$$)}}});Object.defineProperty($obj_86394$$,"id",{enumerable:!0,get:function(){try{return""+($id$jscomp$1118$$??"")}catch($e86596$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86596$$)}}});Object.defineProperty($obj_86394$$,
"name",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10588$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$);return $APP.$app$common$types$tokens_lib$get_name$$($token$jscomp$inline_10588$$)}catch($e86759$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86759$$)}},set:function($val_name_86454$$){try{var $schema_name_86452__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_name_86452_87600$$)?$schema_name_86452_87600$$($val_name_86454$$):
$schema_name_86452_87600$$,$coercer_fn_name_86450__$1$$=$coercer_fn_name_86450_87601$$==null?$APP.$app$common$schema$coercer$$($schema_name_86452__$1$$):$coercer_fn_name_86450_87601$$,$val_name_86454__$1$$=$APP.$app$common$json$__GT_clj$$($val_name_86454$$,null),$val_name_86454__$2$$=$coercer_fn_name_86450__$1$$($val_name_86454__$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$($set_id$jscomp$47$$,
$id$jscomp$1118$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$val_name_86454__$2$$],null)),$plugin_id$jscomp$27$$))}catch($e86761$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86761$$)}}});Object.defineProperty($obj_86394$$,"type",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10591$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$),$G__86766$jscomp$inline_10592$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$inline_10591$$);
return $APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__86766$jscomp$inline_10592$$):(0,$APP.$app$common$types$token$token_type__GT_dtcg_token_type$$)($G__86766$jscomp$inline_10592$$)}catch($e86769$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86769$$)}}});Object.defineProperty($obj_86394$$,"value",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10595$$=
$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$);return $APP.$app$common$json$__GT_js$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$inline_10595$$))}catch($e86774$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86774$$)}},set:function($val_value_86469$$){try{var $schema_value_86467__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_value_86467_87606$$)?$schema_value_86467_87606$$($val_value_86469$$):$schema_value_86467_87606$$,
$coercer_fn_value_86465__$1$$=$coercer_fn_value_86465_87607$$==null?$APP.$app$common$schema$coercer$$($schema_value_86467__$1$$):$coercer_fn_value_86465_87607$$,$val_value_86469__$1$$=$APP.$app$common$json$__GT_clj$$($val_value_86469$$,null),$value$jscomp$inline_14255$$=$coercer_fn_value_86465__$1$$($val_value_86469__$1$$),$token$jscomp$inline_14256$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$),$value__$1$jscomp$inline_14257$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1764$font_family$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$inline_14256$$))?$APP.$app$common$types$tokens_lib$convert_dtcg_font_family$$($value$jscomp$inline_14255$$):$value$jscomp$inline_14255$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$($set_id$jscomp$47$$,$id$jscomp$1118$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$value__$1$jscomp$inline_14257$$],
null)))}catch($e86779$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86779$$)}}});Object.defineProperty($obj_86394$$,"resolvedValue",{enumerable:!1,get:function(){try{var $token$jscomp$inline_10598$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$),$tokens_lib$jscomp$inline_10599$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$),$tokens_tree$jscomp$inline_10600$$=$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$inline_10599$$);
return $app$plugins$tokens$get_resolved_value$$($token$jscomp$inline_10598$$,$tokens_tree$jscomp$inline_10600$$)}catch($e86787$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86787$$)}}});Object.defineProperty($obj_86394$$,"resolvedValueString",{enumerable:!1,get:function(){try{var $token$jscomp$inline_10603$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$),$tokens_lib$jscomp$inline_10604$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$477$$),
$tokens_tree$jscomp$inline_10605$$=$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$inline_10604$$);return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$tokens$get_resolved_value$$($token$jscomp$inline_10603$$,$tokens_tree$jscomp$inline_10605$$))}catch($e86788$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86788$$)}}});Object.defineProperty($obj_86394$$,"description",{enumerable:!0,get:function(){try{var $token$jscomp$inline_10608$$=
$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$);return $APP.$app$common$types$tokens_lib$get_description$$($token$jscomp$inline_10608$$)}catch($e86789$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86789$$)}},set:function($val_description_86493$$){try{var $schema_description_86491__$1$$=$APP.$cljs$core$fn_QMARK_$$($APP.$app$common$files$tokens$schema_COLON_token_description$$)?(0,$APP.$app$common$files$tokens$schema_COLON_token_description$$)($val_description_86493$$):
$APP.$app$common$files$tokens$schema_COLON_token_description$$,$coercer_fn_description_86489__$1$$=$coercer_fn_description_86489_87614$$==null?$APP.$app$common$schema$coercer$$($schema_description_86491__$1$$):$coercer_fn_description_86489_87614$$,$val_description_86493__$1$$=$APP.$app$common$json$__GT_clj$$($val_description_86493$$,null),$val_description_86493__$2$$=$coercer_fn_description_86489__$1$$($val_description_86493__$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$($set_id$jscomp$47$$,
$id$jscomp$1118$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$936$description$$,$val_description_86493__$2$$],null)),$APP.$cljs$cst$1725$plugin_id$$))}catch($e86816$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86816$$)}}});Object.defineProperty($obj_86394$$,"duplicate",{enumerable:!1,get:function(){return function(){try{var $token$jscomp$225$$=$app$plugins$utils$locate_token$$($file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$),$token_SINGLEQUOTE_$jscomp$4$$=
$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$clojure$datafy$datafy$$($token$jscomp$225$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1743$modified_at$$]))]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$($set_id$jscomp$47$$,
$token_SINGLEQUOTE_$jscomp$4$$),$plugin_id$jscomp$27$$));var $G__86827$$=$token_SINGLEQUOTE_$jscomp$4$$.id;return $app$plugins$tokens$token_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$tokens$token_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$27$$,$file_id$jscomp$477$$,$set_id$jscomp$47$$,$G__86827$$):$app$plugins$tokens$token_proxy$$($plugin_id$jscomp$27$$,$file_id$jscomp$477$$,$set_id$jscomp$47$$,$G__86827$$)}catch($e86819$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86819$$)}}.bind(this)}});
Object.defineProperty($obj_86394$$,"remove",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$library_edit$delete_token$$($set_id$jscomp$47$$,$id$jscomp$1118$$),$plugin_id$jscomp$27$$))}catch($e86830$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86830$$)}}.bind(this)}});Object.defineProperty($obj_86394$$,"applyToShapes",{enumerable:!1,
get:function(){var $internal_fn_applytoshapes_86510__$1$$=function($shapes$jscomp$245$$,$attrs$jscomp$188$$){try{return $app$plugins$tokens$apply_token_to_shapes$$($plugin_id$jscomp$27$$,$file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__86392_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__86392_SHARP_$$,"$id")},$shapes$jscomp$245$$),$attrs$jscomp$188$$)}catch($e86841$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86841$$)}}.bind(this);
return function(){try{var $val_applytoshapes_86515$$=Array.from(arguments),$val_applytoshapes_86515__$1$$=$APP.$app$common$json$__GT_clj$$($val_applytoshapes_86515$$,null),$schema_applytoshapes_86513__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_applytoshapes_86513_87625$$)?$schema_applytoshapes_86513_87625$$($val_applytoshapes_86515__$1$$):$schema_applytoshapes_86513_87625$$,$val_applytoshapes_86515__$2$$=($coercer_fn_applytoshapes_86511_87626$$==null?$APP.$app$common$schema$coercer$$($schema_applytoshapes_86513__$1$$):
$coercer_fn_applytoshapes_86511_87626$$)($val_applytoshapes_86515__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_applytoshapes_86510__$1$$,$val_applytoshapes_86515__$2$$)}catch($e86846$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86846$$)}}}});Object.defineProperty($obj_86394$$,"applyToSelected",{enumerable:!1,get:function(){var $internal_fn_applytoselected_86517__$1$$=function($attrs$jscomp$189$$){try{var $selected$jscomp$225$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1938$selected$$],null));return $app$plugins$tokens$apply_token_to_shapes$$($plugin_id$jscomp$27$$,$file_id$jscomp$477$$,$set_id$jscomp$47$$,$id$jscomp$1118$$,$selected$jscomp$225$$,$attrs$jscomp$189$$)}catch($e86853$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86853$$)}}.bind(this);return function(){try{var $val_applytoselected_86522$$=
Array.from(arguments),$val_applytoselected_86522__$1$$=$APP.$app$common$json$__GT_clj$$($val_applytoselected_86522$$,null),$schema_applytoselected_86520__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_applytoselected_86520_87629$$)?$schema_applytoselected_86520_87629$$($val_applytoselected_86522__$1$$):$schema_applytoselected_86520_87629$$,$val_applytoselected_86522__$2$$=($coercer_fn_applytoselected_86518_87630$$==null?$APP.$app$common$schema$coercer$$($schema_applytoselected_86520__$1$$):$coercer_fn_applytoselected_86518_87630$$)($val_applytoselected_86522__$1$$);
return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_applytoselected_86517__$1$$,$val_applytoselected_86522__$2$$)}catch($e86858$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$27$$)($e86858$$)}}}});return $obj_86394$$},$app$plugins$tokens$token_theme_proxy$$=function $app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$30$$,$file_id$jscomp$481$$,$id$jscomp$1121$$){var $obj_87211$$=new $APP.$app$util$object$Proxy$$,$schema_group_87267_87836$$=function(){var $theme$jscomp$35$$=
$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$app$common$files$tokens$make_token_theme_group_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$481$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$35$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$35$$))}(),$coercer_fn_group_87265_87837$$=$schema_group_87267_87836$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_group_87267_87836$$)?null:$APP.$app$common$schema$coercer$$($schema_group_87267_87836$$),
$schema_name_87275_87841$$=function(){var $theme$jscomp$38$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$app$common$files$tokens$make_token_theme_name_schema$$($app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$481$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$38$$),$APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$38$$))}(),$coercer_fn_name_87273_87842$$=$schema_name_87275_87841$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_name_87275_87841$$)?
null:$APP.$app$common$schema$coercer$$($schema_name_87275_87841$$),$coercer_fn_active_87281_87847$$=$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$==null||$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?null:$APP.$app$common$schema$coercer$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$),$schema_addset_87305_87855$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_set_proxy_QMARK_$$],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],null)],null),$coercer_fn_addset_87303_87856$$=$schema_addset_87305_87855$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_addset_87305_87855$$)?null:$APP.$app$common$schema$coercer$$($schema_addset_87305_87855$$),
$schema_removeset_87312_87859$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$433$or$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_set_proxy_QMARK_$$],null),$APP.$cljs$cst$935$app_DOT_common_DOT_schema_SLASH_uuid$$],
null)],null),$coercer_fn_removeset_87310_87860$$=$schema_removeset_87312_87859$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_removeset_87312_87859$$)?null:$APP.$app$common$schema$coercer$$($schema_removeset_87312_87859$$);Object.defineProperty($obj_87211$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"TokenThemeProxy"}});Object.defineProperty($obj_87211$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"TokenThemeProxy"}});Object.defineProperty($obj_87211$$,"$plugin",
{enumerable:!1,get:function(){var $internal_fn_plugin_87229$$=$APP.$cljs$core$constantly$$($plugin_id$jscomp$30$$);try{return $internal_fn_plugin_87229$$.call(this)}catch($e87330$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87330$$)}}});Object.defineProperty($obj_87211$$,"$file-id",{enumerable:!1,get:function(){var $internal_fn_fileid_87236$$=$APP.$cljs$core$constantly$$($file_id$jscomp$481$$);try{return $internal_fn_fileid_87236$$.call(this)}catch($e87333$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87333$$)}}});
Object.defineProperty($obj_87211$$,"$id",{enumerable:!1,get:function(){var $internal_fn_id_87243$$=$APP.$cljs$core$constantly$$($id$jscomp$1121$$);try{return $internal_fn_id_87243$$.call(this)}catch($e87334$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87334$$)}}});Object.defineProperty($obj_87211$$,"id",{enumerable:!0,get:function(){try{return""+($id$jscomp$1121$$??"")}catch($e87335$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87335$$)}}});Object.defineProperty($obj_87211$$,
"external-id",{enumerable:!0,get:function(){try{var $theme$jscomp$inline_10628$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$cljs$cst$2115$external_id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$inline_10628$$)}catch($e87336$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87336$$)}}});Object.defineProperty($obj_87211$$,"group",{enumerable:!0,get:function(){try{var $theme$jscomp$inline_10631$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,
$id$jscomp$1121$$);return $APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$inline_10631$$)}catch($e87337$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87337$$)}},set:function($val_group_87269$$){try{var $schema_group_87267__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_group_87267_87836$$)?$schema_group_87267_87836$$($val_group_87269$$):$schema_group_87267_87836$$,$coercer_fn_group_87265__$1$$=$coercer_fn_group_87265_87837$$==null?$APP.$app$common$schema$coercer$$($schema_group_87267__$1$$):
$coercer_fn_group_87265_87837$$,$val_group_87269__$1$$=$APP.$app$common$json$__GT_clj$$($val_group_87269$$,null),$group$jscomp$inline_10635$$=$coercer_fn_group_87265__$1$$($val_group_87269__$1$$),$theme$jscomp$inline_10636$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1121$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($theme$jscomp$inline_10636$$,
$APP.$cljs$cst$1613$group$$,$group$jscomp$inline_10635$$)))}catch($e87340$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87340$$)}}});Object.defineProperty($obj_87211$$,"name",{enumerable:!0,get:function(){try{var $theme$jscomp$inline_10638$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$inline_10638$$)}catch($e87341$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87341$$)}},
set:function($val_name_87277$$){try{var $schema_name_87275__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_name_87275_87841$$)?$schema_name_87275_87841$$($val_name_87277$$):$schema_name_87275_87841$$,$coercer_fn_name_87273__$1$$=$coercer_fn_name_87273_87842$$==null?$APP.$app$common$schema$coercer$$($schema_name_87275__$1$$):$coercer_fn_name_87273_87842$$,$val_name_87277__$1$$=$APP.$app$common$json$__GT_clj$$($val_name_87277$$,null),$name$jscomp$inline_10642$$=$coercer_fn_name_87273__$1$$($val_name_87277__$1$$),
$theme$jscomp$inline_10643$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$cljs$core$truth_$$($name$jscomp$inline_10642$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1121$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($theme$jscomp$inline_10643$$,$APP.$cljs$cst$725$name$$,$name$jscomp$inline_10642$$))):null}catch($e87344$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87344$$)}}});
Object.defineProperty($obj_87211$$,"active",{enumerable:!1,get:function(){try{var $tokens_lib$jscomp$inline_10645$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$481$$);return $app$common$types$tokens_lib$theme_active_QMARK_$$($tokens_lib$jscomp$inline_10645$$,$id$jscomp$1121$$)}catch($e87345$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87345$$)}},set:function($val_active_87285$$){try{var $schema_active_87283__$1$$=$APP.$cljs$core$fn_QMARK_$$($APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)?
(0,$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$)($val_active_87285$$):$APP.$cljs$cst$964$app_DOT_common_DOT_schema_SLASH_boolean$$,$coercer_fn_active_87281__$1$$=$coercer_fn_active_87281_87847$$==null?$APP.$app$common$schema$coercer$$($schema_active_87283__$1$$):$coercer_fn_active_87281_87847$$,$val_active_87285__$1$$=$APP.$app$common$json$__GT_clj$$($val_active_87285$$,null),$val_active_87285__$2$$=$coercer_fn_active_87281__$1$$($val_active_87285__$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$set_token_theme_active$$($id$jscomp$1121$$,
$val_active_87285__$2$$))}catch($e87348$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87348$$)}}});Object.defineProperty($obj_87211$$,"toggleActive",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1121$$))}catch($e87351$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87351$$)}}.bind(this)}});
Object.defineProperty($obj_87211$$,"activeSets",{enumerable:!0,get:function(){function $internal_fn_activesets_87295$$(){var $tokens_lib$jscomp$66$$=$app$plugins$utils$locate_tokens_lib$$($file_id$jscomp$481$$),$theme$jscomp$40$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__87207_SHARP_$$){return $app$plugins$tokens$token_set_proxy$cljs$0core$0IFn$0_invoke$0arity$03$$($plugin_id$jscomp$30$$,
$file_id$jscomp$481$$,$APP.$app$common$types$tokens_lib$get_id$$($APP.$app$common$types$tokens_lib$get_set_by_name$$($tokens_lib$jscomp$66$$,$p1__87207_SHARP_$$)))},$APP.$cljs$cst$2116$sets$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$40$$)))}try{return $internal_fn_activesets_87295$$.call(this,this)}catch($e87352$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87352$$)}}});Object.defineProperty($obj_87211$$,"addSet",{enumerable:!1,get:function(){var $internal_fn_addset_87302__$1$$=
function($set_arg$jscomp$1$$){try{var $JSCompiler_inline_result$jscomp$11368$$=$app$plugins$tokens$token_set_proxy_QMARK_$$($set_arg$jscomp$1$$)?$set_arg$jscomp$1$$:$app$plugins$utils$locate_token_set$$($file_id$jscomp$481$$,$set_arg$jscomp$1$$);var $set_name$jscomp$32$$=$app$plugins$tokens$token_set_name$$($JSCompiler_inline_result$jscomp$11368$$),$theme$jscomp$41$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($set_name$jscomp$32$$)?
$theme$jscomp$41$$:$set_name$jscomp$32$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1121$$,$app$common$types$tokens_lib$enable_set$$($theme$jscomp$41$$,$set_name$jscomp$32$$))):null}catch($e87353$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87353$$)}}.bind(this);return function(){try{var $val_addset_87307$$=Array.from(arguments),$val_addset_87307__$1$$=$APP.$app$common$json$__GT_clj$$($val_addset_87307$$,
null),$schema_addset_87305__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_addset_87305_87855$$)?$schema_addset_87305_87855$$($val_addset_87307__$1$$):$schema_addset_87305_87855$$,$val_addset_87307__$2$$=($coercer_fn_addset_87303_87856$$==null?$APP.$app$common$schema$coercer$$($schema_addset_87305__$1$$):$coercer_fn_addset_87303_87856$$)($val_addset_87307__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_addset_87302__$1$$,$val_addset_87307__$2$$)}catch($e87354$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87354$$)}}}});
Object.defineProperty($obj_87211$$,"removeSet",{enumerable:!1,get:function(){var $internal_fn_removeset_87309__$1$$=function($set_arg$jscomp$2$$){try{var $JSCompiler_inline_result$jscomp$11369$$=$app$plugins$tokens$token_set_proxy_QMARK_$$($set_arg$jscomp$2$$)?$set_arg$jscomp$2$$:$app$plugins$utils$locate_token_set$$($file_id$jscomp$481$$,$set_arg$jscomp$2$$);var $set_name$jscomp$33$$=$app$plugins$tokens$token_set_name$$($JSCompiler_inline_result$jscomp$11369$$),$theme$jscomp$42$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,
$id$jscomp$1121$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($set_name$jscomp$33$$)?$theme$jscomp$42$$:$set_name$jscomp$33$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($id$jscomp$1121$$,$app$common$types$tokens_lib$disable_set$$($theme$jscomp$42$$,$set_name$jscomp$33$$))):null}catch($e87355$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87355$$)}}.bind(this);return function(){try{var $val_removeset_87314$$=
Array.from(arguments),$val_removeset_87314__$1$$=$APP.$app$common$json$__GT_clj$$($val_removeset_87314$$,null),$schema_removeset_87312__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_removeset_87312_87859$$)?$schema_removeset_87312_87859$$($val_removeset_87314__$1$$):$schema_removeset_87312_87859$$,$val_removeset_87314__$2$$=($coercer_fn_removeset_87310_87860$$==null?$APP.$app$common$schema$coercer$$($schema_removeset_87312__$1$$):$coercer_fn_removeset_87310_87860$$)($val_removeset_87314__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_removeset_87309__$1$$,
$val_removeset_87314__$2$$)}catch($e87360$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87360$$)}}}});Object.defineProperty($obj_87211$$,"duplicate",{enumerable:!1,get:function(){return function(){try{var $theme$jscomp$43$$=$app$plugins$utils$locate_token_theme$$($file_id$jscomp$481$$,$id$jscomp$1121$$),$theme_SINGLEQUOTE_$jscomp$4$$=$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$clojure$datafy$datafy$$($theme$jscomp$43$$),
$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1743$modified_at$$]))]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$($theme_SINGLEQUOTE_$jscomp$4$$));var $G__87444$$=$theme_SINGLEQUOTE_$jscomp$4$$.id;return $app$plugins$tokens$token_theme_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$tokens$token_theme_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$30$$,
$file_id$jscomp$481$$,$G__87444$$):$app$plugins$tokens$token_theme_proxy$$($plugin_id$jscomp$30$$,$file_id$jscomp$481$$,$G__87444$$)}catch($e87441$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87441$$)}}.bind(this)}});Object.defineProperty($obj_87211$$,"remove",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($id$jscomp$1121$$))}catch($e87445$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$30$$)($e87445$$)}}.bind(this)}});
return $obj_87211$$};var $app$plugins$shape$variant_proxy$$=null,$app$plugins$shape$lib_typography_proxy_QMARK_$$=null,$app$plugins$shape$lib_component_proxy$$=null,$app$plugins$shape$shape_proxy$$=function $app$plugins$shape$shape_proxy$$($var_args$jscomp$1529$$){switch(arguments.length){case 2:return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);case 4:return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],
arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$=function($plugin_id$jscomp$38$$,$id$jscomp$1127$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$38$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$id$jscomp$1127$$)};
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$3$=function($plugin_id$jscomp$39$$,$page_id$jscomp$499$$,$id$jscomp$1128$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$39$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$page_id$jscomp$499$$,$id$jscomp$1128$$)};
$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$=function($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$){var $data$jscomp$532$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$G__88031$$=function(){var $G__88032$$=function(){var $G__88033$$=function(){var $G__88034$$=function(){var $obj_88036$$=new $APP.$app$util$object$Proxy$$,$schema_applytoken_88710_90145$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$498$tuple$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$shape$token_proxy_QMARK_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$946$app_DOT_common_DOT_schema_SLASH_set$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,$APP.$cljs$cst$965$app_DOT_common_DOT_schema_SLASH_keyword$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,$app$plugins$tokens$token_attr_QMARK_$$],null)],null)],null)],null)],null),$coercer_fn_applytoken_88708_90146$$=$schema_applytoken_88710_90145$$==null||$APP.$cljs$core$fn_QMARK_$$($schema_applytoken_88710_90145$$)?
null:$APP.$app$common$schema$coercer$$($schema_applytoken_88710_90145$$);Object.defineProperty($obj_88036$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"ShapeProxy"}});Object.defineProperty($obj_88036$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"ShapeProxy"}});Object.defineProperty($obj_88036$$,"$plugin",{enumerable:!1,get:function(){try{return $plugin_id$jscomp$40$$}catch($e88742$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88742$$)}}});
Object.defineProperty($obj_88036$$,"$id",{enumerable:!1,get:function(){try{return $id$jscomp$1129$$}catch($e88743$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88743$$)}}});Object.defineProperty($obj_88036$$,"$file",{enumerable:!1,get:function(){try{return $file_id$jscomp$485$$}catch($e88744$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88744$$)}}});Object.defineProperty($obj_88036$$,"$page",{enumerable:!1,get:function(){try{return $page_id$jscomp$500$$}catch($e88745$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88745$$)}}});
Object.defineProperty($obj_88036$$,"id",{enumerable:!0,get:function(){try{return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88746$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88746$$)}}});Object.defineProperty($obj_88036$$,"type",{enumerable:!0,get:function(){try{return $app$plugins$format$shape_type$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88747$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88747$$)}}});
Object.defineProperty($obj_88036$$,"name",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88748$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88748$$)}},set:function($val_name_88101_value__$1$jscomp$inline_10658$$){try{var $id__$1$jscomp$inline_10657$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");if(typeof $val_name_88101_value__$1$jscomp$inline_10658$$===
"string"){var $path$jscomp$inline_14265$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($val_name_88101_value__$1$jscomp$inline_10658$$);var $JSCompiler_temp$jscomp$11064$$=$APP.$app$common$path_names$join_path$$($APP.$app$common$path_names$split_path$$($path$jscomp$inline_14265$$))}else $JSCompiler_temp$jscomp$11064$$=null;$val_name_88101_value__$1$jscomp$inline_10658$$=$JSCompiler_temp$jscomp$11064$$;var $valid_QMARK_$jscomp$inline_10659$$=$val_name_88101_value__$1$jscomp$inline_10658$$!=
null&&!$APP.$cuerdas$core$ends_with_QMARK_$$($val_name_88101_value__$1$jscomp$inline_10658$$,"/")&&!$APP.$cuerdas$core$blank_QMARK_$$($val_name_88101_value__$1$jscomp$inline_10658$$);return $app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$valid_QMARK_$jscomp$inline_10659$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$rename_shape_or_variant$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$485$$,
$page_id$jscomp$500$$,$id__$1$jscomp$inline_10657$$,$val_name_88101_value__$1$jscomp$inline_10658$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$725$name$$,$val_name_88101_value__$1$jscomp$inline_10658$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$725$name$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'content:write' permission")}catch($e88749$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88749$$)}}});
Object.defineProperty($obj_88036$$,"blocked",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1628$blocked$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88750$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88750$$)}},set:function($val_blocked_88109$$){try{return function($self$jscomp$180$$,$value$jscomp$1137$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1137$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$180$$,"$id")],null),function($p1__87879_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87879_SHARP_$$,
$APP.$cljs$cst$1628$blocked$$,$value$jscomp$1137$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1628$blocked$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1628$blocked$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1628$blocked$$,$value$jscomp$1137$$)}.call(this,this,$val_blocked_88109$$)}catch($e88751$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88751$$)}}});
Object.defineProperty($obj_88036$$,"hidden",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88752$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88752$$)}},set:function($val_hidden_88117$$){try{return function($self$jscomp$181$$,$value$jscomp$1138$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1138$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$181$$,"$id")],null),function($p1__87881_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87881_SHARP_$$,
$APP.$cljs$cst$1625$hidden$$,$value$jscomp$1138$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1625$hidden$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1625$hidden$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1625$hidden$$,$value$jscomp$1138$$)}.call(this,this,$val_hidden_88117$$)}catch($e88753$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88753$$)}}});
Object.defineProperty($obj_88036$$,"visible",{enumerable:!0,get:function(){try{return!$APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88754$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88754$$)}},set:function($val_visible_88125$$){try{return function($self$jscomp$182$$,$value$jscomp$1139$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1139$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$182$$,"$id")],null),function($p1__87883_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87883_SHARP_$$,
$APP.$cljs$cst$1625$hidden$$,$APP.$cljs$core$not$$($value$jscomp$1139$$))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2357$visible$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2357$visible$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2357$visible$$,$value$jscomp$1139$$)}.call(this,this,$val_visible_88125$$)}catch($e88755$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88755$$)}}});
Object.defineProperty($obj_88036$$,"proportionLock",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1814$proportion_lock$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88756$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88756$$)}},set:function($val_proportionlock_88133$$){try{return function($self$jscomp$183$$,$value$jscomp$1140$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1140$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$183$$,"$id")],null),function($p1__87885_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87885_SHARP_$$,
$APP.$cljs$cst$1814$proportion_lock$$,$value$jscomp$1140$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6597$proportionLock$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6597$proportionLock$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6597$proportionLock$$,$value$jscomp$1140$$)}.call(this,this,$val_proportionlock_88133$$)}catch($e88757$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88757$$)}}});
Object.defineProperty($obj_88036$$,"constraintsHorizontal",{enumerable:!0,get:function(){try{return $APP.$app$common$data$name$$($APP.$cljs$cst$1879$constraints_h$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88758$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88758$$)}},set:function($val_constraintshorizontal_88141$$){try{return function($id__$1$jscomp$29_self$jscomp$184$$,$value$jscomp$1141$$){$id__$1$jscomp$29_self$jscomp$184$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$29_self$jscomp$184$$,
"$id");var $value__$1$jscomp$122$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1141$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$horizontal_constraint_types$$,$value__$1$jscomp$122$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$29_self$jscomp$184$$],null),function($p1__87887_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87887_SHARP_$$,$APP.$cljs$cst$1879$constraints_h$$,$value__$1$jscomp$122$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6598$constraintsHorizontal$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6598$constraintsHorizontal$$,
"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6598$constraintsHorizontal$$,$value__$1$jscomp$122$$)}.call(this,this,$val_constraintshorizontal_88141$$)}catch($e88759$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88759$$)}}});Object.defineProperty($obj_88036$$,"constraintsVertical",{enumerable:!0,get:function(){try{return $APP.$app$common$data$name$$($APP.$cljs$cst$1878$constraints_v$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88760$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88760$$)}},
set:function($val_constraintsvertical_88149$$){try{return function($id__$1$jscomp$30_self$jscomp$185$$,$value$jscomp$1142$$){$id__$1$jscomp$30_self$jscomp$185$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$30_self$jscomp$185$$,"$id");var $value__$1$jscomp$123$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1142$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$vertical_constraint_types$$,$value__$1$jscomp$123$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$30_self$jscomp$185$$],null),function($p1__87889_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87889_SHARP_$$,$APP.$cljs$cst$1878$constraints_v$$,
$value__$1$jscomp$123$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6599$constraintsVertical$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6599$constraintsVertical$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6599$constraintsVertical$$,$value__$1$jscomp$123$$)}.call(this,this,$val_constraintsvertical_88149$$)}catch($e88761$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88761$$)}}});
Object.defineProperty($obj_88036$$,"fixedWhenScrolling",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1650$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88762$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88762$$)}},set:function($val_fixedwhenscrolling_88157$$){try{return function($self$jscomp$186$$,$value$jscomp$1143$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1143$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($self$jscomp$186$$,"$id")],null),function($p1__87891_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87891_SHARP_$$,
$APP.$cljs$cst$1650$fixed_scroll$$,$value$jscomp$1143$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6600$fixedWhenScrolling$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6600$fixedWhenScrolling$$,$value$jscomp$1143$$)}.call(this,this,$val_fixedwhenscrolling_88157$$)}catch($e88763$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88763$$)}}});Object.defineProperty($obj_88036$$,"borderRadius",
{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88764$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88764$$)}},set:function($val_borderradius_88165$$){try{return function($id__$1$jscomp$32_self$jscomp$187$$,$value$jscomp$1144$$){$id__$1$jscomp$32_self$jscomp$187$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$32_self$jscomp$187$$,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1144$$))||
$value$jscomp$1144$$<0?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6601$borderRadius$$,$value$jscomp$1144$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id__$1$jscomp$32_self$jscomp$187$$],null),function($p1__87893_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_all_corners$$($p1__87893_SHARP_$$,$value$jscomp$1144$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6601$borderRadius$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6601$borderRadius$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradius_88165$$)}catch($e88765$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88765$$)}}});
Object.defineProperty($obj_88036$$,"borderRadiusTopLeft",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88766$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88766$$)}},set:function($val_borderradiustopleft_88173$$){try{return function($id__$1$jscomp$33_self$jscomp$188$$,$value$jscomp$1145$$){$id__$1$jscomp$33_self$jscomp$188$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$33_self$jscomp$188$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1145$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6602$borderRadiusTopLeft$$,$value$jscomp$1145$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$33_self$jscomp$188$$],null),function($p1__87895_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__87895_SHARP_$$,$APP.$cljs$cst$1651$r1$$,$value$jscomp$1145$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6602$borderRadiusTopLeft$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6602$borderRadiusTopLeft$$,
"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiustopleft_88173$$)}catch($e88767$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88767$$)}}});Object.defineProperty($obj_88036$$,"borderRadiusTopRight",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1652$r2$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88769$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88769$$)}},set:function($val_borderradiustopright_88181$$){try{return function($id__$1$jscomp$34_self$jscomp$189$$,
$value$jscomp$1146$$){$id__$1$jscomp$34_self$jscomp$189$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$34_self$jscomp$189$$,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1146$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6603$borderRadiusTopRight$$,$value$jscomp$1146$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$34_self$jscomp$189$$],null),function($p1__87897_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__87897_SHARP_$$,$APP.$cljs$cst$1652$r2$$,$value$jscomp$1146$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6603$borderRadiusTopRight$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6603$borderRadiusTopRight$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiustopright_88181$$)}catch($e88774$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88774$$)}}});Object.defineProperty($obj_88036$$,"borderRadiusBottomRight",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1653$r3$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88827$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88827$$)}},
set:function($val_borderradiusbottomright_88189$$){try{return function($id__$1$jscomp$35_self$jscomp$190$$,$value$jscomp$1147$$){$id__$1$jscomp$35_self$jscomp$190$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$35_self$jscomp$190$$,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1147$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6604$borderRadiusBottomRight$$,$value$jscomp$1147$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$35_self$jscomp$190$$],null),function($p1__87899_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__87899_SHARP_$$,$APP.$cljs$cst$1653$r3$$,
$value$jscomp$1147$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6604$borderRadiusBottomRight$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6604$borderRadiusBottomRight$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiusbottomright_88189$$)}catch($e88828$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88828$$)}}});Object.defineProperty($obj_88036$$,
"borderRadiusBottomLeft",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1654$r4$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88829$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88829$$)}},set:function($val_borderradiusbottomleft_88197$$){try{return function($id__$1$jscomp$36_self$jscomp$191$$,$value$jscomp$1148$$){$id__$1$jscomp$36_self$jscomp$191$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$36_self$jscomp$191$$,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1148$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6605$borderRadiusBottomLeft$$,$value$jscomp$1148$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$36_self$jscomp$191$$],null),function($p1__87901_SHARP_$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($p1__87901_SHARP_$$,$APP.$cljs$cst$1654$r4$$,$value$jscomp$1148$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6605$borderRadiusBottomLeft$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6605$borderRadiusBottomLeft$$,
"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_borderradiusbottomleft_88197$$)}catch($e88830$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88830$$)}}});Object.defineProperty($obj_88036$$,"opacity",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88833$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88833$$)}},set:function($val_opacity_88205$$){try{return function($id__$1$jscomp$37_self$jscomp$192$$,
$value$jscomp$1149$$){$id__$1$jscomp$37_self$jscomp$192$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$37_self$jscomp$192$$,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1149$$))||$value$jscomp$1149$$<0||$value$jscomp$1149$$>1?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1740$opacity$$,$value$jscomp$1149$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?
$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$37_self$jscomp$192$$],null),function($p1__87926_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87926_SHARP_$$,$APP.$cljs$cst$1740$opacity$$,$value$jscomp$1149$$)})):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1740$opacity$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1740$opacity$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_opacity_88205$$)}catch($e88840$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88840$$)}}});Object.defineProperty($obj_88036$$,"blendMode",{enumerable:!0,get:function(){try{return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1874$blend_mode$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$APP.$cljs$cst$2033$normal$$))}catch($e88867$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88867$$)}},set:function($val_blendmode_88213$$){try{return function($id__$1$jscomp$38_self$jscomp$193$$,$value$jscomp$1150$$){$id__$1$jscomp$38_self$jscomp$193$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$38_self$jscomp$193$$,"$id");var $value__$1$jscomp$124$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1150$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$types$shape$blend_modes$$,
$value__$1$jscomp$124$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$38_self$jscomp$193$$],null),function($p1__87928_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87928_SHARP_$$,
$APP.$cljs$cst$1874$blend_mode$$,$value__$1$jscomp$124$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6606$blendMode$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6606$blendMode$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6606$blendMode$$,$value__$1$jscomp$124$$)}.call(this,this,$val_blendmode_88213$$)}catch($e88868$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88868$$)}}});
Object.defineProperty($obj_88036$$,"shadows",{enumerable:!0,get:function(){function $internal_fn_shadows_88216$$($self$jscomp$194$$){return $app$plugins$shadows$format_shadows$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1659$shadow$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($self$jscomp$194$$)),function($p1__87931_SHARP_$$){return $app$plugins$shape$commit_shadows_BANG_$$($plugin_id$jscomp$40$$,$self$jscomp$194$$,$p1__87931_SHARP_$$)})}try{return $internal_fn_shadows_88216$$.call(this,
this)}catch($e88869$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88869$$)}},set:function($val_shadows_88221$$){try{return $app$plugins$shape$commit_shadows_BANG_$$($plugin_id$jscomp$40$$,this,$val_shadows_88221$$)}catch($e88870$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88870$$)}}});Object.defineProperty($obj_88036$$,"blur",{enumerable:!0,get:function(){try{return $app$plugins$format$format_blur$$($APP.$cljs$cst$1658$blur$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88871$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88871$$)}},
set:function($val_blur_88229$$){try{return function($id__$1$jscomp$39_self$jscomp$196$$,$value$jscomp$1152_value__$1$jscomp$125$$){if($value$jscomp$1152_value__$1$jscomp$125$$==null)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),function($p1__87933_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__87933_SHARP_$$,
$APP.$cljs$cst$1658$blur$$)}));$id__$1$jscomp$39_self$jscomp$196$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$39_self$jscomp$196$$,"$id");$value$jscomp$1152_value__$1$jscomp$125$$=$app$plugins$shape$blur_defaults$$($app$plugins$parser$parse_blur$$($value$jscomp$1152_value__$1$jscomp$125$$));var $value__$2$jscomp$10$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$1152_value__$1$jscomp$125$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1925$layer_blur$$);
return $APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$blur$schema_COLON_blur$$,$value__$2$jscomp$10$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1658$blur$$,$value__$2$jscomp$10$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$39_self$jscomp$196$$],null),function($p1__87934_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87934_SHARP_$$,$APP.$cljs$cst$1658$blur$$,$value__$2$jscomp$10$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1658$blur$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1658$blur$$,"Plugin doesn't have 'content:write' permission")}.call(this,
this,$val_blur_88229$$)}catch($e88872$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88872$$)}}});Object.defineProperty($obj_88036$$,"backgroundBlur",{enumerable:!0,get:function(){try{return $app$plugins$format$format_blur$$($APP.$cljs$cst$1197$background_blur$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88873$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88873$$)}},set:function($val_backgroundblur_88237$$){try{return function($id__$1$jscomp$40_self$jscomp$197$$,
$value$jscomp$1153_value__$1$jscomp$126$$){if($value$jscomp$1153_value__$1$jscomp$126$$==null)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),function($p1__87939_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__87939_SHARP_$$,$APP.$cljs$cst$1197$background_blur$$)}));
$id__$1$jscomp$40_self$jscomp$197$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$40_self$jscomp$197$$,"$id");$value$jscomp$1153_value__$1$jscomp$126$$=$app$plugins$shape$background_blur_defaults$$($app$plugins$parser$parse_blur$$($value$jscomp$1153_value__$1$jscomp$126$$));var $value__$2$jscomp$11$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$1153_value__$1$jscomp$126$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1197$background_blur$$);return $APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$background_blur$schema_COLON_background_blur$$,
$value__$2$jscomp$11$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1197$background_blur$$,$value__$2$jscomp$11$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id__$1$jscomp$40_self$jscomp$197$$],null),function($p1__87943_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__87943_SHARP_$$,$APP.$cljs$cst$1197$background_blur$$,$value__$2$jscomp$11$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1197$background_blur$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1197$background_blur$$,"Plugin doesn't have 'content:write' permission")}.call(this,
this,$val_backgroundblur_88237$$)}catch($e88874$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88874$$)}}});Object.defineProperty($obj_88036$$,"exports",{enumerable:!0,get:function(){function $internal_fn_exports_88240$$($self$jscomp$198$$){return $app$plugins$exports$format_exports$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1877$exports$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($self$jscomp$198$$)),function($p1__87947_SHARP_$$){return $app$plugins$shape$commit_exports_BANG_$$($plugin_id$jscomp$40$$,
$self$jscomp$198$$,$p1__87947_SHARP_$$)})}try{return $internal_fn_exports_88240$$.call(this,this)}catch($e88875$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88875$$)}},set:function($val_exports_88245$$){try{return $app$plugins$shape$commit_exports_BANG_$$($plugin_id$jscomp$40$$,this,$val_exports_88245$$)}catch($e88876$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88876$$)}}});Object.defineProperty($obj_88036$$,"x",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))))}catch($e88877$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88877$$)}},
set:function($val_x_88253$$){try{var $id__$1$jscomp$inline_10663$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_x_88253$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1515$x$$,$val_x_88253$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10663$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1515$x$$,$val_x_88253$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3948$absolute_QMARK_$$,!0],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1515$x$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1515$x$$,"Plugin doesn't have 'content:write' permission")}catch($e88878$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88878$$)}}});
Object.defineProperty($obj_88036$$,"y",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))))}catch($e88879$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88879$$)}},set:function($val_y_88261$$){try{var $id__$1$jscomp$inline_10667$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id");return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($val_y_88261$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1516$y$$,$val_y_88261$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$inline_10667$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1516$y$$,$val_y_88261$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3948$absolute_QMARK_$$,!0],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1516$y$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1516$y$$,"Plugin doesn't have 'content:write' permission")}catch($e88880$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88880$$)}}});
Object.defineProperty($obj_88036$$,"parent",{enumerable:!1,get:function(){try{var $shape$jscomp$inline_10670$$=$app$plugins$utils$proxy__GT_shape$$(this);if($APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$inline_10670$$))var $JSCompiler_inline_result$jscomp$2304$$=null;else{var $parent_id$jscomp$inline_10671$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10670$$);$JSCompiler_inline_result$jscomp$2304$$=$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10671$$)}return $JSCompiler_inline_result$jscomp$2304$$}catch($e88881$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88881$$)}}});Object.defineProperty($obj_88036$$,"parentIndex",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10674$$=$app$plugins$utils$proxy__GT_shape$$(this);if($APP.$app$common$files$helpers$root_QMARK_$$($shape$jscomp$inline_10674$$))var $JSCompiler_inline_result$jscomp$2305$$=
0;else{var $parent$jscomp$inline_10675$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10674$$));$JSCompiler_inline_result$jscomp$2305$$=$APP.$app$common$data$index_of$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10675$$),$id$jscomp$1129$$)}return $JSCompiler_inline_result$jscomp$2305$$}catch($e88882$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88882$$)}}});
Object.defineProperty($obj_88036$$,"parentX",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10678$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_x$jscomp$inline_10679$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10678$$))),$parent_id$jscomp$inline_10680$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10678$$),
$parent$jscomp$inline_10681$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10680$$);return $shape_x$jscomp$inline_10679$$-$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10681$$)}catch($e88883$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88883$$)}},set:function($val_parentx_88283$$){try{return function($parent$jscomp$313_parent_x_self$jscomp$205$$,
$value$jscomp$1157$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1157$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6607$parentX$$,$value$jscomp$1157$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $id__$1$jscomp$43$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$313_parent_x_self$jscomp$205$$,
"$id"),$parent_id$jscomp$118$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($parent$jscomp$313_parent_x_self$jscomp$205$$));$parent$jscomp$313_parent_x_self$jscomp$205$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$313_parent_x_self$jscomp$205$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$313_parent_x_self$jscomp$205$$,"$page"),$parent_id$jscomp$118$$);
$parent$jscomp$313_parent_x_self$jscomp$205$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$313_parent_x_self$jscomp$205$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$43$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1515$x$$,$parent$jscomp$313_parent_x_self$jscomp$205$$+$value$jscomp$1157$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3948$absolute_QMARK_$$,!0],null)))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6607$parentX$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6607$parentX$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_parentx_88283$$)}catch($e88884$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88884$$)}}});Object.defineProperty($obj_88036$$,"parentY",
{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10684$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_y$jscomp$inline_10685$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10684$$))),$parent_id$jscomp$inline_10686$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10684$$),$parent$jscomp$inline_10687$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$parent_id$jscomp$inline_10686$$),$parent_y$jscomp$inline_10688$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_10687$$);return $shape_y$jscomp$inline_10685$$-$parent_y$jscomp$inline_10688$$}catch($e88885$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88885$$)}},set:function($val_parenty_88291$$){try{return function($parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$,
$value$jscomp$1158$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1158$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6608$parentY$$,$value$jscomp$1158$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $id__$1$jscomp$44$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$,
"$id"),$parent_id$jscomp$120$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$));$parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$,
"$page"),$parent_id$jscomp$120$$);$parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$44$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1516$y$$,$parent$jscomp$315_parent_y$jscomp$1_self$jscomp$207$$+
$value$jscomp$1158$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3948$absolute_QMARK_$$,!0],null)))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6608$parentY$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6608$parentY$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_parenty_88291$$)}catch($e88886$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88886$$)}}});
Object.defineProperty($obj_88036$$,"boardX",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10691$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_x$jscomp$inline_10692$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10691$$))),$frame_id$jscomp$inline_10693$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10691$$),
$frame$jscomp$inline_10694$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$frame_id$jscomp$inline_10693$$),$frame_x$jscomp$inline_10695$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_10694$$);return $shape_x$jscomp$inline_10692$$-$frame_x$jscomp$inline_10695$$}catch($e88887$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88887$$)}},
set:function($val_boardx_88299$$){try{return function($frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$,$value$jscomp$1159$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1159$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6609$frameX$$,$value$jscomp$1159$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $id__$1$jscomp$45$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$,"$id"),$frame_id$jscomp$174$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$));$frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$,
"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$,"$page"),$frame_id$jscomp$174$$);$frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$45$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1515$x$$,$frame$jscomp$126_frame_x$jscomp$4_self$jscomp$209$$+$value$jscomp$1159$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3948$absolute_QMARK_$$,!0],null)))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6609$frameX$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6609$frameX$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_boardx_88299$$)}catch($e88888$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88888$$)}}});
Object.defineProperty($obj_88036$$,"boardY",{enumerable:!0,get:function(){try{var $shape$jscomp$inline_10698$$=$app$plugins$utils$proxy__GT_shape$$(this),$shape_y$jscomp$inline_10699$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10698$$))),$frame_id$jscomp$inline_10700$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$inline_10698$$),
$frame$jscomp$inline_10701$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$frame_id$jscomp$inline_10700$$),$frame_y$jscomp$inline_10702$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$inline_10701$$);return $shape_y$jscomp$inline_10699$$-$frame_y$jscomp$inline_10702$$}catch($e88889$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88889$$)}},
set:function($val_boardy_88307$$){try{return function($frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$,$value$jscomp$1160$$){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1160$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6610$frameY$$,$value$jscomp$1160$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $id__$1$jscomp$46$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$,"$id"),$frame_id$jscomp$176$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$));$frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$=$app$plugins$utils$locate_shape$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$,
"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$,"$page"),$frame_id$jscomp$176$$);$frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_position$$.$cljs$core$IFn$_invoke$arity$3$($id__$1$jscomp$46$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1516$y$$,$frame$jscomp$128_frame_y$jscomp$4_self$jscomp$211$$+$value$jscomp$1160$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3948$absolute_QMARK_$$,!0],null)))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6610$frameY$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6610$frameY$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_boardy_88307$$)}catch($e88890$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88890$$)}}});
Object.defineProperty($obj_88036$$,"width",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88891$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88891$$)}}});Object.defineProperty($obj_88036$$,"height",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88892$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88892$$)}}});
Object.defineProperty($obj_88036$$,"bounds",{enumerable:!0,get:function(){try{return $app$plugins$format$format_bounds$$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))))}catch($e88893$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88893$$)}}});Object.defineProperty($obj_88036$$,"center",{enumerable:!0,get:function(){try{var $param49155$jscomp$inline_14267$$=$app$plugins$utils$proxy__GT_shape$$(this);
var $JSCompiler_inline_result$jscomp$11062$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($param49155$jscomp$inline_14267$$);return $app$plugins$format$format_point$$($JSCompiler_inline_result$jscomp$11062$$)}catch($e88894$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88894$$)}}});Object.defineProperty($obj_88036$$,"rotation",{enumerable:!0,get:function(){try{return $APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this))}catch($e88895$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88895$$)}},
set:function($val_rotation_88343$$){try{return function($self$jscomp$212_shape$jscomp$1147$$,$value$jscomp$1161$$){return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1161$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1794$rotation$$,$value$jscomp$1161$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?($self$jscomp$212_shape$jscomp$1147$$=
$app$plugins$utils$proxy__GT_shape$$($self$jscomp$212_shape$jscomp$1147$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self$jscomp$212_shape$jscomp$1147$$)]),$value$jscomp$1161$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1794$rotation$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1794$rotation$$,"Plugin doesn't have 'content:write' permission")}.call(this,this,$val_rotation_88343$$)}catch($e88896$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88896$$)}}});Object.defineProperty($obj_88036$$,"flipX",{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88897$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88897$$)}},
set:function($val_flipx_88351$$){try{return $APP.$cljs$core$boolean_QMARK_$$($val_flipx_88351$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$id")]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6611$flipX$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6611$flipX$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6611$flipX$$,$val_flipx_88351$$)}catch($e88898$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88898$$)}}});Object.defineProperty($obj_88036$$,"flipY",
{enumerable:!0,get:function(){try{return $APP.$cljs$core$boolean$0$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))}catch($e88899$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88899$$)}},set:function($val_flipy_88359$$){try{return $APP.$cljs$core$boolean_QMARK_$$($val_flipy_88359$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id")]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6612$flipY$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6612$flipY$$,"Plugin doesn't have 'content:write' permission"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6612$flipY$$,$val_flipy_88359$$)}catch($e88900$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88900$$)}}});Object.defineProperty($obj_88036$$,"fills",{enumerable:!0,get:function(){function $internal_fn_fills_88362$$($self$jscomp$215$$){var $fill_data$jscomp$5$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)?$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$shape$text_props$$($app$plugins$utils$proxy__GT_shape$$($self$jscomp$215$$))):
$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($self$jscomp$215$$));return $app$plugins$fills$format_fills$cljs$0core$0IFn$0_invoke$0arity$02$$($fill_data$jscomp$5$$,function($p1__87979_SHARP_$$){return $app$plugins$shape$commit_fills_BANG_$$($plugin_id$jscomp$40$$,$self$jscomp$215$$,$p1__87979_SHARP_$$)})}try{return $internal_fn_fills_88362$$.call(this,this)}catch($e88901$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88901$$)}},
set:function($val_fills_88367$$){try{return $app$plugins$shape$commit_fills_BANG_$$($plugin_id$jscomp$40$$,this,$val_fills_88367$$)}catch($e88902$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88902$$)}}});Object.defineProperty($obj_88036$$,"strokes",{enumerable:!0,get:function(){function $internal_fn_strokes_88370$$($self$jscomp$217$$){return $app$plugins$strokes$format_strokes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1641$strokes$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($self$jscomp$217$$)),
function($p1__87980_SHARP_$$){return $app$plugins$shape$commit_strokes_BANG_$$($plugin_id$jscomp$40$$,$self$jscomp$217$$,$p1__87980_SHARP_$$)})}try{return $internal_fn_strokes_88370$$.call(this,this)}catch($e88903$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88903$$)}},set:function($val_strokes_88375$$){try{return $app$plugins$shape$commit_strokes_BANG_$$($plugin_id$jscomp$40$$,this,$val_strokes_88375$$)}catch($e88904$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88904$$)}}});
Object.defineProperty($obj_88036$$,"layoutChild",{enumerable:!0,get:function(){try{var $file_id__$1$jscomp$inline_10711$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10712$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$id__$1$jscomp$inline_10713$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$objects$jscomp$inline_10714$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id__$1$jscomp$inline_10711$$,
$page_id__$1$jscomp$inline_10712$$);return $APP.$app$common$types$shape$layout$any_layout_immediate_child_id_QMARK_$$($objects$jscomp$inline_10714$$,$id__$1$jscomp$inline_10713$$)?$app$plugins$flex$layout_child_proxy$$($plugin_id$jscomp$40$$,$file_id__$1$jscomp$inline_10711$$,$page_id__$1$jscomp$inline_10712$$,$id__$1$jscomp$inline_10713$$):null}catch($e88905$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88905$$)}}});Object.defineProperty($obj_88036$$,"layoutCell",{enumerable:!0,
get:function(){try{var $file_id__$1$jscomp$inline_10717$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10718$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$id__$1$jscomp$inline_10719$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id"),$objects$jscomp$inline_14269$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id__$1$jscomp$inline_10717$$,$page_id__$1$jscomp$inline_10718$$),
$parent_id$jscomp$inline_14271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_14269$$,$id__$1$jscomp$inline_10719$$),$APP.$cljs$cst$1624$parent_id$$),$parent$jscomp$inline_14272$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_14269$$,$parent_id$jscomp$inline_14271$$);return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$inline_14272$$)?
$app$plugins$grid$layout_cell_proxy$$($plugin_id$jscomp$40$$,$file_id__$1$jscomp$inline_10717$$,$page_id__$1$jscomp$inline_10718$$,$id__$1$jscomp$inline_10719$$):null}catch($e88906$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88906$$)}}});Object.defineProperty($obj_88036$$,"interactions",{enumerable:!0,get:function(){function $internal_fn_interactions_88392$$($interactions$jscomp$26_self$jscomp$221$$){$interactions$jscomp$26_self$jscomp$221$$=$APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$($interactions$jscomp$26_self$jscomp$221$$));
return $app$plugins$format$format_array$$(function($p1__87981_SHARP_$$){return $app$plugins$shape$interaction_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$,$p1__87981_SHARP_$$)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(0,$APP.$cljs$core$count$$($interactions$jscomp$26_self$jscomp$221$$)))}try{return $internal_fn_interactions_88392$$.call(this,this)}catch($e88907$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88907$$)}}});
Object.defineProperty($obj_88036$$,"resize",{enumerable:!1,get:function(){return function($width$jscomp$264$$,$height$jscomp$228$$){try{if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($width$jscomp$264$$))||$width$jscomp$264$$<=0)return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1805$resize$$,$width$jscomp$264$$);if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($height$jscomp$228$$))||$height$jscomp$228$$<=0)return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$APP.$cljs$cst$1805$resize$$,$height$jscomp$228$$);if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $shape$jscomp$1148$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$objects$jscomp$870$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$layout_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$870$$,
$shape$jscomp$1148$$)||$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1148$$),$sizing$jscomp$3$$=function(){var $G__88909_G__88909__$1$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__88909_G__88909__$1$$=$layout_QMARK_$jscomp$1$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1148$$),$APP.$cljs$cst$1702$fix$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__88909_G__88909__$1$$,
$APP.$cljs$cst$1713$layout_item_h_sizing$$,$APP.$cljs$cst$1702$fix$$):$G__88909_G__88909__$1$$;return $layout_QMARK_$jscomp$1$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1148$$),$APP.$cljs$cst$1702$fix$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__88909_G__88909__$1$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$,$APP.$cljs$cst$1702$fix$$):$G__88909_G__88909__$1$$}();return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,
function(){var $G__88910_G__88910__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__88910_G__88910__$1$$=$APP.$cljs$core$seq$$($sizing$jscomp$3$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__88910_G__88910__$1$$,$APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$]),$sizing$jscomp$3$$)):$G__88910_G__88910__$1$$;return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__88910_G__88910__$1$$,
$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),$APP.$cljs$cst$290$width$$,$width$jscomp$264$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],
null),$APP.$cljs$cst$1527$height$$,$height$jscomp$228$$)]))}())}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1805$resize$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1805$resize$$,"Plugin doesn't have 'content:write' permission")}catch($e88908$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88908$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"rotate",{enumerable:!1,
get:function(){return function($angle$jscomp$45$$,$center$jscomp$57$$){try{var $center__$1$jscomp$6$$=$APP.$cljs$core$truth_$$($center$jscomp$57$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($center$jscomp$57$$,"x"),$APP.$cljs$cst$1516$y$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($center$jscomp$57$$,"y")],null):null;return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($angle$jscomp$45$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6613$rotate_angle$$,$angle$jscomp$45$$):$center__$1$jscomp$6$$!=null&&($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($center__$1$jscomp$6$$)))||$APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center__$1$jscomp$6$$))))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6614$rotate_center$$,$center__$1$jscomp$6$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$increase_rotation$$)(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),$angle$jscomp$45$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1672$center$$,$center__$1$jscomp$6$$,$APP.$cljs$cst$3912$delta_QMARK_$$,!0],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2874$rotate$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2874$rotate$$,"Plugin doesn't have 'content:write' permission")}catch($e88911$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88911$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,
"clone",{enumerable:!1,get:function(){return function(){try{var $ret_v$jscomp$1$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);return $app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$duplicate_shapes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$]),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3669$change_selection_QMARK_$$,!1,$APP.$cljs$cst$3670$return_ref$$,$ret_v$jscomp$1$$]))),$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$40$$,$APP.$cljs$core$_deref$$($ret_v$jscomp$1$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6615$clone$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6615$clone$$,
"Plugin doesn't have 'content:write' permission")}catch($e88912$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88912$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"remove",{enumerable:!1,get:function(){return function(){try{return $app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$]))):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2601$remove$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'content:write' permission")}catch($e88913$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88913$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$441$$){try{if(typeof $key$jscomp$441$$!==
"string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6616$getPluginData$$,$key$jscomp$441$$);var $shape$jscomp$1149$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1149$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$40$$))),$key$jscomp$441$$)}catch($e88914$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88914$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$442$$,$value$jscomp$1166$$){try{return typeof $key$jscomp$442$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6617$setPluginData_key$$,$key$jscomp$442$$):$value$jscomp$1166$$!=
null&&typeof $value$jscomp$1166$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1166$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$485$$,$APP.$cljs$cst$1817$shape$$,$id$jscomp$1129$$,
$page_id$jscomp$500$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$40$$)),$key$jscomp$442$$,$value$jscomp$1166$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6619$setPluginData$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6619$setPluginData$$,"Plugin doesn't have 'content:write' permission")}catch($e88915$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88915$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1150$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1150$$,$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$40$$)))))}catch($e88916$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88916$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$18$$,$key$jscomp$443$$){try{if(typeof $namespace$jscomp$18$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6620$getSharedPluginData_namespace$$,$namespace$jscomp$18$$);if(typeof $key$jscomp$443$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6621$getSharedPluginData_key$$,$key$jscomp$443$$);var $shape$jscomp$1151$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1151$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$18$$)),$key$jscomp$443$$)}catch($e88917$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88917$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$19$$,$key$jscomp$444$$,$value$jscomp$1167$$){try{return typeof $namespace$jscomp$19$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$19$$):typeof $key$jscomp$444$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6623$setSharedPluginData_key$$,$key$jscomp$444$$):$value$jscomp$1167$$!=null&&typeof $value$jscomp$1167$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1167$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$07$$($file_id$jscomp$485$$,$APP.$cljs$cst$1817$shape$$,$id$jscomp$1129$$,$page_id$jscomp$500$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$19$$),$key$jscomp$444$$,$value$jscomp$1167$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6625$setSharedPluginData$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6625$setSharedPluginData$$,"Plugin doesn't have 'content:write' permission")}catch($e88918$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88918$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$20$$){try{if(typeof $namespace$jscomp$20$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6626$getSharedPluginDataKeys$$,
$namespace$jscomp$20$$);var $shape$jscomp$1152$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1152$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$20$$))))}catch($e88919$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88919$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"getChildren",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1153$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1153$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1153$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1153$$)||
$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1153$$)){var $is_reversed_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1153$$),$reverse_fn$$=$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$40$$)&&$is_reversed_QMARK_$$?$APP.$cljs$core$reverse$$:$APP.$cljs$core$identity$$;return $app$plugins$format$format_array$$(function($p1__87989_SHARP_$$){return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,
$file_id$jscomp$485$$,$page_id$jscomp$500$$,$p1__87989_SHARP_$$)},function(){var $G__88921$$=$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$));return $reverse_fn$$.$cljs$core$IFn$_invoke$arity$1$?$reverse_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__88921$$):$reverse_fn$$($G__88921$$)}())}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6627$getChildren$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1153$$))}catch($e88920$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88920$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"appendChild",{enumerable:!1,get:function(){return function($child$jscomp$128$$){try{var $shape$jscomp$1154$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$valid_child_QMARK_$jscomp$2$$=$app$plugins$shape$shape_proxy_QMARK_$$($child$jscomp$128$$),$child_page$jscomp$2$$=$valid_child_QMARK_$jscomp$2$$?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$128$$,"$page"):null,$child_id$jscomp$14$$=
$valid_child_QMARK_$jscomp$2$$?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$128$$,"$id"):null,$objects$jscomp$871$$=$valid_child_QMARK_$jscomp$2$$?$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$):null,$child_shape$jscomp$3$$=$valid_child_QMARK_$jscomp$2$$?$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$child_id$jscomp$14$$):null,$is_reversed_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$),
$index$jscomp$616$$=!$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$40$$)||$is_reversed_QMARK_$jscomp$1$$?0:$APP.$cljs$core$count$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$));return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$)||
$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1154$$)?$valid_child_QMARK_$jscomp$2$$?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)&&$app$plugins$utils$page_active_QMARK_$$($child_page$jscomp$2$$)?$app$plugins$utils$changes_component_copy_structure_QMARK_$$($objects$jscomp$871$$,$shape$jscomp$1154$$,$child_shape$jscomp$3$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6506$appendChild$$,
"Cannot change the structure of a component copy"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child_id$jscomp$14$$]),$id$jscomp$1129$$,$index$jscomp$616$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$)?
"add-layout-element":"add-element",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($child_shape$jscomp$3$$),$APP.$cljs$cst$3674$parent_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$)]))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6506$appendChild$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6506$appendChild$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6545$appendChild_child$$,$child$jscomp$128$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6506$appendChild$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1154$$))}catch($e88922$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88922$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"insertChild",
{enumerable:!1,get:function(){return function($index$jscomp$617$$,$child$jscomp$129$$){try{var $shape$jscomp$1155$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$valid_child_QMARK_$jscomp$3$$=$app$plugins$shape$shape_proxy_QMARK_$$($child$jscomp$129$$),$child_page$jscomp$3$$=$valid_child_QMARK_$jscomp$3$$?$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$129$$,"$page"):null,$child_id$jscomp$15$$=$valid_child_QMARK_$jscomp$3$$?
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($child$jscomp$129$$,"$id"):null,$objects$jscomp$872$$=$valid_child_QMARK_$jscomp$3$$?$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$):null,$child_shape$jscomp$4$$=$valid_child_QMARK_$jscomp$3$$?$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$child_id$jscomp$15$$):null,$is_reversed_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$),
$index__$1$jscomp$26$$=!$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$40$$)||$is_reversed_QMARK_$jscomp$2$$?$APP.$cljs$core$count$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$))-$index$jscomp$617$$:$index$jscomp$617$$;return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$)||
$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1155$$)?$valid_child_QMARK_$jscomp$3$$?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)&&$app$plugins$utils$page_active_QMARK_$$($child_page$jscomp$3$$)?$app$plugins$utils$changes_component_copy_structure_QMARK_$$($objects$jscomp$872$$,$shape$jscomp$1155$$,$child_shape$jscomp$4$$)?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6628$insertChild$$,
"Cannot change the structure of a component copy"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$relocate_shapes$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$child_id$jscomp$15$$]),$id$jscomp$1129$$,$index__$1$jscomp$26$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$)?
"add-layout-element":"add-element",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($child_shape$jscomp$4$$),$APP.$cljs$cst$3674$parent_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$)]))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6628$insertChild$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6628$insertChild$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6629$insertChild_child$$,$child$jscomp$129$$):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6628$insertChild$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1155$$))}catch($e88923$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88923$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"addFlexLayout",
{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1156$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1156$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$1129$$,
$APP.$cljs$cst$1665$flex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4462$from_frame_QMARK_$$,!0,$APP.$cljs$cst$4463$calculate_params_QMARK_$$,!1])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,"create-shape-layout",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1620$layout$$,"flex"]))])),$app$plugins$flex$flex_layout_proxy$$($plugin_id$jscomp$40$$,
$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6630$addFlexLayout$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6630$addFlexLayout$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6630$addFlexLayout$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1156$$))}catch($e88924$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88924$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"addGridLayout",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1157$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1157$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shape_layout$create_layout_from_id$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($id$jscomp$1129$$,
$APP.$cljs$cst$1664$grid$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4462$from_frame_QMARK_$$,!0,$APP.$cljs$cst$4463$calculate_params_QMARK_$$,!1])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,"create-shape-layout",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1620$layout$$,"grid"]))])),$app$plugins$grid$grid_layout_proxy$$($plugin_id$jscomp$40$$,
$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6631$addGridLayout$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6631$addGridLayout$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6631$addGridLayout$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1157$$))}catch($e88925$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88925$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"makeMask",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1158$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1158$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$groups$mask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$])),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,"create-shape",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$139$type$$,"mask"]))])):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6632$makeMask$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6632$makeMask$$,"Plugin doesn't have 'content:write' permission"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6632$makeMask$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1158$$))}catch($e88926$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88926$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"removeMask",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1159$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1159$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$groups$unmask_group$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$]))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6633$removeMask$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6633$removeMask$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6633$removeMask$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1159$$))}catch($e88927$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88927$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"isMask",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1160$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$cljs$core$boolean$0$$($APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1160$$))}catch($e88928$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88928$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"toD",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1161$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,
$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1161$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$1161$$)?$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1161$$).toString():$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6634$toD$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1161$$))}catch($e88929$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88929$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"getRange",{enumerable:!1,get:function(){return function($start$jscomp$258$$,$end$jscomp$114$$){try{var $shape$jscomp$1162$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1162$$)){if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($start$jscomp$258$$))||$start$jscomp$258$$<0||$start$jscomp$258$$>
$end$jscomp$114$$)return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6636$getRange_start$$,$start$jscomp$258$$);if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($end$jscomp$114$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6637$getRange_end$$,$end$jscomp$114$$);var $y__5114__auto__$jscomp$inline_10722$$=$APP.$cljs$core$count$$($APP.$app$common$types$text$content__GT_text$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1162$$)));
return $app$plugins$text$text_range_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$,$start$jscomp$258$$,$end$jscomp$114$$<$y__5114__auto__$jscomp$inline_10722$$?$end$jscomp$114$$:$y__5114__auto__$jscomp$inline_10722$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6635$getRange_shape$$,"shape is not text")}catch($e88930$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88930$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,
"applyTypography",{enumerable:!1,get:function(){return function($typography$jscomp$42$$){try{var $shape$jscomp$1163$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$cljs$core$not$$($app$plugins$shape$lib_typography_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$app$plugins$shape$lib_typography_proxy_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$42$$):$app$plugins$shape$lib_typography_proxy_QMARK_$$($typography$jscomp$42$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6638$applyTypography_typography$$,$typography$jscomp$42$$);if($APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1163$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $typography__$1$jscomp$6$$=$app$plugins$utils$proxy__GT_library_typography$$($typography$jscomp$42$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$]),
$typography__$1$jscomp$6$$,$file_id$jscomp$485$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6640$applyTypography$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6640$applyTypography$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6639$applyTypography_shape$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1163$$))}catch($e88931$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88931$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"setParentIndex",{enumerable:!1,get:function(){return function($index$jscomp$618$$){try{var $objects$jscomp$873$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$shape$jscomp$1164$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$873$$,$id$jscomp$1129$$);return $APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_int_QMARK_$$)($index$jscomp$618$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6641$setParentIndex$$,$index$jscomp$618$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$cljs$core$boolean$0$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$873$$,$shape$jscomp$1164$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6641$setParentIndex$$,"Cannot change the structure of a component copy"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_shape_index$$($file_id$jscomp$485$$,
$page_id$jscomp$500$$,$id$jscomp$1129$$,$index$jscomp$618$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6641$setParentIndex$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6641$setParentIndex$$,"Plugin doesn't have 'content:write' permission")}catch($e88932$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88932$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"bringForward",{enumerable:!1,
get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$shape$z_order_location$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$,$APP.$cljs$cst$1970$up$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null)))}catch($e88933$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88933$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"sendBackward",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$shape$z_order_location$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$,$APP.$cljs$cst$1969$down$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$1129$$],null)))}catch($e88934$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88934$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"bringToFront",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$shape$z_order_location$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,
$id$jscomp$1129$$,$APP.$cljs$cst$1567$top$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null)))}catch($e88935$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88935$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"sendToBack",{enumerable:!1,get:function(){return function(){try{return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$shape$z_order_location$$($plugin_id$jscomp$40$$,
$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$,$APP.$cljs$cst$1568$bottom$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null)))}catch($e88936$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88936$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"isComponentInstance",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1165$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,
$page_id$jscomp$500$$,$id$jscomp$1129$$),$objects$jscomp$874$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$);return $APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$874$$,$shape$jscomp$1165$$)}catch($e88937$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88937$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"isComponentMainInstance",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1166$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$objects$jscomp$875$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$);return $APP.$app$common$types$container$find_component_main$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$875$$,$shape$jscomp$1166$$,!0)!=null}catch($e88938$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88938$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,
"isComponentCopyInstance",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1167$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$1167$$)}catch($e88939$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88939$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"isComponentRoot",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1168$$=
$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$types$component$instance_root_QMARK_$$($shape$jscomp$1168$$)}catch($e88940$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88940$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"isComponentHead",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1169$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);
return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$1169$$)}catch($e88941$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88941$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"componentRefShape",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$876$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$shape$jscomp$1170$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,
$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$876$$,$shape$jscomp$1170$$))){var $vec__88943$$=$app$plugins$utils$locate_component$$($objects$jscomp$876$$,$shape$jscomp$1170$$),$root$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__88943$$,0,null),$component$jscomp$139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__88943$$,1,null),$component_page_id$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$139$$),
$component_file$jscomp$8$$=$app$plugins$utils$locate_file$$($APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$69$$)),$ref_shape$jscomp$9$$=$APP.$app$common$types$file$get_ref_shape$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$8$$),$component$jscomp$139$$,$shape$jscomp$1170$$);return $APP.$cljs$core$not$$($APP.$cljs$cst$2552$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$139$$))&&$ref_shape$jscomp$9$$!=null&&$component_file$jscomp$8$$!=
null?$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_file$jscomp$8$$),$component_page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ref_shape$jscomp$9$$)):null}return null}catch($e88942$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88942$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"componentRoot",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$877$$=
$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$shape$jscomp$1171$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$877$$,$shape$jscomp$1171$$))){var $vec__88947$$=$app$plugins$utils$locate_component$$($objects$jscomp$877$$,$shape$jscomp$1171$$),$root$jscomp$70$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__88947$$,
0,null),$component$jscomp$140$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__88947$$,1,null);return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$70$$),$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$140$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root$jscomp$70$$))}return null}catch($e88946$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88946$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"componentHead",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$878$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$shape$jscomp$1172$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$878$$,$shape$jscomp$1172$$))){var $head$jscomp$30$$=
$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$shape$jscomp$1172$$);return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$30$$))}return null}catch($e88950$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88950$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"component",{enumerable:!1,get:function(){return function(){try{var $objects$jscomp$879$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$shape$jscomp$1173$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$cljs$core$truth_$$($APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$879$$,$shape$jscomp$1173$$))){var $state$jscomp$inline_10726$$=
$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file$jscomp$inline_10727$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$inline_10726$$),$libraries$jscomp$inline_10728$$=$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$inline_10726$$),$head$jscomp$inline_10729$$=$APP.$app$common$types$container$get_head_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$879$$,$shape$jscomp$1173$$);var $temp__5825__auto__$jscomp$487$$=$APP.$cljs$core$truth_$$($head$jscomp$inline_10729$$)?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$head$jscomp$inline_10729$$,$APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($head$jscomp$inline_10729$$,$file$jscomp$inline_10727$$,$libraries$jscomp$inline_10728$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2551$include_deleted_QMARK_$$,!0],null)]))],null):null;if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$487$$)){var $head$jscomp$31$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$487$$,0,null),$component$jscomp$141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($temp__5825__auto__$jscomp$487$$,1,null),$G__88956$$=$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$31$$),$G__88957$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$141$$);return $app$plugins$shape$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$shape$lib_component_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$40$$,
$G__88956$$,$G__88957$$):$app$plugins$shape$lib_component_proxy$$($plugin_id$jscomp$40$$,$G__88956$$,$G__88957$$)}}return null}catch($e88951$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88951$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"detach",{enumerable:!1,get:function(){return function(){try{return $app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$detach_component$$($id$jscomp$1129$$)):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$5128$detach$$,"Cannot modify a page that is not currently active")}catch($e88958$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88958$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"swapComponent",{enumerable:!1,get:function(){return function($component$jscomp$142$$){try{var $shape$jscomp$1174$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$util$object$type_of_QMARK_$$($component$jscomp$142$$,"LibraryComponentProxy")?$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$1174$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$component_swap$$($shape$jscomp$1174$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($component$jscomp$142$$,"$file"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($component$jscomp$142$$,
"$id"),!0)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6642$swapComponent$$,"The shape is not a component copy instance"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6642$swapComponent$$,"Component not valid"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6642$swapComponent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6642$swapComponent$$,"Cannot modify a page that is not currently active")}catch($e88959$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88959$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"resetOverrides",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1175$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$1175$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$reset_component$$($id$jscomp$1129$$)):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6643$resetOverrides$$,"The shape is not a component copy instance"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6643$resetOverrides$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6643$resetOverrides$$,"Cannot modify a page that is not currently active")}catch($e88960$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88960$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"export",{enumerable:!1,get:function(){return function($value$jscomp$1168$$){try{var $value__$1$jscomp$127$$=$app$plugins$parser$parse_export$$($value$jscomp$1168$$);if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$export$0$schema_COLON_export$$,$value__$1$jscomp$127$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2185$export$$,$value__$1$jscomp$127$$);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$4190$wasm_export$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1539$png$$,null,$APP.$cljs$cst$1541$webp$$,null,$APP.$cljs$cst$1540$jpeg$$,null],null),null),$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$127$$,$APP.$cljs$cst$1539$png$$))){var $uri$jscomp$116$$=$APP.$app$main$data$exports$wasm$export_image_uri$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$485$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$500$$,$APP.$cljs$cst$2281$object_id$$,$id$jscomp$1129$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$127$$,$APP.$cljs$cst$1539$png$$),$APP.$cljs$cst$1910$scale$$,$APP.$cljs$cst$1910$scale$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$127$$,1)],null));return new Promise(function($resolve$jscomp$44$$,$reject$jscomp$29$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$44$$,
$reject$jscomp$29$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,"export-shapes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1583$method$$,"wasm"])))},$APP.$beicon$v2$core$map$$(function($p1__88013_SHARP_$$){return new Uint8Array($p1__88013_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__88012_SHARP_$$){return $p1__88012_SHARP_$$.arrayBuffer()},
$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1586$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$1584$uri$$,$uri$jscomp$116$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$1596$blob$$,$APP.$cljs$cst$1587$omit_default_headers$$,!0],null)))))))})}var $shape$jscomp$1176$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$payload$jscomp$18$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$4191$export_shapes$$,$APP.$cljs$cst$2321$profile_id$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$APP.$cljs$cst$2290$wait$$,!0,$APP.$cljs$cst$4884$is_wasm$$,!1,$APP.$cljs$cst$1877$exports$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,7,
[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$485$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$500$$,$APP.$cljs$cst$2281$object_id$$,$id$jscomp$1129$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1176$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$127$$,$APP.$cljs$cst$1539$png$$),$APP.$cljs$cst$1376$suffix$$,$APP.$cljs$cst$1376$suffix$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$127$$,
""),$APP.$cljs$cst$1910$scale$$,$APP.$cljs$cst$1910$scale$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$127$$,1)],null)],null)],null);return new Promise(function($resolve$jscomp$45$$,$reject$jscomp$30$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$45$$,$reject$jscomp$30$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$40$$,
"export-shapes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1583$method$$,"exporter"])))},$APP.$beicon$v2$core$map$$(function($p1__88015_SHARP_$$){return new Uint8Array($p1__88015_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__88014_SHARP_$$){return $p1__88014_SHARP_$$.arrayBuffer()},$APP.$beicon$v2$core$mapcat$$(function($map__88963__$1_p__88962_uri$jscomp$117$$){$map__88963__$1_p__88962_uri$jscomp$117$$=$APP.$cljs$core$__destructure_map$$($map__88963__$1_p__88962_uri$jscomp$117$$);
$map__88963__$1_p__88962_uri$jscomp$117$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__88963__$1_p__88962_uri$jscomp$117$$,$APP.$cljs$cst$1584$uri$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$cst$1586$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$1584$uri$$,$map__88963__$1_p__88962_uri$jscomp$117$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$1596$blob$$,$APP.$cljs$cst$1587$omit_default_headers$$,
!0],null)))},$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$data$persistence$wait_persisted$cljs$0core$0IFn$0_invoke$0arity$01$$(5E3)),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2185$export$$,$payload$jscomp$18$$)))))))})}catch($e88961$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88961$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"addInteraction",{enumerable:!1,get:function(){return function($trigger$jscomp$7$$,
$action$jscomp$12$$,$delay$jscomp$10$$){try{var $JSCompiler_temp_const$jscomp$2142$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$;if(typeof $trigger$jscomp$7$$==="string"&&$action$jscomp$12$$!=null){var $trigger__$1$jscomp$inline_10734$$=$app$plugins$parser$parse_keyword$$($trigger$jscomp$7$$),$action__$1$jscomp$inline_10735$$=$app$plugins$parser$parse_action$$($action$jscomp$12$$);var $JSCompiler_inline_result$jscomp$2144$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1562$event_type$$,$trigger__$1$jscomp$inline_10734$$,$APP.$cljs$cst$1330$delay$$,$delay$jscomp$10$$],null),$action__$1$jscomp$inline_10735$$))}else $JSCompiler_inline_result$jscomp$2144$$=null;var $interaction$jscomp$58$$=$JSCompiler_temp_const$jscomp$2142$$.call($APP.$app$common$data$patch_object$$,$APP.$app$common$types$shape$interactions$default_interaction$$,$JSCompiler_inline_result$jscomp$2144$$);if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$shape$interactions$schema_COLON_interaction$$,
$interaction$jscomp$58$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6644$addInteraction$$,$interaction$jscomp$58$$);var $index$jscomp$619$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$APP.$cljs$core$PersistentVector$EMPTY$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$interactions$add_interaction$$($page_id$jscomp$500$$,
$id$jscomp$1129$$,$interaction$jscomp$58$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$40$$,"add-interaction")]));return $app$plugins$shape$interaction_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$,$index$jscomp$619$$)}catch($e88964$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88964$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"removeInteraction",
{enumerable:!1,get:function(){return function($interaction$jscomp$59$$){try{if($app$util$object$type_of_QMARK_$$($interaction$jscomp$59$$,"InteractionProxy")){var $JSCompiler_temp_const$jscomp$1282$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$1284$$=$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1129$$],
null),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($interaction$jscomp$59$$,"$index"));var $JSCompiler_temp$jscomp$1281$$=$JSCompiler_temp_const$jscomp$1282$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1284$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$$($plugin_id$jscomp$40$$,"remove-interaction")]))}else $JSCompiler_temp$jscomp$1281$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6645$removeInteraction$$,
$interaction$jscomp$59$$);return $JSCompiler_temp$jscomp$1281$$}catch($e88965$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88965$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"addRulerGuide",{enumerable:!1,get:function(){return function($orientation$jscomp$9$$,$value$jscomp$1169$$){try{var $shape$jscomp$1177$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);if($APP.$cljs$core$not$$((0,$APP.$app$common$schema$valid_safe_number_QMARK_$$)($value$jscomp$1169$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6646$addRulerGuide$$,"Value not a safe number");if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["vertical",null,"horizontal",null],null),null),$orientation$jscomp$9$$)){if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1177$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $ruler_id$jscomp$2$$=
$APP.$app$common$uuid$next$$(),$axis$jscomp$70$$=$app$plugins$parser$orientation__GT_axis$$($orientation$jscomp$9$$),$objects$jscomp$880$$=$app$plugins$utils$locate_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$485$$,$page_id$jscomp$500$$),$frame$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$880$$,$id$jscomp$1129$$),$position$jscomp$257$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$129$$,$axis$jscomp$70$$)+$value$jscomp$1169$$;
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$update_guides$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$ruler_id$jscomp$2$$,$APP.$cljs$cst$2062$axis$$,$axis$jscomp$70$$,$APP.$cljs$cst$1681$position$$,$position$jscomp$257$$,$APP.$cljs$cst$1612$frame_id$$,$id$jscomp$1129$$],null)),$plugin_id$jscomp$40$$));return $app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$40$$,
$file_id$jscomp$485$$,$page_id$jscomp$500$$,$ruler_id$jscomp$2$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6646$addRulerGuide$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6646$addRulerGuide$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6646$addRulerGuide$$,"The shape is not a board")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6646$addRulerGuide$$,"Orientation should be either 'vertical' or 'horizontal'")}catch($e88966$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88966$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"removeRulerGuide",{enumerable:!1,get:function(){return function($value$jscomp$1170$$){try{if($app$util$object$type_of_QMARK_$$($value$jscomp$1170$$,"RulerGuideProxy")){if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){var $guide$jscomp$43$$=
$app$plugins$utils$proxy__GT_ruler_guide$$($value$jscomp$1170$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$43$$),$plugin_id$jscomp$40$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6647$removeRulerGuide$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6647$removeRulerGuide$$,
"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6647$removeRulerGuide$$,"Guide not provided")}catch($e88967$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88967$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"tokens",{enumerable:!0,get:function(){function $internal_fn_tokens_88700$$(){var $applied_tokens$jscomp$36$$=$app$plugins$tokens$applied_tokens_plugin__GT_applied_tokens$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,
$page_id$jscomp$500$$,$id$jscomp$1129$$),$APP.$cljs$cst$1881$applied_tokens$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$173$$,$name$jscomp$520_p__88968$$){var $prop$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$520_p__88968$$,0,null);$name$jscomp$520_p__88968$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($name$jscomp$520_p__88968$$,1,null);return $APP.$app$util$object$set_BANG_$$($acc$jscomp$173$$,$APP.$app$common$json$write_camel_key$$($prop$jscomp$45$$),
$name$jscomp$520_p__88968$$)},{},$applied_tokens$jscomp$36$$)}try{return $internal_fn_tokens_88700$$.call(this,this)}catch($e88972$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88972$$)}}});Object.defineProperty($obj_88036$$,"applyToken",{enumerable:!1,get:function(){var $internal_fn_applytoken_88707__$1$$=function($token$jscomp$228$$,$attrs$jscomp$193$$){try{var $token__$1$jscomp$7$$=$app$plugins$utils$locate_token$$($file_id$jscomp$485$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$228$$,
"$set-id"),$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$228$$,"$id")),$kw_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$tokens$token_attr_plugin__GT_token_attr$$,$attrs$jscomp$193$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__88016_SHARP_$$){return!$app$plugins$tokens$token_attr_QMARK_$$($p1__88016_SHARP_$$)},$kw_attrs$$))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6648$applyToken$$,$attrs$jscomp$193$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$token__$1$jscomp$7$$,$APP.$cljs$cst$2656$attrs$$,$kw_attrs$$,$APP.$cljs$cst$4722$shape_ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$1129$$],null),$APP.$cljs$cst$4735$expand_with_children$$,!1],null)),$plugin_id$jscomp$40$$))}catch($e88973$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88973$$)}}.bind(this);return function(){try{var $val_applytoken_88712$$=Array.from(arguments),$val_applytoken_88712__$1$$=$APP.$app$common$json$__GT_clj$$($val_applytoken_88712$$,null),$schema_applytoken_88710__$1$$=$APP.$cljs$core$fn_QMARK_$$($schema_applytoken_88710_90145$$)?$schema_applytoken_88710_90145$$($val_applytoken_88712__$1$$):
$schema_applytoken_88710_90145$$,$val_applytoken_88712__$2$$=($coercer_fn_applytoken_88708_90146$$==null?$APP.$app$common$schema$coercer$$($schema_applytoken_88710__$1$$):$coercer_fn_applytoken_88708_90146$$)($val_applytoken_88712__$1$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($internal_fn_applytoken_88707__$1$$,$val_applytoken_88712__$2$$)}catch($e88974$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88974$$)}}}});Object.defineProperty($obj_88036$$,"isVariantHead",
{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1178$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$component$jscomp$143$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$485$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1178$$));return $APP.$app$common$types$component$instance_head_QMARK_$$($shape$jscomp$1178$$)&&$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$143$$)}catch($e88975$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88975$$)}}.bind(this)}});
Object.defineProperty($obj_88036$$,"isVariantContainer",{enumerable:!1,get:function(){return function(){try{var $shape$jscomp$1179$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$);return $APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1179$$)}catch($e88976$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88976$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"switchVariant",{enumerable:!1,get:function(){return function($pos$jscomp$166$$,
$value$jscomp$1171$$){try{if($APP.$cljs$core$nat_int_QMARK_$$($pos$jscomp$166$$)){if(typeof $value$jscomp$1171$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$260$value$$,$value$jscomp$1171$$);var $shape$jscomp$1180$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$id$jscomp$1129$$),$component$jscomp$144$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$485$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1180$$));
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$144$$)?$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$144$$):$component$jscomp$144$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$variants$variants_switch$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1619$shapes$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1180$$],null),$APP.$cljs$cst$1411$pos$$,$pos$jscomp$166$$,$APP.$cljs$cst$108$val$$,$value$jscomp$1171$$],null)),$plugin_id$jscomp$40$$)):null}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1411$pos$$,$pos$jscomp$166$$)}catch($e88977$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88977$$)}}.bind(this)}});Object.defineProperty($obj_88036$$,"combineAsVariants",{enumerable:!1,get:function(){return function($ids$jscomp$328$$){try{if($APP.$cljs$core$not$$($APP.$cljs$core$seq$$($ids$jscomp$328$$))||
!$APP.$cljs$core$every_QMARK_$$($APP.$app$common$uuid$parse_STAR_$$,$ids$jscomp$328$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1729$ids$$,$ids$jscomp$328$$);var $ids__$1$jscomp$33$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$uuid$parse_STAR_$$),
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id$jscomp$1129$$])),$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$()),$ids$jscomp$328$$);if($APP.$cljs$core$every_QMARK_$$(function($component$jscomp$145_id__$1$jscomp$51_shape$jscomp$1181$$){$component$jscomp$145_id__$1$jscomp$51_shape$jscomp$1181$$=$app$plugins$utils$locate_shape$$($file_id$jscomp$485$$,$page_id$jscomp$500$$,$component$jscomp$145_id__$1$jscomp$51_shape$jscomp$1181$$);
$component$jscomp$145_id__$1$jscomp$51_shape$jscomp$1181$$=$app$plugins$utils$locate_library_component$$($file_id$jscomp$485$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$145_id__$1$jscomp$51_shape$jscomp$1181$$));return!$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$145_id__$1$jscomp$51_shape$jscomp$1181$$)},$ids__$1$jscomp$33$$)){var $variant_id$jscomp$57$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids__$1$jscomp$33$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4491$trigger$$,"plugin:combine-as-variants",$APP.$cljs$cst$2016$variant_id$$,$variant_id$jscomp$57$$],null)),$plugin_id$jscomp$40$$));return $app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$2$($plugin_id$jscomp$40$$,$variant_id$jscomp$57$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1729$ids$$,"One of the components is not on the same page or is already a variant")}catch($e88978$$){return $app$plugins$utils$handle_error$$($plugin_id$jscomp$40$$)($e88978$$)}}.bind(this)}});
return $obj_88036$$}();if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($data$jscomp$532$$)){var $set_fn89172_92377$$=function($page_id__$1$jscomp$35_self$jscomp$223$$,$children$jscomp$324_ids$jscomp$329$$){var $valid_children_QMARK_$$=
$APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$children$jscomp$324_ids$jscomp$329$$),$shape$jscomp$1182$$=$app$plugins$utils$proxy__GT_shape$$($page_id__$1$jscomp$35_self$jscomp$223$$),$file_id__$1$jscomp$16$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page_id__$1$jscomp$35_self$jscomp$223$$,"$file");$page_id__$1$jscomp$35_self$jscomp$223$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($page_id__$1$jscomp$35_self$jscomp$223$$,"$page");
var $reverse_fn$jscomp$1$$=$app$plugins$utils$natural_child_ordering_QMARK_$$($plugin_id$jscomp$40$$)?$APP.$cljs$core$reverse$$:$APP.$cljs$core$identity$$;$children$jscomp$324_ids$jscomp$329$$=$valid_children_QMARK_$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__88017_SHARP_$$){return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__88017_SHARP_$$,"$id")},$reverse_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$reverse_fn$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$324_ids$jscomp$329$$):
$reverse_fn$jscomp$1$$($children$jscomp$324_ids$jscomp$329$$)):null;return $app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id__$1$jscomp$35_self$jscomp$223$$)?$valid_children_QMARK_$$?$APP.$cljs$core$boolean$0$$($APP.$app$common$types$component$in_component_copy_QMARK_$$($shape$jscomp$1182$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$342$children$$,"Cannot change the structure of a component copy"):
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($children$jscomp$324_ids$jscomp$329$$),$APP.$cljs$core$set$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1182$$)))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$342$children$$,"Not all children are present in the input"):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$reorder_children$$($file_id__$1$jscomp$16$$,$page_id__$1$jscomp$35_self$jscomp$223$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1182$$),$children$jscomp$324_ids$jscomp$329$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$342$children$$,"Every children needs to be shape proxies"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$342$children$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$342$children$$,"Plugin doesn't have 'content:write' permission")};
Object.defineProperty($G__88034$$,"children",function(){return{enumerable:!1,get:function(){return this.getChildren()},set:function($value__42827__auto__$jscomp$15$$){return $set_fn89172_92377$$(this,$value__42827__auto__$jscomp$15$$)}}}())}return $G__88034$$}();if($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)){var $set_fn89178_92379$$=function($_$jscomp$3308$$,$value$jscomp$1172$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1172$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),function($p1__88018_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__88018_SHARP_$$,
$APP.$cljs$cst$1884$show_content$$,$APP.$cljs$core$not$$($value$jscomp$1172$$))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6649$clipContent$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6649$clipContent$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6649$clipContent$$,$value$jscomp$1172$$)};Object.defineProperty($G__88033$$,"clipContent",
function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$not$$($APP.$cljs$cst$1884$show_content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42827__auto__$jscomp$16$$){return $set_fn89178_92379$$(this,$value__42827__auto__$jscomp$16$$)}}}());var $set_fn89178_92381$$=function($_$jscomp$3309$$,$value$jscomp$1173$$){return $APP.$cljs$core$boolean_QMARK_$$($value$jscomp$1173$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,
"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),function($p1__88019_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__88019_SHARP_$$,$APP.$cljs$cst$1883$hide_in_viewer$$,
$APP.$cljs$core$not$$($value$jscomp$1173$$))})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6650$showInViewMode$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6650$showInViewMode$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6650$showInViewMode$$,$value$jscomp$1173$$)};Object.defineProperty($G__88033$$,"showInViewMode",function(){return{enumerable:!0,
get:function(){return $APP.$cljs$core$not$$($APP.$cljs$cst$1883$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},set:function($value__42827__auto__$jscomp$17$$){return $set_fn89178_92381$$(this,$value__42827__auto__$jscomp$17$$)}}}());Object.defineProperty($G__88033$$,"grid",function(){return{enumerable:!0,get:function(){var $layout$jscomp$inline_10741$$=$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),
$file_id__$1$jscomp$inline_10742$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10743$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$page"),$id__$1$jscomp$inline_10744$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1664$grid$$,$layout$jscomp$inline_10741$$)?$app$plugins$grid$grid_layout_proxy$$($plugin_id$jscomp$40$$,
$file_id__$1$jscomp$inline_10742$$,$page_id__$1$jscomp$inline_10743$$,$id__$1$jscomp$inline_10744$$):null}}}());Object.defineProperty($G__88033$$,"flex",function(){return{enumerable:!0,get:function(){var $layout$jscomp$inline_10747$$=$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$file_id__$1$jscomp$inline_10748$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$file"),$page_id__$1$jscomp$inline_10749$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
"$page"),$id__$1$jscomp$inline_10750$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,$layout$jscomp$inline_10747$$)?$app$plugins$flex$flex_layout_proxy$$($plugin_id$jscomp$40$$,$file_id__$1$jscomp$inline_10748$$,$page_id__$1$jscomp$inline_10749$$,$id__$1$jscomp$inline_10750$$):null}}}());var $set_fn89178_92467$$=function($id__$1$jscomp$54_self$jscomp$228$$,$value$jscomp$1174$$){$id__$1$jscomp$54_self$jscomp$228$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($id__$1$jscomp$54_self$jscomp$228$$,"$id");var $value__$1$jscomp$128$$=$app$plugins$parser$parse_frame_guides$$($value$jscomp$1174$$);return $APP.$cljs$core$not$$($app$common$schema$validate$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,$APP.$app$common$types$grid$schema_COLON_grid$$],null),$value__$1$jscomp$128$$))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$APP.$cljs$cst$2065$guides$$,$value__$1$jscomp$128$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id__$1$jscomp$54_self$jscomp$228$$],null),function($p1__88021_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__88021_SHARP_$$,
$APP.$cljs$cst$2058$grids$$,$value__$1$jscomp$128$$)})):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2065$guides$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$2065$guides$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__88033$$,"guides",function(){return{enumerable:!0,get:function(){var $guides$jscomp$inline_14274$$=$APP.$cljs$cst$2058$grids$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));
return $app$plugins$format$format_array$$($app$plugins$format$format_frame_guide$$,$guides$jscomp$inline_14274$$)},set:function($value__42827__auto__$jscomp$18$$){return $set_fn89178_92467$$(this,$value__42827__auto__$jscomp$18$$)}}}());var $get_fn89177_92468$$=function(){var $guides$jscomp$19$$=$APP.$cljs$cst$2065$guides$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$locate_page$$($file_id$jscomp$485$$,$page_id$jscomp$500$$));return $app$plugins$format$format_array$$(function($p1__88023_SHARP_$$){return $app$plugins$ruler_guides$ruler_guide_proxy$$($plugin_id$jscomp$40$$,
$file_id$jscomp$485$$,$page_id$jscomp$500$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__88023_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__88022_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1129$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__88022_SHARP_$$))},$APP.$cljs$core$vals$$($guides$jscomp$19$$)))};Object.defineProperty($G__88033$$,"rulerGuides",function(){return{enumerable:!0,
get:function(){return $get_fn89177_92468$$(this)}}}());Object.defineProperty($G__88033$$,"horizontalSizing",function(){return{enumerable:!0,get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1702$fix$$))},set:function($value__$1$jscomp$inline_10755_value__42827__auto__$jscomp$19$$){var $id__$1$jscomp$inline_10754$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10755_value__42827__auto__$jscomp$19$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$inline_10755_value__42827__auto__$jscomp$19$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1702$fix$$,null,$APP.$cljs$cst$1677$auto$$,null],null),null),$value__$1$jscomp$inline_10755_value__42827__auto__$jscomp$19$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id__$1$jscomp$inline_10754$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$layout_item_h_sizing$$,$value__$1$jscomp$inline_10755_value__42827__auto__$jscomp$19$$],
null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6507$horizontalSizing$$,"Cannot modify a page that is not currently active"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6507$horizontalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6507$horizontalSizing$$,$value__$1$jscomp$inline_10755_value__42827__auto__$jscomp$19$$)}}}());Object.defineProperty($G__88033$$,"verticalSizing",function(){return{enumerable:!0,
get:function(){return $APP.$app$common$data$name$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)),$APP.$cljs$cst$1702$fix$$))},set:function($value__$1$jscomp$inline_10760_value__42827__auto__$jscomp$20$$){var $id__$1$jscomp$inline_10759$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$(this,"$id");$value__$1$jscomp$inline_10760_value__42827__auto__$jscomp$20$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$inline_10760_value__42827__auto__$jscomp$20$$);return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1702$fix$$,null,$APP.$cljs$cst$1677$auto$$,null],null),null),$value__$1$jscomp$inline_10760_value__42827__auto__$jscomp$20$$)?$app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")?$app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$id__$1$jscomp$inline_10759$$]),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1714$layout_item_v_sizing$$,$value__$1$jscomp$inline_10760_value__42827__auto__$jscomp$20$$],null))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6508$verticalSizing$$,"Cannot modify a page that is not currently active"):
$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6508$verticalSizing$$,"Plugin doesn't have 'content:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$cljs$cst$6508$verticalSizing$$,$value__$1$jscomp$inline_10760_value__42827__auto__$jscomp$20$$)}}}());Object.defineProperty($G__88033$$,"variants",function(){return{enumerable:!1,get:function(){var $G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$=$app$plugins$utils$proxy__GT_shape$$(this);
$APP.$app$common$types$component$is_variant_container_QMARK_$$($G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$)?($G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$),$G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$=
$app$plugins$shape$variant_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$shape$variant_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$):$app$plugins$shape$variant_proxy$$($plugin_id$jscomp$40$$,$file_id$jscomp$485$$,$G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$)):$G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$=
null;return $G__89199$jscomp$inline_10764_JSCompiler_inline_result$jscomp$2318_shape$jscomp$inline_10763$$}}}())}return $G__88033$$}();return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)?$app$plugins$text$add_text_props$$($G__88032$$,$plugin_id$jscomp$40$$):$G__88032$$}();if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($data$jscomp$532$$)){var $set_fn89203_92505$$=
function($_$jscomp$3311_segments$jscomp$17$$,$value$jscomp$1177$$){$_$jscomp$3311_segments$jscomp$17$$=(0,$APP.$app$common$types$path$impl$decode_segments$$)($APP.$app$common$json$__GT_clj$$($value$jscomp$1177$$));if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$path$impl$schema_COLON_segments$$,
$_$jscomp$3311_segments$jscomp$17$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1642$content$$,$_$jscomp$3311_segments$jscomp$17$$);var $selrect$jscomp$101$$=$APP.$app$common$types$path$calc_selrect$$($_$jscomp$3311_segments$jscomp$17$$),$content$jscomp$279$$=$APP.$app$common$types$path$impl$from_plain$$($_$jscomp$3311_segments$jscomp$17$$),$points$jscomp$113$$=$APP.$app$common$geom$rect$rect__GT_points$$($selrect$jscomp$101$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),function($shape$jscomp$1184$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1184$$,$APP.$cljs$cst$1642$content$$,$content$jscomp$279$$),$APP.$cljs$cst$1610$selrect$$,$selrect$jscomp$101$$),$APP.$cljs$cst$1609$points$$,$points$jscomp$113$$)}))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$APP.$cljs$cst$1642$content$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1642$content$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__88031$$,"commands",function(){return{enumerable:!0,get:function(){var $content$jscomp$inline_14276$$=$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this));return $app$plugins$format$format_array$$($app$plugins$format$format_command$$,
$content$jscomp$inline_14276$$)},set:function($value__42827__auto__$jscomp$21$$){return $set_fn89203_92505$$(this,$value__42827__auto__$jscomp$21$$)}}}());var $set_fn89203_92514$$=function($_$jscomp$3312_segments$jscomp$18$$,$value$jscomp$1178$$){$_$jscomp$3312_segments$jscomp$18$$=typeof $value$jscomp$1178$$==="string"?$APP.$app$common$svg$path$parse$$($value$jscomp$1178$$):$value$jscomp$1178$$;if($app$plugins$register$check_permission$$($plugin_id$jscomp$40$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($page_id$jscomp$500$$)){if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$532$$)){if($APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$path$impl$schema_COLON_segments$$,
$_$jscomp$3312_segments$jscomp$18$$)))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1642$content$$,$_$jscomp$3312_segments$jscomp$18$$);var $selrect$jscomp$102$$=$APP.$app$common$types$path$calc_selrect$$($_$jscomp$3312_segments$jscomp$18$$),$content$jscomp$280$$=$APP.$app$common$types$path$impl$from_plain$$($_$jscomp$3312_segments$jscomp$18$$),$points$jscomp$114$$=$APP.$app$common$geom$rect$rect__GT_points$$($selrect$jscomp$102$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1129$$],null),function($shape$jscomp$1185$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1185$$,$APP.$cljs$cst$1642$content$$,$content$jscomp$280$$),$APP.$cljs$cst$1610$selrect$$,$selrect$jscomp$102$$),$APP.$cljs$cst$1609$points$$,$points$jscomp$114$$)}))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,
$cljs$cst$6651$content_type$$,$APP.$cljs$core$type$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1642$content$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$40$$,$APP.$cljs$cst$1642$content$$,"Plugin doesn't have 'content:write' permission")};Object.defineProperty($G__88031$$,"d",function(){return{enumerable:!0,get:function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_shape$$(this)))},
set:function($value__42827__auto__$jscomp$22$$){return $set_fn89203_92514$$(this,$value__42827__auto__$jscomp$22$$)}}}());Object.defineProperty($G__88031$$,"content",function(){return{enumerable:!0,get:function(){return this.d},set:function($value__42827__auto__$jscomp$23$$){return this.d=$value__42827__auto__$jscomp$23$$}}}())}return $G__88031$$};$app$plugins$shape$shape_proxy$$.$cljs$lang$maxFixedArity$=4;var $app$plugins$file$file_version_proxy$$=function $app$plugins$file$file_version_proxy$$($plugin_id$jscomp$48$$,$file_id$jscomp$490$$,$users$jscomp$11$$,$data$jscomp$538_obj_91667$$){var $data__$1$jscomp$19$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($data$jscomp$538_obj_91667$$);$data$jscomp$538_obj_91667$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($data$jscomp$538_obj_91667$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"FileVersionProxy"}});Object.defineProperty($data$jscomp$538_obj_91667$$,
Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"FileVersionProxy"}});Object.defineProperty($data$jscomp$538_obj_91667$$,"$plugin",{enumerable:!1,get:function(){return $plugin_id$jscomp$48$$}});Object.defineProperty($data$jscomp$538_obj_91667$$,"$file",{enumerable:!1,get:function(){return $file_id$jscomp$490$$}});Object.defineProperty($data$jscomp$538_obj_91667$$,"label",{enumerable:!0,get:function(){return $APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$))},
set:function($val_label_91704$$){return function($value$jscomp$1188$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$48$$,"content:write")){if(typeof $value$jscomp$1188$$!=="string"||$APP.$cljs$core$empty_QMARK_$$($value$jscomp$1188$$))return $app$plugins$utils$not_valid$$($plugin_id$jscomp$48$$,$APP.$cljs$cst$2296$label$$,$value$jscomp$1188$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($data__$1$jscomp$19$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2296$label$$,
$value$jscomp$1188$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5162$created_by$$,"user"]));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$48$$,"rename-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$490$$])))},
$APP.$beicon$v2$core$take$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5144$update_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)),$APP.$cljs$cst$2296$label$$,$value$jscomp$1188$$],null))))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$48$$,$APP.$cljs$cst$2296$label$$,"Plugin doesn't have 'content:write' permission")}.call(this,
$val_label_91704$$)}});Object.defineProperty($data$jscomp$538_obj_91667$$,"createdBy",{enumerable:!0,get:function(){var $temp__5825__auto__$jscomp$inline_10790$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($users$jscomp$11$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_10790$$)?$app$plugins$user$user_proxy$$($plugin_id$jscomp$48$$,$temp__5825__auto__$jscomp$inline_10790$$):
null}});Object.defineProperty($data$jscomp$538_obj_91667$$,"createdAt",{enumerable:!0,get:function(){return $APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$))}});Object.defineProperty($data$jscomp$538_obj_91667$$,"isAutosave",{enumerable:!0,get:function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5162$created_by$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)))}});
Object.defineProperty($data$jscomp$538_obj_91667$$,"restore",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$54$$,$reject$jscomp$35$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$48$$,"content:write")){var $version_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$),$APP.$cljs$cst$266$id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$restore_version_from_plugin$$($file_id$jscomp$490$$,
$version_id$$,$resolve$jscomp$54$$,$reject$jscomp$35$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$48$$,"restore-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$490$$]))]))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$35$$,$cljs$cst$6666$restore$$,"Plugin doesn't have 'content:write' permission")})}.bind(this)}});
Object.defineProperty($data$jscomp$538_obj_91667$$,"remove",{enumerable:!1,get:function(){return function(){return new Promise(function($resolve$jscomp$55$$,$reject$jscomp$36$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$48$$,"content:write")){var $version_id$jscomp$1$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$));return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($resolve$jscomp$55$$,$reject$jscomp$36$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$(null),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5148$delete_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$version_id$jscomp$1$$],null))))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$36$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'content:write' permission")})}.bind(this)}});Object.defineProperty($data$jscomp$538_obj_91667$$,"pin",{enumerable:!1,
get:function(){return function(){return new Promise(function($resolve$jscomp$56$$,$reject$jscomp$37$$){if($app$plugins$register$check_permission$$($plugin_id$jscomp$48$$,"content:write")){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5162$created_by$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$))))return $app$plugins$utils$reject_not_valid$$($reject$jscomp$37$$,$cljs$cst$6667$pin$$,"Only auto-saved versions can be pinned");
var $params$jscomp$473$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)),$APP.$cljs$cst$2296$label$$,$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($data__$1$jscomp$19$$)),$APP.$cljs$cst$5141$localized_date$$)],null);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$){var $G__91753_users__$1_users__$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$,0,null);$G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$,1,null);$G__91753_users__$1_users__$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$G__91753_users__$1_users__$2$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$event$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($plugin_id$jscomp$48$$,
"pin-version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$490$$])));$G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$=$APP.$cljs$core$_deref$$($G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$);$G__91753_users__$1_users__$2$$=$app$plugins$file$file_version_proxy$$.$cljs$core$IFn$_invoke$arity$4$?$app$plugins$file$file_version_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$48$$,$file_id$jscomp$490$$,$G__91753_users__$1_users__$2$$,
$G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$):$app$plugins$file$file_version_proxy$$($plugin_id$jscomp$48$$,$file_id$jscomp$490$$,$G__91753_users__$1_users__$2$$,$G__91757$jscomp$inline_10792_data__$2$jscomp$2_p__91749$$);return $resolve$jscomp$56$$.$cljs$core$IFn$_invoke$arity$1$?$resolve$jscomp$56$$.$cljs$core$IFn$_invoke$arity$1$($G__91753_users__$1_users__$2$$):$resolve$jscomp$56$$($G__91753_users__$1_users__$2$$)},$reject$jscomp$37$$,$APP.$beicon$v2$core$zip$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6668$get_team_users$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$490$$],null)),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5144$update_file_snapshot$$,$params$jscomp$473$$)))}return $app$plugins$utils$reject_not_valid$$($reject$jscomp$37$$,$cljs$cst$6667$pin$$,"Plugin doesn't have 'content:write' permission")})}.bind(this)}});return $data$jscomp$538_obj_91667$$};var $app$plugins$events$handle_state_change$$=function(){var $method_table__5622__auto__$jscomp$26$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$prefer_table__5623__auto__$jscomp$26$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$method_cache__5624__auto__$jscomp$26$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$cached_hierarchy__5625__auto__$jscomp$26$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hierarchy__5626__auto__$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$204$hierarchy$$,$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$core$get_global_hierarchy$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$cljs$core$get_global_hierarchy$$());return new $APP.$cljs$core$MultiFn$$($APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$("app.plugins.events",
"handle-state-change"),function($type$jscomp$752$$){return $type$jscomp$752$$},$APP.$cljs$cst$205$default$$,$hierarchy__5626__auto__$jscomp$26$$,$method_table__5622__auto__$jscomp$26$$,$prefer_table__5623__auto__$jscomp$26$$,$method_cache__5624__auto__$jscomp$26$$,$cached_hierarchy__5625__auto__$jscomp$26$$)}();
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"finish",function($_$jscomp$3328_old_file_id$$,$___$1$jscomp$2130$$,$old_val$jscomp$9$$,$new_file_id_new_val$jscomp$10$$){$_$jscomp$3328_old_file_id$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($old_val$jscomp$9$$);$new_file_id_new_val$jscomp$10$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_file_id_new_val$jscomp$10$$);return $_$jscomp$3328_old_file_id$$!=
null&&$new_file_id_new_val$jscomp$10$$==null?$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3328_old_file_id$$):$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"filechange",function($_$jscomp$3329_old_file_id$jscomp$1$$,$plugin_id$jscomp$50$$,$old_val$jscomp$10$$,$new_file_id$jscomp$1_new_val$jscomp$11$$){$_$jscomp$3329_old_file_id$jscomp$1$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($old_val$jscomp$10$$);$new_file_id$jscomp$1_new_val$jscomp$11$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_file_id$jscomp$1_new_val$jscomp$11$$);
return $_$jscomp$3329_old_file_id$jscomp$1$$===$new_file_id$jscomp$1_new_val$jscomp$11$$?$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$app$plugins$file$file_proxy$$($plugin_id$jscomp$50$$,$new_file_id$jscomp$1_new_val$jscomp$11$$)});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"pagechange",function($_$jscomp$3330_old_page_id$$,$plugin_id$jscomp$51$$,$new_page_id$jscomp$1_old_val$jscomp$11$$,$new_val$jscomp$12$$){$_$jscomp$3330_old_page_id$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($new_page_id$jscomp$1_old_val$jscomp$11$$);$new_page_id$jscomp$1_old_val$jscomp$11$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$12$$);
return $_$jscomp$3330_old_page_id$$===$new_page_id$jscomp$1_old_val$jscomp$11$$?$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$app$plugins$page$page_proxy$$($plugin_id$jscomp$51$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$12$$),$new_page_id$jscomp$1_old_val$jscomp$11$$)});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"selectionchange",function($_$jscomp$3331_old_selection$$,$___$1$jscomp$2133$$,$old_val$jscomp$12$$,$new_selection_new_val$jscomp$13$$){$_$jscomp$3331_old_selection$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$12$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1938$selected$$],null));
$new_selection_new_val$jscomp$13$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_selection_new_val$jscomp$13$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1938$selected$$],null));return $_$jscomp$3331_old_selection$$===$new_selection_new_val$jscomp$13$$?$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$new_selection_new_val$jscomp$13$$))});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"themechange",function($_$jscomp$3332_old_theme$$,$___$1$jscomp$2134$$,$old_val$jscomp$13$$,$new_theme_new_val$jscomp$14$$){$_$jscomp$3332_old_theme$$=$app$plugins$events$get_theme$$($old_val$jscomp$13$$);$new_theme_new_val$jscomp$14$$=$app$plugins$events$get_theme$$($new_theme_new_val$jscomp$14$$);return $_$jscomp$3332_old_theme$$===$new_theme_new_val$jscomp$14$$?$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$:
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_theme_new_val$jscomp$14$$,"default")?"dark":$new_theme_new_val$jscomp$14$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"shapechange",function($_$jscomp$3333_temp__5823__auto__$jscomp$264$$,$plugin_id$jscomp$52$$,$old_shape$jscomp$4_old_val$jscomp$14$$,$new_val$jscomp$15_page_id$jscomp$506$$,$new_shape$jscomp$25_props$jscomp$428$$){$_$jscomp$3333_temp__5823__auto__$jscomp$264$$=$app$plugins$parser$parse_id$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($new_shape$jscomp$25_props$jscomp$428$$,"shapeId"));if($APP.$cljs$core$truth_$$($_$jscomp$3333_temp__5823__auto__$jscomp$264$$)){$old_shape$jscomp$4_old_val$jscomp$14$$=
$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($old_shape$jscomp$4_old_val$jscomp$14$$,$_$jscomp$3333_temp__5823__auto__$jscomp$264$$);$new_shape$jscomp$25_props$jscomp$428$$=$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($new_val$jscomp$15_page_id$jscomp$506$$,$_$jscomp$3333_temp__5823__auto__$jscomp$264$$);var $file_id$jscomp$491$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$15_page_id$jscomp$506$$);
$new_val$jscomp$15_page_id$jscomp$506$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($new_val$jscomp$15_page_id$jscomp$506$$);return $old_shape$jscomp$4_old_val$jscomp$14$$===$new_shape$jscomp$25_props$jscomp$428$$&&$plugin_id$jscomp$52$$!=null&&$file_id$jscomp$491$$!=null&&$new_val$jscomp$15_page_id$jscomp$506$$!=null&&$_$jscomp$3333_temp__5823__auto__$jscomp$264$$!=null?$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$:$app$plugins$shape$shape_proxy$$.$cljs$core$IFn$_invoke$arity$4$($plugin_id$jscomp$52$$,
$file_id$jscomp$491$$,$new_val$jscomp$15_page_id$jscomp$506$$,$_$jscomp$3333_temp__5823__auto__$jscomp$264$$)}return $cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,"contentsave",function($_$jscomp$3334_old_status$$,$___$1$jscomp$2135$$,$old_val$jscomp$15$$,$new_status_new_val$jscomp$16$$){$_$jscomp$3334_old_status$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$15$$,$APP.$cljs$cst$2186$persistence$$),$APP.$cljs$cst$109$status$$);$new_status_new_val$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_status_new_val$jscomp$16$$,
$APP.$cljs$cst$2186$persistence$$),$APP.$cljs$cst$109$status$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3172$saved$$,$new_status_new_val$jscomp$16$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_status_new_val$jscomp$16$$,$_$jscomp$3334_old_status$$)?$cljs$cst$6678$app_DOT_plugins_DOT_events_SLASH_void$$:$cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$});
$app$plugins$events$handle_state_change$$.$cljs$core$IMultiFn$_add_method$arity$3$(null,$APP.$cljs$cst$205$default$$,function(){return $cljs$cst$6677$app_DOT_plugins_DOT_events_SLASH_not_changed$$});var $app$plugins$library$lib_color_proxy$$=function $app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$57$$,$file_id$jscomp$492$$,$id$jscomp$1138$$){var $obj_89332$$=new $APP.$app$util$object$Proxy$$;Object.defineProperty($obj_89332$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryColorProxy"}});Object.defineProperty($obj_89332$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryColorProxy"}});Object.defineProperty($obj_89332$$,"$plugin",{enumerable:!1,
get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$57$$).call(this)}});Object.defineProperty($obj_89332$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1138$$).call(this)}});Object.defineProperty($obj_89332$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$492$$).call(this)}});Object.defineProperty($obj_89332$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1138$$??"")}});Object.defineProperty($obj_89332$$,
"libraryId",{enumerable:!0,get:function(){return""+($file_id$jscomp$492$$??"")}});Object.defineProperty($obj_89332$$,"fileId",{enumerable:!0,get:function(){return""+($file_id$jscomp$492$$??"")}});Object.defineProperty($obj_89332$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},set:function($JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$){if(typeof $JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$!==
"string")$JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")){var $color$jscomp$inline_10797$$=$app$plugins$utils$proxy__GT_library_color$$(this);$JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$=
""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$inline_10797$$),"")??"")+" / "+($JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$??"");$JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$rename_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$,
$JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$))}else $JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2325_val_name_89404_value__$1$jscomp$inline_10798$$}});Object.defineProperty($obj_89332$$,"path",{enumerable:!0,get:function(){return $APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},
set:function($val_path_89412$$){return function($color$jscomp$254_self$jscomp$237$$,$value$jscomp$1193$$){return typeof $value$jscomp$1193$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$296$path$$,$value$jscomp$1193$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?($color$jscomp$254_self$jscomp$237$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$($color$jscomp$254_self$jscomp$237$$),
$APP.$cljs$cst$725$name$$,function($p1__89214_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1193$$)," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__89214_SHARP_$$)].join("")}),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_color$$($color$jscomp$254_self$jscomp$237$$,$file_id$jscomp$492$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$296$path$$,"Plugin doesn't have 'library:write' permission")}.call(this,
this,$val_path_89412$$)}});Object.defineProperty($obj_89332$$,"color",{enumerable:!0,get:function(){return $APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},set:function($JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$){typeof $JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$==="string"&&$APP.$app$common$types$color$valid_hex_color_QMARK_$$($JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$)?
$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?($JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),$APP.$cljs$cst$1303$color$$,$JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$),$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1617$image$$])),
$JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$,$file_id$jscomp$492$$))):$JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$1303$color$$,"Plugin doesn't have 'library:write' permission"):
$JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$1303$color$$,$JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$);return $JSCompiler_inline_result$jscomp$2326_color$jscomp$inline_10802_val_color_89420$$}});Object.defineProperty($obj_89332$$,"opacity",{enumerable:!0,get:function(){return $APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this))},
set:function($JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$){typeof $JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$!=="number"||$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$<0||$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$>1?$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,
$APP.$cljs$cst$1740$opacity$$,$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?($JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),$APP.$cljs$cst$1740$opacity$$,$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$),
$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$,$file_id$jscomp$492$$))):$JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$1740$opacity$$,"Plugin doesn't have 'library:write' permission");
return $JSCompiler_inline_result$jscomp$2327_color$jscomp$inline_10806_val_opacity_89429$$}});Object.defineProperty($obj_89332$$,"gradient",{enumerable:!0,get:function(){return $app$plugins$format$format_gradient$$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this)))},set:function($JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$){$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$=
$app$plugins$parser$parse_gradient$$($JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$);$APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_gradient$$,$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$))?$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$=
$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$1730$gradient$$,$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?($JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),
$APP.$cljs$cst$1730$gradient$$,$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$),$APP.$cljs$cst$1303$color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1617$image$$])),$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$,
$file_id$jscomp$492$$))):$JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$1730$gradient$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2328_color$jscomp$inline_10811_val_gradient_89451_value__$1$jscomp$inline_10810$$}});Object.defineProperty($obj_89332$$,"image",{enumerable:!0,get:function(){return $app$plugins$format$format_image$$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_color$$(this)))},
set:function($JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$){$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$=$app$plugins$parser$parse_image_data$$($JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$);$APP.$cljs$core$not$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$color$schema_COLON_image$$,
$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$))?$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$1617$image$$,$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?
($JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_color$$(this),$APP.$cljs$cst$1617$image$$,$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$),$APP.$cljs$cst$1303$color$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1730$gradient$$])),
$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_color_data$$($JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$,$file_id$jscomp$492$$))):$JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,
$APP.$cljs$cst$1617$image$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2329_color$jscomp$inline_10816_val_image_89472_value__$1$jscomp$inline_10815$$}});Object.defineProperty($obj_89332$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$delete_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$id$jscomp$1138$$],null)),$plugin_id$jscomp$57$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89332$$,"clone",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")){var $color_id$jscomp$12$$=$APP.$app$common$uuid$next$$(),$color$jscomp$259$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,
$id$jscomp$1138$$),$APP.$cljs$cst$266$id$$,$color_id$jscomp$12$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$($color$jscomp$259$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3970$rename_QMARK_$$,!1],null)),$plugin_id$jscomp$57$$));return $app$plugins$library$lib_color_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$library$lib_color_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$57$$,
$id$jscomp$1138$$,$color_id$jscomp$12$$):$app$plugins$library$lib_color_proxy$$($plugin_id$jscomp$57$$,$id$jscomp$1138$$,$color_id$jscomp$12$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6615$clone$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89332$$,"asFill",{enumerable:!1,get:function(){return function(){var $color$jscomp$260$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$);return $app$plugins$format$format_fill$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$1752$fill_color$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$260$$),$APP.$cljs$cst$1753$fill_opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$260$$),$APP.$cljs$cst$1754$fill_color_gradient$$,$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$260$$),$APP.$cljs$cst$1645$fill_color_ref_file$$,$file_id$jscomp$492$$,$APP.$cljs$cst$1751$fill_color_ref_id$$,$id$jscomp$1138$$,$APP.$cljs$cst$1637$fill_image$$,
$APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$260$$)],null))}.bind(this)}});Object.defineProperty($obj_89332$$,"asStroke",{enumerable:!1,get:function(){return function(){var $color$jscomp$261$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$);return $app$plugins$format$format_stroke$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1745$stroke_color$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$261$$),
$APP.$cljs$cst$1746$stroke_opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$261$$),$APP.$cljs$cst$1747$stroke_color_gradient$$,$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$261$$),$APP.$cljs$cst$1646$stroke_color_ref_file$$,$file_id$jscomp$492$$,$APP.$cljs$cst$1748$stroke_color_ref_id$$,$id$jscomp$1138$$,$APP.$cljs$cst$1640$stroke_image$$,$APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$261$$),$APP.$cljs$cst$1873$stroke_style$$,
$APP.$cljs$cst$1919$solid$$,$APP.$cljs$cst$1875$stroke_alignment$$,$APP.$cljs$cst$1918$inner$$],null))}.bind(this)}});Object.defineProperty($obj_89332$$,"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$455$$){if(typeof $key$jscomp$455$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6669$getPluginData_key$$,$key$jscomp$455$$);var $color$jscomp$262$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$262$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$57$$))),$key$jscomp$455$$)}.bind(this)}});Object.defineProperty($obj_89332$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$456$$,$value$jscomp$1198$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$492$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6686$setPluginData_non_local_library$$,$file_id$jscomp$492$$):typeof $key$jscomp$456$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6617$setPluginData_key$$,$key$jscomp$456$$):$value$jscomp$1198$$!=null&&typeof $value$jscomp$1198$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1198$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$492$$,$APP.$cljs$cst$1303$color$$,$id$jscomp$1138$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$57$$)),$key$jscomp$456$$,$value$jscomp$1198$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6619$setPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});
Object.defineProperty($obj_89332$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $color$jscomp$263$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$263$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$57$$)))))}.bind(this)}});Object.defineProperty($obj_89332$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$27$$,$key$jscomp$457$$){if(typeof $namespace$jscomp$27$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6620$getSharedPluginData_namespace$$,$namespace$jscomp$27$$);if(typeof $key$jscomp$457$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,
$cljs$cst$6621$getSharedPluginData_key$$,$key$jscomp$457$$);var $color$jscomp$264$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$264$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$27$$)),$key$jscomp$457$$)}.bind(this)}});
Object.defineProperty($obj_89332$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$28$$,$key$jscomp$458$$,$value$jscomp$1199$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$492$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6687$setSharedPluginData_non_local_library$$,$file_id$jscomp$492$$):
typeof $namespace$jscomp$28$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$28$$):typeof $key$jscomp$458$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6623$setSharedPluginData_key$$,$key$jscomp$458$$):$value$jscomp$1199$$!=null&&typeof $value$jscomp$1199$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1199$$):
$app$plugins$register$check_permission$$($plugin_id$jscomp$57$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$492$$,$APP.$cljs$cst$1303$color$$,$id$jscomp$1138$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$28$$),$key$jscomp$458$$,$value$jscomp$1199$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6625$setSharedPluginData$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_89332$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$29$$){if(typeof $namespace$jscomp$29$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$57$$,$cljs$cst$6688$getSharedPluginDataKeys_namespace$$,$namespace$jscomp$29$$);var $color$jscomp$265$$=$app$plugins$utils$locate_library_color$$($file_id$jscomp$492$$,$id$jscomp$1138$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,
$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$265$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$29$$))))}.bind(this)}});return $obj_89332$$},$app$plugins$library$lib_typography_proxy$$=function $app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$58$$,$file_id$jscomp$493$$,$id$jscomp$1139$$){var $obj_90538$$=new $APP.$app$util$object$Proxy$$;
Object.defineProperty($obj_90538$$,Symbol.toStringTag,{enumerable:!1,get:function(){return"LibraryTypographyProxy"}});Object.defineProperty($obj_90538$$,Symbol["for"]("penpot.reify:type"),{enumerable:!1,get:function(){return"LibraryTypographyProxy"}});Object.defineProperty($obj_90538$$,"$plugin",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($plugin_id$jscomp$58$$).call(this)}});Object.defineProperty($obj_90538$$,"$id",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($id$jscomp$1139$$).call(this)}});
Object.defineProperty($obj_90538$$,"$file",{enumerable:!1,get:function(){return $APP.$cljs$core$constantly$$($file_id$jscomp$493$$).call(this)}});Object.defineProperty($obj_90538$$,"id",{enumerable:!0,get:function(){return""+($id$jscomp$1139$$??"")}});Object.defineProperty($obj_90538$$,"libraryId",{enumerable:!0,get:function(){return""+($file_id$jscomp$493$$??"")}});Object.defineProperty($obj_90538$$,"name",{enumerable:!0,get:function(){return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$){if(typeof $JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$!=="string")$JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$APP.$cljs$cst$725$name$$,$JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$);else if($app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")){var $typo$jscomp$inline_10820$$=$app$plugins$utils$proxy__GT_library_typography$$(this);$JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$=""+($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($typo$jscomp$inline_10820$$),"")??"")+" / "+($JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$??"");$JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$rename_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$,$JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$),$plugin_id$jscomp$58$$))}else $JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$APP.$cljs$cst$725$name$$,"Plugin doesn't have 'library:write' permission");
return $JSCompiler_inline_result$jscomp$2330_val_name_90608_value__$1$jscomp$inline_10821$$}});Object.defineProperty($obj_90538$$,"path",{enumerable:!0,get:function(){return $APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},set:function($val_path_90637$$){return function($self$jscomp$243_typo$jscomp$1$$,$value$jscomp$1201$$){return typeof $value$jscomp$1201$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$APP.$cljs$cst$296$path$$,
$value$jscomp$1201$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,"library:write")?($self$jscomp$243_typo$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$($self$jscomp$243_typo$jscomp$1$$),$APP.$cljs$cst$725$name$$,function($p1__90506_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$1201$$)," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__90506_SHARP_$$)].join("")}),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($self$jscomp$243_typo$jscomp$1$$,$file_id$jscomp$493$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$APP.$cljs$cst$296$path$$,"Plugin doesn't have 'library:write' permission")}.call(this,this,$val_path_90637$$)}});Object.defineProperty($obj_90538$$,"fontId",{enumerable:!0,get:function(){return $APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$){typeof $JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$!=="string"?$JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6569$fontId$$,$JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1763$font_id$$,$JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$),$JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6569$fontId$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2331_typo$jscomp$inline_10825_val_fontid_90645$$}});Object.defineProperty($obj_90538$$,"fontFamily",{enumerable:!0,get:function(){return $APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$){typeof $JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$!=="string"?$JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6570$fontFamily$$,$JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1764$font_family$$,$JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$),$JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6570$fontFamily$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2332_typo$jscomp$inline_10829_val_fontfamily_90653$$}});Object.defineProperty($obj_90538$$,"fontVariantId",{enumerable:!0,get:function(){return $APP.$cljs$cst$1765$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$){typeof $JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$!=="string"?$JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6571$fontVariantId$$,$JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1765$font_variant_id$$,$JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$),$JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6571$fontVariantId$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2333_typo$jscomp$inline_10833_val_fontvariantid_90661$$}});Object.defineProperty($obj_90538$$,"fontSize",{enumerable:!0,get:function(){return $APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$){typeof $JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$!=="string"?$JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6572$fontSize$$,$JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1766$font_size$$,$JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$),$JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6572$fontSize$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2334_typo$jscomp$inline_10837_val_fontsize_90669$$}});Object.defineProperty($obj_90538$$,"fontWeight",{enumerable:!0,get:function(){return $APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$){typeof $JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$!=="string"?$JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6573$fontWeight$$,$JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1767$font_weight$$,$JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$),$JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6573$fontWeight$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2335_typo$jscomp$inline_10841_val_fontweight_90677$$}});Object.defineProperty($obj_90538$$,"fontStyle",{enumerable:!0,get:function(){return $APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$){typeof $JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$!=="string"?$JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6574$fontStyle$$,$JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1768$font_style$$,$JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$),$JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6574$fontStyle$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2336_typo$jscomp$inline_10845_val_fontstyle_90685$$}});Object.defineProperty($obj_90538$$,"lineHeight",{enumerable:!0,get:function(){return $cljs$cst$6689$font_height$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$){typeof $JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$!=="string"?$JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6575$lineHeight$$,$JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$cljs$cst$6689$font_height$$,$JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$),$JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6575$lineHeight$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2337_typo$jscomp$inline_10849_val_lineheight_90693$$}});Object.defineProperty($obj_90538$$,"letterSpacing",{enumerable:!0,get:function(){return $APP.$cljs$cst$1772$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$){typeof $JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$!=="string"?$JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6576$letterSpacing$$,$JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1772$letter_spacing$$,$JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$),$JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6576$letterSpacing$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2338_typo$jscomp$inline_10853_val_letterspacing_90701$$}});Object.defineProperty($obj_90538$$,"textTransform",{enumerable:!0,get:function(){return $APP.$cljs$cst$1775$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$utils$proxy__GT_library_typography$$(this))},
set:function($JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$){typeof $JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$!=="string"?$JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6577$textTransform$$,$JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?($JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$proxy__GT_library_typography$$(this),$APP.$cljs$cst$1775$text_transform$$,$JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$),$JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$,
$file_id$jscomp$493$$))):$JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$=$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6577$textTransform$$,"Plugin doesn't have 'library:write' permission");return $JSCompiler_inline_result$jscomp$2339_typo$jscomp$inline_10857_val_texttransform_90709$$}});Object.defineProperty($obj_90538$$,"setFont",{enumerable:!1,get:function(){return function($font$jscomp$75_typo$jscomp$11$$,$source$jscomp$47_variant$jscomp$46$$){return $app$util$object$type_of_QMARK_$$($font$jscomp$75_typo$jscomp$11$$,
"FontProxy")?$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,"library:write")?($source$jscomp$47_variant$jscomp$46$$=$app$util$object$type_of_QMARK_$$($source$jscomp$47_variant$jscomp$46$$,"FontVariantProxy")?$source$jscomp$47_variant$jscomp$46$$:$font$jscomp$75_typo$jscomp$11$$,$font$jscomp$75_typo$jscomp$11$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$),$APP.$cljs$cst$1763$font_id$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($font$jscomp$75_typo$jscomp$11$$,"fontId"),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1764$font_family$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($font$jscomp$75_typo$jscomp$11$$,"fontFamily"),$APP.$cljs$cst$1765$font_variant_id$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($source$jscomp$47_variant$jscomp$46$$,"fontVariantId"),$APP.$cljs$cst$1768$font_style$$,
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($source$jscomp$47_variant$jscomp$46$$,"fontStyle"),$APP.$cljs$cst$1767$font_weight$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($source$jscomp$47_variant$jscomp$46$$,"fontWeight")])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($font$jscomp$75_typo$jscomp$11$$,$file_id$jscomp$493$$))):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,
$cljs$cst$6690$setFont$$,"Plugin doesn't have 'library:write' permission"):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6690$setFont$$,$font$jscomp$75_typo$jscomp$11$$)}.bind(this)}});Object.defineProperty($obj_90538$$,"remove",{enumerable:!1,get:function(){return function(){return $app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$delete_typography$$($id$jscomp$1139$$),
$plugin_id$jscomp$58$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$APP.$cljs$cst$2601$remove$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90538$$,"clone",{enumerable:!1,get:function(){return function(){if($app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,"library:write")){var $typo_id$$=$APP.$app$common$uuid$next$$(),$typo$jscomp$12$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,
$id$jscomp$1139$$),$APP.$cljs$cst$266$id$$,$typo_id$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$plugins$system_events$add_event$$($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($typo$jscomp$12$$,!1),$plugin_id$jscomp$58$$));return $app$plugins$library$lib_typography_proxy$$.$cljs$core$IFn$_invoke$arity$3$?$app$plugins$library$lib_typography_proxy$$.$cljs$core$IFn$_invoke$arity$3$($plugin_id$jscomp$58$$,$id$jscomp$1139$$,$typo_id$$):
$app$plugins$library$lib_typography_proxy$$($plugin_id$jscomp$58$$,$id$jscomp$1139$$,$typo_id$$)}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6615$clone$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90538$$,"applyToText",{enumerable:!1,get:function(){return function($shape$jscomp$1190_shape_id$jscomp$191$$){if($app$plugins$shape$shape_proxy_QMARK_$$($shape$jscomp$1190_shape_id$jscomp$191$$)){if($app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"content:write")){if($app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1190_shape_id$jscomp$191$$,"$page"))){$shape$jscomp$1190_shape_id$jscomp$191$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1190_shape_id$jscomp$191$$,"$id");var $typography$jscomp$43$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape$jscomp$1190_shape_id$jscomp$191$$]),
$typography$jscomp$43$$,$file_id$jscomp$493$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6679$applyToText$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6679$applyToText$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6679$applyToText$$,$shape$jscomp$1190_shape_id$jscomp$191$$)}.bind(this)}});Object.defineProperty($obj_90538$$,
"applyToTextRange",{enumerable:!1,get:function(){return function($end$jscomp$116_range$jscomp$20$$){if($app$util$object$type_of_QMARK_$$($end$jscomp$116_range$jscomp$20$$,"TextRange")){if($app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,"content:write")){if($app$plugins$utils$page_active_QMARK_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,"$page"))){var $shape_id$jscomp$192$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,
"$id"),$start$jscomp$260$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,"$start");$end$jscomp$116_range$jscomp$20$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($end$jscomp$116_range$jscomp$20$$,"$end");var $attrs$jscomp$194_typography$jscomp$44$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$);$attrs$jscomp$194_typography$jscomp$44$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$194_typography$jscomp$44$$,
$APP.$cljs$cst$1647$typography_ref_file$$,$file_id$jscomp$493$$),$APP.$cljs$cst$1762$typography_ref_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$194_typography$jscomp$44$$)),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_range$$($shape_id$jscomp$192$$,$start$jscomp$260$$,$end$jscomp$116_range$jscomp$20$$,
$attrs$jscomp$194_typography$jscomp$44$$))}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6679$applyToText$$,"Cannot modify a page that is not currently active")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6679$applyToText$$,"Plugin doesn't have 'content:write' permission")}return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6679$applyToText$$,$end$jscomp$116_range$jscomp$20$$)}.bind(this)}});Object.defineProperty($obj_90538$$,
"getPluginData",{enumerable:!1,get:function(){return function($key$jscomp$459$$){if(typeof $key$jscomp$459$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6691$typography_plugin_data_key$$,$key$jscomp$459$$);var $typography$jscomp$45$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$45$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$58$$))),$key$jscomp$459$$)}.bind(this)}});Object.defineProperty($obj_90538$$,"setPluginData",{enumerable:!1,get:function(){return function($key$jscomp$460$$,$value$jscomp$1211$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$493$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6686$setPluginData_non_local_library$$,$file_id$jscomp$493$$):typeof $key$jscomp$460$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6617$setPluginData_key$$,$key$jscomp$460$$):$value$jscomp$1211$$!=null&&typeof $value$jscomp$1211$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6618$setPluginData_value$$,$value$jscomp$1211$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,
"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$493$$,$APP.$cljs$cst$1997$typography$$,$id$jscomp$1139$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$58$$)),$key$jscomp$460$$,$value$jscomp$1211$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6619$setPluginData$$,
"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90538$$,"getPluginDataKeys",{enumerable:!1,get:function(){return function(){var $typography$jscomp$46$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$46$$,
$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("plugin",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($plugin_id$jscomp$58$$)))))}.bind(this)}});Object.defineProperty($obj_90538$$,"getSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$30$$,$key$jscomp$461$$){if(typeof $namespace$jscomp$30$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6620$getSharedPluginData_namespace$$,$namespace$jscomp$30$$);
if(typeof $key$jscomp$461$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6621$getSharedPluginData_key$$,$key$jscomp$461$$);var $typography$jscomp$47$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$47$$,$APP.$cljs$cst$1744$plugin_data$$),
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$30$$)),$key$jscomp$461$$)}.bind(this)}});Object.defineProperty($obj_90538$$,"setSharedPluginData",{enumerable:!1,get:function(){return function($namespace$jscomp$31$$,$key$jscomp$462$$,$value$jscomp$1212$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$493$$,$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)))?
$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6687$setSharedPluginData_non_local_library$$,$file_id$jscomp$493$$):typeof $namespace$jscomp$31$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6622$setSharedPluginData_namespace$$,$namespace$jscomp$31$$):typeof $key$jscomp$462$$!=="string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6623$setSharedPluginData_key$$,$key$jscomp$462$$):$value$jscomp$1212$$!=null&&typeof $value$jscomp$1212$$!==
"string"?$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6624$setSharedPluginData_value$$,$value$jscomp$1212$$):$app$plugins$register$check_permission$$($plugin_id$jscomp$58$$,"library:write")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$plugins$set_plugin_data$cljs$0core$0IFn$0_invoke$0arity$06$$($file_id$jscomp$493$$,$APP.$cljs$cst$1997$typography$$,$id$jscomp$1139$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$31$$),
$key$jscomp$462$$,$value$jscomp$1212$$)):$app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6625$setSharedPluginData$$,"Plugin doesn't have 'library:write' permission")}.bind(this)}});Object.defineProperty($obj_90538$$,"getSharedPluginDataKeys",{enumerable:!1,get:function(){return function($namespace$jscomp$32$$){if(typeof $namespace$jscomp$32$$!=="string")return $app$plugins$utils$not_valid$$($plugin_id$jscomp$58$$,$cljs$cst$6688$getSharedPluginDataKeys_namespace$$,$namespace$jscomp$32$$);
var $typography$jscomp$48$$=$app$plugins$utils$locate_library_typography$$($file_id$jscomp$493$$,$id$jscomp$1139$$);return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$array$$,$APP.$cljs$core$keys$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typography$jscomp$48$$,$APP.$cljs$cst$1744$plugin_data$$),$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$("shared",$namespace$jscomp$32$$))))}.bind(this)}});
return $obj_90538$$};$app$plugins$shape$variant_proxy$$=$app$plugins$library$variant_proxy$$;var $app$plugins$local_storage$local_storage$$;try{$app$plugins$local_storage$local_storage$$=$APP.$app$util$globals$global$$.localStorage}catch($e88768$jscomp$inline_10879$$){$app$plugins$local_storage$local_storage$$=null};$APP.$goog$exportSymbol$$("app.plugins.public_utils.centerShapes",function($shapes$jscomp$263_shapes__$1$jscomp$45$$){if($APP.$cljs$core$every_QMARK_$$($app$plugins$shape$shape_proxy_QMARK_$$,$shapes$jscomp$263_shapes__$1$jscomp$45$$)){if($APP.$cljs$core$empty_QMARK_$$($shapes$jscomp$263_shapes__$1$jscomp$45$$))return null;$shapes$jscomp$263_shapes__$1$jscomp$45$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$plugins$utils$proxy__GT_shape$$,$shapes$jscomp$263_shapes__$1$jscomp$45$$);
return $app$plugins$format$format_point$$($APP.$app$common$geom$rect$rect__GT_center$$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$263_shapes__$1$jscomp$45$$)))}return $app$plugins$utils$not_valid$$(null,$cljs$cst$6732$centerShapes$$,$shapes$jscomp$263_shapes__$1$jscomp$45$$)});$app$plugins$grid$shape_proxy_QMARK_$$=$app$plugins$flex$shape_proxy_QMARK_$$=$app$plugins$shape$shape_proxy_QMARK_$$;$app$plugins$ruler_guides$shape_proxy$$=$app$plugins$format$shape_proxy$$=$app$plugins$shape$shape_proxy$$;$app$plugins$ruler_guides$shape_proxy_QMARK_$$=$app$plugins$shape$shape_proxy_QMARK_$$;$app$plugins$shape$lib_typography_proxy_QMARK_$$=function($p$jscomp$286$$){return $app$util$object$type_of_QMARK_$$($p$jscomp$286$$,"LibraryTypographyProxy")};
$app$plugins$shape$lib_component_proxy$$=$app$plugins$library$lib_component_proxy$$;$APP.$goog$exportSymbol$$("features.grid",function(){$APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$features$toggle_feature$$())});return null});$APP.$goog$exportSymbol$$("features.get_enabled",function(){return $APP.$cljs$core$clj__GT_js$$($APP.$app$main$features$global_enabled_features$$)});
$APP.$goog$exportSymbol$$("features.get_team_enabled",function(){return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$227$features$$))});$APP.$goog$exportSymbol$$("features.plugins",function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$features$enable_feature$$());$app$plugins$init_plugins_runtime$$();return null});$APP.$app$common$logging$setup_BANG_$$();$APP.$app$common$logging$loggers$$.set("app.main",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1362$browser$$,$APP.$app$config$target$$)&&($APP.$app$common$logging$enabled_QMARK_$$("app.main",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1726$version$$,$APP.$cljs$cst$1278$full$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6734$asserts$$,$APP.$cljs$core$_STAR_assert_STAR_$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6735$build_date$$,$APP.$app$config$build_date$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3152$public_uri$$,""+($APP.$app$config$public_uri$$??"")],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2343$session_id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$session_id$$)],null)],null)}),null,"app.main",$APP.$cljs$cst$1161$info$$,!1),$APP.$app$common$logging$enabled_QMARK_$$("app.main",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"enabled flags"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1472$flags$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$APP.$app$config$flags$$))],null)],null)}),null,"app.main",$APP.$cljs$cst$1161$info$$,!1));
var $app$main$app_root$$,$el$jscomp$inline_10893$$=$APP.$goog$dom$getElement$$("app");$app$main$app_root$$=(0,$APP.$rumext$v2$create_root$$)($el$jscomp$inline_10893$$);$APP.$goog$exportSymbol$$("app.main.init",$app$main$init$$);
$APP.$app$main$reinit$$=function $app$main$reinit$$($var_args$jscomp$1531$$){switch(arguments.length){case 0:return $app$main$reinit$$.$cljs$core$IFn$_invoke$arity$0$();case 1:return $app$main$reinit$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$APP.$goog$exportSymbol$$("app.main.reinit",$APP.$app$main$reinit$$);$APP.$app$main$reinit$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $APP.$app$main$reinit$$.$cljs$core$IFn$_invoke$arity$1$(!1)};
$APP.$app$main$reinit$$.$cljs$core$IFn$_invoke$arity$1$=function($hard_QMARK_$$){$APP.$cljs$core$truth_$$($hard_QMARK_$$)&&($app$main$app_root$$.unmount(),$app$main$app_root$$=(0,$APP.$rumext$v2$create_root$$)($APP.$goog$dom$getElement$$("app")));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$event$initialize$$());return $rumext$v2$render_BANG_$$()};$APP.$app$main$reinit$$.$cljs$lang$maxFixedArity$=1;Error.stackTraceLimit=50;export const init=$app$main$init$$;
//# sourceMappingURL=main.js.map
