/*
http://meyerweb.com/eric/tools/css/reset/
v2.0 | 20110126
License: none (public domain)
*/
div {
  vertical-align: top;
}

img {
  display: block;
}

a,
abbr,
acronym,
address,
applet,
article,
aside,
audio,
b,
big,
blockquote,
body,
canvas,
caption,
center,
cite,
code,
dd,
del,
details,
dfn,
div,
dl,
dt,
em,
embed,
fieldset,
figcaption,
figure,
footer,
form,
h1,
h2,
h3,
h4,
h5,
h6,
header,
hgroup,
html,
i,
iframe,
img,
ins,
kbd,
label,
legend,
li,
mark,
menu,
nav,
object,
ol,
output,
p,
pre,
q,
ruby,
s,
samp,
section,
small,
span,
strike,
strong,
sub,
summary,
sup,
table,
tbody,
td,
tfoot,
th,
thead,
time,
tr,
tt,
u,
ul,
var,
video {
  border: 0;
  font: inherit;
  /* stylelint-disable-next-line declaration-property-unit-allowed-list */
  font-size: 100%;
  line-height: 1.43;
  margin: 0;
  padding: 0;
  text-decoration: none;
  vertical-align: baseline;
}

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
menu,
nav,
section {
  display: block;
}

body {
  line-height: 1;
}

ol,
ul {
  list-style: none;
}

blockquote,
q {
  quotes: none;
}

blockquote::before,
blockquote::after,
q::before,
q::after {
  content: "";
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

select {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
}

:root {
  --db-primary-60: rgba(24, 24, 26, 0.6);
  --df-secondary: #8f9da3;
  --df-secondary-40: rgba(143, 157, 163, 0.4);
  --da-tertiary-10: rgba(0, 209, 184, 0.1);
  --da-tertiary-70: rgba(0, 209, 184, 0.7);
  --lb-primary-60: rgba(255, 255, 255, 0.6);
  --lb-quaternary: #eef0f2;
  --lf-secondary-40: rgba(73, 94, 116, 0.4);
  --la-tertiary-10: rgba(140, 51, 235, 0.1);
  --la-tertiary-70: rgba(140, 51, 235, 0.7);
  --status-color-success-200: #a7e8d9;
  --status-color-success-500: #2d9f8f;
  --status-color-warning-500: #f5a91b;
  --status-color-error-500: #ff3277;
  --status-color-info-500: #0e9be9;
  --app-white: #fff;
  --app-black: #000;
  --google-login-background: #4285f4;
  --google-login-background-hover: rgb(12.8425, 91.065, 220.6575);
  --google-login-foreground: var(--app-white);
  --github-login-background: #4c4c4c;
  --github-login-background-hover: rgb(37.75, 37.75, 37.75);
  --github-login-foreground: var(--app-white);
  --oidc-login-background: #b3b3b3;
  --oidc-login-background-hover: rgb(140.75, 140.75, 140.75);
  --oidc-login-foreground: var(--app-white);
  --gitlab-login-background: #fc6d26;
  --gitlab-login-background-hover: rgb(210.5886363636, 71.8136363636, 2.9113636364);
  --gitlab-login-foreground: var(--app-white);
}

@font-face {
  font-family: "worksans";
  src: url("../fonts/WorkSans-VariableFont.ttf") format("truetype");
  unicode-range: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD, U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF";
}
@font-face {
  font-family: "vazirmatn";
  src: url("../fonts/Vazirmatn-VariableFont.ttf") format("truetype");
  unicode-range: "U+0600-06FF, U+0750-077F, U+0870-088E, U+0890-0891, U+0898-08E1, U+08E3-08FF, U+200C-200E, U+2010-2011, U+204F, U+2E41, U+FB50-FDFF, U+FE70-FE74, U+FE76-FEFC, U+102E0-102FB, U+10E60-10E7E, U+10EFD-10EFF, U+1EE00-1EE03, U+1EE05-1EE1F, U+1EE21-1EE22, U+1EE24, U+1EE27, U+1EE29-1EE32, U+1EE34-1EE37, U+1EE39, U+1EE3B, U+1EE42, U+1EE47, U+1EE49, U+1EE4B, U+1EE4D-1EE4F, U+1EE51-1EE52, U+1EE54, U+1EE57, U+1EE59, U+1EE5B, U+1EE5D, U+1EE5F, U+1EE61-1EE62, U+1EE64, U+1EE67-1EE6A, U+1EE6C-1EE72, U+1EE74-1EE77, U+1EE79-1EE7C, U+1EE7E, U+1EE80-1EE89, U+1EE8B-1EE9B, U+1EEA1-1EEA3, U+1EEA5-1EEA9, U+1EEAB-1EEBB, U+1EEF0-1EEF1";
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-extralight.woff2") format("woff2"), url("../fonts/sourcesanspro-extralight.ttf") format("truetype");
  font-weight: 200;
  font-style: normal;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-extralightitalic.woff2") format("woff2"), url("../fonts/sourcesanspro-extralightitalic.ttf") format("truetype");
  font-weight: 200;
  font-style: italic;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-light.woff2") format("woff2"), url("../fonts/sourcesanspro-light.ttf") format("truetype");
  font-weight: 300;
  font-style: normal;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-lightitalic.woff2") format("woff2"), url("../fonts/sourcesanspro-lightitalic.ttf") format("truetype");
  font-weight: 300;
  font-style: italic;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-regular.woff2") format("woff2"), url("../fonts/sourcesanspro-regular.ttf") format("truetype");
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-italic.woff2") format("woff2"), url("../fonts/sourcesanspro-italic.ttf") format("truetype");
  font-weight: normal;
  font-style: italic;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-semibold.woff2") format("woff2"), url("../fonts/sourcesanspro-semibold.ttf") format("truetype");
  font-weight: 600;
  font-style: normal;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-semibolditalic.woff2") format("woff2"), url("../fonts/sourcesanspro-semibolditalic.ttf") format("truetype");
  font-weight: 600;
  font-style: italic;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-bold.woff2") format("woff2"), url("../fonts/sourcesanspro-bold.ttf") format("truetype");
  font-weight: bold;
  font-style: normal;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-bolditalic.woff2") format("woff2"), url("../fonts/sourcesanspro-bolditalic.ttf") format("truetype");
  font-weight: bold;
  font-style: italic;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-black.woff2") format("woff2"), url("../fonts/sourcesanspro-black.ttf") format("truetype");
  font-weight: 900;
  font-style: normal;
}
@font-face {
  font-family: "sourcesanspro";
  src: url("../fonts/sourcesanspro-blackitalic.woff2") format("woff2"), url("../fonts/sourcesanspro-blackitalic.ttf") format("truetype");
  font-weight: 900;
  font-style: italic;
}
@font-face {
  font-family: "robotomono";
  src: url("../fonts/RobotoMono-Regular.woff2") format("woff2"), url("../fonts/RobotoMono-Regular.ttf") format("truetype");
  font-weight: normal;
  font-style: normal;
  unicode-range: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD, U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF";
}
/*!
 * animate.css -http://daneden.me/animate
 * Version - 3.5.1
 * Licensed under the MIT license - http://opensource.org/licenses/MIT
 *
 * Copyright (c) 2016 Daniel Eden
 */
.animated {
  animation-duration: 1s;
  animation-fill-mode: both;
}

@keyframes fade-in {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
.fade-in {
  animation-name: fade-in;
}

@keyframes fade-in-down {
  0% {
    opacity: 0;
    transform: translate3d(0, -100%, 0);
  }
  100% {
    opacity: 1;
    transform: none;
  }
}
.fade-in-down {
  animation-name: fade-in-down;
}

:root {
  /*!
    Theme: GitHub Dark Dimmed
    Description: Dark dimmed theme as seen on github.com
    Author: github.com
    Maintainer: @Hirse
    Updated: 2021-05-15

    Colors taken from GitHub's CSS
  */
}
:root .hljs {
  color: #adbac7;
  background: #22272e;
}
:root .hljs-doctag,
:root .hljs-keyword,
:root .hljs-meta .hljs-keyword,
:root .hljs-template-tag,
:root .hljs-template-variable,
:root .hljs-type,
:root .hljs-variable.language_ {
  /* prettylights-syntax-keyword */
  color: #f47067;
}
:root .hljs-title,
:root .hljs-title.class_,
:root .hljs-title.class_.inherited__,
:root .hljs-title.function_ {
  /* prettylights-syntax-entity */
  color: #dcbdfb;
}
:root .hljs-attr,
:root .hljs-attribute,
:root .hljs-literal,
:root .hljs-meta,
:root .hljs-number,
:root .hljs-operator,
:root .hljs-variable,
:root .hljs-selector-attr,
:root .hljs-selector-class,
:root .hljs-selector-id {
  /* prettylights-syntax-constant */
  color: #6cb6ff;
}
:root .hljs-regexp,
:root .hljs-string,
:root .hljs-meta .hljs-string {
  /* prettylights-syntax-string */
  color: #96d0ff;
}
:root .hljs-built_in,
:root .hljs-symbol {
  /* prettylights-syntax-variable */
  color: #f69d50;
}
:root .hljs-comment,
:root .hljs-code,
:root .hljs-formula {
  /* prettylights-syntax-comment */
  color: #768390;
}
:root .hljs-name,
:root .hljs-quote,
:root .hljs-selector-tag,
:root .hljs-selector-pseudo {
  /* prettylights-syntax-entity-tag */
  color: #8ddb8c;
}
:root .hljs-subst {
  /* prettylights-syntax-storage-modifier-import */
  color: #adbac7;
}
:root .hljs-section {
  /* prettylights-syntax-markup-heading */
  color: #316dca;
  font-weight: 700;
}
:root .hljs-bullet {
  /* prettylights-syntax-markup-list */
  color: #eac55f;
}
:root .hljs-emphasis {
  /* prettylights-syntax-markup-italic */
  color: #adbac7;
  font-style: italic;
}
:root .hljs-strong {
  /* prettylights-syntax-markup-bold */
  color: #adbac7;
  font-weight: 700;
}
:root .hljs-addition {
  /* prettylights-syntax-markup-inserted */
  color: #b4f1b4;
  background-color: #1b4721;
}
:root .hljs-deletion {
  /* prettylights-syntax-markup-deleted */
  color: #ffd8d3;
  background-color: #78191b;
}
:root .hljs-char.escape_,
:root .hljs-link,
:root .hljs-params,
:root .hljs-property,
:root .hljs-punctuation,
:root .hljs-tag {
  /* purposely ignored */
}

.light {
  /*!
    Theme: GitHub
    Description: Light theme as seen on github.com
    Author: github.com
    Maintainer: @Hirse
    Updated: 2021-05-15

    Outdated base version: https://github.com/primer/github-syntax-light
    Current colors taken from GitHub's CSS
  */
}
.light .hljs {
  color: #24292e;
  background: #fff;
}
.light .hljs-doctag,
.light .hljs-keyword,
.light .hljs-meta .hljs-keyword,
.light .hljs-template-tag,
.light .hljs-template-variable,
.light .hljs-type,
.light .hljs-variable.language_ {
  /* prettylights-syntax-keyword */
  color: #d73a49;
}
.light .hljs-title,
.light .hljs-title.class_,
.light .hljs-title.class_.inherited__,
.light .hljs-title.function_ {
  /* prettylights-syntax-entity */
  color: #6f42c1;
}
.light .hljs-attr,
.light .hljs-attribute,
.light .hljs-literal,
.light .hljs-meta,
.light .hljs-number,
.light .hljs-operator,
.light .hljs-variable,
.light .hljs-selector-attr,
.light .hljs-selector-class,
.light .hljs-selector-id {
  /* prettylights-syntax-constant */
  color: #005cc5;
}
.light .hljs-regexp,
.light .hljs-string,
.light .hljs-meta .hljs-string {
  /* prettylights-syntax-string */
  color: #032f62;
}
.light .hljs-built_in,
.light .hljs-symbol {
  /* prettylights-syntax-variable */
  color: #e36209;
}
.light .hljs-comment,
.light .hljs-code,
.light .hljs-formula {
  /* prettylights-syntax-comment */
  color: #6a737d;
}
.light .hljs-name,
.light .hljs-quote,
.light .hljs-selector-tag,
.light .hljs-selector-pseudo {
  /* prettylights-syntax-entity-tag */
  color: #22863a;
}
.light .hljs-subst {
  /* prettylights-syntax-storage-modifier-import */
  color: #24292e;
}
.light .hljs-section {
  /* prettylights-syntax-markup-heading */
  color: #005cc5;
  font-weight: 700;
}
.light .hljs-bullet {
  /* prettylights-syntax-markup-list */
  color: #735c0f;
}
.light .hljs-emphasis {
  /* prettylights-syntax-markup-italic */
  color: #24292e;
  font-style: italic;
}
.light .hljs-strong {
  /* prettylights-syntax-markup-bold */
  color: #24292e;
  font-weight: 700;
}
.light .hljs-addition {
  /* prettylights-syntax-markup-inserted */
  color: #22863a;
  background-color: #f0fff4;
}
.light .hljs-deletion {
  /* prettylights-syntax-markup-deleted */
  color: #b31d28;
  background-color: #ffeef0;
}
.light .hljs-char.escape_,
.light .hljs-link,
.light .hljs-params,
.light .hljs-property,
.light .hljs-punctuation,
.light .hljs-tag {
  /* purposely ignored */
  color: #6a737d;
}

.sb-show-main.sb-main-fullscreen,
.sb-show-main.sb-main-padded {
  overflow-y: auto;
}

:root {
  --color-background-disabled: var(--df-secondary);
  --color-foreground-disabled: var(--df-secondary-40);
  --color-accent-tertiary-muted: var(--da-tertiary-10);
  --overlay-color: var(--db-primary-60);
}

.light {
  --color-background-disabled: var(--lb-quaternary);
  --color-foreground-disabled: var(--lf-secondary-40);
  --color-accent-tertiary-muted: var(--la-tertiary-10);
  --overlay-color: var(--lb-primary-60);
}

.light,
.default {
  --canvas-background-color: var(--color-background-primary);
  --canvas-fill-color: var(--color-canvas);
  --scrollbar-background-color: var(--color-foreground-secondary);
  --panel-background-color: var(--color-background-primary);
  --panel-border-color: var(--color-background-quaternary);
  --app-background: var(--color-background-primary);
  --loader-background: var(--color-background-primary);
  --button-foreground-hover: var(--color-accent-primary);
  --button-background-color-focus: var(--color-background-secondary);
  --button-foreground-color-focus: var(--color-foreground-primary);
  --button-border-color-focus: var(--color-accent-primary);
  --button-foreground-color-disabled: var(--color-foreground-disabled);
  --button-background-color-disabled: var(--color-background-quaternary);
  --button-border-color-disabled: var(--color-background-quaternary);
  --button-primary-background-color-rest: var(--color-accent-primary);
  --button-primary-border-color-rest: var(--color-accent-primary);
  --button-primary-foreground-color-rest: var(--color-background-secondary);
  --button-primary-background-color-hover: var(--color-accent-tertiary);
  --button-primary-border-color-hover: var(--color-accent-tertiary);
  --button-primary-foreground-color-hover: var(--color-background-secondary);
  --button-primary-background-color-active: var(--color-background-secondary);
  --button-primary-border-color-active: var(--color-background-secondary);
  --button-primary-foreground-color-active: var(--color-accent-primary);
  --button-primary-background-color-focus: var(--color-background-tertiary);
  --button-primary-border-color-focus: var(--color-accent-primary);
  --button-primary-foreground-color-focus: var(--color-foreground-secondary);
  --button-secondary-background-color-rest: var(--color-background-tertiary);
  --button-secondary-border-color-rest: var(--color-background-tertiary);
  --button-secondary-foreground-color-rest: var(--color-foreground-secondary);
  --button-secondary-background-color-hover: var(--color-background-quaternary);
  --button-secondary-border-color-hover: var(--color-background-quaternary);
  --button-secondary-foreground-color-hover: var(--color-accent-primary);
  --button-secondary-background-color-active: var(--color-background-secondary);
  --button-secondary-border-color-active: var(--color-background-quaternary);
  --button-secondary-foreground-color-active: var(--color-accent-primary);
  --button-secondary-background-color-focus: var(--color-background-tertiary);
  --button-secondary-border-color-focus: var(--color-accent-primary);
  --button-secondary-foreground-color-focus: var(--color-foreground-secondary);
  --button-tertiary-foreground-color-rest: var(--color-foreground-secondary);
  --button-tertiary-background-color-hover: var(--color-background-quaternary);
  --button-tertiary-border-color-hover: var(--color-background-quaternary);
  --button-tertiary-foreground-color-hover: var(--color-accent-primary);
  --button-tertiary-background-color-active: var(--color-background-secondary);
  --button-tertiary-border-color-active: var(--color-background-quaternary);
  --button-tertiary-foreground-color-active: var(--color-accent-primary);
  --button-tertiary-background-color-focus: var(--color-background-tertiary);
  --button-tertiary-border-color-focus: var(--color-accent-primary);
  --button-tertiary-foreground-color-focus: var(--color-foreground-primary);
  --expand-button-icon-border-width: 0;
  --expand-button-icon-border-width-selected: 0;
  --button-icon-foreground-color: var(--color-foreground-secondary);
  --button-icon-foreground-color-hover: var(--color-foreground-secondary);
  --button-icon-background-color-selected: var(--color-background-quaternary);
  --button-icon-foreground-color-selected: var(--color-accent-primary);
  --button-icon-border-color-selected: var(--color-background-quaternary);
  --button-radio-background-color-rest: var(--color-background-tertiary);
  --button-radio-border-color-rest: var(--color-background-tertiary);
  --button-radio-foreground-color-rest: var(--color-foreground-secondary);
  --button-radio-border-color-hover: var(--color-background-quaternary);
  --button-radio-foreground-color-hover: var(--color-accent-primary);
  --button-radio-background-color-active: var(--color-background-quaternary);
  --button-radio-border-color-active: var(--color-background-quaternary);
  --button-radio-foreground-color-active: var(--color-accent-primary);
  --button-radio-background-color-focus: var(--color-background-tertiary);
  --button-radio-border-color-focus: var(--color-accent-primary);
  --button-radio-foreground-color-focus: var(--color-foreground-secondary);
  --button-warning-background-color-rest: var(--status-color-warning-500);
  --button-warning-border-color-rest: var(--status-color-warning-500);
  --button-warning-foreground-color-rest: var(--color-background-secondary);
  --button-disabled-background-color-rest: var(--color-background-disabled);
  --button-disabled-border-color-rest: var(--color-background-disabled);
  --button-disabled-foreground-color-rest: var(--color-foreground-disabled);
  --button-constraint-background-color-rest: var(--color-foreground-secondary);
  --button-constraint-border-color-rest: var(--color-background-tertiary);
  --button-constraint-border-color-hover: var(--color-accent-primary-muted);
  --button-constraint-background-color-hover: var(--color-accent-primary);
  --constraint-widget-background-color: var(--color-background-tertiary);
  --constraint-center-area-background-color: var(--color-background-primary);
  --tabs-background-color: var(--color-background-secondary);
  --tab-background-color-hover: var(--color-background-primary);
  --tab-background-color-selected: var(--color-background-quaternary);
  --tab-foreground-color: var(--color-foreground-secondary);
  --tab-foreground-color-hover: var(--color-foreground-primary);
  --tab-foreground-color-selected: var(--color-accent-primary);
  --tab-border-color: var(--color-background-secondary);
  --tab-border-color-selected: var(--color-background-secondary);
  --title-background-color: var(--color-background-primary);
  --title-foreground-color: var(--color-foreground-secondary);
  --title-foreground-color-hover: var(--color-foreground-primary);
  --layer-row-background-color: var(--color-background-primary);
  --layer-row-background-color-hover: var(--color-background-secondary);
  --layer-row-background-color-selected: var(--color-background-quaternary);
  --layer-row-background-color-drag: var(--color-background-quaternary);
  --layer-row-foreground-color: var(--color-foreground-secondary);
  --layer-row-foreground-color-hover: var(--color-accent-primary);
  --layer-row-foreground-color-selected: var(--color-accent-primary);
  --layer-row-foreground-color-drag: var(--color-accent-tertiary);
  --layer-row-foreground-color-focus: var(--color-foreground-primary);
  --layer-row-foreground-color-placeholder: var(--color-foreground-secondary);
  --layer-row-border-color-focus: var(--color-accent-primary);
  --layer-child-row-background-color: var(--color-background-tertiary);
  --layer-child-row-foreground-color: var(--color-foreground-secondary);
  --layer-row-component-foreground-color: var(--color-accent-secondary);
  --palette-background-color: var(--color-background-primary);
  --palette-btn-background-color-selected: var(--color-background-secondary);
  --palette-btn-border-color-selected: var(--color-background-quaternary);
  --palette-btn-foreground-color-selected: var(--color-accent-primary);
  --palette-text-color: var(--color-foreground-secondary);
  --palette-text-color-selected: var(--color-foreground-primary);
  --palette-text-background-color: var(--color-background-tertiary);
  --palette-text-background-color-hover: var(--color-background-quaternary);
  --palette-button-shadow-initial: var(--color-background-primary);
  --palette-button-shadow-final: transparent;
  --palette-handler-background-color: var(--color-background-quaternary);
  --color-bullet-background-color: var(--app-white);
  --color-bullet-border-color: var(--color-background-quaternary);
  --color-bullet-border-color-selected: var(--color-accent-primary);
  --icon-foreground: var(--color-foreground-secondary);
  --main-icon-foreground: var(--color-foreground-primary);
  --icon-foreground-hover: var(--color-foreground-primary);
  --icon-foreground-accept: var(--status-color-success-500);
  --icon-foreground-discard: var(--status-color-error-500);
  --icon-foreground-active: var(--color-accent-primary);
  --icon-foreground-selected: var(--color-accent-tertiary);
  --input-placeholder-color: var(--color-foreground-secondary);
  --input-background-color: var(--color-background-tertiary);
  --input-foreground-color: var(--color-foreground-secondary);
  --input-border-color: var(--color-background-tertiary);
  --input-background-color-rest: var(--color-background-tertiary);
  --input-foreground-color-rest: var(--color-foreground-primary);
  --input-border-color-rest: var(--color-background-tertiary);
  --input-background-color-hover: var(--color-background-quaternary);
  --input-foreground-color-hover: var(--color-foreground-primary);
  --input-border-color-hover: var(--color-background-quaternary);
  --input-background-color-focus: var(--color-background-tertiary);
  --input-foreground-color-focus: var(--color-foreground-primary);
  --input-border-color-focus: var(--color-accent-primary);
  --input-background-color-active: var(--color-background-primary);
  --input-foreground-color-active: var(--color-foreground-primary);
  --input-border-outline-color-active: var(--color-accent-primary-muted);
  --input-border-color-active: var(--color-accent-primary);
  --input-background-color-disabled: var(--color-background-primary);
  --input-foreground-color-disabled: var(--color-foreground-secondary);
  --input-border-color-disabled: var(--color-background-quaternary);
  --input-border-color-error: var(--status-color-error-500);
  --input-border-color-success: var(--color-accent-primary);
  --input-details-color: var(--color-background-primary);
  --input-checkbox-background-color-rest: var(--color-background-quaternary);
  --input-checkbox-border-color-rest: var(--color-foreground-secondary);
  --input-checkbox-border-color-active: var(--color-background-quaternary);
  --input-checkbox-border-color-focus: var(--color-accent-primary);
  --input-checkbox-border-color: var(--color-background-secondary);
  --input-checkbox-border-color-hover: var(--color-accent-primary-muted);
  --input-checkbox-background-color-intermediate: var(--color-foreground-secondary);
  --input-checkbox-border-color-intermediate: var(--color-foreground-secondary);
  --input-checkbox-foreground-color-intermediate: var(--color-background-secondary);
  --input-checkbox-inactive-background-color: var(--color-foreground-secondary);
  --input-checkbox-inactive-foreground-color: var(--color-background-primary);
  --input-checkbox-background-color-active: var(--color-accent-primary);
  --input-checkbox-foreground-color-active: var(--color-background-primary);
  --input-checkbox-text-foreground-color: var(--color-foreground-secondary);
  --menu-background-color: var(--color-background-tertiary);
  --menu-foreground-color: var(--color-foreground-primary);
  --menu-icon-foreground-color: var(--color-foreground-secondary);
  --menu-background-color-selected: var(--color-background-tertiary);
  --menu-background-color-hover: var(--color-background-quaternary);
  --menu-foreground-color-hover: var(--color-foreground-primary);
  --menu-background-color-focus: var(--color-background-tertiary);
  --menu-foreground-color-focus: var(--color-foreground-primary);
  --menu-foreground-color-rest: var(--color-foreground-secondary);
  --menu-border-color-focus: var(--color-accent-primary);
  --menu-shortcut-background-color: var(--color-background-primary);
  --menu-shortcut-foreground-color: var(--color-foreground-secondary);
  --menu-shortcut-foreground-color-selected: var(--color-foreground-primary);
  --menu-shortcut-foreground-color-hover: var(--color-foreground-primary);
  --menu-shadow-color: var(--color-shadow-dark);
  --menu-background-color-disabled: var(--color-background-primary);
  --menu-foreground-color-disabled: var(--color-foreground-secondary);
  --menu-border-color-disabled: var(--color-background-quaternary);
  --context-menu-background-color: var(--color-background-tertiary);
  --context-menu-foreground-color: var(--color-foreground-secondary);
  --context-menu-background-color-selected: var(--color-background-quaternary);
  --context-menu-foreground-color-selected: var(--color-foreground-primary);
  --assets-title-background-color: var(--color-background-primary);
  --assets-item-background-color: var(--color-background-tertiary);
  --assets-item-background-color-hover: var(--color-background-quaternary);
  --assets-item-name-background-color: var(--color-background-primary);
  --assets-item-name-foreground-color-rest: var(--color-foreground-secondary);
  --assets-item-name-foreground-color: var(--color-foreground-primary);
  --assets-item-name-foreground-color-hover: var(--color-foreground-primary);
  --assets-item-name-foreground-color-disabled: var(--color-foreground-disabled);
  --assets-item-border-color: var(--color-accent-primary);
  --assets-item-background-color-drag: transparent;
  --assets-item-border-color-drag: var(--color-accent-primary-muted);
  --assets-component-background-color: var(--color-canvas);
  --assets-component-background-color-disabled: var(--color-foreground-secondary);
  --assets-component-border-color: var(--color-background-tertiary);
  --assets-component-border-selected: var(--color-accent-tertiary);
  --assets-component-second-border-selected: var(--color-background-primary);
  --assets-component-hightlight: var(--color-accent-secondary);
  --radio-btns-background-color: var(--color-background-tertiary);
  --radio-btn-background-color-selected: var(--color-background-quaternary);
  --radio-btn-foreground-color: var(--color-foreground-secondary);
  --radio-btn-foreground-color-selected: var(--color-accent-primary);
  --radio-btn-border-color: var(--color-background-tertiary);
  --radio-btn-border-color-selected: var(--color-background-quaternary);
  --library-name-foreground-color: var(--color-foreground-primary);
  --library-content-foreground-color: var(--color-foreground-secondary);
  --dropdown-background-color: var(--color-background-tertiary);
  --dropdown-separator-color: var(--color-background-primary);
  --profile-drowpdown-background-color: var(--color-background-primary);
  --not-found-background-color: var(--color-background-tertiary);
  --not-found-foreground-color: var(--color-foreground-secondary);
  --entry-foreground-color: var(--color-foreground-secondary);
  --entry-background-color: var(--color-background-tertiary);
  --entry-background-color-disabled: var(--color-background-primary);
  --entry-border-color-disabled: var(--color-background-quaternary);
  --entry-foreground-color-hover: var(--color-foreground-primary);
  --entry-background-color-hover: var(--color-background-quaternary);
  --empty-message-background-color: var(--color-background-tertiary);
  --empty-message-foreground-color: var(--color-foreground-secondary);
  --user-count-background-color: var(--color-accent-primary);
  --user-count-foreground-color: var(--color-background-secondary);
  --colorpicker-details-color: var(--color-background-quaternary);
  --colorpicker-details-color-selected: var(--color-accent-primary);
  --colorpicker-handlers-color: var(--color-foreground-primary);
  --colorpicker-background-color: var(--color-foreground-primary);
  --comment-title-color: var(--color-foreground-primary);
  --comment-subtitle-color: var(--color-foreground-secondary);
  --comment-bullet-background-color-rest: var(--color-background-quaternary);
  --comment-bullet-foreground-color-rest: var(--color-foreground-primary);
  --comment-bullet-border-color-rest: var(--color-background-secondary);
  --comment-bullet-background-color-unread: var(--color-accent-primary);
  --comment-bullet-foreground-color-unread: var(--color-background-primary);
  --comment-bullet-border-color-unread: var(--color-background-secondary);
  --comment-bullet-background-color-resolved: var(--color-background-primary);
  --comment-bullet-foreground-color-resolved: var(--color-foreground-secondary);
  --comment-bullet-border-color-resolved: var(--color-background-quaternary);
  --comment-modal-background-color: var(--color-background-primary);
  --comment-thread-background-color-hover: var(--color-background-primary);
  --grid-editor-marker-color: var(--color-accent-quaternary);
  --grid-editor-marker-text: var(--color-accent-quaternary);
  --grid-editor-area-background: var(--color-accent-quaternary);
  --grid-editor-area-text: var(--color-accent-quaternary);
  --grid-editor-line-color: var(--color-accent-quaternary);
  --grid-editor-plus-btn-foreground: var(--app-white);
  --grid-editor-plus-btn-background: var(--color-accent-quaternary);
  --modal-background-color: var(--color-background-primary);
  --modal-title-foreground-color: var(--color-foreground-primary);
  --modal-text-foreground-color: var(--color-foreground-secondary);
  --modal-hint-border-color: var(--color-background-quaternary);
  --modal-button-background-color-error: var(--status-color-error-500);
  --modal-button-foreground-color-error: var(--color-foreground-primary);
  --modal-link-foreground-color: var(--color-accent-primary);
  --modal-border-color: var(--color-background-quaternary);
  --modal-separator-background-color: var(--color-background-quaternary);
  --modal-navigator-foreground-color-rest: var(--color-background-quaternary);
  --modal-navigator-foreground-color-active: var(--color-accent-primary);
  --alert-background-color-default: var(--color-background-primary);
  --alert-text-foreground-color-default: var(--color-foreground-primary);
  --alert-icon-foreground-color-default: var(--color-foreground-primary);
  --alert-border-color-default: var(--color-background-quaternary);
  --alert-background-color-success: var(--color-background-success);
  --alert-text-foreground-color-success: var(--color-foreground-primary);
  --alert-icon-foreground-color-success: var(--color-accent-success);
  --alert-border-color-success: var(--color-accent-success);
  --alert-background-color-warning: var(--color-background-warning);
  --alert-text-foreground-color-warning: var(--color-foreground-primary);
  --alert-icon-foreground-color-warning: var(--color-accent-warning);
  --alert-border-color-warning: var(--color-accent-warning);
  --alert-background-color-error: var(--color-background-error);
  --alert-text-foreground-color-error: var(--color-foreground-primary);
  --alert-icon-foreground-color-error: var(--color-accent-error);
  --alert-border-color-error: var(--color-accent-error);
  --alert-background-color-info: var(--color-background-info);
  --alert-text-foreground-color-info: var(--color-foreground-primary);
  --alert-icon-foreground-color-info: var(--color-accent-info);
  --alert-border-color-info: var(--color-accent-info);
  --alert-text-foreground-color-focus: var(--color-accent-primary);
  --alert-border-color-focus: var(--color-accent-primary);
  --notification-foreground-color-default: var(--color-foreground-secondary);
  --element-foreground-warning: var(--status-color-warning-500);
  --element-foreground-error: var(--status-color-error-500);
  --status-widget-background-color-success: var(--status-color-success-500);
  --status-widget-background-color-warning: var(--status-color-warning-500);
  --status-widget-background-color-pending: var(--status-color-info-500);
  --status-widget-background-color-error: var(--status-color-error-500);
  --status-widget-icon-foreground-color: var(--color-background-primary);
  --search-bar-background-color: var(--color-background-primary);
  --search-bar-input-background-color: var(--color-background-tertiary);
  --search-bar-input-border-color: var(--color-background-tertiary);
  --search-bar-input-border-color-focus: var(--color-accent-primary);
  --search-bar-placeholder-foreground-color: var(--color-foreground-secondary);
  --search-bar-foreground-color: var(--color-foreground-primary);
  --search-bar-icon-foreground-color: var(--color-foreground-secondary);
  --search-bar-icon-foreground-color-hover: var(--color-accent-primary);
  --pill-background-color: var(--color-background-tertiary);
  --pill-foreground-color: var(--color-foreground-primary);
  --link-foreground-color: var(--color-accent-primary);
  --register-confirmation-color: var(--status-color-success-200);
  --resize-area-background-color: var(--color-background-primary);
  --resize-area-border-color: var(--color-background-quaternary);
  --profile-section-background-color: var(--color-background-tertiary);
  --dashboard-list-background-color: var(--color-background-tertiary);
  --dashboard-list-foreground-color: var(--color-foreground-primary);
  --dashboard-list-text-foreground-color: var(--color-foreground-secondary);
  --communication-tag-background-color: var(--color-foreground-primary);
  --communication-tag-foreground-color: var(--color-background-tertiary);
  --viewer-background-color: var(--color-background-secondary);
  --viewer-paginator-background-color: var(--color-background-tertiary);
  --viewer-controls-background-color: var(--color-background-primary);
  --viewer-inspect-border-color: var(--color-background-tertiary);
  --viewer-thumbnails-control-foreground-color: var(--color-foreground-secondary);
  --viewer-thumbnail-border-color: var(--color-accent-primary);
  --viewer-thumbnail-background-color-selected: var(--color-accent-primary-muted);
  --text-editor-selection-background-color: var(--da-tertiary-70);
  --text-editor-selection-foreground-color: var(--app-white);
  --text-editor-caret-color: var(--app-black);
  --new-team-button-background-color: var(--color-background-primary);
  --sidebar-element-foreground-color: var(--color-foreground-secondary);
  --sidebar-element-background-color-hover: var(--color-background-secondary);
  --sidebar-element-foreground-color-hover: var(--color-accent-primary);
  --sidebar-element-background-color-selected: var(--color-background-quaternary);
  --sidebar-element-foreground-color-selected: var(--color-accent-primary);
  --profile-foreground-color: var(--color-foreground-primary);
}

#app {
  background-color: var(--app-background);
}

.light {
  --tabs-background-color: var(--color-background-tertiary);
  --tab-background-color-selected: var(--color-background-primary);
  --tab-border-color: var(--color-background-tertiary);
  --tab-border-color-selected: var(--color-background-secondary);
  --radio-btns-background-color: var(--color-background-tertiary);
  --radio-btn-background-color-selected: var(--color-background-primary);
  --radio-btn-foreground-color: var(--color-foreground-secondary);
  --radio-btn-foreground-color-selected: var(--color-accent-primary);
  --radio-btn-border-color: var(--color-background-tertiary);
  --radio-btn-border-color-selected: var(--color-background-secondary);
  --button-icon-background-color-selected: var(--color-background-primary);
  --button-icon-border-color-selected: var(--color-background-secondary);
  --assets-item-name-foreground-color: var(--color-foreground-primary);
  --text-editor-selection-background-color: var(--la-tertiary-70);
  --expand-button-icon-border-width-selected: 2px;
  --colorpicker-background-color: var(--color-background-primary);
}

body {
  background-color: var(--color-background-primary);
  color: var(--color-foreground-primary);
  display: flex;
  flex-direction: column;
  font-family: "worksans", "vazirmatn", sans-serif;
  width: 100vw;
  height: 100vh;
  overflow: hidden;
}

#app {
  width: 100vw;
  height: 100vh;
  overflow: hidden;
  position: relative;
}

* {
  box-sizing: border-box;
  scrollbar-width: thin;
}

img {
  height: auto;
  width: 100%;
}

svg * {
  transition: none;
}

a {
  cursor: pointer;
  font-weight: 500;
  color: #303236;
}
a:hover {
  text-decoration: underline;
}

button {
  font-family: "worksans", "vazirmatn", sans-serif;
}

p {
  font-size: 0.75rem;
  margin-bottom: 1rem;
  line-height: 1.33;
}

li {
  line-height: 1.33;
}

ul {
  margin-bottom: 1rem;
}

h1 {
  font-size: 2.125rem;
  font-weight: 500;
  line-height: 1.15;
}

h2 {
  font-size: 1.5rem;
  font-weight: 300;
  line-height: 1.15;
}

h3 {
  font-size: 1.5rem;
  font-weight: 300;
  padding: 0.5rem 0;
}

h4 {
  font-size: 1.125rem;
  font-weight: 300;
}

hr {
  border-top: solid 1px var(--color-background-primary);
  border-right: 0;
  border-left: 0;
  border-bottom: 0;
  margin: 1rem 0;
}

input[type=number]::-webkit-inner-spin-button,
input[type=number]::-webkit-outer-spin-button {
  -webkit-appearance: none;
          appearance: none;
  margin: 0;
}

input[type=number] {
  -webkit-appearance: textfield;
     -moz-appearance: textfield;
          appearance: textfield;
}

[contenteditable] {
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
}

input,
select {
  box-sizing: border-box;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  margin-bottom: 1rem;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
}

[draggable] {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  /* Required to make elements draggable in old WebKit */
  -khtml-user-drag: element;
  -webkit-user-drag: element;
}

.text-editor,
.rich-text {
  color: var(--app-black);
  height: 100%;
  font-family: sans-serif, "sourcesanspro";
}
.text-editor div,
.rich-text div {
  line-height: inherit;
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
}
.text-editor span,
.rich-text span {
  line-height: inherit;
}

.text-editor .DraftEditor-root {
  height: 100%;
  display: flex;
  flex-direction: column;
}
.text-editor .public-DraftStyleDefault-block {
  white-space: pre;
}
.text-editor.align-top .DraftEditor-root {
  justify-content: flex-start;
}
.text-editor.align-center .DraftEditor-root {
  justify-content: center;
}
.text-editor.align-bottom .DraftEditor-root {
  justify-content: flex-end;
}

.rich-text .paragraphs {
  height: 100%;
  display: flex;
  flex-direction: column;
}
.rich-text .paragraphs.align-top {
  justify-content: flex-start;
}
.rich-text .paragraphs.align-center {
  justify-content: center;
}
.rich-text .paragraphs.align-bottom {
  justify-content: flex-end;
}
@keyframes main_ui_components_button_link__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_button_link__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_button_link__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_button_link__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_button_link__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_button_link__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_button_link__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_button_link__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_button_link__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_button_link__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_button_link__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_button_link__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_button_link__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_button_link__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_button_link__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_button_link__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_button_link__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_button_link__button {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  align-items: center;
  border: none;
  cursor: pointer;
  display: flex;
  font-family: "worksans", "vazirmatn", sans-serif;
  justify-content: center;
  min-width: 25px;
  padding: 0 1rem;
  transition: all 0.4s;
  text-decoration: none !important;
  height: 40px;
}
.main_ui_components_button_link__button svg {
  height: 20px;
  width: 20px;
}
.main_ui_components_code_block__code-display {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
  border-radius: 0.5rem;
  margin-top: var(--sp-s);
  padding: var(--sp-m);
  background-color: var(--menu-background-color);
  color: var(--input-foreground-color-active);
  overflow: auto;
}
@keyframes main_ui_components_color_bullet__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_color_bullet__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_color_bullet__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_color_bullet__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_color_bullet__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_color_bullet__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_color_bullet__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_color_bullet__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_color_bullet__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_color_bullet__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_color_bullet__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_color_bullet__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_color_bullet__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_color_bullet__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_color_bullet__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_color_bullet__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_color_bullet__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_color_bullet__color-bullet {
  position: relative;
  display: flex;
  flex-direction: row;
  width: var(--bullet-size, 1.5rem);
  height: var(--bullet-size, 1.5rem);
  min-width: var(--bullet-size, 1.5rem);
  min-height: var(--bullet-size, 1.5rem);
  border: 0.125rem solid var(--color-bullet-border-color);
  border-radius: 50%;
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__grid-area {
  grid-area: color;
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__mini {
  width: var(--bullet-size, 1rem);
  height: var(--bullet-size, 1rem);
  min-width: var(--bullet-size, 1rem);
  min-height: var(--bullet-size, 1rem);
  margin-top: 0;
  border: 1px solid var(--color-bullet-border-color);
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__is-not-library-color {
  overflow: hidden;
  border-radius: 8px;
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__is-not-library-color .main_ui_components_color_bullet__color-bullet-wrapper {
  clip-path: none;
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__is-not-library-color.main_ui_components_color_bullet__mini {
  border-radius: 4px;
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__is-gradient {
  background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAAAXNSR0IArs4c6QAAAExJREFUSIljvHnz5n8GLEBNTQ2bMMOtW7ewiuNSz4RVlIpg1IKBt4Dx////WFMRqakFl/qhH0SjFhAELNRKLaNl0Qi2YLQsGrWAcgAA0gAgQPhT2rAAAAAASUVORK5CYII=") left center;
  background-color: var(--color-bullet-background-color);
  transform: rotate(-90deg);
}
.main_ui_components_color_bullet__color-bullet.main_ui_components_color_bullet__is-transparent {
  background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAAAXNSR0IArs4c6QAAAExJREFUSIljvHnz5n8GLEBNTQ2bMMOtW7ewiuNSz4RVlIpg1IKBt4Dx////WFMRqakFl/qhH0SjFhAELNRKLaNl0Qi2YLQsGrWAcgAA0gAgQPhT2rAAAAAASUVORK5CYII=") left center;
  background-color: var(--color-bullet-background-color);
}
.main_ui_components_color_bullet__color-bullet .main_ui_components_color_bullet__color-bullet-wrapper {
  display: flex;
  flex-direction: row;
  height: 100%;
  width: 100%;
  clip-path: circle(50%);
  background-size: contain;
  background-repeat: no-repeat;
  background-position: center;
}
.main_ui_components_color_bullet__color-bullet .main_ui_components_color_bullet__color-bullet-wrapper > * {
  width: 100%;
  height: 100%;
  background-color: var(--color-bullet-background-color);
}
.main_ui_components_color_bullet__color-bullet:hover:not(.main_ui_components_color_bullet__read-only) {
  border: 0.125rem solid var(--color-bullet-border-color-selected);
}

.main_ui_components_color_bullet__color-text {
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  width: 5rem;
  text-align: center;
  margin-top: 0.125rem;
  max-height: 1.75rem;
  color: var(--palette-text-color);
}
.main_ui_components_color_bullet__color-text.main_ui_components_color_bullet__small-text {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-height: 1rem;
}

.main_ui_components_color_bullet__big-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: inline-block;
  width: -moz-fit-content;
  width: fit-content;
  padding: 0;
  margin: 0;
  text-align: left;
  color: var(--menu-foreground-color);
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  line-height: 1;
  color: var(--palette-text-color);
  text-align: center;
}

.main_ui_components_color_bullet__no-text {
  display: none;
}

.main_ui_components_color_bullet__color-row-name {
  color: var(--menu-foreground-color);
}
@keyframes main_ui_components_context_menu_a11y__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_context_menu_a11y__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_context_menu_a11y__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_context_menu_a11y__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_context_menu_a11y__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_context_menu_a11y__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_context_menu_a11y__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_context_menu_a11y__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon:focus-visible {
  outline: none;
  background-color: var(--button-background-color-focus);
  border: 1px solid var(--button-border-color-focus);
  color: var(--button-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon:focus-visible svg {
  stroke: var(--button-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon:hover svg {
  stroke: var(--title-foreground-color-hover);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon:active {
  border: none;
  background-color: transparent;
}

.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu .main_ui_components_context_menu_a11y__submenu-icon svg, .main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu-back .main_ui_components_context_menu_a11y__submenu-icon-back svg, .main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon svg, .main_ui_components_context_menu_a11y__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu .main_ui_components_context_menu_a11y__submenu-icon svg, .main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu-back .main_ui_components_context_menu_a11y__submenu-icon-back svg, .main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon svg, .main_ui_components_context_menu_a11y__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_context_menu_a11y__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_context_menu_a11y__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_context_menu_a11y__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_context_menu_a11y__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_context_menu_a11y__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_components_context_menu_a11y__context-menu {
  position: relative;
  visibility: hidden;
  opacity: 0;
  z-index: var(--z-index-dropdown);
}
.main_ui_components_context_menu_a11y__context-menu.main_ui_components_context_menu_a11y__is-open {
  position: relative;
  display: block;
  opacity: 1;
  visibility: visible;
}
.main_ui_components_context_menu_a11y__context-menu.main_ui_components_context_menu_a11y__fixed {
  position: fixed;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 0.75rem;
  left: calc(-1 * 0.375rem);
  max-height: 30rem;
  min-width: 6rem;
  margin: 0px;
  padding: 0.25rem;
  border-radius: 8px;
  border: 0.125rem solid var(--panel-border-color);
  background-color: var(--menu-background-color);
  overflow: auto;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__separator {
  border-top: solid 1px var(--color-background-quaternary);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items.main_ui_components_context_menu_a11y__min-width {
  min-width: 12rem;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item {
  display: flex;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: flex-start;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  white-space: nowrap;
  color: var(--menu-foreground-color);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu {
  display: flex;
  align-items: center;
  justify-content: space-between;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu .main_ui_components_context_menu_a11y__submenu-icon {
  margin-left: 0.5rem;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu .main_ui_components_context_menu_a11y__submenu-icon svg {
  stroke: var(--menu-foreground-color);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu-back {
  display: flex;
  align-items: center;
  font-weight: 700;
  background: none;
  border: none;
  cursor: pointer;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu-back .main_ui_components_context_menu_a11y__submenu-icon-back svg {
  stroke: var(--menu-foreground-color);
  transform: rotate(180deg);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:hover .main_ui_components_context_menu_a11y__context-menu-action {
  background-color: var(--menu-background-color-hover);
  text-decoration: none;
  color: var(--menu-foreground-color);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:hover .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu .main_ui_components_context_menu_a11y__submenu-icon svg {
  stroke: var(--menu-foreground-color);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:hover .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu-back .main_ui_components_context_menu_a11y__submenu-icon-back svg {
  stroke: var(--menu-foreground-color);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item .main_ui_components_context_menu_a11y__context-menu-action-disabled, .main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:hover .main_ui_components_context_menu_a11y__context-menu-action-disabled {
  color: var(--color-foreground-secondary);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:focus {
  outline: none;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:focus-visible {
  outline: none;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:focus-visible .main_ui_components_context_menu_a11y__context-menu-action {
  border: 1px solid var(--menu-border-color-focus);
  background-color: var(--menu-background-color-focus);
  text-decoration: none;
  color: var(--menu-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:focus-visible .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu .main_ui_components_context_menu_a11y__submenu-icon svg {
  stroke: var(--menu-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item:focus-visible .main_ui_components_context_menu_a11y__context-menu-action.main_ui_components_context_menu_a11y__submenu-back .main_ui_components_context_menu_a11y__submenu-icon-back svg {
  stroke: var(--menu-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__context-menu-action {
  justify-content: space-between;
  color: var(--menu-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon {
  border-radius: 8px;
  height: 100%;
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__context-menu-item.main_ui_components_context_menu_a11y__selected .main_ui_components_context_menu_a11y__selected-icon svg {
  stroke: var(--menu-foreground-color-focus);
}
.main_ui_components_context_menu_a11y__context-menu .main_ui_components_context_menu_a11y__context-menu-items .main_ui_components_context_menu_a11y__is-selected .main_ui_components_context_menu_a11y__context-menu-action {
  padding-left: 1.75rem;
  background-image: url("/images/icons/tick.svg");
  background-repeat: no-repeat;
  background-position: 5% 48%;
  background-size: 0.75rem;
  font-weight: 700;
}
.main_ui_components_context_menu_a11y__context-menu.main_ui_components_context_menu_a11y__is-selectable .main_ui_components_context_menu_a11y__context-menu-action {
  padding-left: 1.5rem;
}
@keyframes main_ui_components_copy_button__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_copy_button__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_copy_button__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_copy_button__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_copy_button__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_copy_button__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_copy_button__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_copy_button__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_copy_button__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_copy_button__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_copy_button__copy-button .main_ui_components_copy_button__icon-btn svg, .main_ui_components_copy_button__copy-wrapper .main_ui_components_copy_button__icon-btn svg, .main_ui_components_copy_button__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_copy_button__copy-button .main_ui_components_copy_button__icon-btn svg, .main_ui_components_copy_button__copy-wrapper .main_ui_components_copy_button__icon-btn svg, .main_ui_components_copy_button__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_copy_button__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_copy_button__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_copy_button__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_copy_button__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_copy_button__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_copy_button__copy-button {
  border: none;
  background: none;
  cursor: pointer;
  width: 100%;
  height: 2rem;
  border: 1px solid transparent;
  border-radius: 8px;
  background-color: transparent;
  box-sizing: border-box;
}
.main_ui_components_copy_button__copy-button .main_ui_components_copy_button__icon-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2rem;
  min-width: 1.75rem;
  width: 1.75rem;
}
.main_ui_components_copy_button__copy-button .main_ui_components_copy_button__icon-btn svg {
  stroke: var(--icon-foreground);
}
.main_ui_components_copy_button__copy-button:hover {
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: 1px solid var(--color-background-tertiary);
}
.main_ui_components_copy_button__copy-button:hover .main_ui_components_copy_button__icon-btn svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_components_copy_button__copy-button:focus, .main_ui_components_copy_button__copy-button:focus-visible {
  outline: none;
  border: 1px solid var(--button-tertiary-border-color-focus);
  background-color: transparent;
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_components_copy_button__copy-button:focus .main_ui_components_copy_button__icon-btn svg, .main_ui_components_copy_button__copy-button:focus-visible .main_ui_components_copy_button__icon-btn svg {
  stroke: var(--button-tertiary-foreground-color-active);
}

.main_ui_components_copy_button__copy-wrapper {
  border: none;
  background: none;
  cursor: pointer;
  position: relative;
  min-height: 2rem;
  width: 9rem;
  padding: calc(0.5rem - 1px) 0 calc(0.5rem - 1px) calc(0.5rem - 1px);
  border-radius: 0.5rem;
  box-sizing: border-box;
  width: 100%;
  height: -moz-fit-content;
  height: fit-content;
  text-align: left;
  border: 1px solid transparent;
}
.main_ui_components_copy_button__copy-wrapper .main_ui_components_copy_button__icon-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  top: 0;
  right: 0;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_components_copy_button__copy-wrapper .main_ui_components_copy_button__icon-btn svg {
  stroke: var(--button-tertiary-foreground-color-focus);
  display: none;
}
.main_ui_components_copy_button__copy-wrapper:hover {
  background-color: var(--button-tertiary-background-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
  border: 1px solid var(--button-tertiary-background-color-focus);
}
.main_ui_components_copy_button__copy-wrapper:hover .main_ui_components_copy_button__icon-btn svg {
  display: flex;
}
.main_ui_components_copy_button__copy-wrapper:focus, .main_ui_components_copy_button__copy-wrapper:focus-visible {
  outline: none;
  border: 1px solid var(--button-tertiary-border-color-focus);
  background-color: transparent;
  color: var(--button-tertiary-foreground-color-focus);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_components_editable_label__editable-label-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  outline: none;
  width: 100%;
  height: 100%;
  margin: 0;
  padding: 0 var(--sp-s);
  border: 0.0625rem solid var(--color-accent-primary);
  color: var(--color-foreground-primary);
  background: var(--color-background-primary);
}

.main_ui_components_editable_label__editable-label-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
@keyframes main_ui_components_editable_select__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_editable_select__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_editable_select__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_editable_select__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_editable_select__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_editable_select__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_editable_select__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_editable_select__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_editable_select__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_editable_select__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__dropdown-button svg, .main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element .main_ui_components_editable_select__check-icon svg, .main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element span svg, .main_ui_components_editable_select__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__dropdown-button svg, .main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element .main_ui_components_editable_select__check-icon svg, .main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element span svg, .main_ui_components_editable_select__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_editable_select__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_editable_select__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_editable_select__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_editable_select__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_editable_select__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_editable_select__editable-select {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  padding: 0.5rem 0.75rem;
  background-color: var(--assets-item-background-color);
  color: var(--assets-item-name-foreground-color-hover);
}
.main_ui_components_editable_select__editable-select:hover {
  background-color: var(--assets-item-background-color-hover);
  color: var(--assets-item-name-foreground-color-hover);
}

.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_components_editable_select__editable-select {
  margin: 0;
  border: 0.0625rem solid var(--input-border-color);
  position: relative;
  display: flex;
  height: 2rem;
  width: 100%;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  cursor: pointer;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__dropdown-button {
  display: flex;
  place-content: center;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__dropdown-button svg {
  transform: rotate(90deg);
  stroke: var(--icon-foreground);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown {
  width: -moz-fit-content;
  width: fit-content;
  max-height: 20rem;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__separator {
  margin: 0;
  height: 0.75rem;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element {
  color: var(--menu-foreground-color-rest);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element .main_ui_components_editable_select__label {
  flex-grow: 1;
  width: 100%;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element .main_ui_components_editable_select__check-icon {
  display: flex;
  place-content: center;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element .main_ui_components_editable_select__check-icon svg {
  visibility: hidden;
  stroke: var(--icon-foreground);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element.main_ui_components_editable_select__is-selected {
  color: var(--menu-foreground-color);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element.main_ui_components_editable_select__is-selected .main_ui_components_editable_select__check-icon svg {
  stroke: var(--menu-foreground-color);
  visibility: visible;
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color-hover);
}
.main_ui_components_editable_select__editable-select .main_ui_components_editable_select__custom-select-dropdown .main_ui_components_editable_select__dropdown-element:hover .main_ui_components_editable_select__check-icon svg {
  stroke: var(--menu-foreground-color-hover);
}
@keyframes main_ui_components_forms__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_forms__button-submit {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_components_forms__button-submit svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_components_forms__button-submit:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_components_forms__button-submit:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_components_forms__button-submit:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_components_forms__button-submit:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_components_forms__button-submit:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_components_forms__button-submit:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_components_forms__button-submit.disabled, [disabled].main_ui_components_forms__button-submit, .main_ui_components_forms__button-submit:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_components_forms__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_forms__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_forms__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_forms__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_forms__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_forms__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_forms__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_forms__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_forms__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_forms__button-submit:disabled {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_components_forms__help-icon svg, .main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__icon svg, .main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around .main_ui_components_forms__icon svg, .main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.intermediate svg, .main_ui_components_forms__radio-icon.intermediate svg, .main_ui_components_forms__checkbox label span.intermediate svg, .main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.checked svg, .main_ui_components_forms__radio-icon.checked svg, .main_ui_components_forms__checkbox label span.checked svg, .main_ui_components_forms__input-with-label-form input span svg,
.main_ui_components_forms__input-with-label-form input label svg, .main_ui_components_forms__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_forms__help-icon svg, .main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__icon svg, .main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around .main_ui_components_forms__icon svg, .main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.intermediate svg, .main_ui_components_forms__radio-icon.intermediate svg, .main_ui_components_forms__checkbox label span.intermediate svg, .main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.checked svg, .main_ui_components_forms__radio-icon.checked svg, .main_ui_components_forms__checkbox label span.checked svg, .main_ui_components_forms__input-with-label-form input span svg,
.main_ui_components_forms__input-with-label-form input label svg, .main_ui_components_forms__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_forms__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_forms__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_forms__input-with-label-form input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_components_forms__input-with-label-form input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_components_forms__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_forms__input-with-label-form input span,
.main_ui_components_forms__input-with-label-form input label, .main_ui_components_forms__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_forms__input-with-label-form input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_components_forms__input-with-label-form input span svg,
.main_ui_components_forms__input-with-label-form input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_components_forms__input-with-label-form input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_components_forms__input-with-label-form input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_components_forms__input-with-label-form input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_components_forms__input-with-label-form input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_components_forms__input-with-label-form input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_components_forms__input-with-label-form input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_components_forms__input-with-label-form input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_components_forms__input-with-label-form input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_components_forms__input-with-label-form input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_components_forms__input-with-label-form input:focus, .main_ui_components_forms__input-with-label-form input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_components_forms__input-with-label-form input:focus span, .main_ui_components_forms__input-with-label-form input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_components_forms__input-with-label-form input:focus input, .main_ui_components_forms__input-with-label-form input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_components_forms__input-with-label-form input:focus:hover, .main_ui_components_forms__input-with-label-form input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_components_forms__input-with-label-form input:focus:hover span, .main_ui_components_forms__input-with-label-form input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_components_forms__input-with-label-form input:focus:hover input, .main_ui_components_forms__input-with-label-form input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_components_forms__input-wrapper.main_ui_components_forms__valid input, .main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid input {
  background-color: var(--input-background-color-disabled);
  border: 1px solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__valid input input, .main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid input input {
  pointer-events: none;
  cursor: default;
  color: var(--input-foreground-color-disabled);
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__valid input svg, .main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid input svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span, .main_ui_components_forms__radio-icon, .main_ui_components_forms__checkbox label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span svg, .main_ui_components_forms__radio-icon svg, .main_ui_components_forms__checkbox label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span:hover, .main_ui_components_forms__radio-icon:hover, .main_ui_components_forms__checkbox label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span:focus, .main_ui_components_forms__radio-icon:focus, .main_ui_components_forms__checkbox label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.checked, .main_ui_components_forms__radio-icon.checked, .main_ui_components_forms__checkbox label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.checked svg, .main_ui_components_forms__radio-icon.checked svg, .main_ui_components_forms__checkbox label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.intermediate, .main_ui_components_forms__radio-icon.intermediate, .main_ui_components_forms__checkbox label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.intermediate svg, .main_ui_components_forms__radio-icon.intermediate svg, .main_ui_components_forms__checkbox label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.unchecked, .main_ui_components_forms__radio-icon.unchecked, .main_ui_components_forms__checkbox label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label span.unchecked svg, .main_ui_components_forms__radio-icon.unchecked svg, .main_ui_components_forms__checkbox label span.unchecked svg {
  display: none;
}

.main_ui_components_forms__checkbox {
  display: flex;
  align-items: center;
}
.main_ui_components_forms__checkbox label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_components_forms__checkbox label input {
  margin: 0;
}
.main_ui_components_forms__checkbox label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_components_forms__checkbox label:focus span, .main_ui_components_forms__checkbox label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_components_forms__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_forms__custom-select select {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_components_forms__custom-select, .main_ui_components_forms__custom-select .main_ui_components_forms__input-container {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  position: relative;
  display: flex;
  align-items: center;
  justify-content: normal;
  width: 100%;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_components_forms__input-wrapper {
  --input-icon-padding: var(--sp-l);
  display: flex;
  flex-direction: column;
  align-items: center;
  position: relative;
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__valid input {
  border: 0.0625rem solid var(--input-border-color-success);
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__valid input:hover, .main_ui_components_forms__input-wrapper.main_ui_components_forms__valid input:focus {
  border: 0.0625rem solid var(--input-border-color-success);
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid input {
  border: 0.0625rem solid var(--input-border-color-error);
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid input:hover, .main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid input:focus {
  border: 0.0625rem solid var(--input-border-color-error);
}
.main_ui_components_forms__input-wrapper.main_ui_components_forms__valid .main_ui_components_forms__help-icon, .main_ui_components_forms__input-wrapper.main_ui_components_forms__invalid .main_ui_components_forms__help-icon {
  inset-inline-end: 2.5rem;
}

.main_ui_components_forms__input-with-label-form {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
  justify-content: flex-start;
  align-items: flex-start;
  block-size: 100%;
  inline-size: 100%;
  padding: 0;
  cursor: pointer;
  color: var(--modal-title-foreground-color);
  text-transform: uppercase;
}
.main_ui_components_forms__input-with-label-form input {
  color: var(--input-foreground-color-active);
  margin-block-start: 0;
  inline-size: 100%;
  max-inline-size: 100%;
  block-size: 100%;
  padding: 0 var(--sp-s);
}
.main_ui_components_forms__input-with-label-form input:focus {
  outline: none;
  border: 0.0625rem solid var(--input-border-color-focus);
  border-radius: var(--sp-s);
}
.main_ui_components_forms__input-with-label-form input:-webkit-autofill,
.main_ui_components_forms__input-with-label-form input:-webkit-autofill:hover,
.main_ui_components_forms__input-with-label-form input:-webkit-autofill:focus,
.main_ui_components_forms__input-with-label-form input:-webkit-autofill:active {
  -webkit-text-fill-color: var(--input-foreground-color-active);
  box-shadow: inset 0 0 20px 20px var(--input-background-color);
  border: 0.0625rem solid var(--input-border-color);
  -webkit-background-clip: text;
          background-clip: text;
  -webkit-transition: background-color 5000s ease-in-out 0s;
  transition: background-color 5000s ease-in-out 0s;
  caret-color: var(--input-foreground-color-active);
}

.main_ui_components_forms__input-and-icon {
  position: relative;
  inline-size: var(--input-width, calc(100% - 1px));
  min-inline-size: var(--input-min-width);
  block-size: var(--input-height, 2rem);
}

.main_ui_components_forms__help-icon {
  cursor: pointer;
  position: absolute;
  inset-inline-end: var(--sp-l);
  inset-block-start: calc(50% - var(--sp-s));
}
.main_ui_components_forms__help-icon svg {
  stroke: var(--color-foreground-secondary);
  inline-size: 1rem;
  block-size: 1rem;
}

.main_ui_components_forms__invalid-icon {
  inline-size: 1rem;
  block-size: 1rem;
  padding: 0;
  border: none;
  background: var(--input-border-color-error);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  position: absolute;
  inset-inline-end: var(--input-icon-padding);
  inset-block-start: calc(50% - var(--sp-s));
  cursor: pointer;
}
.main_ui_components_forms__invalid-icon svg {
  inline-size: 0.75rem;
  block-size: 0.75rem;
  stroke: var(--input-background-color);
}

.main_ui_components_forms__valid-icon {
  inline-size: 1rem;
  block-size: 1rem;
  background: var(--input-border-color-success);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  position: absolute;
  inset-inline-end: var(--sp-l);
  inset-block-start: calc(50% - var(--sp-s));
}
.main_ui_components_forms__valid-icon svg {
  inline-size: 0.75rem;
  block-size: 0.75rem;
  fill: var(--input-border-color-success);
  stroke: var(--input-background-color);
}

.main_ui_components_forms__error {
  color: var(--input-border-color-error);
  inline-size: 100%;
  font-size: 0.875rem;
}

.main_ui_components_forms__hint {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  inline-size: 99%;
  margin-block-start: var(--sp-s);
  color: var(--modal-text-foreground-color);
}

.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-direction: row-reverse;
  gap: 0.375rem;
  min-block-size: var(--sp-xxxl);
  cursor: pointer;
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label input {
  display: none !important;
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_components_forms__checkbox .main_ui_components_forms__checkbox-label a {
  color: var(--link-foreground-color);
}

.main_ui_components_forms__custom-select {
  block-size: 2rem;
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  block-size: 2rem;
  inline-size: 100%;
  border-radius: var(--sp-s);
  border: 0.0625rem solid var(--input-border-color);
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color);
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__main-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: relative;
  justify-content: center;
  flex-grow: 1;
  block-size: 100%;
  padding: var(--sp-s);
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__main-content .main_ui_components_forms__label {
  color: var(--input-foreground-color);
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__main-content .main_ui_components_forms__value {
  inline-size: 100%;
  padding: 0;
  margin: 0;
  border: 0;
  color: var(--input-foreground-color-active);
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  block-size: 2rem;
  inline-size: 1.5rem;
  pointer-events: none;
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container .main_ui_components_forms__icon svg {
  stroke: var(--icon-foreground);
  transform: rotate(90deg);
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container.main_ui_components_forms__disabled {
  background-color: var(--input-background-color-disabled);
  border: 0.0625rem solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_components_forms__custom-select .main_ui_components_forms__input-container.main_ui_components_forms__focus {
  outline: none;
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 0.0625rem solid var(--input-border-color-active);
}
.main_ui_components_forms__custom-select select {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  box-sizing: border-box;
  position: absolute;
  inset-block-start: 0;
  inset-inline-start: 0;
  min-block-size: 2rem;
  block-size: auto;
  inline-size: calc(100% - 1px);
  padding: 0 var(--sp-m);
  margin: 0;
  border: none;
  opacity: 0;
  z-index: var(--z-index-dropdown);
  background-color: transparent;
  cursor: pointer;
}
.main_ui_components_forms__custom-select select option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  block-size: 2rem;
}

.main_ui_components_forms__button-submit:disabled {
  min-block-size: 2rem;
}

.main_ui_components_forms__custom-multi-input {
  display: flex;
  flex-direction: column;
  position: relative;
  min-block-size: 2.5rem;
  max-block-size: 11.25rem;
  inline-size: 100%;
  overflow-y: hidden;
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__inside-input {
  border: none;
  background: none;
  outline: none;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  inline-size: 100%;
  max-inline-size: calc(100% - 1px);
  min-block-size: 2rem;
  padding-block-start: 0;
  block-size: 2rem;
  padding: var(--sp-s);
  margin: 0;
  border-radius: var(--sp-s);
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__inside-input:focus {
  outline: none;
  border: 0.0625rem solid var(--input-border-color-focus);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__inside-input.main_ui_components_forms__invalid {
  border: 0.0625rem solid var(--input-border-color-error);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__inside-input.main_ui_components_forms__invalid:hover, .main_ui_components_forms__custom-multi-input .main_ui_components_forms__inside-input.main_ui_components_forms__invalid:focus {
  border: 0.0625rem solid var(--input-border-color-error);
}
.main_ui_components_forms__custom-multi-input label {
  display: none;
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items {
  display: flex;
  flex-wrap: wrap;
  gap: var(--sp-xs);
  max-block-size: 8.5rem;
  padding: var(--sp-xs) 0;
  overflow-y: auto;
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  block-size: 1.5rem;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  padding-inline-start: 0.375rem;
  border-radius: 0.375rem;
  background-color: var(--pill-background-color);
  border: 0.0625rem solid var(--pill-background-color);
  box-sizing: border-box;
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around .main_ui_components_forms__text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding-inline-end: var(--sp-s);
  color: var(--pill-foreground-color);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around .main_ui_components_forms__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  background: none;
  cursor: pointer;
  block-size: 2rem;
  inline-size: 1.5rem;
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around .main_ui_components_forms__icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around.main_ui_components_forms__invalid {
  background-color: var(--status-widget-background-color-error);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around.main_ui_components_forms__invalid .main_ui_components_forms__text {
  color: var(--alert-text-foreground-color-error);
}
.main_ui_components_forms__custom-multi-input .main_ui_components_forms__selected-items .main_ui_components_forms__selected-item .main_ui_components_forms__around.main_ui_components_forms__invalid .main_ui_components_forms__icon svg {
  stroke: var(--alert-text-foreground-color-error);
}

.main_ui_components_forms__custom-radio {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: var(--sp-l);
}

.main_ui_components_forms__radio-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  align-items: flex-start;
  gap: var(--sp-s);
  min-block-size: 2rem;
  block-size: -moz-fit-content;
  block-size: fit-content;
  border-radius: var(--sp-s);
  padding: var(--sp-s);
  color: var(--input-foreground-color-rest);
  border: 0.0625rem solid transparent;
}
.main_ui_components_forms__radio-label:has(:focus-visible) {
  outline: none;
  border: 0.0625rem solid var(--input-border-color-active);
}

.main_ui_components_forms__radio-dot {
  block-size: var(--sp-s);
  inline-size: var(--sp-s);
  border-radius: 50%;
  background-color: var(--color-background-tertiary);
}

.main_ui_components_forms__radio-input {
  inline-size: 0;
  margin: 0;
}

.main_ui_components_forms__radio-icon {
  border-radius: 50%;
}

.main_ui_components_forms__radio-label-image {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: grid;
  grid-template-rows: auto auto 0;
  justify-items: center;
  gap: 0;
  border-radius: var(--sp-s);
  margin: 0;
  border: 0.0625rem solid var(--color-background-tertiary);
  cursor: pointer;
}
.main_ui_components_forms__radio-label-image.checked {
  border: 0.0625rem solid var(--color-accent-primary);
}
.main_ui_components_forms__radio-label-image:focus, .main_ui_components_forms__radio-label-image:focus-within {
  outline: none;
  border: 0.0625rem solid var(--input-border-color-active);
}
.main_ui_components_forms__radio-label-image .main_ui_components_forms__image-text {
  color: var(--input-foreground-color-rest);
  display: grid;
  align-self: center;
  margin-block-end: var(--sp-l);
  padding-inline: var(--sp-s);
  text-align: center;
}

.main_ui_components_forms__image-inside {
  margin: var(--sp-l);
  background-size: 100%;
  background-repeat: no-repeat;
  background-position: center;
}

.main_ui_components_forms__icon-inside {
  margin: var(--sp-l);
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_components_forms__icon-inside svg {
  inline-size: 40px;
  block-size: 60px;
  stroke: var(--icon-foreground);
  fill: none;
}

.main_ui_components_forms__textarea-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
  margin-block-end: var(--sp-s);
}

.main_ui_components_forms__textarea-wrapper {
  display: grid;
  grid-template-rows: auto 1fr;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_components_org_avatar__org-avatar {
  position: relative;
  border-radius: 50%;
  overflow: hidden;
  flex-shrink: 0;
}

.main_ui_components_org_avatar__org-avatar-custom {
  -o-object-fit: cover;
     object-fit: cover;
}

.main_ui_components_org_avatar__org-avatar-xxxl {
  width: var(--sp-xxxl);
  height: var(--sp-xxxl);
}

.main_ui_components_org_avatar__org-avatar-xxl {
  width: var(--sp-xxl);
  height: var(--sp-xxl);
}

.main_ui_components_org_avatar__org-avatar-xl {
  width: var(--sp-xl);
  height: var(--sp-xl);
}

.main_ui_components_org_avatar__org-avatar-bg {
  position: absolute;
  inset: 0;
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.main_ui_components_org_avatar__org-avatar-initials {
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  inset: 0;
  color: #18181a;
}

.main_ui_components_org_avatar__size-initials-xxl {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  font-weight: 600;
}

.main_ui_components_org_avatar__size-initials-xxxl {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  font-weight: 600;
}
@keyframes main_ui_components_progress__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_progress__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_progress__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_progress__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_progress__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_progress__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_progress__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_progress__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_progress__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_progress__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_progress__icon, .main_ui_components_progress__close-icon, .main_ui_components_progress__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_progress__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_progress__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_progress__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_progress__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_progress__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_progress__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_progress__progress-widget {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.75rem;
  height: 1.75rem;
}

.main_ui_components_progress__progress-modal {
  --export-modal-bg-color: var(--alert-background-color-default);
  --export-modal-fg-color: var(--alert-text-foreground-color-default);
  --export-modal-icon-color: var(--alert-icon-foreground-color-default);
  --export-modal-border-color: var(--alert-border-color-default);
  position: absolute;
  right: 1rem;
  top: 3rem;
  display: grid;
  grid-template-columns: 1.5rem 1fr 1.5rem;
  grid-template-areas: "icon text close" "bar bar bar";
  gap: 0.25rem 0.5rem;
  padding-block-start: 0.5rem;
  background-color: var(--export-modal-bg-color);
  border: 1px solid var(--export-modal-border-color);
  border-radius: 8px;
  z-index: 300;
  overflow: hidden;
}

.main_ui_components_progress__has-error {
  --export-modal-bg-color: var(--alert-background-color-error);
  --export-modal-fg-color: var(--alert-text-foreground-color-error);
  --export-modal-icon-color: var(--alert-icon-foreground-color-error);
  --export-modal-border-color: var(--alert-border-color-error);
  grid-template-areas: "icon text close";
  gap: 0.5rem;
  padding-block: 0.5rem;
}

.main_ui_components_progress__icon {
  grid-area: icon;
  align-self: center;
  margin-inline-start: 0.5rem;
  stroke: var(--export-modal-icon-color);
}

.main_ui_components_progress__title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 0.5rem;
  grid-area: text;
  align-self: center;
  padding: 0;
  margin: 0;
  color: var(--export-modal-fg-color);
}

.main_ui_components_progress__progress {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  padding-left: 0.5rem;
  margin: 0;
  align-self: center;
  color: var(--modal-text-foreground-color);
}

.main_ui_components_progress__retry-btn {
  border: none;
  background: none;
  cursor: pointer;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: inline;
  text-align: left;
  color: var(--modal-link-foreground-color);
  margin: 0;
  padding: 0;
}

.main_ui_components_progress__progress-close-button {
  border: none;
  background: none;
  cursor: pointer;
  padding: 0;
  margin-inline-end: 0.5rem;
}

.main_ui_components_progress__close-icon {
  stroke: var(--export-modal-icon-color);
}

.main_ui_components_progress__progress-bar {
  margin-top: 0;
  grid-area: bar;
}
@keyframes main_ui_components_radio_buttons__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_radio_buttons__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_radio_buttons__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_radio_buttons__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_radio_buttons__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_radio_buttons__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_radio_buttons__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_radio_buttons__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_radio_buttons__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_radio_buttons__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_radio_buttons__radio-icon svg, .main_ui_components_radio_buttons__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_radio_buttons__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_radio_buttons__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_radio_buttons__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_radio_buttons__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_radio_buttons__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_radio_buttons__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_radio_buttons__radio-btn-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  height: 2rem;
  background-color: var(--input-background-color);
  gap: 0.25rem;
}

.main_ui_components_radio_buttons__radio-icon {
  --radio-icon-border-color: var(--radio-btn-border-color);
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_components_radio_buttons__radio-icon:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_radio_buttons__radio-icon:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_radio_buttons__radio-icon {
  height: 2rem;
  flex-grow: 1;
  border-radius: 0.5rem;
  box-sizing: border-box;
  border: 2px solid var(--radio-icon-border-color);
}
.main_ui_components_radio_buttons__radio-icon input {
  display: none;
}
.main_ui_components_radio_buttons__radio-icon svg {
  stroke: var(--radio-btn-foreground-color);
}
.main_ui_components_radio_buttons__radio-icon .main_ui_components_radio_buttons__title-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--radio-btn-foreground-color);
}
.main_ui_components_radio_buttons__radio-icon:hover svg {
  stroke: var(--radio-btn-foreground-color-selected);
}

.main_ui_components_radio_buttons__checked {
  --radio-icon-border-color: var(--radio-btn-border-color-selected);
  background-color: var(--radio-btn-background-color-selected);
}
.main_ui_components_radio_buttons__checked svg {
  stroke: var(--radio-btn-foreground-color-selected);
}
.main_ui_components_radio_buttons__checked .main_ui_components_radio_buttons__title-name {
  color: var(--radio-btn-foreground-color-selected);
}

.main_ui_components_radio_buttons__disabled {
  cursor: default;
  background-color: transparent;
  border: 0.125rem solid transparent;
}
.main_ui_components_radio_buttons__disabled svg {
  stroke: var(--button-foreground-color-disabled);
}
.main_ui_components_radio_buttons__disabled .main_ui_components_radio_buttons__title-name {
  color: var(--button-foreground-color-disabled);
}
.main_ui_components_radio_buttons__disabled:hover {
  background-color: transparent;
  border: 0.125rem solid transparent;
}
.main_ui_components_radio_buttons__disabled:hover svg {
  stroke: var(--button-foreground-color-disabled);
}
.main_ui_components_radio_buttons__disabled:hover .main_ui_components_radio_buttons__title-name {
  color: var(--button-foreground-color-disabled);
}
.main_ui_components_reorder_handler__reorder {
  cursor: grab;
  display: flex;
  flex-direction: column;
  block-size: calc(100% + var(--sp-m));
  justify-content: center;
  inset-inline-start: var(--reorder-left-position, -11px);
  position: absolute;
  inset-block-start: calc(-1 * var(--sp-m) / 2);
  z-index: var(--z-index-panels);
}

.main_ui_components_reorder_handler__reorder-icon {
  block-size: var(--sp-l);
  pointer-events: none;
  visibility: var(--reorder-icon-visibility, hidden);
  --icon-stroke-color: var(--color-foreground-secondary);
}

.main_ui_components_reorder_handler__reorder-separator-top,
.main_ui_components_reorder_handler__reorder-separator-bottom {
  border-color: var(--color-accent-primary);
  margin: 0;
  position: absolute;
  inline-size: 100%;
}

.main_ui_components_reorder_handler__reorder-separator-top {
  display: var(--reorder-top-display, none);
  inset-block-start: calc(-1 * var(--sp-xxs));
}

.main_ui_components_reorder_handler__reorder-separator-bottom {
  display: var(--reorder-bottom-display, none);
  inset-block-end: calc(-1 * var(--sp-xxs));
}
@keyframes main_ui_components_search_bar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_search_bar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_search_bar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_search_bar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_search_bar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_search_bar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_search_bar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_search_bar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_search_bar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_search_bar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_search_bar__clear-icon {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_components_search_bar__clear-icon:focus-visible {
  outline: none;
  background-color: var(--button-background-color-focus);
  border: 1px solid var(--button-border-color-focus);
  color: var(--button-foreground-color-focus);
}
.main_ui_components_search_bar__clear-icon:focus-visible svg {
  stroke: var(--button-foreground-color-focus);
}
.main_ui_components_search_bar__clear-icon:hover svg {
  stroke: var(--title-foreground-color-hover);
}
.main_ui_components_search_bar__clear-icon:active {
  border: none;
  background-color: transparent;
}

.main_ui_components_search_bar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_search_bar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_search_bar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_search_bar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_search_bar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_search_bar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_search_bar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_search_bar__search-box {
  display: flex;
  gap: 0.125rem;
  height: 2rem;
  width: 100%;
  border-radius: 8px;
  background-color: var(--search-bar-background-color);
}

.main_ui_components_search_bar__icon {
  margin-left: 0.5rem;
  flex: 0 0 1rem;
  color: var(--color-foreground-primary);
}

.main_ui_components_search_bar__search-input-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2rem;
  width: 100%;
  border: 1px solid var(--search-bar-input-border-color);
  border-radius: 8px;
  background-color: var(--search-bar-input-background-color);
}
.main_ui_components_search_bar__search-input-wrapper:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_components_search_bar__search-input-wrapper:hover .main_ui_components_search_bar__search-input {
  background-color: var(--input-background-color-hover);
}
.main_ui_components_search_bar__search-input-wrapper:focus-within {
  background-color: var(--input-background-color-active);
  color: var(--input-foreground-color-active);
  border: 1px solid var(--input-border-color-focus);
}
.main_ui_components_search_bar__search-input-wrapper:focus-within .main_ui_components_search_bar__search-input {
  background-color: var(--input-background-color-active);
}

.main_ui_components_search_bar__search-input {
  width: 100%;
  height: 100%;
  margin: 0 0.5rem 0 0.25rem;
  border: 0;
  background-color: var(--input-background-color);
  font-size: 0.75rem;
  color: var(--input-foreground-color);
  border-radius: 8px;
}
.main_ui_components_search_bar__search-input:focus {
  outline: none;
}

.main_ui_components_search_bar__clear-icon {
  flex: 0 0 2rem;
  height: 100%;
  color: var(--color-icon-default);
}

.main_ui_components_search_bar__search-box.main_ui_components_search_bar__has-children .main_ui_components_search_bar__search-input-wrapper {
  border-radius: 0 8px 8px 0;
  margin-left: 0;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_components_select__custom-select {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3019607843) transparent;
}
.main_ui_components_select__custom-select:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7019607843) transparent;
}
.main_ui_components_select__custom-select::-webkit-scrollbar {
  background: transparent;
  cursor: pointer;
  width: 0.75rem;
  height: 0.75rem;
}
.main_ui_components_select__custom-select::-webkit-scrollbar-track, .main_ui_components_select__custom-select::-webkit-scrollbar-corner {
  background: transparent;
}
.main_ui_components_select__custom-select::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3019607843);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 0.5rem;
}
.main_ui_components_select__custom-select::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7019607843);
}
.main_ui_components_select__custom-select::-moz-selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_components_select__custom-select::selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_components_select__custom-select::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_components_select__custom-select::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_components_select__custom-select {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  --border-color: var(--color-background-tertiary);
  --bg-color: var(--color-background-tertiary);
  --icon-color: var(--color-foreground-secondary);
  --text-color: var(--color-foreground-primary);
  position: relative;
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  block-size: 2rem;
  inline-size: 100%;
  margin: 0;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  background-color: var(--bg-color);
  border: 0.0625rem solid var(--border-color);
  color: var(--text-color);
  cursor: pointer;
}
.main_ui_components_select__custom-select.main_ui_components_select__icon {
  grid-template-columns: auto 1fr auto;
}
.main_ui_components_select__custom-select:hover {
  --bg-color: var(--color-background-quaternary);
  --border-color: var(--color-background-tertiary);
  --icon-color: var(--color-foreground-primary);
}
.main_ui_components_select__custom-select:has(*:focus-visible) {
  --bg-color: var(--color-background-tertiary);
  --border-color: var(--color-accent-primary);
}

.main_ui_components_select__searchable-select {
  --searchable-select-bg-color: var(--color-background-tertiary);
  --searchable-select-icon-color: var(--color-foreground-secondary);
  --searchable-select-outline-color: none;
  background: var(--searchable-select-bg-color);
  outline: 0.0625rem solid var(--searchable-select-outline-color);
}
.main_ui_components_select__searchable-select:hover {
  --searchable-select-bg-color: var(--color-background-quaternary);
}
.main_ui_components_select__searchable-select:has(*:focus-visible) {
  --searchable-select-bg-color: var(--color-background-primary);
  --searchable-select-outline-color: var(--color-accent-primary);
}
.main_ui_components_select__searchable-select:has(*:disabled) {
  --searchable-select-bg-color: var(--color-background-primary);
  --searchable-select-outline-color: var(--color-background-quaternary);
}
.main_ui_components_select__searchable-select[data-option-focused=true]:has(*:focus-visible) {
  --searchable-select-bg-color: var(--color-background-tertiary);
  --searchable-select-outline-color: none;
}

.main_ui_components_select__disabled {
  --bg-color: var(--color-background-primary);
  --border-color: var(--color-background-quaternary);
  --icon-color: var(--color-foreground-secondary);
  --text-color: var(--color-foreground-secondary);
  pointer-events: none;
  cursor: default;
}

.main_ui_components_select__dropdown-button {
  display: flex;
  justify-content: center;
  align-items: center;
  margin-inline-end: var(--sp-xxs);
}
.main_ui_components_select__dropdown-button svg {
  display: flex;
  align-items: center;
  gap: var(--sp-xxs);
  color: transparent;
  fill: none;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke-width: 1.33px;
  stroke: var(--color-foreground-secondary);
  transform: rotate(90deg);
}

.main_ui_components_select__current-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  inline-size: 1.5rem;
  padding-inline-end: var(--sp-xs);
}
.main_ui_components_select__current-icon svg {
  display: flex;
  align-items: center;
  gap: var(--sp-xxs);
  color: transparent;
  fill: none;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke-width: 1.33px;
  visibility: hidden;
  stroke: var(--color-foreground-secondary);
}

.main_ui_components_select__custom-select-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--color-shadow-dark);
  position: absolute;
  top: 2rem;
  left: 0;
  inline-size: 100%;
  max-block-size: var(--menu-max-height, 18.75rem);
  padding: var(--sp-xxs);
  margin: 0;
  margin-block-start: 1px;
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  overflow: hidden auto;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: 0.125rem solid var(--color-background-quaternary);
}
.main_ui_components_select__custom-select-dropdown .main_ui_components_select__separator {
  margin: 0;
  block-size: 0.75rem;
  border-block-start: 0.0625rem solid var(--color-background-quaternary);
}
.main_ui_components_select__custom-select-dropdown[data-direction=up] {
  bottom: 2rem;
  top: auto;
  max-block-size: var(--menu-max-height-up, 18.75rem);
}

.main_ui_components_select__current-label-input {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  inline-size: 100%;
  block-size: 100%;
  margin: 0;
  padding: 0;
  border: none;
  background-color: transparent;
  color: inherit;
  font: inherit;
  outline: none;
  cursor: pointer;
}
.main_ui_components_select__current-label-input::-moz-placeholder {
  color: inherit;
  opacity: 1;
}
.main_ui_components_select__current-label-input::placeholder {
  color: inherit;
  opacity: 1;
}
.main_ui_components_select__current-label-input:focus {
  cursor: text;
}
.main_ui_components_select__current-label-input:disabled {
  cursor: default;
}

.main_ui_components_select__custom-select-no-matches {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding: var(--sp-s) var(--sp-m);
  color: var(--color-foreground-secondary);
  text-align: center;
  pointer-events: none;
}

.main_ui_components_select__custom-select-dropdown[data-direction=up] {
  bottom: 2rem;
  top: auto;
}

.main_ui_components_select__checked-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  gap: var(--sp-s);
  block-size: 2rem;
  padding: 0 var(--sp-s);
  border-radius: 0.375rem;
  cursor: pointer;
  color: var(--color-foreground-primary);
}
.main_ui_components_select__checked-element:hover {
  background-color: var(--color-background-quaternary);
  color: var(--color-foreground-primary);
}
.main_ui_components_select__checked-element:hover svg {
  stroke: var(--color-foreground-primary);
}
.main_ui_components_select__checked-element span {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  display: flex;
  align-items: center;
}
.main_ui_components_select__checked-element span svg {
  display: flex;
  align-items: center;
  gap: var(--sp-xxs);
  color: transparent;
  fill: none;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke-width: 1.33px;
  visibility: hidden;
  stroke: var(--color-foreground-secondary);
}
.main_ui_components_select__checked-element .main_ui_components_select__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  block-size: 1.5rem;
  inline-size: 1.5rem;
  padding-inline-end: var(--sp-xs);
}
.main_ui_components_select__checked-element .main_ui_components_select__icon svg {
  display: flex;
  align-items: center;
  gap: var(--sp-xxs);
  color: transparent;
  fill: none;
  block-size: 1rem;
  width: 1rem;
  stroke-width: 0.0625rem;
  visibility: hidden;
  stroke: var(--color-foreground-secondary);
}
.main_ui_components_select__checked-element .main_ui_components_select__label {
  flex-grow: 1;
  inline-size: 100%;
}
.main_ui_components_select__checked-element .main_ui_components_select__check-icon {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_components_select__checked-element .main_ui_components_select__check-icon svg {
  display: flex;
  align-items: center;
  gap: var(--sp-xxs);
  color: transparent;
  fill: none;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke-width: 1.33px;
  visibility: hidden;
  stroke: var(--color-foreground-secondary);
}
.main_ui_components_select__checked-element.main_ui_components_select__is-selected {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_components_select__checked-element.main_ui_components_select__is-selected .main_ui_components_select__check-icon svg {
  stroke: var(--color-foreground-primary);
  visibility: visible;
}
.main_ui_components_select__checked-element.main_ui_components_select__disabled {
  display: none;
}

.main_ui_components_select__current-label {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
@keyframes main_ui_components_tab_container__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_tab_container__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_tab_container__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_tab_container__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_tab_container__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_tab_container__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_tab_container__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_tab_container__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_tab_container__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_tab_container__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_tab_container__tab-container-tab-title svg, .main_ui_components_tab_container__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_tab_container__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_tab_container__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_tab_container__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_tab_container__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_tab_container__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_tab_container__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_tab_container__tab-container {
  display: grid;
  grid-template-rows: 2rem 1fr;
  height: 100%;
}

.main_ui_components_tab_container__tab-container-tabs {
  display: flex;
  align-items: center;
  flex-direction: row;
  gap: 0.125rem;
  border-radius: 8px;
  background: var(--tabs-background-color);
  cursor: pointer;
  font-size: 0.75rem;
  height: 100%;
}

.main_ui_components_tab_container__tab-container-tab-wrapper {
  display: grid;
  grid-auto-flow: column;
  height: 100%;
  width: 100%;
}

.main_ui_components_tab_container__tab-container-tab-title {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 100%;
  padding: 0 0.5rem;
  margin: 0;
  border-radius: 8px;
  background-color: transparent;
  color: var(--tab-foreground-color);
  border: 0.125rem solid var(--tab-border-color);
  min-width: 0;
}
.main_ui_components_tab_container__tab-container-tab-title svg {
  stroke: var(--tab-foreground-color);
}
.main_ui_components_tab_container__tab-container-tab-title .main_ui_components_tab_container__content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  text-align: center;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.main_ui_components_tab_container__tab-container-tab-title.main_ui_components_tab_container__current, .main_ui_components_tab_container__tab-container-tab-title.main_ui_components_tab_container__current:hover {
  background: var(--tab-background-color-selected);
  border-color: var(--tab-border-color-selected);
  color: var(--tab-foreground-color-selected);
}
.main_ui_components_tab_container__tab-container-tab-title.main_ui_components_tab_container__current svg, .main_ui_components_tab_container__tab-container-tab-title.main_ui_components_tab_container__current:hover svg {
  stroke: var(--tab-foreground-color-selected);
}
.main_ui_components_tab_container__tab-container-tab-title:hover {
  color: var(--tab-foreground-color-hover);
}
.main_ui_components_tab_container__tab-container-tab-title:hover svg {
  stroke: var(--tab-foreground-color-hover);
}

.main_ui_components_tab_container__collapse-sidebar {
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  background: none;
  cursor: pointer;
  height: 100%;
  width: 1.5rem;
  min-width: 1.5rem;
  padding: 0 0.375rem;
  border-radius: 0.313rem;
}
.main_ui_components_tab_container__collapse-sidebar svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  stroke: var(--icon-foreground);
  transform: rotate(180deg);
  fill: none;
  color: transparent;
}
.main_ui_components_tab_container__collapse-sidebar:hover svg {
  stroke: var(--icon-foreground-hover);
}
.main_ui_components_tab_container__collapse-sidebar.main_ui_components_tab_container__collapsed svg {
  transform: rotate(0deg);
  padding: 0 0 0 0.375rem;
}

.main_ui_components_tab_container__tab-container-content {
  overflow: hidden auto;
  display: flex;
  flex-direction: column;
}

@supports (-moz-appearance: none) {
  .main_ui_components_tab_container__tab-container-content {
    padding-right: 0.5rem;
  }
}
@keyframes main_ui_components_title_bar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_components_title_bar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_components_title_bar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_components_title_bar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_components_title_bar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_components_title_bar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_components_title_bar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_components_title_bar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_components_title_bar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_components_title_bar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_components_title_bar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_components_title_bar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_components_title_bar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_components_title_bar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_components_title_bar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_components_title_bar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_components_title_bar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_components_title_bar__title-bar {
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 2rem;
  width: 100%;
  min-height: 2rem;
  --arrow-icon-color: var(--icon-foreground);
  --title-color: var(--title-foreground-color);
}

.main_ui_components_title_bar__title,
.main_ui_components_title_bar__title-only,
.main_ui_components_title_bar__inspect-title {
  display: grid;
  align-items: center;
  justify-content: flex-start;
  text-align: start;
  grid-auto-flow: column;
  height: 100%;
  min-height: 2rem;
  overflow: hidden;
}

.main_ui_components_title_bar__title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--title-color);
}

.main_ui_components_title_bar__title-only {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  --title-bar-title-margin: 0.5rem;
  color: var(--title-color);
  margin-inline-start: var(--title-bar-title-margin);
}

.main_ui_components_title_bar__title-only-icon-gap {
  --title-bar-title-margin: 0.75rem;
}

.main_ui_components_title_bar__inspect-title {
  color: var(--title-foreground-color-hover);
}

.main_ui_components_title_bar__icon {
  color: var(--arrow-icon-color);
}

.main_ui_components_title_bar__title-wrapper {
  display: flex;
  align-items: center;
  flex-grow: 1;
  padding: 0;
  overflow: hidden;
}

.main_ui_components_title_bar__icon-text-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  flex-grow: 1;
  padding: 0;
  overflow: hidden;
}
.main_ui_components_title_bar__icon-text-btn:hover {
  --arrow-icon-color: var(--icon-foreground-hover);
  --title-color: var(--title-foreground-color-hover);
}



.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}
.light,
.default {
  --el-shadow-dark: 0 0 10px 0 var(--color-shadow-dark);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}
.main_ui_ds_storybook__story-wrapper {
  display: grid;
  row-gap: 1rem;
}

.main_ui_ds_storybook__story-grid {
  display: grid;
  grid-template-columns: repeat(auto-fit, var(--component-grid-size, 16px));
  gap: 1rem;
  color: var(--color-foreground-primary);
}

.main_ui_ds_storybook__story-grid-cell {
  max-width: 100%;
}

.main_ui_ds_storybook__story-header {
  color: var(--color-foreground-primary);
  margin-bottom: 1rem;
}

.main_ui_ds_storybook__story-grid-row {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 60px;
  gap: 1rem;
  color: var(--color-foreground-primary);
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}
.main_ui_ds_utilities_date__date {
  color: var(--date-color, var(--color-foreground-secondary));
}

.main_ui_ds_utilities_date__is-selected {
  color: var(--date-color, var(--color-accent-primary));
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

@property --solid-color-overlay {
  syntax: "<color>";
  inherits: false;
  initial-value: rgba(0, 0, 0, 0);
}
.main_ui_ds_utilities_swatch__swatch {
  --border-color: var(--color-accent-primary-muted);
  --border-radius: 0.25rem;
  --border-color-active: var(--color-foreground-primary);
  --border-color-active-inset: var(--color-background-primary);
  --checkerboard-background: repeating-conic-gradient(rgb(212 212 212) 0% 25%, rgb(255 255 255) 0% 50%);
  --checkerboard-size: 0.5rem 0.5rem;
  border: 0.0625rem solid var(--border-color);
  border-radius: var(--border-radius);
  overflow: hidden;
}
.main_ui_ds_utilities_swatch__swatch:focus-visible {
  --border-color: var(--color-accent-primary);
}

.main_ui_ds_utilities_swatch__small {
  inline-size: 1rem;
  block-size: 1rem;
}

.main_ui_ds_utilities_swatch__medium {
  --checkerboard-size: 1rem 1rem;
  inline-size: 1.5rem;
  block-size: 1.5rem;
}

.main_ui_ds_utilities_swatch__large {
  --checkerboard-size: 2rem 2rem;
  inline-size: 3rem;
  block-size: 3rem;
}

.main_ui_ds_utilities_swatch__rounded {
  --border-radius: 50%;
}

.main_ui_ds_utilities_swatch__active {
  --border-color: var(--border-color-active);
  position: relative;
}
.main_ui_ds_utilities_swatch__active::before {
  content: "";
  position: absolute;
  inset-block-start: 0;
  inset-inline-start: 0;
  inline-size: 100%;
  block-size: 100%;
  border-radius: 3px;
  box-shadow: 0 0 0 1px var(--border-color-active-inset) inset;
}

.main_ui_ds_utilities_swatch__interactive {
  cursor: pointer;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  margin: 0;
  padding: 0;
  background: none;
}
.main_ui_ds_utilities_swatch__interactive:hover {
  --border-color: var(--color-accent-primary-muted);
  border-width: 0.125rem;
}

.main_ui_ds_utilities_swatch__swatch-image,
.main_ui_ds_utilities_swatch__swatch-gradient,
.main_ui_ds_utilities_swatch__swatch-opacity,
.main_ui_ds_utilities_swatch__swatch-solid {
  block-size: 100%;
  display: block;
}

.main_ui_ds_utilities_swatch__swatch-gradient {
  background-size: cover, var(--checkerboard-size);
  background-position: center, center;
  background-repeat: no-repeat, repeat;
}

.main_ui_ds_utilities_swatch__swatch-image {
  background-size: cover, var(--checkerboard-size);
  background-position: center, center;
  background-repeat: no-repeat, repeat;
}

.main_ui_ds_utilities_swatch__swatch-opacity {
  display: grid;
  grid-template-columns: auto auto;
}

.main_ui_ds_utilities_swatch__swatch-opacity-side-transparency {
  background-image: linear-gradient(var(--solid-color-overlay), var(--solid-color-overlay)), var(--checkerboard-background);
  background-size: cover, var(--checkerboard-size);
  background-position: center, center;
  background-repeat: no-repeat, repeat;
  clip-path: inset(0 0 0 0 round 0 0.25rem 0.25rem 0);
}

.main_ui_ds_utilities_swatch__swatch-opacity-side-solid-color {
  background: var(--solid-color-overlay);
  background-size: cover;
}

.main_ui_ds_utilities_swatch__swatch-solid-side,
.main_ui_ds_utilities_swatch__swatch-opacity-side {
  flex: 1;
  display: block;
}

.main_ui_ds_utilities_swatch__swatch-error {
  background: var(--color-background-primary);
}
:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_ds_tooltip_tooltip__tooltip {
  position: fixed;
  max-inline-size: 22rem;
  background-color: transparent;
  overflow: hidden;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  block-size: -moz-fit-content;
  block-size: fit-content;
  z-index: var(--z-index-notifications);
}

.main_ui_ds_tooltip_tooltip__tooltip-content-wrapper {
  display: grid;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  block-size: -moz-fit-content;
  block-size: fit-content;
}

.main_ui_ds_tooltip_tooltip__tooltip-arrow {
  background-color: var(--color-background-primary);
  border-radius: var(--sp-xs);
  inline-size: 12px;
  block-size: 12px;
  grid-area: arrow;
}

.main_ui_ds_tooltip_tooltip__tooltip-top {
  grid-template-areas: "content" "arrow";
}

.main_ui_ds_tooltip_tooltip__tooltip-top .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  justify-self: center;
  border-radius: 0 0 var(--sp-xs) 0;
  transform-origin: 0 0;
  transform: rotate(45deg) translate(-2px, -10px);
  border-block-end: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-end: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-bottom {
  grid-template-areas: "arrow" "content";
}

.main_ui_ds_tooltip_tooltip__tooltip-bottom .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  justify-self: center;
  border-radius: var(--sp-xs) 0;
  transform-origin: 0 0;
  transform: rotate(45deg) translate(7px, -2px);
  border-block-start: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-left {
  grid-template-areas: "content arrow ";
}

.main_ui_ds_tooltip_tooltip__tooltip-left .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  align-self: center;
  border-radius: 0 var(--sp-xs);
  transform-origin: 0 0;
  transform: rotate(45deg) translate(-2px, -1px);
  border-block-start: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-end: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-right {
  grid-template-areas: "arrow content";
}

.main_ui_ds_tooltip_tooltip__tooltip-right .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  align-self: center;
  border-radius: 0 var(--sp-xs);
  transform-origin: 0 0;
  transform: rotate(45deg) translate(7px, -10px);
  border-block-end: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-top-right {
  grid-template-areas: "content" "arrow";
}

.main_ui_ds_tooltip_tooltip__tooltip-top-right .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  margin: 0 var(--sp-l);
  border-radius: var(--sp-xs) 0;
  transform: rotate(45deg) translateX(calc(-1 * var(--sp-s)));
  border-block-end: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-end: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-bottom-right {
  grid-template-areas: "arrow" "content";
}

.main_ui_ds_tooltip_tooltip__tooltip-bottom-right .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  margin: 0 var(--sp-s);
  transform: rotate(45deg) translateX(var(--sp-s));
  border-radius: var(--sp-xs) 0;
  border-block-start: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-bottom-left {
  grid-template-areas: "arrow" "content";
}

.main_ui_ds_tooltip_tooltip__tooltip-bottom-left .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  justify-self: end;
  margin: 0 var(--sp-s);
  transform: rotate(45deg) translateY(var(--sp-s));
  border-radius: var(--sp-xs) 0;
  border-block-start: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-top-left {
  grid-template-areas: "content" "arrow";
}

.main_ui_ds_tooltip_tooltip__tooltip-top-left .main_ui_ds_tooltip_tooltip__tooltip-arrow {
  margin: 0 var(--sp-s);
  justify-self: end;
  border-radius: var(--sp-xs) 0;
  transform: rotate(45deg) translateX(calc(-1 * var(--sp-s)));
  border-block-end: 0.0625rem solid var(--color-accent-primary-muted);
  border-inline-end: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_ds_tooltip_tooltip__tooltip-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  background-color: var(--color-background-primary);
  color: var(--color-foreground-secondary);
  border-radius: var(--sp-xs);
  border: 0.0625rem solid var(--color-accent-primary-muted);
  padding: var(--sp-s) var(--sp-m);
  grid-area: content;
  block-size: -moz-fit-content;
  block-size: fit-content;
  overflow-wrap: anywhere;
}

.main_ui_ds_tooltip_tooltip__tooltip-trigger {
  block-size: -moz-fit-content;
  block-size: fit-content;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  line-height: 0;
  display: grid;
  max-width: 100%;
}
.main_ui_ds_product_avatar__avatar {
  border-radius: 50%;
  overflow: hidden;
  border: 0.0625rem solid var(--border-color, none);
}

.main_ui_ds_product_avatar__avatar-small {
  width: 1.5rem;
  height: 1.5rem;
}

.main_ui_ds_product_avatar__avatar-medium {
  width: 2rem;
  height: 2rem;
}

.main_ui_ds_product_avatar__avatar-large {
  width: 2.5rem;
  height: 2.5rem;
}

.main_ui_ds_product_avatar__avatar-image {
  overflow: hidden;
  border-radius: 50%;
  background-color: var(--avatar-color);
}

.main_ui_ds_product_avatar__is-selected {
  --border-color: var(--color-accent-primary);
  padding: var(--sp-xxs);
}

.main_ui_ds_product_avatar__avatar:hover, .main_ui_ds_product_avatar__avatar:focus {
  --border-color: var(--color-accent-primary);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_ds_product_cta__cta {
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--color-accent-primary-muted);
  background: var(--color-accent-select);
  padding: var(--sp-m);
}

.main_ui_ds_product_cta__cta-title {
  color: var(--color-foreground-primary);
  line-height: 1.2;
  margin-block-end: var(--sp-m);
}

.main_ui_ds_product_cta__cta-message {
  line-height: 100%;
}
.main_ui_ds_product_empty_placeholder__empty-placeholder {
  display: grid;
  grid-template-columns: auto 1fr auto;
  place-content: center;
  background: none;
  color: var(--color-foreground-secondary);
  height: 10rem;
  max-width: 60.25rem;
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_ds_product_empty_placeholder__text-wrapper {
  display: grid;
  grid-auto-rows: auto;
  place-self: center center;
  max-width: 25rem;
}

.main_ui_ds_product_empty_placeholder__placeholder-title {
  color: var(--color-foreground-primary);
}

.main_ui_ds_product_empty_placeholder__svg-decor {
  height: 10rem;
  width: 12.5rem;
  color: var(--color-background-quaternary);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_product_empty_state__group {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: var(--sp-m);
}

.main_ui_ds_product_empty_state__icon-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  inline-size: 3rem;
  block-size: 3rem;
}

.main_ui_ds_product_empty_state__icon {
  color: var(--color-foreground-secondary);
  inline-size: 2rem;
  block-size: 2rem;
}

.main_ui_ds_product_empty_state__text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  text-align: center;
  color: var(--color-foreground-secondary);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_product_input_with_meta__input-with-meta-container {
  --input-meta-value: var(--color-foreground-primary);
  --input-meta-data: var(--color-foreground-secondary);
  --input-meta-background: var(--color-background-tertiary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  border-radius: 0.5rem;
  background-color: var(--input-meta-background);
  padding: var(--sp-s);
  width: 99%;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: var(--sp-s);
  overflow: hidden;
  white-space: nowrap;
  height: 2rem;
}
.main_ui_ds_product_input_with_meta__input-with-meta-container:hover {
  --input-meta-background: var(--color-background-quaternary);
  cursor: text;
}

.main_ui_ds_product_input_with_meta__input-with-meta-edit-container {
  width: 99%;
  border-radius: 0.5rem;
  height: 2rem;
}

.main_ui_ds_product_input_with_meta__input-with-meta-value,
.main_ui_ds_product_input_with_meta__input-with-meta-data {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_ds_product_input_with_meta__input-with-meta-value {
  color: var(--input-meta-value);
  min-width: 0;
}

.main_ui_ds_product_input_with_meta__input-with-meta-data {
  color: var(--input-meta-data);
  min-width: 0;
}
@keyframes main_ui_ds_product_loader__line-pencil {
  0% {
    transform: translateY(0);
  }
  100% {
    transform: translateY(-150px);
  }
}
.main_ui_ds_product_loader__wrapper {
  --loader-color-foreground: var(--color-foreground-secondary);
  --loader-icon-width: unset;
  display: inline-flex;
  -moz-column-gap: var(--sp-s);
       column-gap: var(--sp-s);
  align-items: center;
  color: var(--loader-color-foreground);
}
.main_ui_ds_product_loader__wrapper.main_ui_ds_product_loader__file-loading {
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 100%;
  width: 100%;
  padding: var(--sp-xxl);
}
.main_ui_ds_product_loader__wrapper.main_ui_ds_product_loader__file-loading .main_ui_ds_product_loader__loader-content {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: var(--sp-xl);
}
.main_ui_ds_product_loader__wrapper.main_ui_ds_product_loader__file-loading .main_ui_ds_product_loader__tips-container {
  text-align: center;
  min-width: 37.5rem;
  max-width: 50rem;
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
  border: 1px solid var(--color-background-tertiary);
  border-radius: var(--sp-l);
  padding: var(--sp-xxl) var(--sp-xxxl);
}
.main_ui_ds_product_loader__wrapper.main_ui_ds_product_loader__file-loading .main_ui_ds_product_loader__tips-container .main_ui_ds_product_loader__tip-title {
  color: var(--color-foreground-primary);
  font-weight: 500;
}
.main_ui_ds_product_loader__wrapper.main_ui_ds_product_loader__file-loading .main_ui_ds_product_loader__tips-container .main_ui_ds_product_loader__tip-message {
  color: var(--color-foreground-secondary);
}

.main_ui_ds_product_loader__wrapper-overlay {
  display: grid;
  place-content: center;
  height: 100%;
  width: 100%;
  row-gap: var(--sp-s);
}

.main_ui_ds_product_loader__loader {
  fill: currentcolor;
  width: var(--icon-width);
}

.main_ui_ds_product_loader__loader-line {
  animation: main_ui_ds_product_loader__line-pencil 0.8s infinite linear;
}
.main_ui_ds_product_milestone__milestone {
  border: 0.0625rem solid var(--border-color, transparent);
  border-radius: 0.5rem;
  background: var(--color-background-primary);
  display: grid;
  grid-template: "avatar name button" auto "avatar content button" 1fr/calc(var(--sp-xxl) + var(--sp-l)) 1fr auto;
  padding: var(--sp-s) 0;
  align-items: center;
  -moz-column-gap: var(--sp-s);
       column-gap: var(--sp-s);
}
.main_ui_ds_product_milestone__milestone.main_ui_ds_product_milestone__is-selected, .main_ui_ds_product_milestone__milestone:hover {
  --border-color: var(--color-accent-primary);
}

.main_ui_ds_product_milestone__name-input {
  grid-area: name;
}

.main_ui_ds_product_milestone__avatar {
  grid-area: avatar;
  justify-self: flex-end;
}

.main_ui_ds_product_milestone__name-wrapper {
  display: flex;
  align-items: baseline;
}

.main_ui_ds_product_milestone__name {
  grid-area: name;
  color: var(--color-foreground-primary);
}

.main_ui_ds_product_milestone__lock-icon {
  margin-left: 8px;
  transform: scale(0.8);
  color: var(--color-foreground-secondary);
  align-self: anchor-center;
}

.main_ui_ds_product_milestone__date {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-area: content;
  color: var(--color-foreground-secondary);
}

.main_ui_ds_product_milestone__snapshots {
  grid-area: content;
}

.main_ui_ds_product_milestone__milestone-buttons {
  grid-area: button;
  display: flex;
  padding-right: var(--sp-xs);
}

.main_ui_ds_product_milestone__menu-button {
  cursor: pointer;
}
.main_ui_ds_product_milestone_group__milestone {
  border: 0.0625rem solid var(--border-color, transparent);
  border-radius: 0.5rem;
  background: var(--color-background-primary);
  display: grid;
  grid-template: "avatar name button" auto "avatar content button" 1fr/calc(var(--sp-xxl) + var(--sp-l)) 1fr auto;
  padding: var(--sp-s) 0;
  align-items: center;
  -moz-column-gap: var(--sp-s);
       column-gap: var(--sp-s);
}
.main_ui_ds_product_milestone_group__milestone.main_ui_ds_product_milestone_group__is-selected, .main_ui_ds_product_milestone_group__milestone:hover {
  --border-color: var(--color-accent-primary);
}

.main_ui_ds_product_milestone_group__avatar {
  grid-area: avatar;
  justify-self: flex-end;
}

.main_ui_ds_product_milestone_group__name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-area: name;
  color: var(--color-foreground-primary);
}

.main_ui_ds_product_milestone_group__toggle-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-area: name;
}

.main_ui_ds_product_milestone_group__date {
  grid-area: content;
  color: var(--date-color, var(--color-foreground-secondary));
}
.main_ui_ds_product_milestone_group__date:hover {
  --date-color: var(--color-accent-primary);
}

.main_ui_ds_product_milestone_group__snapshots {
  grid-area: content;
}

.main_ui_ds_product_milestone_group__milestone-buttons {
  grid-area: button;
  display: flex;
  padding-right: var(--sp-xs);
}

.main_ui_ds_product_milestone_group__version-entry {
  display: grid;
  grid-template-columns: 1fr auto;
  grid-template-areas: "content button";
  align-items: center;
}
.main_ui_ds_product_milestone_group__version-entry:hover {
  --date-color: var(--color-accent-primary);
  --display-button: visible;
}

.main_ui_ds_product_milestone_group__toggle-snapshots {
  background: none;
  border: none;
  color: var(--color-foreground-secondary);
  display: flex;
  flex-direction: row;
  gap: var(--sp-xs);
  align-items: flex-end;
  margin: 0;
  margin-top: var(--sp-xxs);
  margin-bottom: var(--sp-s);
  padding: 0;
  cursor: pointer;
}
.main_ui_ds_product_milestone_group__toggle-snapshots:hover {
  color: var(--color-accent-primary);
  --icon-stroke-color: var(--color-accent-primary);
}

.main_ui_ds_product_milestone_group__icon-clock {
  --icon-stroke-color: var(--color-accent-warning);
}

.main_ui_ds_product_milestone_group__icon-arrow {
  --icon-stroke-color: var(--icon-stroke-color, var(--color-foreground-secondary));
}

.main_ui_ds_product_milestone_group__icon-arrow-toggled {
  transform: rotate(90deg);
}

.main_ui_ds_product_milestone_group__entry-button {
  visibility: var(--display-button, hidden);
}
.main_ui_ds_product_panel_title__panel-title {
  display: flex;
  align-items: center;
  justify-content: center;
  block-size: 2rem;
  border-radius: 0.5rem;
  background-color: var(--color-background-secondary);
}

.main_ui_ds_product_panel_title__panel-title-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  flex-grow: 1;
  text-align: center;
  color: var(--color-foreground-primary);
}
.main_ui_ds_notifications_actionable__notification {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  --actionable-bg-color: var(--color-background-primary);
  --actionable-fg-color: var(--color-foreground-primary);
  --actionable-border-color: var(--color-background-quaternary);
  --actionable-icon-color: var(--color-foreground-secondary);
  --actionable-padding: var(--sp-s);
  align-items: center;
  background: var(--actionable-bg-color);
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--actionable-border-color);
  color: var(--actionable-fg-color);
  display: grid;
  gap: var(--sp-s);
  grid-template-columns: 1fr auto auto;
  justify-content: space-between;
  padding: var(--actionable-padding);
  padding-inline-start: var(--sp-l);
}
.main_ui_ds_notifications_actionable__notification a {
  color: var(--color-accent-primary);
  text-decoration: none;
}

.main_ui_ds_notifications_actionable__notification-message {
  display: flex;
  align-items: center;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_ds_notifications_toast__toast {
  --toast-icon-color: var(--color-foreground-secondary);
  --toast-vertical-index: var(--z-index-notifications);
  --toast-inset-block-start-position: var(--sp-l);
  --toast-inset-inline-end-position: var(--sp-l);
  min-inline-size: 14rem;
  max-inline-size: 30rem;
  display: block;
  position: fixed;
  inset-block-start: var(--toast-inset-block-start-position);
  inset-inline-end: var(--toast-inset-inline-end-position);
  z-index: var(--toast-vertical-index);
}

.main_ui_ds_notifications_toast__level-default {
  --toast-icon-color: var(--color-icon-default);
}

.main_ui_ds_notifications_toast__level-info {
  --toast-icon-color: var(--color-accent-info);
}

.main_ui_ds_notifications_toast__level-error {
  --toast-icon-color: var(--color-accent-error);
}

.main_ui_ds_notifications_toast__level-warning {
  --toast-icon-color: var(--color-accent-warning);
}

.main_ui_ds_notifications_toast__level-success {
  --toast-icon-color: var(--color-accent-success);
}

.main_ui_ds_notifications_toast__close-button {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  width: 1rem;
  height: 1rem;
  position: absolute;
  top: var(--sp-l);
  right: var(--sp-l);
  background: none;
  border: none;
  color: var(--toast-icon-color);
}
@charset "UTF-8";
.main_ui_ds_notifications_shared_notification_pill__notification-pill {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  --notification-bg-color: var(--color-background-primary);
  --notification-fg-color: var(--color-foreground-primary);
  --notification-border-color: var(--color-background-quaternary);
  --notification-padding: var(--sp-m);
  --notification-icon-color: var(--color-foreground-secondary);
  --notification-icon-margin: var(--sp-xxs);
  background-color: var(--notification-bg-color);
  border: 0.0625rem solid var(--notification-border-color);
  border-radius: 0.5rem;
  padding: var(--notification-padding);
  display: flex;
  gap: var(--sp-s);
  color: var(--notification-fg-color);
}
.main_ui_ds_notifications_shared_notification_pill__notification-pill a {
  color: var(--color-accent-primary);
  text-decoration: none;
}

.main_ui_ds_notifications_shared_notification_pill__type-toast {
  padding-inline-end: var(--sp-xxxl);
}

.main_ui_ds_notifications_shared_notification_pill__appearance-ghost {
  background-color: transparent;
}

.main_ui_ds_notifications_shared_notification_pill__level-default {
  --notification-bg-color: var(--color-background-default);
  --notification-fg-color: var(--color-foreground-primary);
  --notification-border-color: var(--color-accent-default);
  --notification-icon-color: var(--color-icon-default);
}

.main_ui_ds_notifications_shared_notification_pill__level-info {
  --notification-bg-color: var(--color-background-info);
  --notification-fg-color: var(--color-foreground-primary);
  --notification-border-color: var(--color-accent-info);
  --notification-icon-color: var(--color-accent-info);
}

.main_ui_ds_notifications_shared_notification_pill__level-error {
  --notification-bg-color: var(--color-background-error);
  --notification-fg-color: var(--color-foreground-primary);
  --notification-border-color: var(--color-accent-error);
  --notification-icon-color: var(--color-accent-error);
}

.main_ui_ds_notifications_shared_notification_pill__level-warning {
  --notification-bg-color: var(--color-background-warning);
  --notification-fg-color: var(--color-foreground-primary);
  --notification-border-color: var(--color-accent-warning);
  --notification-icon-color: var(--color-accent-warning);
}

.main_ui_ds_notifications_shared_notification_pill__level-success {
  --notification-bg-color: var(--color-background-success);
  --notification-fg-color: var(--color-foreground-primary);
  --notification-border-color: var(--color-accent-success);
  --notification-icon-color: var(--color-accent-success);
}

.main_ui_ds_notifications_shared_notification_pill__icon {
  flex-shrink: 0;
  color: var(--notification-icon-color);
  margin-block-start: var(--notification-icon-margin);
}

.main_ui_ds_notifications_shared_notification_pill__notification-pill {
  display: grid;
  max-height: 92vh;
  overflow: hidden;
}

.main_ui_ds_notifications_shared_notification_pill__with-detail {
  grid-template-rows: auto 1fr;
}

.main_ui_ds_notifications_shared_notification_pill__error-message {
  display: flex;
  gap: var(--sp-s);
}

.main_ui_ds_notifications_shared_notification_pill__error-detail {
  list-style: none;
  padding-inline-start: var(--sp-xxl);
}

.main_ui_ds_notifications_shared_notification_pill__error-detail-summary {
  list-style: none;
  cursor: pointer;
  position: relative;
}
.main_ui_ds_notifications_shared_notification_pill__error-detail-summary::marker {
  display: none;
}
.main_ui_ds_notifications_shared_notification_pill__error-detail-summary::before {
  content: "‣";
  position: absolute;
  inset-block-start: 0;
  inset-inline-start: -1.5rem;
  inline-size: 1rem;
  text-box: trim-start cap alphabetic;
  text-align: end;
  font-size: 1lh;
  line-height: 1;
  font-weight: 700;
  color: currentcolor;
}

.main_ui_ds_notifications_shared_notification_pill__error-detail-content {
  padding-block-start: var(--sp-s);
}
.main_ui_ds_notifications_shared_notification_pill__error-detail-content ul {
  list-style: disc inside;
}
.main_ui_ds_layout_tab_switcher__tabs {
  --tabs-bg-color: var(--color-background-secondary);
  display: grid;
  grid-template-rows: auto 1fr;
}

.main_ui_ds_layout_tab_switcher__padding-wrapper {
  padding-inline: var(--tabs-nav-padding-inline-start, 0) var(--tabs-nav-padding-inline-end, 0);
  padding-block: var(--tabs-nav-padding-block-start, 0) var(--tabs-nav-padding-block-end, 0);
}

.main_ui_ds_layout_tab_switcher__tab-nav {
  display: grid;
  gap: var(--sp-xxs);
  width: 100%;
  border-radius: 0.5rem;
  padding: var(--sp-xxs);
  background-color: var(--tabs-bg-color);
}

.main_ui_ds_layout_tab_switcher__tab-nav-start {
  grid-template-columns: auto 1fr;
}

.main_ui_ds_layout_tab_switcher__tab-nav-end {
  grid-template-columns: 1fr auto;
}

.main_ui_ds_layout_tab_switcher__tab-list {
  display: grid;
  grid-auto-flow: column;
  gap: var(--sp-xxs);
  width: 100%;
  margin-block-end: 0;
  border-radius: 0.5rem;
}

.main_ui_ds_layout_tab_switcher__tab {
  --tabs-item-bg-color: var(--color-background-secondary);
  --tabs-item-fg-color: var(--color-foreground-secondary);
  --tabs-item-fg-color-hover: var(--color-foreground-primary);
  --tabs-item-outline-color: none;
}
.main_ui_ds_layout_tab_switcher__tab:hover {
  --tabs-item-fg-color: var(--tabs-item-fg-color-hover);
}
.main_ui_ds_layout_tab_switcher__tab:focus-visible {
  --tabs-item-outline-color: var(--color-accent-primary);
}
.main_ui_ds_layout_tab_switcher__tab {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  height: 2rem;
  border: none;
  border-radius: 0.5rem;
  outline: 0.0625rem solid var(--tabs-item-outline-color);
  display: grid;
  grid-auto-flow: column;
  align-items: center;
  justify-content: center;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  background: var(--tabs-item-bg-color);
  color: var(--tabs-item-fg-color);
  padding: 0 var(--sp-m);
  width: 100%;
}

.main_ui_ds_layout_tab_switcher__selected {
  --tabs-item-bg-color: var(--color-background-quaternary);
  --tabs-item-fg-color: var(--color-accent-primary);
  --tabs-item-fg-color-hover: var(--color-accent-primary);
}

.main_ui_ds_layout_tab_switcher__tab-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
  min-width: 0;
}

.main_ui_ds_layout_tab_switcher__tab-text-and-icon {
  padding-inline: var(--sp-xxs);
}

.main_ui_ds_layout_tab_switcher__tab-panel {
  --tab-panel-outline-color: none;
}
.main_ui_ds_layout_tab_switcher__tab-panel:focus {
  outline: none;
}
.main_ui_ds_layout_tab_switcher__tab-panel:focus-visible {
  --tab-panel-outline-color: var(--color-accent-primary);
}
.main_ui_ds_layout_tab_switcher__tab-panel {
  display: grid;
  width: 100%;
  height: 100%;
  outline: 0.0625rem solid var(--tab-panel-outline-color);
}

.main_ui_ds_layout_tab_switcher__scrollable-panel {
  overflow-y: auto;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_ds_layers_layer_button__layer-button-wrapper {
  --layer-button-block-size: 2rem;
  --layer-button-background: var(--color-background-primary);
  --layer-button-text: var(--color-foreground-secondary);
  display: flex;
  justify-content: space-between;
  block-size: var(--layer-button-block-size);
  background: var(--layer-button-background);
  color: var(--layer-button-text);
}

.main_ui_ds_layers_layer_button__layer-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  flex: 1;
  display: flex;
  align-items: center;
  border: none;
  background: none;
  color: inherit;
}

.main_ui_ds_layers_layer_button__layer-button-expanded .main_ui_ds_layers_layer_button__layer-button-name {
  color: var(--color-foreground-primary);
}

.main_ui_ds_layers_layer_button__layer-button-content {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_ds_layers_layer_button__layer-button-description {
  padding: var(--sp-xs);
  background-color: var(--color-background-tertiary);
  border-radius: 0.375rem;
}
.main_ui_ds_foundations_utilities_token_token_status__token-icon {
  fill: currentcolor;
  stroke: none;
}
.main_ui_ds_foundations_typography_heading__display-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 2.25rem;
}

.main_ui_ds_foundations_typography_heading__title-large-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
}

.main_ui_ds_foundations_typography_heading__title-medium-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.25rem;
}

.main_ui_ds_foundations_typography_heading__title-small-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
}

.main_ui_ds_foundations_typography_heading__headline-large-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
}

.main_ui_ds_foundations_typography_heading__headline-medium-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
}

.main_ui_ds_foundations_typography_heading__headline-small-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
}

.main_ui_ds_foundations_typography_heading__body-large-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}

.main_ui_ds_foundations_typography_heading__body-medium-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}

.main_ui_ds_foundations_typography_heading__body-small-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_ds_foundations_typography_heading__code-font-typography {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
}
.main_ui_ds_foundations_typography_text__display-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 2.25rem;
}

.main_ui_ds_foundations_typography_text__title-large-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
}

.main_ui_ds_foundations_typography_text__title-medium-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.25rem;
}

.main_ui_ds_foundations_typography_text__title-small-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
}

.main_ui_ds_foundations_typography_text__headline-large-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
}

.main_ui_ds_foundations_typography_text__headline-medium-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
}

.main_ui_ds_foundations_typography_text__headline-small-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
}

.main_ui_ds_foundations_typography_text__body-large-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}

.main_ui_ds_foundations_typography_text__body-medium-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}

.main_ui_ds_foundations_typography_text__body-small-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_ds_foundations_typography_text__code-font-typography {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
}
.main_ui_ds_foundations_assets_icon__icon {
  fill: var(--icon-fill-color, none);
  stroke: var(--icon-stroke-color, currentColor);
}
.main_ui_ds_controls_checkbox__checkbox {
  --input-checkbox-border-color: var(--color-foreground-secondary);
  --input-checkbox-border-color-focus: var(--color-accent-primary);
  --input-checkbox-border-color-hover: var(--color-accent-primary-muted);
  --input-checkbox-foreground-color: var(--color-foreground-primary);
  --input-checkbox-background-color: var(--color-background-quaternary);
  --input-checkbox-border-color-checked: var(--color-background-quaternary);
  --input-checkbox-foreground-color-checked: var(--color-background-primary);
  --input-checkbox-background-color-checked: var(--color-accent-primary);
  --input-checkbox-foreground-color-disabled: var(--color-background-primary);
  --input-checkbox-background-color-disabled: var(--color-foreground-secondary);
  --input-checkbox-text-color: var(--color-foreground-secondary);
}

.main_ui_ds_controls_checkbox__checkbox-label {
  display: grid;
  grid-template-columns: var(--sp-l) 1fr 0;
  align-items: center;
}
.main_ui_ds_controls_checkbox__checkbox-label:hover .main_ui_ds_controls_checkbox__checkbox-box {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_ds_controls_checkbox__checkbox-label:focus .main_ui_ds_controls_checkbox__checkbox-box, .main_ui_ds_controls_checkbox__checkbox-label:focus-within .main_ui_ds_controls_checkbox__checkbox-box {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_ds_controls_checkbox__checkbox-box {
  display: flex;
  align-items: center;
  justify-content: center;
  inline-size: 1rem;
  block-size: 1rem;
  border-radius: 0.25rem;
  border: 0.0625rem solid var(--input-checkbox-border-color);
  color: var(--input-checkbox-foreground-color);
  background-color: var(--input-checkbox-background-color);
}
.main_ui_ds_controls_checkbox__checkbox-box.main_ui_ds_controls_checkbox__disabled {
  border: 0;
}
.main_ui_ds_controls_checkbox__checkbox-box.main_ui_ds_controls_checkbox__checked {
  --input-checkbox-border-color: var(--input-checkbox-border-color-checked);
  --input-checkbox-foreground-color: var(--input-checkbox-foreground-color-checked);
  --input-checkbox-background-color: var(--input-checkbox-background-color-checked);
}
.main_ui_ds_controls_checkbox__checkbox-box.main_ui_ds_controls_checkbox__checked.main_ui_ds_controls_checkbox__disabled {
  --input-checkbox-foreground-color: var(--input-checkbox-foreground-color-disabled);
  --input-checkbox-background-color: var(--input-checkbox-background-color-disabled);
}

.main_ui_ds_controls_checkbox__checkbox-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding-inline-start: var(--sp-s);
  color: var(--input-checkbox-text-color);
}

.main_ui_ds_controls_checkbox__checkbox-input:focus {
  outline: 0;
  inline-size: 0;
  block-size: 0;
}
.main_ui_ds_controls_combobox__wrapper {
  --combobox-icon-color: var(--color-icon-default);
  --combobox-text-color: var(--color-foreground-primary);
  --combobox-background-color: var(--color-background-tertiary);
  --combobox-outline-color: none;
  --combobox-border-color: none;
  --combobox-error-outline-color: var(--color-accent-error);
}
.main_ui_ds_controls_combobox__wrapper:hover:not(.main_ui_ds_controls_combobox__disabled) {
  --combobox-background-color: var(--color-background-quaternary);
}
.main_ui_ds_controls_combobox__wrapper:focus-within:not(.main_ui_ds_controls_combobox__disabled) {
  --combobox-outline-color: var(--color-accent-primary);
  --combobox-background-color: var(--color-background-primary);
}
.main_ui_ds_controls_combobox__wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  position: relative;
  display: grid;
  grid-template-rows: auto;
  gap: var(--sp-xxs);
  width: 100%;
}

.main_ui_ds_controls_combobox__combobox {
  display: grid;
  grid-template-columns: 1fr auto;
  gap: var(--sp-xs);
  height: 2rem;
  width: 100%;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  outline: 0.0625rem solid var(--combobox-outline-color);
  border: 0.0625rem solid var(--combobox-border-color);
  background: var(--combobox-background-color);
  color: var(--combobox-text-color);
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  align-content: center;
  place-items: center start;
}

.main_ui_ds_controls_combobox__arrow {
  color: var(--combobox-icon-color);
}

.main_ui_ds_controls_combobox__header {
  display: grid;
  justify-items: start;
  gap: var(--sp-xs);
}

.main_ui_ds_controls_combobox__header-icon {
  grid-template-columns: auto 1fr;
  color: var(--combobox-icon-color);
}

.main_ui_ds_controls_combobox__header-avatar {
  grid-template-columns: auto 1fr;
  gap: var(--sp-s);
  width: 100%;
}

.main_ui_ds_controls_combobox__input {
  all: unset;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  background-color: transparent;
  overflow: hidden;
  text-align: left;
  inline-size: 100%;
  padding-inline-start: var(--sp-xxs);
  color: var(--combobox-text-color);
}
.main_ui_ds_controls_combobox__input::-moz-placeholder {
  color: var(--input-placeholder-color);
  text-overflow: ellipsis;
}
.main_ui_ds_controls_combobox__input::placeholder {
  color: var(--input-placeholder-color);
  text-overflow: ellipsis;
}

.main_ui_ds_controls_combobox__button-toggle-list {
  all: unset;
  display: flex;
}

.main_ui_ds_controls_combobox__disabled {
  cursor: default;
  --combobox-background-color: var(--color-background-primary);
  --combobox-border-color: var(--color-background-quaternary);
  --combobox-text-color: var(--color-foreground-secondary);
}

.main_ui_ds_controls_combobox__has-error {
  --combobox-outline-color: var(--combobox-error-outline-color);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_controls_input__input-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  inline-size: 100%;
}

.main_ui_ds_controls_input__hint-formated {
  white-space: pre;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_controls_numeric_input__input-wrapper {
  --input-padding-size: var(--sp-xs);
  --opacity-button: 0;
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  inline-size: 100%;
  position: relative;
}
.main_ui_ds_controls_numeric_input__input-wrapper.main_ui_ds_controls_numeric_input__resizable:not(:focus-within) {
  cursor: ew-resize;
}
.main_ui_ds_controls_numeric_input__input-wrapper:hover {
  --opacity-button: 1;
}
.main_ui_ds_controls_numeric_input__input-wrapper:focus-within {
  --opacity-button: 1;
}

.main_ui_ds_controls_numeric_input__icon {
  color: var(--color-foreground-secondary);
  min-inline-size: var(--sp-l);
}

.main_ui_ds_controls_numeric_input__text-icon {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  min-inline-size: 2.875rem;
  padding-inline-start: var(--sp-xs);
}

.main_ui_ds_controls_numeric_input__invisible-button {
  position: absolute;
  inset-inline-end: 0;
  inset-block-start: 0;
  opacity: var(--opacity-button);
  background-color: var(--color-background-quaternary);
}
.main_ui_ds_controls_numeric_input__invisible-button:hover {
  background-color: var(--color-background-quaternary);
  --opacity-button: 1;
}
.main_ui_ds_controls_numeric_input__invisible-button:focus {
  background-color: var(--color-background-quaternary);
  --opacity-button: 1;
}

.main_ui_ds_controls_numeric_input__button-tooltip {
  inline-size: 1.75rem;
  block-size: 100%;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_controls_radio_buttons__wrapper {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  width: -moz-fit-content;
  width: fit-content;
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
  gap: var(--sp-xs);
}
.main_ui_ds_controls_radio_buttons__wrapper.main_ui_ds_controls_radio_buttons__extended {
  width: 100%;
  display: flex;
}
.main_ui_ds_controls_radio_buttons__wrapper.main_ui_ds_controls_radio_buttons__disabled {
  outline: 0.0625rem solid var(--color-background-quaternary);
  background-color: transparent;
}

.main_ui_ds_controls_radio_buttons__label.main_ui_ds_controls_radio_buttons__extended {
  display: flex;
  flex: 1 1 0;
}

.main_ui_ds_controls_radio_buttons__button.main_ui_ds_controls_radio_buttons__extended {
  flex-grow: 1;
}

.main_ui_ds_controls_radio_buttons__input {
  display: none;
}
.main_ui_ds_controls_select__select-wrapper {
  --select-icon-color: var(--color-icon-default);
  --select-text-color: var(--color-foreground-primary);
  --select-text-color-dimmed: var(--color-foreground-secondary);
  --select-background-color: var(--color-background-tertiary);
  --select-outline-color: none;
  --select-border-color: none;
}
.main_ui_ds_controls_select__select-wrapper:hover {
  --select-background-color: var(--color-background-quaternary);
  --select-icon-color: var(--color-foreground-primary);
}
.main_ui_ds_controls_select__select-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  position: relative;
  display: grid;
  grid-template-rows: auto;
  gap: var(--sp-xxs);
  width: 100%;
}

.main_ui_ds_controls_select__select:focus-visible {
  --select-background-color: var(--color-background-quaternary);
  --select-outline-color: var(--color-accent-primary);
}
.main_ui_ds_controls_select__select:disabled {
  --select-background-color: var(--color-background-primary);
  --select-border-color: var(--color-background-quaternary);
  --select-text-color: var(--color-foreground-secondary);
}
.main_ui_ds_controls_select__select {
  display: grid;
  grid-template-columns: 1fr auto;
  gap: var(--sp-xs);
  block-size: 2rem;
  inline-size: 100%;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  outline: 0.0625rem solid var(--select-outline-color);
  border: 0.0625rem solid var(--select-border-color);
  background: var(--select-background-color);
  color: var(--select-text-color);
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
}

.main_ui_ds_controls_select__variant-ghost {
  --select-background-color: transparent;
  --select-text-color: var(--color-foreground-secondary);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  padding-inline: var(--sp-xxs);
}
.main_ui_ds_controls_select__variant-ghost .main_ui_ds_controls_select__arrow {
  margin-inline-start: var(--sp-xs);
}
.main_ui_ds_controls_select__variant-ghost:is(:hover, [aria-expanded=true]) {
  --select-text-color: var(--color-foreground-primary);
  --select-icon-color: var(--color-foreground-primary);
}
.main_ui_ds_controls_select__variant-ghost:is(:focus-visible, :disabled) {
  --select-background-color: transparent;
  --select-text-color: var(--color-foreground-primary);
  --select-icon-color: var(--color-foreground-primary);
}

.main_ui_ds_controls_select__arrow {
  color: var(--select-icon-color);
}

.main_ui_ds_controls_select__select-header {
  display: grid;
  justify-items: start;
  gap: var(--sp-xs);
}

.main_ui_ds_controls_select__header-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
  min-width: 0;
  padding-inline-start: var(--sp-xxs);
  text-align: left;
  color: var(--select-text-color);
}

.main_ui_ds_controls_select__header-label-dimmed {
  color: var(--select-text-color-dimmed);
}

.main_ui_ds_controls_select__header-icon {
  grid-template-columns: auto 1fr;
  color: var(--select-icon-color);
}

.main_ui_ds_controls_select__header-icon-only {
  grid-template-columns: 1fr;
  color: var(--select-icon-color);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_controls_switch__switch {
  --switch-label-foreground-color: var(--color-foreground-primary);
  --switch-track-outline-color: none;
  --switch-track-shadow: inset 0 1px 2px var(--color-shadow-light);
  --switch-thumb-shadow: 0 1px 2px var(--color-shadow-light);
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  gap: var(--sp-s);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  outline: none;
}
.main_ui_ds_controls_switch__switch.main_ui_ds_controls_switch__off {
  --switch-track-justify-content: start;
  --switch-track-background-color: var(--color-foreground-secondary);
  --switch-thumb-width: 0.875rem;
  --switch-thumb-height: 0.875rem;
  --switch-thumb-background-color: var(--color-accent-off);
  --switch-thumb-border-radius: 50%;
}
.main_ui_ds_controls_switch__switch.main_ui_ds_controls_switch__neutral {
  --switch-track-justify-content: center;
  --switch-track-background-color: var(--color-accent-tertiary);
  --switch-thumb-width: 0.875rem;
  --switch-thumb-height: 0.25rem;
  --switch-thumb-background-color: var(--color-accent-off);
  --switch-thumb-border-radius: 0.5rem;
}
.main_ui_ds_controls_switch__switch.main_ui_ds_controls_switch__on {
  --switch-track-justify-content: end;
  --switch-track-background-color: var(--color-accent-tertiary);
  --switch-thumb-width: 0.875rem;
  --switch-thumb-height: 0.875rem;
  --switch-thumb-background-color: var(--color-accent-off);
  --switch-thumb-border-radius: 50%;
}
.main_ui_ds_controls_switch__switch[disabled] {
  pointer-events: none;
  --switch-label-foreground-color: var(--color-foreground-secondary);
  --switch-track-shadow: none;
  --switch-thumb-shadow: none;
}
.main_ui_ds_controls_switch__switch.main_ui_ds_controls_switch__off[disabled] {
  --switch-track-background-color: var(--color-background-primary);
  --switch-track-border-color: var(--color-background-disabled);
  --switch-thumb-background-color: var(--color-background-disabled);
}
.main_ui_ds_controls_switch__switch.main_ui_ds_controls_switch__on[disabled], .main_ui_ds_controls_switch__switch.main_ui_ds_controls_switch__neutral[disabled] {
  --switch-track-background-color: var(--color-background-disabled);
  --switch-thumb-background-color: var(--color-background-primary);
}
.main_ui_ds_controls_switch__switch:focus-visible {
  --switch-track-outline-color: var(--color-accent-primary);
}
.main_ui_ds_controls_switch__switch:hover {
  --switch-thumb-background-color: var(--color-static-white);
}

.main_ui_ds_controls_switch__switch-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--switch-label-foreground-color);
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_ds_controls_switch__switch-track {
  display: flex;
  align-items: center;
  justify-content: var(--switch-track-justify-content);
  inline-size: 1.875rem;
  block-size: 1.125rem;
  padding: var(--sp-xxs);
  border-radius: 0.75rem;
  border: 0.0625rem solid var(--switch-track-border-color);
  outline: 0.0625rem solid var(--switch-track-outline-color);
  outline-offset: 0.0625rem;
  box-shadow: var(--switch-track-shadow);
  background-color: var(--switch-track-background-color);
}

.main_ui_ds_controls_switch__switch-thumb {
  inline-size: var(--switch-thumb-width);
  block-size: var(--switch-thumb-height);
  border-radius: var(--switch-thumb-border-radius);
  box-shadow: var(--switch-thumb-shadow);
  background-color: var(--switch-thumb-background-color);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_ds_controls_utilities_hint_message__hint-message {
  --hint-color: var(--color-foreground-secondary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--hint-color);
}

.main_ui_ds_controls_utilities_hint_message__type-hint {
  --hint-color: var(--color-foreground-secondary);
}

.main_ui_ds_controls_utilities_hint_message__type-warning {
  --hint-color: var(--color-accent-warning);
}

.main_ui_ds_controls_utilities_hint_message__type-error {
  --hint-color: var(--color-foreground-error);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_ds_controls_utilities_input_field__input-wrapper {
  --input-bg-color: var(--color-background-tertiary);
  --input-fg-color: var(--color-foreground-primary);
  --input-icon-color: var(--color-foreground-secondary);
  --input-outline-color: none;
  --input-height: 2rem;
  --input-margin: unset;
  display: inline-flex;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  align-items: center;
  position: relative;
  inline-size: 100%;
  background: var(--input-bg-color);
  border-radius: 0.5rem;
  padding: 0 var(--input-padding-size, var(--sp-s));
  outline: 0.0625rem solid var(--input-outline-color);
}
.main_ui_ds_controls_utilities_input_field__input-wrapper:hover {
  --input-bg-color: var(--color-background-quaternary);
}
.main_ui_ds_controls_utilities_input_field__input-wrapper:has(*:focus-visible) {
  --input-bg-color: var(--color-background-primary);
  --input-outline-color: var(--color-accent-primary);
}
.main_ui_ds_controls_utilities_input_field__input-wrapper:has(*:disabled) {
  --input-bg-color: var(--color-background-primary);
  --input-outline-color: var(--color-background-quaternary);
  --input-fg-color: var(--color-foreground-secondary);
}
.main_ui_ds_controls_utilities_input_field__input-wrapper[data-option-focused=true]:has(*:focus-visible) {
  --input-bg-color: var(--color-background-tertiary);
  --input-outline-color: none;
}

.main_ui_ds_controls_utilities_input_field__variant-dense,
.main_ui_ds_controls_utilities_input_field__variant-seamless {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_ds_controls_utilities_input_field__variant-comfortable {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}

.main_ui_ds_controls_utilities_input_field__variant-seamless {
  --input-bg-color: none;
  --input-outline-color: none;
  --input-height: auto;
  --input-margin: 0;
  padding: 0;
  border: none;
}
.main_ui_ds_controls_utilities_input_field__variant-seamless:hover {
  --input-bg-color: none;
  --input-outline-color: none;
}
.main_ui_ds_controls_utilities_input_field__variant-seamless:has(*:focus-visible) {
  --input-bg-color: none;
  --input-outline-color: none;
}

.main_ui_ds_controls_utilities_input_field__input {
  margin: var(--input-margin);
  padding: 0;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  height: var(--input-height);
  border: none;
  background: none;
  inline-size: 100%;
  font-family: inherit;
  font-size: inherit;
  font-weight: inherit;
  line-height: inherit;
  color: var(--input-fg-color);
}
.main_ui_ds_controls_utilities_input_field__input:focus-visible {
  outline: none;
}
.main_ui_ds_controls_utilities_input_field__input::-moz-selection {
  background: var(--color-accent-select);
}
.main_ui_ds_controls_utilities_input_field__input::selection {
  background: var(--color-accent-select);
}
.main_ui_ds_controls_utilities_input_field__input::-moz-placeholder {
  --input-fg-color: var(--color-foreground-secondary);
}
.main_ui_ds_controls_utilities_input_field__input::placeholder {
  --input-fg-color: var(--color-foreground-secondary);
}
.main_ui_ds_controls_utilities_input_field__input:is(:-webkit-autofill, :-webkit-autofill:hover, :-webkit-autofill:focus, :-webkit-autofill:active) {
  -webkit-text-fill-color: var(--input-fg-color);
  -webkit-background-clip: text;
          background-clip: text;
  caret-color: var(--input-bg-color);
}
.main_ui_ds_controls_utilities_input_field__input:is(:autofill, :autofill:hover, :autofill:focus, :autofill:active) {
  -webkit-text-fill-color: var(--input-fg-color);
  -webkit-background-clip: text;
          background-clip: text;
  caret-color: var(--input-bg-color);
}

.main_ui_ds_controls_utilities_input_field__input-with-icon {
  margin-inline-start: var(--sp-xxs);
}

.main_ui_ds_controls_utilities_input_field__hint-type-error {
  --input-outline-color: var(--color-foreground-error);
}

.main_ui_ds_controls_utilities_input_field__icon {
  color: var(--color-foreground-secondary);
  min-inline-size: var(--sp-l);
}

.main_ui_ds_controls_utilities_input_field__tooltip-wrapper {
  inline-size: 100%;
}

.main_ui_ds_controls_utilities_input_field__text-icon {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  min-inline-size: px2rem(46);
  padding-inline-start: var(--sp-xs);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_ds_controls_utilities_label__label {
  --label-color: var(--color-foreground-primary);
  --label-optional-color: var(--color-foreground-secondary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--label-color);
  display: flex;
  gap: var(--sp-xs);
  align-items: center;
}

.main_ui_ds_controls_utilities_label__label-text,
.main_ui_ds_controls_utilities_label__label-optional {
  line-height: inherit;
}

.main_ui_ds_controls_utilities_label__label-text {
  color: var(--label-color);
}

.main_ui_ds_controls_utilities_label__label-optional {
  color: var(--label-optional-color);
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_ds_controls_utilities_token_field__token-field {
  --token-field-bg-color: var(--color-background-tertiary);
  --token-field-icon-color: var(--color-foreground-secondary);
  --token-field-outline-color: none;
  --token-field-height: var(--sp-xxxl);
  --token-field-margin: unset;
  display: inline-flex;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  align-items: center;
  inline-size: 100%;
  background: var(--token-field-bg-color);
  border-radius: 0.5rem;
  padding: var(--sp-xs);
  outline: 0.0625rem solid var(--token-field-outline-color);
  position: relative;
}
.main_ui_ds_controls_utilities_token_field__token-field:hover {
  --token-field-bg-color: var(--color-background-quaternary);
}
.main_ui_ds_controls_utilities_token_field__token-field:focus {
  --token-field-bg-color: var(--color-background-primary);
  --token-field-outline-color: var(--color-accent-primary);
}

.main_ui_ds_controls_utilities_token_field__token-field-wrapper {
  inline-size: 100%;
}

.main_ui_ds_controls_utilities_token_field__with-icon {
  grid-template-columns: auto 1fr;
}

.main_ui_ds_controls_utilities_token_field__token-field-disabled {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  --token-field-bg-color: var(--color-background-primary);
  --token-field-outline-color: var(--color-background-quaternary);
}
.main_ui_ds_controls_utilities_token_field__token-field-disabled:hover {
  --token-field-bg-color: var(--color-background-primary);
  --token-field-outline-color: var(--color-background-quaternary);
}

.main_ui_ds_controls_utilities_token_field__pill {
  --pill-border-color: var(--color-token-border);
  --pill-bg-color: var(--color-background-tertiary);
  --pill-fg-color: var(--color-token-foreground);
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  display: block;
  block-size: var(--sp-xxl);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  background: var(--pill-bg-color);
  cursor: pointer;
  border: 0.0625rem solid var(--pill-border-color);
  color: var(--pill-fg-color);
  border-radius: 0.375rem;
  padding-inline: 0.375rem;
  max-inline-size: 100%;
}
.main_ui_ds_controls_utilities_token_field__pill:hover {
  --pill-bg-color: var(--color-token-background);
  --pill-fg-color: var(--color-foreground-primary);
  --pill-border-color: var(--color-token-foreground);
}
.main_ui_ds_controls_utilities_token_field__pill:focus-visible {
  --pill-bg-color: var(--color-token-background);
  --pill-fg-color: var(--color-foreground-primary);
  --pill-border-color: var(--color-accent-primary);
  outline: none;
}

.main_ui_ds_controls_utilities_token_field__pill-disabled {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  --pill-bg-color: none;
  --pill-fg-color: var(--color-foreground-secondary);
  --pill-border-color: var(--color-token-border);
}
.main_ui_ds_controls_utilities_token_field__pill-disabled:hover {
  --pill-bg-color: none;
  --pill-fg-color: var(--color-foreground-secondary);
  --pill-border-color: var(--color-token-border);
}

.main_ui_ds_controls_utilities_token_field__no-set-pill {
  --pill-bg-color: none;
  --pill-fg-color: var(--color-foreground-secondary);
  --pill-border-color: var(--color-token-border);
  position: relative;
}
.main_ui_ds_controls_utilities_token_field__no-set-pill:hover {
  --pill-bg-color: none;
  --pill-fg-color: var(--color-foreground-secondary);
  --pill-border-color: var(--color-token-border);
}

.main_ui_ds_controls_utilities_token_field__pill-dot {
  inline-size: 0.375rem;
  block-size: 0.375rem;
  outline: var(--sp-xxs) solid var(--color-background-primary);
  border-radius: 50%;
  background-color: var(--color-foreground-error);
  margin-inline-start: var(--sp-xs);
  position: absolute;
  inset-inline-end: 0;
  inset-block-start: 0;
}

.main_ui_ds_controls_utilities_token_field__invisible-button {
  position: absolute;
  inset-inline-end: 0;
  inset-block-start: 0;
  opacity: var(--opacity-button);
  background-color: var(--color-background-quaternary);
}
.main_ui_ds_controls_utilities_token_field__invisible-button:hover {
  background-color: var(--color-background-quaternary);
  --opacity-button: 1;
}
.main_ui_ds_controls_utilities_token_field__invisible-button:focus {
  background-color: var(--color-background-quaternary);
  --opacity-button: 1;
}

.main_ui_ds_controls_utilities_token_field__invisible-btn-dropdown-open {
  --opacity-button: 0;
}

.main_ui_ds_controls_utilities_token_field__content-wrapper {
  inline-size: 100%;
}

.main_ui_ds_controls_utilities_token_field__button-tooltip {
  inline-size: 1.75rem;
  block-size: 100%;
}
.main_ui_ds_controls_shared_option__option {
  --options-fg-color: var(--color-foreground-primary);
  --options-bg-color: unset;
  --options-empty: var(--color-canvas);
  display: grid;
  align-content: center;
  place-items: center start;
  grid-template-columns: 1fr auto;
  gap: var(--sp-xs);
  width: 100%;
  height: 2rem;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  outline: 0.0625rem solid var(--options-outline-color);
  outline-offset: -0.0625rem;
  background-color: var(--options-bg-color);
  color: var(--options-fg-color);
  cursor: default;
}
.main_ui_ds_controls_shared_option__option:hover:not(.main_ui_ds_controls_shared_option__option-disabled), .main_ui_ds_controls_shared_option__option[aria-selected=true] {
  --options-bg-color: var(--color-background-quaternary);
}

.main_ui_ds_controls_shared_option__option-with-icon {
  grid-template-columns: auto 1fr auto;
}

.main_ui_ds_controls_shared_option__option-with-avatar {
  grid-template-columns: auto 1fr auto;
  gap: var(--sp-s);
}

.main_ui_ds_controls_shared_option__option-text {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
  min-width: 0;
  padding-inline-start: var(--sp-xxs);
}

.main_ui_ds_controls_shared_option__option-text-dimmed {
  color: var(--options-empty);
}

.main_ui_ds_controls_shared_option__option-icon {
  color: var(--options-icon-fg-color);
}

.main_ui_ds_controls_shared_option__option-current {
  --options-outline-color: var(--color-accent-primary);
  outline: 0.0625rem solid var(--options-outline-color);
}

.main_ui_ds_controls_shared_option__option-selected {
  --options-fg-color: var(--color-accent-primary);
  --options-icon-fg-color: var(--color-accent-primary);
}

.main_ui_ds_controls_shared_option__option-disabled {
  opacity: 0.6;
}

.main_ui_ds_controls_shared_option__option-check {
  color: var(--token-options-icon-fg-color);
  min-width: var(--sp-l);
}
.main_ui_ds_controls_shared_options_dropdown__option-list {
  --options-dropdown-icon-fg-color: var(--color-foreground-secondary);
  --options-dropdown-bg-color: var(--color-background-tertiary);
  --options-dropdown-outline-color: none;
  --options-dropdown-border-color: var(--color-background-quaternary);
  position: absolute;
  inset-block: var(--dropdown-start, 2.25rem) var(--dropdown-end, auto);
  inline-size: var(--dropdown-width, 100%);
  transform: translateX(var(--dropdown-translate-distance, 0));
  background-color: var(--options-dropdown-bg-color);
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--options-dropdown-border-color);
  padding-block: var(--sp-xs);
  margin-block-end: 0;
  max-block-size: 25rem;
  overflow: hidden auto;
  z-index: var(--z-index-dropdown);
  box-shadow: 0 0 0.75rem 0 var(--color-shadow-dark);
}
.main_ui_ds_controls_shared_options_dropdown__option-list:focus {
  outline: none;
}

.main_ui_ds_controls_shared_options_dropdown__left-align {
  inset-inline-start: var(--dropdown-offset, 0);
}

.main_ui_ds_controls_shared_options_dropdown__right-align {
  inset-inline-end: var(--dropdown-offset, 0);
}

.main_ui_ds_controls_shared_options_dropdown__option-separator {
  border: 0.0625rem solid var(--options-dropdown-border-color);
  margin-block: var(--sp-xs) var(--sp-xs);
}
.main_ui_ds_controls_shared_render_option__left-align {
  inset-inline-start: var(--dropdown-offset, 0);
}

.main_ui_ds_controls_shared_render_option__right-align {
  inset-inline-end: var(--dropdown-offset, 0);
}

.main_ui_ds_controls_shared_render_option__option-separator {
  border: 0.0625rem solid var(--options-dropdown-border-color);
  margin-block: var(--sp-xs) var(--sp-xs);
}

.main_ui_ds_controls_shared_render_option__group-option,
.main_ui_ds_controls_shared_render_option__option-empty {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  color: var(--color-foreground-secondary);
  padding-inline: var(--sp-s);
  block-size: var(--sp-xxxl);
}

.main_ui_ds_controls_shared_render_option__option-check {
  color: var(--token-options-icon-fg-color);
  min-width: var(--sp-l);
}
.main_ui_ds_controls_shared_searchable_options_dropdown__option-list {
  --options-dropdown-icon-fg-color: var(--color-foreground-secondary);
  --options-dropdown-bg-color: var(--color-background-tertiary);
  --options-dropdown-outline-color: none;
  --options-dropdown-border-color: var(--color-background-quaternary);
  position: absolute;
  inset-block-start: 2.25rem;
  inline-size: var(--dropdown-width, 100%);
  transform: translateX(var(--dropdown-translate-distance, 0));
  background-color: var(--options-dropdown-bg-color);
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--options-dropdown-border-color);
  padding-block: var(--sp-xs);
  margin-block-end: 0;
  max-block-size: 25rem;
  overflow: hidden auto;
  z-index: var(--z-index-dropdown);
  box-shadow: 0 0 0.75rem 0 var(--color-shadow-dark);
}
.main_ui_ds_controls_shared_searchable_options_dropdown__option-list:focus {
  outline: none;
}

.main_ui_ds_controls_shared_searchable_options_dropdown__left-align {
  inset-inline-start: var(--dropdown-offset, 0);
}

.main_ui_ds_controls_shared_searchable_options_dropdown__right-align {
  inset-inline-end: var(--dropdown-offset, 0);
}

.main_ui_ds_controls_shared_searchable_options_dropdown__option-search {
  padding: var(--sp-xs);
}
.main_ui_ds_controls_shared_token_option__token-option {
  --token-options-fg-color: var(--color-foreground-primary);
  --token-options-bg-color: unset;
  --token-options-empty: var(--color-canvas);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: grid;
  place-items: center start;
  grid-template-columns: 1fr auto;
  gap: 0.375rem;
  width: 100%;
  height: 2rem;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  outline: 0.0625rem solid var(--token-options-outline-color);
  outline-offset: -0.0625rem;
  background-color: var(--token-options-bg-color);
  color: var(--token-options-fg-color);
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.main_ui_ds_controls_shared_token_option__token-option:hover, .main_ui_ds_controls_shared_token_option__token-option[aria-selected=true] {
  --token-options-bg-color: var(--color-background-quaternary);
}

.main_ui_ds_controls_shared_token_option__option-with-pill {
  grid-template-columns: auto 1fr auto;
}

.main_ui_ds_controls_shared_token_option__option-text {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  min-width: 0;
  width: 100%;
  padding-inline-start: var(--sp-xxs);
}

.main_ui_ds_controls_shared_token_option__option-current {
  --token-options-outline-color: var(--color-accent-primary);
  outline: 0.0625rem solid var(--token-options-outline-color);
}

.main_ui_ds_controls_shared_token_option__option-pill {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  background-color: var(--color-background-primary);
  border-radius: 0.375rem;
  padding: var(--sp-xxs) var(--sp-xs);
}

.main_ui_ds_controls_shared_token_option__option-selected-token {
  --token-options-fg-color: var(--color-foreground-primary);
  --token-options-icon-fg-color: var(--color-accent-primary);
}

.main_ui_ds_controls_shared_token_option__icon-placeholder {
  inline-size: var(--sp-l);
}

.main_ui_ds_controls_shared_token_option__option-check {
  color: var(--token-options-icon-fg-color);
  min-width: var(--sp-l);
}

.main_ui_ds_controls_shared_token_option__option-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_ds_controls_shared_token_option__token-name-tooltip {
  color: var(--color-foreground-primary);
  overflow-wrap: anywhere;
}

.main_ui_ds_buttons_button__button {
  --button-bg-color: initial;
  --button-fg-color: initial;
  --button-hover-bg-color: initial;
  --button-hover-fg-color: initial;
  --button-active-bg-color: initial;
  --button-active-fg-color: initial;
  --button-disabled-bg-color: initial;
  --button-disabled-fg-color: initial;
  --button-border-color: var(--button-bg-color);
  --button-focus-inner-ring-color: initial;
  --button-focus-outer-ring-color: initial;
  --button-width: initial;
  --button-height: 2rem;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  width: var(--button-width);
  height: var(--button-height);
  background: var(--button-bg-color);
  color: var(--button-fg-color);
  border: 0.0625rem solid var(--button-border-color);
  border-radius: 0.5rem;
}
.main_ui_ds_buttons_button__button:hover {
  --button-bg-color: var(--button-hover-bg-color);
  --button-fg-color: var(--button-hover-fg-color);
}
.main_ui_ds_buttons_button__button:active, [aria-pressed=true].main_ui_ds_buttons_button__button {
  --button-bg-color: var(--button-active-bg-color);
  --button-fg-color: var(--button-active-fg-color);
}
.main_ui_ds_buttons_button__button:focus-visible {
  outline: var(--button-focus-inner-ring-color) solid 0.125rem;
  outline-offset: -0.1875rem;
  --button-border-color: var(--button-focus-outer-ring-color);
  --button-fg-color: var(--button-focus-fg-color);
}
.main_ui_ds_buttons_button__button:disabled {
  --button-bg-color: var(--button-disabled-bg-color);
  --button-fg-color: var(--button-disabled-fg-color);
}

.main_ui_ds_buttons_button__button-primary {
  --button-bg-color: var(--color-accent-primary);
  --button-fg-color: var(--color-background-secondary);
  --button-hover-bg-color: var(--color-accent-tertiary);
  --button-hover-fg-color: var(--color-background-secondary);
  --button-active-bg-color: var(--color-accent-tertiary);
  --button-active-fg-color: var(--color-background-secondary);
  --button-disabled-bg-color: var(--color-accent-primary-muted);
  --button-disabled-fg-color: var(--color-background-secondary);
  --button-focus-bg-color: var(--color-accent-primary);
  --button-focus-fg-color: var(--color-background-secondary);
  --button-focus-inner-ring-color: var(--color-background-secondary);
  --button-focus-outer-ring-color: var(--color-accent-primary);
}
.main_ui_ds_buttons_button__button-primary:active, [aria-pressed=true].main_ui_ds_buttons_button__button-primary {
  box-shadow: inset 0 0 0.625rem 0.125rem rgba(0, 0, 0, 0.2);
}

.main_ui_ds_buttons_button__button-secondary {
  --button-bg-color: var(--color-background-tertiary);
  --button-fg-color: var(--color-foreground-secondary);
  --button-hover-bg-color: var(--color-background-tertiary);
  --button-hover-fg-color: var(--color-accent-primary);
  --button-active-bg-color: var(--color-background-quaternary);
  --button-active-fg-color: var(--color-accent-primary);
  --button-disabled-bg-color: transparent;
  --button-disabled-fg-color: var(--color-foreground-secondary);
  --button-focus-bg-color: var(--color-background-tertiary);
  --button-focus-fg-color: var(--color-foreground-primary);
  --button-focus-inner-ring-color: var(--color-background-secondary);
  --button-focus-outer-ring-color: var(--color-accent-primary);
}

.main_ui_ds_buttons_button__button-ghost {
  --button-bg-color: transparent;
  --button-fg-color: var(--color-foreground-secondary);
  --button-hover-bg-color: var(--color-background-tertiary);
  --button-hover-fg-color: var(--color-accent-primary);
  --button-active-bg-color: var(--color-background-quaternary);
  --button-active-fg-color: var(--color-accent-primary);
  --button-disabled-bg-color: transparent;
  --button-disabled-fg-color: var(--color-accent-primary-muted);
  --button-focus-bg-color: transparent;
  --button-focus-fg-color: var(--color-foreground-secondary);
  --button-focus-inner-ring-color: transparent;
  --button-focus-outer-ring-color: var(--color-accent-primary);
}

.main_ui_ds_buttons_button__button-destructive {
  --button-bg-color: var(--color-accent-error);
  --button-fg-color: var(--color-foreground-primary);
  --button-hover-bg-color: var(--color-background-error);
  --button-hover-fg-color: var(--color-foreground-primary);
  --button-active-bg-color: var(--color-accent-error);
  --button-active-fg-color: var(--color-foreground-primary);
  --button-disabled-bg-color: var(--color-background-error);
  --button-disabled-fg-color: var(--color-accent-error);
  --button-focus-bg-color: var(--color-accent-error);
  --button-focus-fg-color: var(--color-foreground-primary);
  --button-focus-inner-ring-color: var(--color-background-primary);
  --button-focus-outer-ring-color: var(--color-accent-primary);
}
.main_ui_ds_buttons_button__button-destructive:active, [aria-pressed=true].main_ui_ds_buttons_button__button-destructive {
  box-shadow: inset 0 0 0.625rem 0.125rem rgba(0, 0, 0, 0.2);
}

.main_ui_ds_buttons_button__button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 var(--sp-m);
  display: inline-flex;
  align-items: center;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_ds_buttons_button__button-link:hover {
  text-decoration: none;
}
.main_ui_ds_buttons_icon_button__icon-button {
  --button-bg-color: initial;
  --button-fg-color: initial;
  --button-hover-bg-color: initial;
  --button-hover-fg-color: initial;
  --button-active-bg-color: initial;
  --button-active-fg-color: initial;
  --button-disabled-bg-color: initial;
  --button-disabled-fg-color: initial;
  --button-border-color: var(--button-bg-color);
  --button-focus-inner-ring-color: initial;
  --button-focus-outer-ring-color: initial;
  --button-width: initial;
  --button-height: 2rem;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  width: var(--button-width);
  height: var(--button-height);
  background: var(--button-bg-color);
  color: var(--button-fg-color);
  border: 0.0625rem solid var(--button-border-color);
  border-radius: 0.5rem;
}
.main_ui_ds_buttons_icon_button__icon-button:hover {
  --button-bg-color: var(--button-hover-bg-color);
  --button-fg-color: var(--button-hover-fg-color);
}
.main_ui_ds_buttons_icon_button__icon-button:active, [aria-pressed=true].main_ui_ds_buttons_icon_button__icon-button {
  --button-bg-color: var(--button-active-bg-color);
  --button-fg-color: var(--button-active-fg-color);
}
.main_ui_ds_buttons_icon_button__icon-button:focus-visible {
  outline: var(--button-focus-inner-ring-color) solid 0.125rem;
  outline-offset: -0.1875rem;
  --button-border-color: var(--button-focus-outer-ring-color);
  --button-fg-color: var(--button-focus-fg-color);
}
.main_ui_ds_buttons_icon_button__icon-button:disabled {
  --button-bg-color: var(--button-disabled-bg-color);
  --button-fg-color: var(--button-disabled-fg-color);
}

.main_ui_ds_buttons_icon_button__icon-button-primary {
  --button-bg-color: var(--color-accent-primary);
  --button-fg-color: var(--color-background-secondary);
  --button-hover-bg-color: var(--color-accent-tertiary);
  --button-hover-fg-color: var(--color-background-secondary);
  --button-active-bg-color: var(--color-accent-tertiary);
  --button-active-fg-color: var(--color-background-secondary);
  --button-disabled-bg-color: var(--color-accent-primary-muted);
  --button-disabled-fg-color: var(--color-background-secondary);
  --button-focus-bg-color: var(--color-accent-primary);
  --button-focus-fg-color: var(--color-background-secondary);
  --button-focus-inner-ring-color: var(--color-background-secondary);
  --button-focus-outer-ring-color: var(--color-accent-primary);
}
.main_ui_ds_buttons_icon_button__icon-button-primary:active, [aria-pressed=true].main_ui_ds_buttons_icon_button__icon-button-primary {
  box-shadow: inset 0 0 0.625rem 0.125rem rgba(0, 0, 0, 0.2);
}

.main_ui_ds_buttons_icon_button__icon-button-secondary {
  --button-bg-color: var(--color-background-tertiary);
  --button-fg-color: var(--color-foreground-secondary);
  --button-hover-bg-color: var(--color-background-tertiary);
  --button-hover-fg-color: var(--color-accent-primary);
  --button-active-bg-color: var(--color-background-quaternary);
  --button-active-fg-color: var(--color-accent-primary);
  --button-disabled-bg-color: transparent;
  --button-disabled-fg-color: var(--color-foreground-secondary);
  --button-focus-bg-color: var(--color-background-tertiary);
  --button-focus-fg-color: var(--color-foreground-primary);
  --button-focus-inner-ring-color: var(--color-background-secondary);
  --button-focus-outer-ring-color: var(--color-accent-primary);
}

.main_ui_ds_buttons_icon_button__icon-button-ghost {
  --button-bg-color: transparent;
  --button-fg-color: var(--color-foreground-secondary);
  --button-hover-bg-color: var(--color-background-tertiary);
  --button-hover-fg-color: var(--color-accent-primary);
  --button-active-bg-color: var(--color-background-quaternary);
  --button-active-fg-color: var(--color-accent-primary);
  --button-disabled-bg-color: transparent;
  --button-disabled-fg-color: var(--color-accent-primary-muted);
  --button-focus-bg-color: transparent;
  --button-focus-fg-color: var(--color-foreground-secondary);
  --button-focus-inner-ring-color: transparent;
  --button-focus-outer-ring-color: var(--color-accent-primary);
}

.main_ui_ds_buttons_icon_button__icon-button-destructive {
  --button-bg-color: var(--color-accent-error);
  --button-fg-color: var(--color-foreground-primary);
  --button-hover-bg-color: var(--color-background-error);
  --button-hover-fg-color: var(--color-foreground-primary);
  --button-active-bg-color: var(--color-accent-error);
  --button-active-fg-color: var(--color-foreground-primary);
  --button-disabled-bg-color: var(--color-background-error);
  --button-disabled-fg-color: var(--color-accent-error);
  --button-focus-bg-color: var(--color-accent-error);
  --button-focus-fg-color: var(--color-foreground-primary);
  --button-focus-inner-ring-color: var(--color-background-primary);
  --button-focus-outer-ring-color: var(--color-accent-primary);
}
.main_ui_ds_buttons_icon_button__icon-button-destructive:active, [aria-pressed=true].main_ui_ds_buttons_icon_button__icon-button-destructive {
  box-shadow: inset 0 0 0.625rem 0.125rem rgba(0, 0, 0, 0.2);
}

.main_ui_ds_buttons_icon_button__icon-button {
  --button-width: 2rem;
  --button-height: 2rem;
  display: grid;
  place-content: center;
}

.main_ui_ds_buttons_icon_button__icon-button-action {
  --button-bg-color: transparent;
  --button-fg-color: var(--color-foreground-secondary);
  --button-hover-bg-color: transparent;
  --button-hover-fg-color: var(--color-accent-primary);
  --button-active-bg-color: var(--color-background-quaternary);
  --button-disabled-bg-color: transparent;
  --button-disabled-fg-color: var(--color-accent-primary-muted);
  --button-focus-bg-color: transparent;
  --button-focus-fg-color: var(--color-accent-primary);
  --button-focus-inner-ring-color: transparent;
  --button-focus-outer-ring-color: var(--color-accent-primary);
  --button-width: 1.5rem;
  --button-height: 1.5rem;
}
@keyframes main_ui_alert__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_alert__accept-btn.main_ui_alert__danger, .main_ui_alert__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_alert__accept-btn.main_ui_alert__danger svg, .main_ui_alert__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_alert__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_alert__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_alert__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_alert__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_alert__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_alert__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_alert__accept-btn.disabled, [disabled].main_ui_alert__accept-btn, .main_ui_alert__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_alert__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_alert__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_alert__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_alert__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_alert__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_alert__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_alert__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_alert__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_alert__cancel-button.disabled, [disabled].main_ui_alert__cancel-button, .main_ui_alert__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_alert__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_alert__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_alert__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_alert__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_alert__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_alert__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_alert__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_alert__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_alert__modal-close-btn.disabled, [disabled].main_ui_alert__modal-close-btn, .main_ui_alert__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_alert__modal-close-btn.disabled svg, [disabled].main_ui_alert__modal-close-btn svg, .main_ui_alert__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_alert__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_alert__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_alert__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_alert__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_alert__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_alert__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_alert__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_alert__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_alert__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_alert__modal-close-btn svg, .main_ui_alert__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_alert__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_alert__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_alert__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_alert__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_alert__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_alert__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_alert__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_alert__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_alert__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_alert__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_alert__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_alert__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_alert__accept-btn.main_ui_alert__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_alert__modal-overlay.main_ui_alert__transparent {
  background-color: transparent;
}

.main_ui_alert__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_alert__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.4;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_alert__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  margin-bottom: 1.5rem;
}

.main_ui_alert__modal-scd-msg,
.main_ui_alert__modal-subtitle,
.main_ui_alert__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  line-height: 1.5;
}

.main_ui_alert__link {
  color: var(--color-accent-primary);
}

.main_ui_alert__link::before {
  content: " ";
}

.main_ui_alert__link::after {
  content: " ";
}
@keyframes main_ui_auth__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_auth__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_auth__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_auth__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_auth__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_auth__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_auth__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_auth__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_auth__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_auth__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_auth__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_auth__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_auth__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_auth__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_auth__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_auth__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_auth__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_auth__auth-section {
  position: relative;
  align-items: center;
  background: var(--panel-background-color);
  display: grid;
  gap: 2rem;
  grid-template-columns: repeat(5, 1fr);
  height: 100%;
  padding: 2rem;
  width: 100%;
  overflow: auto;
}
@media (width <= 992px) {
  .main_ui_auth__auth-section {
    display: flex;
    justify-content: center;
  }
}
.main_ui_auth__auth-section.main_ui_auth__register {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_auth__auth-section.main_ui_auth__register .main_ui_auth__login-illustration {
  display: none;
}

.main_ui_auth__logo-container {
  position: absolute;
  top: 1.25rem;
  left: 1.25rem;
  display: flex;
  justify-content: flex-start;
  width: 7.5rem;
  height: 6rem;
  margin-block-end: 3.25rem;
}

.main_ui_auth__login-illustration {
  display: flex;
  justify-content: center;
  grid-column: 1/4;
  width: 40vw;
  height: auto;
  justify-self: center;
}
@media (width <= 992px) {
  .main_ui_auth__login-illustration {
    display: none;
  }
}

.main_ui_auth__auth-content {
  grid-column: 4/6;
  display: grid;
  grid-template-rows: 1fr auto;
  gap: 1.5rem;
  height: -moz-fit-content;
  height: fit-content;
  max-width: 25.75rem;
  padding-block-end: 0.5rem;
  position: relative;
  width: 100%;
}

.main_ui_auth__logo-btn svg {
  width: 7.5rem;
  height: 2.5rem;
  fill: var(--main-icon-foreground);
}
@keyframes main_ui_comments__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_comments__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_comments__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_comments__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_comments__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_comments__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_comments__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_comments__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_comments__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_comments__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_comments__dropdown-menu-option span svg, .main_ui_comments__checkbox.intermediate svg, .main_ui_comments__checkbox.checked svg, .main_ui_comments__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_comments__dropdown-menu-option span svg, .main_ui_comments__checkbox.intermediate svg, .main_ui_comments__checkbox.checked svg, .main_ui_comments__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_comments__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_comments__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_comments__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_comments__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_comments__checkbox {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_comments__checkbox svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_comments__checkbox:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_comments__checkbox:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_comments__checkbox.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_comments__checkbox.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_comments__checkbox.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_comments__checkbox.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_comments__checkbox.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_comments__checkbox.unchecked svg {
  display: none;
}

.main_ui_comments__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_comments__dropdown-menu-option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_comments__dropdown-menu-option span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_comments__dropdown-menu-option span svg {
  stroke: var(--icon-foreground);
}
.main_ui_comments__dropdown-menu-option:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_comments__dropdown-menu-option:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_comments__dropdown-menu {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_comments__cursor-grabbing {
  cursor: grabbing;
}

.main_ui_comments__cursor-pointer {
  cursor: pointer;
}

.main_ui_comments__cursor-auto {
  cursor: auto;
}

.main_ui_comments__grayed-text {
  color: var(--comment-subtitle-color);
}

.main_ui_comments__error-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-error);
}

.main_ui_comments__location {
  color: var(--comment-subtitle-color);
  display: flex;
  align-items: center;
  gap: 0.375rem;
}

.main_ui_comments__location-icon {
  display: flex;
}

.main_ui_comments__location-text {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_comments__author {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
}

.main_ui_comments__author-identity {
  flex-grow: 1;
}

.main_ui_comments__author-fullname {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--comment-title-color);
}

.main_ui_comments__author-timeago {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--comment-subtitle-color);
}

.main_ui_comments__avatar {
  position: relative;
  height: 1.5rem;
  width: 1.5rem;
  border-radius: 50%;
}

.main_ui_comments__avatar-lg {
  height: 2rem;
  width: 2rem;
}

.main_ui_comments__avatar-read {
  border: 0.125rem solid var(--color-background-tertiary);
}

.main_ui_comments__avatar-unread {
  border: 0.125rem solid var(--color-accent-primary);
}

.main_ui_comments__avatar-solved {
  border: 0.125rem solid var(--color-background-tertiary);
}

.main_ui_comments__avatar-image {
  border-radius: 50%;
}

.main_ui_comments__avatar-text {
  border-radius: 50%;
  height: 100%;
  width: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 0.75rem;
  background-color: var(--color-background-quaternary);
}

.main_ui_comments__avatar-mask {
  border-radius: 50%;
  position: absolute;
  height: 100%;
  width: 100%;
  left: 0;
  top: 0;
}

.main_ui_comments__avatar-darken {
  background: rgba(0, 0, 0, 0.5);
}

.main_ui_comments__cover {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  cursor: pointer;
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
  padding: 1.25rem;
  border-bottom: 1px solid var(--color-background-quaternary);
}

.main_ui_comments__item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  overflow-wrap: break-word;
  hyphens: auto;
  white-space: pre-wrap;
}

.main_ui_comments__replies {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  gap: 0.5rem;
}

.main_ui_comments__replies-total {
  color: var(--color-foreground-secondary);
}

.main_ui_comments__replies-unread {
  color: var(--color-accent-primary);
}

.main_ui_comments__floating-preview-wrapper {
  z-index: 1;
  position: absolute;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  cursor: pointer;
  pointer-events: auto;
  transform: translate(calc(-1 * 1rem), calc(-1 * 1rem));
}

.main_ui_comments__floating-preview-bubble {
  z-index: initial;
}

.main_ui_comments__floating-thread-draft-wrapper {
  position: absolute;
  display: flex;
  flex-direction: row;
  -moz-column-gap: 0.75rem;
       column-gap: 0.75rem;
  --translate-x: 0%;
  --translate-y: 0%;
  transform: translate(var(--translate-x), var(--translate-y));
}
.main_ui_comments__floating-thread-draft-wrapper.main_ui_comments__left {
  --translate-x: -100%;
  flex-direction: row-reverse;
}
.main_ui_comments__floating-thread-draft-wrapper.main_ui_comments__top {
  --translate-y: -100%;
  align-items: flex-end;
}

.main_ui_comments__floating-thread-draft-inner-wrapper {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  width: 17.75rem;
  padding: 0.5rem 0.75rem 0.5rem 0.75rem;
  pointer-events: auto;
  border-radius: 8px;
  border: 0.125rem solid var(--modal-border-color);
  background-color: var(--comment-modal-background-color);
  max-height: var(--comment-height);
}

.main_ui_comments__floating-preview-displacement {
  margin-left: calc(-1 * (0.75rem + 0.125rem));
  margin-top: calc(-1 * (0.5rem + 0.125rem));
}

.main_ui_comments__floating-thread-wrapper {
  position: absolute;
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  width: 17.75rem;
  padding: 0.5rem 0.75rem 0.5rem 0.75rem;
  pointer-events: auto;
  border-radius: 8px;
  border: 0.125rem solid var(--modal-border-color);
  background-color: var(--comment-modal-background-color);
  max-height: var(--comment-height);
  --translate-x: 0%;
  --translate-y: 0%;
  transform: translate(var(--translate-x), var(--translate-y));
}
.main_ui_comments__floating-thread-wrapper.main_ui_comments__left {
  --translate-x: -100%;
}
.main_ui_comments__floating-thread-wrapper.main_ui_comments__top {
  --translate-y: -100%;
}

.main_ui_comments__floating-thread-header {
  position: relative;
  display: flex;
  justify-content: space-between;
  align-items: center;
  height: 2rem;
}

.main_ui_comments__floating-thread-header-left {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
}

.main_ui_comments__floating-thread-header-right {
  display: flex;
  align-items: center;
}

.main_ui_comments__floating-thread-main {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  overflow-y: auto;
  padding-bottom: 1rem;
}

.main_ui_comments__floating-thread-item-wrapper {
  position: relative;
}

.main_ui_comments__floating-thread-item {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_comments__checkbox-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1.5rem;
  margin-right: 0.5rem;
}

.main_ui_comments__dropdown-menu {
  position: absolute;
  width: -moz-fit-content;
  width: fit-content;
  max-width: 12.5rem;
  right: 2rem;
  top: 0;
  left: unset;
}

.main_ui_comments__form {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
  max-height: calc(var(--comment-height) - 8.25rem);
}

.main_ui_comments__form-buttons-wrapper {
  display: grid;
  grid-template-columns: 1fr auto auto;
  justify-content: flex-end;
  gap: 0.5rem;
  margin-top: 0.5rem;
}

.main_ui_comments__open-mentions-button {
  color: var(--color-foreground-secondary);
}
.main_ui_comments__open-mentions-button.main_ui_comments__is-toggled {
  color: var(--color-accent-primary);
}

.main_ui_comments__comments-mentions-choice {
  background: var(--color-background-tertiary);
  border-radius: 0.5rem;
  border: none;
  display: flex;
  flex-direction: column;
  left: -0.125rem;
  margin-top: 0.5rem;
  overflow: hidden;
  padding: 0.125rem;
  position: absolute;
  top: 100%;
  width: calc(100% + 0.25rem);
}

.main_ui_comments__comments-mentions-entry {
  cursor: pointer;
  display: grid;
  grid-template-areas: "avatar name" "avatar email";
  grid-template-columns: 2rem 1fr;
  -moz-column-gap: 0.5rem;
       column-gap: 0.5rem;
  margin: 0.25rem 0.5rem;
  padding: 0 0.25rem;
  border-radius: 8px;
  border: 1px solid transparent;
}
.main_ui_comments__comments-mentions-entry:hover {
  background: var(--color-background-quaternary);
}
.main_ui_comments__comments-mentions-entry .main_ui_comments__comments-mentions-avatar {
  grid-area: avatar;
  border-radius: 50%;
}
.main_ui_comments__comments-mentions-entry .main_ui_comments__comments-mentions-name {
  grid-area: name;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
}
.main_ui_comments__comments-mentions-entry .main_ui_comments__comments-mentions-email {
  grid-area: email;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_comments__comments-mentions-entry.main_ui_comments__is-selected {
  border: 1px solid var(--color-accent-primary-muted);
  background: var(--color-background-quaternary);
}

.main_ui_comments__comment-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  background: var(--input-background-color);
  border-radius: 8px;
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
  height: 2.25rem;
  max-width: 16.25rem;
  overflow-y: auto;
  padding: 0.5rem;
  resize: vertical;
  width: 100%;
  white-space: pre-wrap;
  overflow-wrap: break-word;
}
.main_ui_comments__comment-input:focus {
  border: 1px solid var(--input-border-color-active);
  outline: none;
}
.main_ui_comments__comment-input [data-type=mention] {
  color: var(--color-accent-primary);
}
.main_ui_comments__comment-input [data-type=text] {
  color: var(--color-foreground-primary);
}
.main_ui_comments__comment-input::before {
  content: var(--placeholder);
}

.main_ui_comments__comment-mention {
  color: var(--color-accent-primary);
}

.main_ui_comments__comment-link {
  color: var(--color-accent-primary);
  text-decoration: underline;
  cursor: pointer;
}

.main_ui_comments__comments-mentions-empty {
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  padding: 0.375rem 0.5rem;
}
@keyframes main_ui_confirm__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_confirm__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_confirm__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_confirm__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_confirm__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_confirm__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_confirm__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_confirm__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_confirm__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_confirm__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_confirm__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_confirm__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_confirm__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_confirm__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_confirm__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_confirm__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_confirm__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_confirm__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_confirm__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_confirm__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_confirm__modal-overlay.main_ui_confirm__transparent {
  background-color: transparent;
}

.main_ui_confirm__modal-container {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
}

.main_ui_confirm__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.4;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_confirm__modal-close-btn {
  position: absolute;
  top: var(--sp-m);
  right: var(--sp-m);
}

.main_ui_confirm__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
}

.main_ui_confirm__modal-item-element {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}

.main_ui_confirm__modal-component-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  color: var(--color-foreground-secondary);
}

.main_ui_confirm__modal-component-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--color-foreground-secondary);
}

.main_ui_confirm__modal-scd-msg,
.main_ui_confirm__modal-subtitle,
.main_ui_confirm__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
}

.main_ui_confirm__modal-error-msg {
  margin: var(--sp-xxl) 0;
}
@keyframes main_ui_dashboard__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard__dashboard {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3) transparent;
}
.main_ui_dashboard__dashboard:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7) transparent;
}
.main_ui_dashboard__dashboard ::-webkit-scrollbar {
  background-color: transparent;
  cursor: pointer;
  height: 0.75rem;
  width: 0.75rem;
}
.main_ui_dashboard__dashboard ::-webkit-scrollbar-track,
.main_ui_dashboard__dashboard ::-webkit-scrollbar-corner {
  background-color: transparent;
}
.main_ui_dashboard__dashboard ::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 8px;
}
.main_ui_dashboard__dashboard ::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7);
  outline: none;
}
.main_ui_dashboard__dashboard ::-moz-selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_dashboard__dashboard ::selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_dashboard__dashboard ::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_dashboard__dashboard ::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}

.main_ui_dashboard__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard__dashboard {
  background-color: var(--app-background);
  display: grid;
  grid-template-columns: 2.5rem 16rem 1fr;
  grid-template-rows: 3.25rem 1fr;
  height: 100vh;
}

.main_ui_dashboard__dashboard-content {
  display: grid;
  grid-template-rows: 4rem 1fr;
  position: relative;
  grid-row: 1/span 2;
  padding: 1rem 1rem 0 0;
  overflow: hidden;
  width: 100%;
}
@keyframes main_ui_delete_shared__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_delete_shared__accept-btn.main_ui_delete_shared__danger, .main_ui_delete_shared__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_delete_shared__accept-btn.main_ui_delete_shared__danger svg, .main_ui_delete_shared__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_delete_shared__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_delete_shared__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_delete_shared__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_delete_shared__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_delete_shared__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_delete_shared__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_delete_shared__accept-btn.disabled, [disabled].main_ui_delete_shared__accept-btn, .main_ui_delete_shared__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_delete_shared__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_delete_shared__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_delete_shared__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_delete_shared__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_delete_shared__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_delete_shared__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_delete_shared__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_delete_shared__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_delete_shared__cancel-button.disabled, [disabled].main_ui_delete_shared__cancel-button, .main_ui_delete_shared__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_delete_shared__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_delete_shared__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_delete_shared__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_delete_shared__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_delete_shared__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_delete_shared__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_delete_shared__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_delete_shared__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_delete_shared__modal-close-btn.disabled, [disabled].main_ui_delete_shared__modal-close-btn, .main_ui_delete_shared__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_delete_shared__modal-close-btn.disabled svg, [disabled].main_ui_delete_shared__modal-close-btn svg, .main_ui_delete_shared__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_delete_shared__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_delete_shared__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_delete_shared__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_delete_shared__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_delete_shared__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_delete_shared__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_delete_shared__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_delete_shared__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_delete_shared__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_delete_shared__modal-close-btn svg, .main_ui_delete_shared__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_delete_shared__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_delete_shared__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_delete_shared__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_delete_shared__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_delete_shared__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_delete_shared__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_delete_shared__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_delete_shared__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_delete_shared__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_delete_shared__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_delete_shared__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_delete_shared__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_delete_shared__accept-btn.main_ui_delete_shared__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_delete_shared__modal-overlay.main_ui_delete_shared__transparent {
  background-color: transparent;
}

.main_ui_delete_shared__modal-container {
  display: grid;
  gap: var(--sp-xxl);
  grid-template-rows: auto minmax(0, 1fr) auto;
}

.main_ui_delete_shared__list-wrapper {
  display: grid;
  grid-template-rows: auto 1fr auto;
  max-height: 100%;
}

.main_ui_delete_shared__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_delete_shared__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: grid;
  gap: var(--sp-s);
}

.main_ui_delete_shared__element-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
  overflow-y: auto;
  margin-block: 0;
}

.main_ui_delete_shared__modal-scd-msg {
  margin-block: 0;
}

.main_ui_delete_shared__modal-scd-msg,
.main_ui_delete_shared__modal-subtitle,
.main_ui_delete_shared__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
  line-height: 1.5;
}
.main_ui_forms__multi-input {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}

.main_ui_forms__multi-input-chips {
  display: flex;
  flex-wrap: wrap;
  gap: var(--sp-xs);
}

.main_ui_forms__multi-input-chip {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  block-size: 1.5rem;
  padding-inline-start: var(--sp-s);
  border-radius: 0.375rem;
  background-color: var(--color-background-tertiary);
}

.main_ui_forms__multi-input-chip-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
}

.main_ui_forms__multi-input-chip-icon {
  inline-size: 1.5rem;
  block-size: 1.5rem;
}
.main_ui_measurements__badge-text {
  fill: var(--color-static-white);
  font-size: calc(0.75rem / var(--zoom));
}
@keyframes main_ui_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_modal__modal-wrapper {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3) transparent;
}
.main_ui_modal__modal-wrapper:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7) transparent;
}
.main_ui_modal__modal-wrapper ::-webkit-scrollbar {
  background-color: transparent;
  cursor: pointer;
  height: 0.75rem;
  width: 0.75rem;
}
.main_ui_modal__modal-wrapper ::-webkit-scrollbar-track,
.main_ui_modal__modal-wrapper ::-webkit-scrollbar-corner {
  background-color: transparent;
}
.main_ui_modal__modal-wrapper ::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 8px;
}
.main_ui_modal__modal-wrapper ::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7);
  outline: none;
}
.main_ui_modal__modal-wrapper ::-moz-selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_modal__modal-wrapper ::selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_modal__modal-wrapper ::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_modal__modal-wrapper ::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}

.main_ui_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --s-4: 0.25rem;
}
@keyframes main_ui_settings__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings__btn-primary.disabled, [disabled].main_ui_settings__btn-primary, .main_ui_settings__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings__btn-secondary.disabled, [disabled].main_ui_settings__btn-secondary, .main_ui_settings__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_settings__dashboard-header.main_ui_settings__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__element-name {
  margin-right: 0.5rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_settings__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_settings__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_settings__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_settings__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-title .main_ui_settings__context-menu.main_ui_settings__is-open {
  margin-top: 0.5rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_settings__dashboard-header .main_ui_settings__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_settings__dashboard-header .main_ui_settings__dashboard-header-options li.main_ui_settings__active a {
  color: var(--color-foreground-primary);
}

.main_ui_settings__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_settings__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

.main_ui_settings__dashboard {
  background-color: var(--app-background);
  display: grid;
  grid-template-rows: 3rem 1fr;
  grid-template-columns: 2.5rem 16rem 1fr;
  height: 100vh;
}

.main_ui_settings__dashboard-content {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3019607843) transparent;
}
.main_ui_settings__dashboard-content:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7019607843) transparent;
}
.main_ui_settings__dashboard-content::-webkit-scrollbar {
  background: transparent;
  cursor: pointer;
  width: 0.75rem;
  height: 0.75rem;
}
.main_ui_settings__dashboard-content::-webkit-scrollbar-track, .main_ui_settings__dashboard-content::-webkit-scrollbar-corner {
  background: transparent;
}
.main_ui_settings__dashboard-content::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3019607843);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 0.5rem;
}
.main_ui_settings__dashboard-content::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7019607843);
}
.main_ui_settings__dashboard-content::-moz-selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_settings__dashboard-content::selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_settings__dashboard-content::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_settings__dashboard-content::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_settings__dashboard-content {
  display: flex;
  flex-direction: column;
  position: relative;
  grid-row: 1/span 2;
  padding: 1rem 1rem 0 0;
}

.main_ui_settings__dashboard-container {
  flex: 1 0 0;
  margin-right: 1rem;
  overflow-y: auto;
  width: 100%;
  border-top: 1px solid var(--color-background-quaternary);
}
.main_ui_settings__dashboard-container.main_ui_settings__dashboard-projects {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_settings__dashboard-container.main_ui_settings__dashboard-shared {
  width: calc(100vw - 20rem);
  margin-right: 3.25rem;
}
.main_ui_settings__dashboard-container.main_ui_settings__search {
  margin-top: 0.75rem;
}

.main_ui_settings__dashboard-settings {
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.main_ui_settings__dashboard-settings a {
  color: var(--color-foreground-secondary);
}

.main_ui_settings__form-container {
  margin: 3rem auto 2rem 7.5rem;
  display: flex;
  max-width: 23rem;
  width: 100%;
}
.main_ui_settings__form-container.main_ui_settings__two-columns {
  max-width: 32.5rem;
  justify-content: space-between;
  flex-direction: row;
}
.main_ui_settings__form-container h2 {
  margin-bottom: 1rem;
}
.main_ui_settings__form-container form {
  width: 29.25rem;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input,
.main_ui_settings__form-container form .main_ui_settings__custom-select {
  flex-direction: column-reverse;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input label,
.main_ui_settings__form-container form .main_ui_settings__custom-select label {
  position: relative;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  font-size: 0.688rem;
  margin-bottom: 0.75rem;
  margin-left: -0.25rem;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input input,
.main_ui_settings__form-container form .main_ui_settings__custom-input select,
.main_ui_settings__form-container form .main_ui_settings__custom-select input,
.main_ui_settings__form-container form .main_ui_settings__custom-select select {
  background-color: var(--color-background-tertiary);
  border-radius: 0.5rem;
  border-color: transparent;
  color: var(--color-foreground-primary);
  padding: 0 1rem;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input input:focus,
.main_ui_settings__form-container form .main_ui_settings__custom-input select:focus,
.main_ui_settings__form-container form .main_ui_settings__custom-select input:focus,
.main_ui_settings__form-container form .main_ui_settings__custom-select select:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input input ::-moz-placeholder, .main_ui_settings__form-container form .main_ui_settings__custom-input select ::-moz-placeholder, .main_ui_settings__form-container form .main_ui_settings__custom-select input ::-moz-placeholder, .main_ui_settings__form-container form .main_ui_settings__custom-select select ::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input input ::placeholder,
.main_ui_settings__form-container form .main_ui_settings__custom-input select ::placeholder,
.main_ui_settings__form-container form .main_ui_settings__custom-select input ::placeholder,
.main_ui_settings__form-container form .main_ui_settings__custom-select select ::placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input .main_ui_settings__help-icon,
.main_ui_settings__form-container form .main_ui_settings__custom-select .main_ui_settings__help-icon {
  bottom: 0.75rem;
  top: auto;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input .main_ui_settings__help-icon svg,
.main_ui_settings__form-container form .main_ui_settings__custom-select .main_ui_settings__help-icon svg {
  fill: var(--color-foreground-secondary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input.main_ui_settings__disabled input,
.main_ui_settings__form-container form .main_ui_settings__custom-select.main_ui_settings__disabled input {
  background-color: var(--input-background-color-disabled);
  border-color: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input .main_ui_settings__input-container,
.main_ui_settings__form-container form .main_ui_settings__custom-select .main_ui_settings__input-container {
  background-color: var(--color-background-tertiary);
  border-radius: 0.5rem;
  border-color: transparent;
  margin-top: 1.5rem;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input .main_ui_settings__input-container .main_ui_settings__main-content label,
.main_ui_settings__form-container form .main_ui_settings__custom-select .main_ui_settings__input-container .main_ui_settings__main-content label {
  position: absolute;
  top: calc(-1 * 1.5rem);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input .main_ui_settings__input-container .main_ui_settings__main-content span,
.main_ui_settings__form-container form .main_ui_settings__custom-select .main_ui_settings__input-container .main_ui_settings__main-content span {
  color: var(--color-foreground-primary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input .main_ui_settings__input-container:focus,
.main_ui_settings__form-container form .main_ui_settings__custom-select .main_ui_settings__input-container:focus {
  border: 1px solid var(--color-accent-primary);
}
.main_ui_settings__form-container form .main_ui_settings__custom-input textarea,
.main_ui_settings__form-container form .main_ui_settings__custom-select textarea {
  border-radius: 0.5rem;
  padding: 0.75rem 1rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings__form-container form .main_ui_settings__custom-input textarea:focus,
.main_ui_settings__form-container form .main_ui_settings__custom-select textarea:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings__form-container form .main_ui_settings__field-title {
  color: var(--color-foreground-primary);
}
.main_ui_settings__form-container form .main_ui_settings__field-title:not(:first-child) {
  margin-top: 4rem;
}
.main_ui_settings__form-container form .main_ui_settings__field-text {
  color: var(--color-foreground-secondary);
}
.main_ui_settings__form-container form button,
.main_ui_settings__form-container form .main_ui_settings__btn-secondary {
  width: 100%;
  font-size: 0.688rem;
  text-transform: uppercase;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_settings__form-container form button:hover,
.main_ui_settings__form-container form .main_ui_settings__btn-secondary:hover {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_settings__form-container form hr {
  display: none;
}
.main_ui_settings__form-container .main_ui_settings__links {
  margin-top: 0.75rem;
}

.main_ui_settings__profile-form {
  display: flex;
  flex-direction: column;
  max-width: 23rem;
  width: 100%;
}
.main_ui_settings__profile-form .main_ui_settings__newsletter-subs {
  border-bottom: 1px solid var(--color-foreground-secondary);
  border-top: 1px solid var(--color-foreground-secondary);
  padding: 2rem 0;
  margin-bottom: 2rem;
}
.main_ui_settings__profile-form .main_ui_settings__newsletter-subs .main_ui_settings__newsletter-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.875rem;
}
.main_ui_settings__profile-form .main_ui_settings__newsletter-subs label {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-background-primary);
  font-size: 0.75rem;
  margin-right: calc(-1 * 1rem);
  margin-bottom: 0.75rem;
}
.main_ui_settings__profile-form .main_ui_settings__newsletter-subs .main_ui_settings__info {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  margin-bottom: 0.5rem;
}
.main_ui_settings__profile-form .main_ui_settings__newsletter-subs .main_ui_settings__input-checkbox label {
  align-items: flex-start;
}

.main_ui_settings__avatar-form {
  display: flex;
  flex-direction: column;
  width: 7.5rem;
  min-width: 7.5rem;
}
.main_ui_settings__avatar-form img {
  border-radius: 50%;
  flex-shrink: 0;
  height: 7.5rem;
  margin-right: 1rem;
  width: 7.5rem;
}
.main_ui_settings__avatar-form .main_ui_settings__image-change-field {
  position: relative;
  width: 7.5rem;
  height: 7.5rem;
}
.main_ui_settings__avatar-form .main_ui_settings__image-change-field .main_ui_settings__update-overlay {
  opacity: 0;
  cursor: pointer;
  position: absolute;
  width: 7.5rem;
  height: 7.5rem;
  border-radius: 50%;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  line-height: 5;
  text-align: center;
  background: var(--color-accent-tertiary);
  z-index: 14;
}
.main_ui_settings__avatar-form .main_ui_settings__image-change-field input[type=file] {
  width: 7.5rem;
  height: 7.5rem;
  position: absolute;
  opacity: 0;
  cursor: pointer;
  top: 0;
  z-index: 15;
}
.main_ui_settings__avatar-form .main_ui_settings__image-change-field:hover .main_ui_settings__update-overlay {
  opacity: 0.8;
}

.main_ui_settings__options-form h2,
.main_ui_settings__password-form h2 {
  font-size: 0.875rem;
  margin-bottom: 1.25rem;
}
@keyframes main_ui_static__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_static__login-header, .main_ui_static__sign-info button, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_static__login-header svg, .main_ui_static__sign-info button svg, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_static__login-header:focus-visible, .main_ui_static__sign-info button:focus-visible, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:focus-visible,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_static__login-header:focus-visible svg, .main_ui_static__sign-info button:focus-visible svg, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:focus-visible svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_static__login-header:hover, .main_ui_static__sign-info button:hover, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:hover,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_static__login-header:hover svg, .main_ui_static__sign-info button:hover svg, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:hover svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_static__login-header:active, .main_ui_static__sign-info button:active, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:active,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_static__login-header:active svg, .main_ui_static__sign-info button:active svg, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:active svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_static__login-header.disabled, .main_ui_static__sign-info button.disabled, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button.disabled,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button.disabled, [disabled].main_ui_static__login-header, .main_ui_static__sign-info button[disabled], .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button[disabled],
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button[disabled], .main_ui_static__login-header:disabled, .main_ui_static__sign-info button:disabled, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button:disabled,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:focus-visible,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:focus-visible svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:hover,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:hover svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:active,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:active svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button.disabled,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button.disabled, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info [disabled].main_ui_static__cancel-button,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info [disabled].main_ui_static__cancel-button, .main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button:disabled,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_static__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_static__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_static__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_static__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_static__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_static__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_static__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_static__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_static__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_static__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_static__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_static__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_static__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_static__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_static__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_static__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_static__exception-layout {
  width: 100%;
  height: 100%;
  background-color: var(--color-background-secondary);
}

.main_ui_static__nitrate-unavailable-layout {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: space-between;
  background-color: var(--color-background-primary);
  padding: var(--sp-xxxl);
}

.main_ui_static__nitrate-unavailable-content {
  flex: 1;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  gap: var(--sp-xxxl);
}

.main_ui_static__nitrate-unavailable-logo {
  inline-size: 146px;
  block-size: 64px;
  color: var(--color-foreground-primary);
}

.main_ui_static__nitrate-unavailable-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  margin: 0;
  max-inline-size: 32rem;
  text-align: center;
  color: var(--color-foreground-primary);
  font-weight: 500;
}

.main_ui_static__nitrate-unavailable-footer {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.25rem;
  margin: 0;
  text-align: center;
  color: var(--color-foreground-secondary);
}

.main_ui_static__deco-before,
.main_ui_static__deco-after {
  position: absolute;
  left: calc(50% - 2.5rem);
}
.main_ui_static__deco-before svg,
.main_ui_static__deco-after svg {
  position: absolute;
  fill: var(--color-foreground-secondary);
  height: 1537px;
  width: 5rem;
}

.main_ui_static__deco-before {
  height: 34vh;
  top: 0;
}
.main_ui_static__deco-before svg {
  bottom: 0;
}

.main_ui_static__deco-after {
  height: 34vh;
  bottom: 0;
}
.main_ui_static__deco-after svg {
  top: 0;
}

.main_ui_static__deco-after2 {
  display: flex;
  justify-content: center;
  gap: 0.5rem;
  width: 100%;
  height: 34vh;
  position: absolute;
  left: 0;
  bottom: 0;
  color: var(--color-foreground-primary);
}
.main_ui_static__deco-after2 svg {
  fill: var(--color-foreground-secondary);
  height: 1537px;
  width: 5rem;
}
.main_ui_static__deco-after2 span {
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  height: 100%;
  width: 25%;
  padding-bottom: 1.75rem;
}
.main_ui_static__deco-after2 span:first-child {
  text-align: right;
}

.main_ui_static__exception-header {
  color: var(--color-foreground-secondary);
  padding: 1.5rem 2rem;
  position: fixed;
  background: none;
  border: none;
  cursor: pointer;
  display: flex;
  align-items: center;
}

.main_ui_static__penpot-logo {
  fill: var(--color-foreground-primary);
  width: 3rem;
  height: 3rem;
}

.main_ui_static__back-arrow {
  transform: rotate(180deg);
}

.main_ui_static__go-back-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 0.5rem;
  margin-left: 0.75rem;
  font-size: 0.875rem;
}

.main_ui_static__login-header {
  padding: 0.5rem 1rem;
  font-size: 0.688rem;
  position: fixed;
  right: 0;
  margin: 2.5rem 2rem;
}

.main_ui_static__exception-content {
  display: flex;
  height: 100%;
  justify-content: center;
  width: 100%;
}
.main_ui_static__exception-content .main_ui_static__container {
  align-items: center;
  display: flex;
  flex-direction: column;
  gap: 1rem;
  height: 34vh;
  justify-content: center;
  margin-top: 33vh;
  text-align: center;
  width: 40rem;
}

.main_ui_static__main-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
}

.main_ui_static__desc-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--color-foreground-secondary);
}

.main_ui_static__desc-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--color-foreground-secondary);
  margin-block-end: 0;
}

.main_ui_static__download-link {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
  text-transform: lowercase;
}

.main_ui_static__sign-info {
  text-align: center;
}
.main_ui_static__sign-info button {
  text-transform: uppercase;
  padding: 0.5rem 1rem;
  font-size: 0.688rem;
}

.main_ui_static__image svg {
  fill: var(--color-foreground-primary);
}

.main_ui_static__workspace {
  width: 100%;
  height: 100%;
  display: flex;
  justify-content: space-between;
  background-color: var(--color-canvas);
  position: relative;
}
.main_ui_static__workspace .main_ui_static__workspace-left,
.main_ui_static__workspace .main_ui_static__workspace-right {
  padding: 0.75rem;
  width: 17.25rem;
  height: 100%;
  background-color: var(--color-background-primary);
  display: flex;
  gap: 0.25rem;
}
.main_ui_static__workspace .main_ui_static__workspace-left svg,
.main_ui_static__workspace .main_ui_static__workspace-right svg {
  width: 2rem;
  height: 2rem;
  fill: var(--icon-foreground-hover);
}
.main_ui_static__workspace .main_ui_static__workspace-left .main_ui_static__project-name,
.main_ui_static__workspace .main_ui_static__workspace-right .main_ui_static__project-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--title-foreground-color);
}
.main_ui_static__workspace .main_ui_static__workspace-left .main_ui_static__file-name,
.main_ui_static__workspace .main_ui_static__workspace-right .main_ui_static__file-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-transform: none;
  color: var(--title-foreground-color-hover);
}

.main_ui_static__dashboard {
  width: 100%;
  height: 100%;
}
.main_ui_static__dashboard .main_ui_static__dashboard-sidebar {
  width: 18.75rem;
  height: 100%;
}

.main_ui_static__viewer {
  width: 100%;
  height: 100%;
}

.main_ui_static__overlay {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 100;
  background-color: rgba(0, 0, 0, 0.65);
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_static__overlay .main_ui_static__dialog,
.main_ui_static__overlay .main_ui_static__dialog-login {
  width: 556px;
  background-color: var(--color-background-primary);
  border-radius: 0.5rem;
  display: flex;
  flex-direction: column;
  align-content: stretch;
  padding: 2.25rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__modal-close,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__modal-close {
  text-align: right;
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__modal-close .main_ui_static__modal-close-button,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__modal-close .main_ui_static__modal-close-button {
  background: none;
  border: none;
  cursor: pointer;
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__modal-close .main_ui_static__modal-close-button svg,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__modal-close .main_ui_static__modal-close-button svg {
  cursor: pointer;
  width: 1.5rem;
  height: 1.5rem;
  fill: var(--modal-text-foreground-color);
  stroke: var(--modal-text-foreground-color);
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__dialog-title,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__dialog-title {
  font-size: 1.25rem;
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info {
  display: flex;
  justify-content: flex-end;
  margin-top: 2rem;
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info button,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info button {
  text-transform: uppercase;
  padding: 0.5rem 1rem;
  font-size: 0.688rem;
}
.main_ui_static__overlay .main_ui_static__dialog .main_ui_static__sign-info .main_ui_static__cancel-button,
.main_ui_static__overlay .main_ui_static__dialog-login .main_ui_static__sign-info .main_ui_static__cancel-button {
  text-transform: uppercase;
  padding: 0.5rem 1rem;
  font-size: 0.688rem;
  margin-right: 1rem;
}
.main_ui_static__overlay .main_ui_static__dialog {
  gap: 0.75rem;
}
.main_ui_static__overlay .main_ui_static__login {
  gap: 0;
  padding: 0 2.25rem 4.5rem 2.25rem;
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__logo {
  margin-bottom: 2.5rem;
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__logo svg {
  fill: var(--color-foreground-primary);
  width: 7.5rem;
  height: 2.5rem;
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__logo-title {
  font-size: 1.25rem;
  color: var(--title-foreground-color-hover);
  margin-bottom: 0.25rem;
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__logo-subtitle {
  font-size: 0.875rem;
  color: var(--title-foreground-color-hover);
  margin-bottom: 1.5rem;
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__change-section {
  width: 100%;
  text-align: center;
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__change-section a {
  color: var(--link-foreground-color);
}
.main_ui_static__overlay .main_ui_static__login hr {
  margin: 1.25rem 0;
  border-top: solid 1px var(--modal-separator-background-color);
}
.main_ui_static__overlay .main_ui_static__login .main_ui_static__separator {
  margin: 1.25rem 0;
}
.main_ui_static__overlay .main_ui_static__login form div {
  margin-bottom: 0.5rem;
}

.main_ui_static__login-container {
  width: 100%;
  background-color: var(--color-background-error);
}

.main_ui_static__buttons-container {
  display: flex;
}
.main_ui_static__buttons-container .main_ui_static__retry-btn {
  margin-inline-start: var(--sp-xxl);
}
@keyframes main_ui_viewer__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer__viewer-section {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3) transparent;
}
.main_ui_viewer__viewer-section:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7) transparent;
}
.main_ui_viewer__viewer-section ::-webkit-scrollbar {
  background-color: transparent;
  cursor: pointer;
  height: 0.75rem;
  width: 0.75rem;
}
.main_ui_viewer__viewer-section ::-webkit-scrollbar-track,
.main_ui_viewer__viewer-section ::-webkit-scrollbar-corner {
  background-color: transparent;
}
.main_ui_viewer__viewer-section ::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 8px;
}
.main_ui_viewer__viewer-section ::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7);
  outline: none;
}
.main_ui_viewer__viewer-section ::-moz-selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_viewer__viewer-section ::selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_viewer__viewer-section ::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_viewer__viewer-section ::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}

.main_ui_viewer__viewer-go-prev,
.main_ui_viewer__viewer-go-next, .main_ui_viewer__reset-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_viewer__viewer-go-prev svg,
.main_ui_viewer__viewer-go-next svg, .main_ui_viewer__reset-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_viewer__viewer-go-prev:focus-visible,
.main_ui_viewer__viewer-go-next:focus-visible, .main_ui_viewer__reset-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_viewer__viewer-go-prev:focus-visible svg,
.main_ui_viewer__viewer-go-next:focus-visible svg, .main_ui_viewer__reset-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_viewer__viewer-go-prev:hover,
.main_ui_viewer__viewer-go-next:hover, .main_ui_viewer__reset-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_viewer__viewer-go-prev:hover svg,
.main_ui_viewer__viewer-go-next:hover svg, .main_ui_viewer__reset-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_viewer__viewer-go-prev:active,
.main_ui_viewer__viewer-go-next:active, .main_ui_viewer__reset-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_viewer__viewer-go-prev:active svg,
.main_ui_viewer__viewer-go-next:active svg, .main_ui_viewer__reset-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_viewer__viewer-go-prev.disabled,
.main_ui_viewer__viewer-go-next.disabled, .main_ui_viewer__reset-button.disabled, [disabled].main_ui_viewer__viewer-go-prev,
[disabled].main_ui_viewer__viewer-go-next, [disabled].main_ui_viewer__reset-button, .main_ui_viewer__viewer-go-prev:disabled,
.main_ui_viewer__viewer-go-next:disabled, .main_ui_viewer__reset-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_viewer__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer__viewer-go-prev svg,
.main_ui_viewer__viewer-go-next svg, .main_ui_viewer__reset-button svg, .main_ui_viewer__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer__viewer-layout {
  height: 100vh;
  display: grid;
  grid-template-rows: 3rem auto;
  grid-template-columns: 1fr;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_viewer__viewer-content {
  overflow: hidden;
  grid-row: 2/span 1;
  display: grid;
  grid-template-rows: 15.75rem auto;
  grid-template-columns: 1fr;
  background-color: var(--viewer-background-color);
}

.main_ui_viewer__empty-state {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--empty-message-foreground-color);
  display: grid;
  place-items: center;
  height: 100%;
  width: 100%;
}

.main_ui_viewer__viewer-header {
  grid-row: 1/span 1;
}

.main_ui_viewer__inspect-layout {
  display: grid;
  grid-template-rows: 3rem auto;
  grid-template-columns: 1fr;
  height: 100vh;
  margin-top: 0;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_viewer__thumbnails-close {
  border: none;
  background: none;
  cursor: pointer;
  grid-row: 1/span 2;
  grid-column: 1/span 1;
  z-index: 10;
  background-color: var(--overlay-color);
}

.main_ui_viewer__thumbnails-close.main_ui_viewer__invisible {
  display: none;
}

.main_ui_viewer__viewer-section {
  grid-row: 1/span 2;
  grid-column: 1/span 1;
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  height: calc(100vh - 3rem);
  overflow: auto;
}

.main_ui_viewer__inspect-layout .main_ui_viewer__viewer-section {
  flex-wrap: nowrap;
  margin-top: 0;
  height: 100%;
  overflow: hidden;
}

.main_ui_viewer__viewer-go-prev,
.main_ui_viewer__viewer-go-next {
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  right: 0.5rem;
  height: 4rem;
  width: 2rem;
  top: calc(50vh - 2rem);
  z-index: 2;
  background-color: var(--viewer-controls-background-color);
  transition: transform 400ms ease 300ms;
}
.main_ui_viewer__viewer-go-prev svg,
.main_ui_viewer__viewer-go-next svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer__viewer-go-next.main_ui_viewer__comment-sidebar {
  right: 17.5rem;
}

.main_ui_viewer__viewer-go-prev {
  left: 0.5rem;
  right: unset;
}
.main_ui_viewer__viewer-go-prev svg {
  transform: rotate(180deg);
}

.main_ui_viewer__viewer-bottom {
  position: fixed;
  bottom: 0;
  display: flex;
  align-items: flex-start;
  justify-content: space-between;
  width: 100%;
  height: 2.5rem;
  padding-right: 0 0.5rem 2.5rem 0.5rem;
  transition: transform 400ms ease 300ms;
  z-index: 2;
  pointer-events: none;
}

.main_ui_viewer__reset-button {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2rem;
  width: 1.75rem;
  margin-left: 0.5rem;
  background-color: var(--viewer-controls-background-color);
  pointer-events: all;
}
.main_ui_viewer__reset-button svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer__counter {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border-radius: 8px;
  width: 4rem;
  height: 2rem;
  color: var(--viewer-thumbnails-control-foreground-color);
  background-color: var(--viewer-controls-background-color);
}

.main_ui_viewer__viewer-wrapper {
  position: relative;
  margin: 0 auto;
}

.main_ui_viewer__viewer-clipper {
  display: grid;
  grid-template-rows: 1fr;
  grid-template-columns: 1fr;
  place-items: center center;
  overflow: hidden;
}

.main_ui_viewer__viewer-overlay-background {
  position: absolute;
  top: 0;
  left: 0;
}
.main_ui_viewer__viewer-overlay-background.main_ui_viewer__visible {
  background-color: rgba(0, 0, 0, 0.2);
}

.main_ui_viewer__viewer-overlay {
  position: absolute;
}

.main_ui_viewer__viewport-container {
  clip-path: inset(0 0 0 0);
  grid-column: 1/1;
  grid-row: 1/1;
}
.main_ui_viewer__viewport-container .main_ui_viewer__not-fixed {
  position: absolute;
}
.main_ui_viewer__viewport-container .main_ui_viewer__fixed {
  position: fixed;
  pointer-events: none;
}
.main_ui_viewer__viewport-container .main_ui_viewer__fixed .main_ui_viewer__frame-children g {
  pointer-events: auto;
}

/** FULLSCREEN */
[data-fullscreen=true] .main_ui_viewer__viewer-bottom {
  transform: translateY(2.5rem);
}

[data-force-visible=true] .main_ui_viewer__viewer-bottom {
  transform: translateY(0);
}

[data-fullscreen=true] .main_ui_viewer__viewer-go-next {
  transform: translateX(2.5rem);
}

[data-fullscreen=true] .main_ui_viewer__viewer-go-prev {
  transform: translateX(-2.5rem);
}

[data-fullscreen=true] .main_ui_viewer__viewer-content {
  transform: translateY(-3rem);
  height: 100vh;
}

[data-fullscreen=true] .main_ui_viewer__viewer-section {
  height: 100vh;
}

[data-force-visible=true] .main_ui_viewer__viewer-go-next {
  transform: translateX(0);
}

[data-force-visible=true] .main_ui_viewer__viewer-go-prev {
  transform: translateX(0);
}
@keyframes main_ui_workspace__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace__workspace {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3) transparent;
}
.main_ui_workspace__workspace:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7) transparent;
}
.main_ui_workspace__workspace ::-webkit-scrollbar {
  background-color: transparent;
  cursor: pointer;
  height: 0.75rem;
  width: 0.75rem;
}
.main_ui_workspace__workspace ::-webkit-scrollbar-track,
.main_ui_workspace__workspace ::-webkit-scrollbar-corner {
  background-color: transparent;
}
.main_ui_workspace__workspace ::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 8px;
}
.main_ui_workspace__workspace ::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7);
  outline: none;
}
.main_ui_workspace__workspace ::-moz-selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_workspace__workspace ::selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_workspace__workspace ::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_workspace__workspace ::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}

.main_ui_workspace__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace__workspace {
  width: 100vw;
  height: 100vh;
  max-height: 100vh;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  display: grid;
  grid-template: "left-sidebar viewport right-sidebar" 1fr/auto 1fr auto;
  overflow: hidden;
}

.main_ui_workspace__workspace-loader {
  position: absolute;
  inset: 0;
  z-index: var(--z-index-loaders);
  background-color: var(--color-background-primary);
}

.main_ui_workspace__workspace-content {
  background-color: var(--color-canvas);
  display: flex;
  padding: 0;
  margin: 0;
  grid-area: viewport;
}

.main_ui_workspace__history-debug-overlay {
  bottom: 0;
  max-height: 31.25rem;
  width: 31.25rem;
  overflow-y: auto;
  position: absolute;
  z-index: 300;
}

.main_ui_workspace__workspace-viewport {
  overflow: hidden;
  transition: none;
  display: grid;
  grid-template-rows: 1.25rem 1fr;
  grid-template-columns: 1.25rem 1fr;
  flex: 1;
}
@keyframes main_ui_workspace_color_palette__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_color_palette__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_color_palette__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_color_palette__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_color_palette__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_color_palette__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_color_palette__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_color_palette__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_color_palette__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_color_palette__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_color_palette__left-arrow svg,
.main_ui_workspace_color_palette__right-arrow svg, .main_ui_workspace_color_palette__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_color_palette__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_color_palette__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_color_palette__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_color_palette__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_color_palette__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_color_palette__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_color_palette__color-palette {
  height: 100%;
  display: flex;
}

.main_ui_workspace_color_palette__palette-search,
.main_ui_workspace_color_palette__palette-search-collapsed {
  display: flex;
  align-items: center;
  padding-inline: 0.25rem;
}

.main_ui_workspace_color_palette__palette-search {
  gap: 0.25rem;
  width: 12rem;
  min-width: 12rem;
}

.main_ui_workspace_color_palette__palette-search-collapsed {
  width: 2rem;
  min-width: 2rem;
}

.main_ui_workspace_color_palette__left-arrow,
.main_ui_workspace_color_palette__right-arrow {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  height: 100%;
  width: 1.5rem;
  padding: 0;
  z-index: 5;
}
.main_ui_workspace_color_palette__left-arrow svg,
.main_ui_workspace_color_palette__right-arrow svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_color_palette__left-arrow::after,
.main_ui_workspace_color_palette__right-arrow::after {
  content: "";
  position: absolute;
  z-index: 1;
  bottom: 0;
  left: calc(-1 * 5rem);
  height: 100%;
  width: 5rem;
  background-image: linear-gradient(to left, var(--palette-button-shadow-initial) 0%, var(--palette-button-shadow-final) 100%);
  pointer-events: none;
}
.main_ui_workspace_color_palette__left-arrow:hover svg,
.main_ui_workspace_color_palette__right-arrow:hover svg {
  stroke: var(--button-foreground-hover);
}
.main_ui_workspace_color_palette__left-arrow:disabled svg,
.main_ui_workspace_color_palette__right-arrow:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}
.main_ui_workspace_color_palette__left-arrow:disabled::after,
.main_ui_workspace_color_palette__right-arrow:disabled::after {
  background-image: none;
}

.main_ui_workspace_color_palette__left-arrow::after {
  left: 1.5rem;
  background-image: linear-gradient(to right, var(--palette-button-shadow-initial) 0%, var(--palette-button-shadow-final) 100%);
}
.main_ui_workspace_color_palette__left-arrow:disabled::after {
  background-image: none;
}
.main_ui_workspace_color_palette__left-arrow svg {
  transform: rotate(180deg);
}

.main_ui_workspace_color_palette__color-palette-content {
  overflow: hidden;
  display: flex;
  align-items: center;
}

.main_ui_workspace_color_palette__color-palette-inside {
  display: grid;
  grid-auto-flow: column;
  grid-auto-columns: var(--color-cell-width);
  gap: 0.5rem;
}

.main_ui_workspace_color_palette__color-cell {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background: none;
  border: none;
  margin: 0;
  padding: 0;
  display: grid;
  grid-template-columns: 100%;
  grid-template-rows: auto 1fr;
  justify-items: center;
  height: 100%;
}
.main_ui_workspace_color_palette__color-cell.main_ui_workspace_color_palette__no-text {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 2rem;
}

.main_ui_workspace_color_palette__color-palette-empty {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--palette-text-color);
}
@keyframes main_ui_workspace_color_palette_ctx_menu__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_color_palette_ctx_menu__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_color_palette_ctx_menu__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_color_palette_ctx_menu__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_color_palette_ctx_menu__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_color_palette_ctx_menu__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_color_palette_ctx_menu__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_color_palette_ctx_menu__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_color_palette_ctx_menu__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_color_palette_ctx_menu__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_color_palette_ctx_menu__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_color_palette_ctx_menu__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_color_palette_ctx_menu__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_color_palette_ctx_menu__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_color_palette_ctx_menu__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_color_palette_ctx_menu__palette-menu {
  position: absolute;
  left: auto;
  bottom: var(--height);
  max-width: 30rem;
  padding: 0.25rem;
  margin: 0 0 0.25rem 0;
  z-index: 4;
  border-radius: 10px;
  background-color: var(--context-menu-background-color);
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library {
  position: relative;
  display: flex;
  align-items: flex-start;
  width: 100%;
  padding: 0.5rem;
  border-radius: 8px;
  margin-bottom: 0.25rem;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:last-child,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:last-child,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:last-child {
  margin-bottom: 0;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper {
  width: 100%;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--context-menu-foreground-color);
  display: grid;
  grid-template-columns: 1fr 1.5rem;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper {
  display: flex;
  max-width: 25rem;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper .main_ui_workspace_color_palette_ctx_menu__lib-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper .main_ui_workspace_color_palette_ctx_menu__lib-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper .main_ui_workspace_color_palette_ctx_menu__lib-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-width: 23.75rem;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper .main_ui_workspace_color_palette_ctx_menu__lib-num,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper .main_ui_workspace_color_palette_ctx_menu__lib-num,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper .main_ui_workspace_color_palette_ctx_menu__lib-num {
  margin-left: 0.25rem;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper {
  margin-left: 0.25rem;
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg {
  display: flex;
  justify-content: center;
  align-items: center;
  stroke: var(--icon-foreground);
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__color-sample,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__color-sample,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__color-sample {
  display: flex;
  flex-direction: row;
  gap: 0.5rem;
  margin-top: 0.25rem;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name {
  color: var(--context-menu-foreground-color-selected);
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library.main_ui_workspace_color_palette_ctx_menu__selected .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:hover .main_ui_workspace_color_palette_ctx_menu__option-wrapper .main_ui_workspace_color_palette_ctx_menu__library-name .main_ui_workspace_color_palette_ctx_menu__icon-wrapper svg {
  display: flex;
  justify-content: center;
  align-items: center;
  stroke: var(--context-menu-foreground-color-selected);
}
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__palette-library:hover,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__recent-colors:hover,
.main_ui_workspace_color_palette_ctx_menu__palette-menu .main_ui_workspace_color_palette_ctx_menu__file-library:hover {
  background-color: var(--context-menu-background-color-selected);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

@keyframes main_ui_workspace_colorpicker__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker__accept-color {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_workspace_colorpicker__accept-color svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_workspace_colorpicker__accept-color:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__accept-color:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__accept-color:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_colorpicker__accept-color:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_workspace_colorpicker__accept-color:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_workspace_colorpicker__accept-color:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_workspace_colorpicker__accept-color.disabled, [disabled].main_ui_workspace_colorpicker__accept-color, .main_ui_workspace_colorpicker__accept-color:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_colorpicker__choose-image {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_colorpicker__choose-image svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_colorpicker__choose-image:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__choose-image:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__choose-image:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_colorpicker__choose-image:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_colorpicker__choose-image:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_colorpicker__choose-image:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_colorpicker__choose-image.disabled, [disabled].main_ui_workspace_colorpicker__choose-image, .main_ui_workspace_colorpicker__choose-image:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_colorpicker__gradient-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_colorpicker__gradient-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_colorpicker__gradient-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__gradient-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__gradient-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_colorpicker__gradient-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_colorpicker__gradient-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_colorpicker__gradient-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_colorpicker__gradient-btn.disabled, [disabled].main_ui_workspace_colorpicker__gradient-btn, .main_ui_workspace_colorpicker__gradient-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_colorpicker__gradient-btn.disabled svg, [disabled].main_ui_workspace_colorpicker__gradient-btn svg, .main_ui_workspace_colorpicker__gradient-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_colorpicker__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker__picker-btn svg, .main_ui_workspace_colorpicker__checkbox-option label span.intermediate svg, .main_ui_workspace_colorpicker__checkbox-option label span.checked svg, .main_ui_workspace_colorpicker__opacity-input-wrapper span svg,
.main_ui_workspace_colorpicker__opacity-input-wrapper label svg, .main_ui_workspace_colorpicker__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker__checkbox-option label span.intermediate svg, .main_ui_workspace_colorpicker__checkbox-option label span.checked svg, .main_ui_workspace_colorpicker__opacity-input-wrapper span svg,
.main_ui_workspace_colorpicker__opacity-input-wrapper label svg, .main_ui_workspace_colorpicker__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker__opacity-input-wrapper input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_colorpicker__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker__opacity-input-wrapper span,
.main_ui_workspace_colorpicker__opacity-input-wrapper label, .main_ui_workspace_colorpicker__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker__opacity-input-wrapper {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper span svg,
.main_ui_workspace_colorpicker__opacity-input-wrapper label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus, .main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus span, .main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus input, .main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus:hover, .main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus:hover span, .main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_colorpicker__opacity-input-wrapper:focus:hover input, .main_ui_workspace_colorpicker__opacity-input-wrapper:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_colorpicker__checkbox-option label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_workspace_colorpicker__checkbox-option label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_workspace_colorpicker__checkbox-option label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_colorpicker__checkbox-option label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_workspace_colorpicker__checkbox-option label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_workspace_colorpicker__checkbox-option label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_workspace_colorpicker__checkbox-option label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_workspace_colorpicker__checkbox-option label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_workspace_colorpicker__checkbox-option label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_workspace_colorpicker__checkbox-option label span.unchecked svg {
  display: none;
}

.main_ui_workspace_colorpicker__checkbox-option {
  display: flex;
  align-items: center;
}
.main_ui_workspace_colorpicker__checkbox-option label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_workspace_colorpicker__checkbox-option label input {
  margin: 0;
}
.main_ui_workspace_colorpicker__checkbox-option label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_colorpicker__checkbox-option label:focus span, .main_ui_workspace_colorpicker__checkbox-option label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_workspace_colorpicker__colorpicker-tooltip {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  display: flex;
  flex-direction: column;
  padding: 0.75rem;
  border-radius: 8px;
  z-index: 10;
  color: var(--modal-title-foreground-color);
  background-color: var(--modal-background-color);
}

.main_ui_workspace_colorpicker__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_colorpicker__colorpicker-tooltip {
  --colorpicker-width: 17.75rem;
  left: 87.5rem;
  padding: var(--sp-m);
  width: var(--colorpicker-width);
  overflow: auto;
  display: flex;
  flex-direction: column;
}

.main_ui_workspace_colorpicker__colorpicker {
  border-radius: 0.5rem;
  overflow: hidden;
}

.main_ui_workspace_colorpicker__top-actions {
  display: flex;
  align-items: flex-start;
  flex-direction: row-reverse;
  justify-content: space-between;
  height: 2.5rem;
}

.main_ui_workspace_colorpicker__top-actions-right {
  display: flex;
  gap: var(--sp-s);
}

.main_ui_workspace_colorpicker__opacity-input-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  width: 4.25rem;
}

.main_ui_workspace_colorpicker__picker-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  background: none;
  cursor: pointer;
  background-color: transparent;
  border: 0.0625rem solid transparent;
  height: var(--sp-xl);
  width: var(--sp-xl);
  border-radius: 0.25rem;
  padding: 0;
  margin-top: var(--sp-xs);
}
.main_ui_workspace_colorpicker__picker-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_colorpicker__picker-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_colorpicker__picker-btn:focus, .main_ui_workspace_colorpicker__picker-btn:focus-visible {
  outline: none;
}
.main_ui_workspace_colorpicker__picker-btn:focus svg, .main_ui_workspace_colorpicker__picker-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_colorpicker__picker-btn:active {
  outline: none;
  border: 0.0625rem solid transparent;
}
.main_ui_workspace_colorpicker__picker-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_colorpicker__picker-btn.main_ui_workspace_colorpicker__selected svg {
  stroke: var(--button-tertiary-foreground-color-active);
}

.main_ui_workspace_colorpicker__gradient-buttons {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_workspace_colorpicker__gradient-btn {
  height: var(--sp-xl);
  width: var(--sp-xl);
  border-radius: 0.25rem;
  border: 0.125rem solid transparent;
}
.main_ui_workspace_colorpicker__gradient-btn:hover {
  border: 0.125rem solid var(--colorpicker-details-color-selected);
}

.main_ui_workspace_colorpicker__linear-gradient-btn {
  background: linear-gradient(180deg, var(--color-foreground-secondary), transparent);
}
.main_ui_workspace_colorpicker__linear-gradient-btn.main_ui_workspace_colorpicker__selected {
  background: linear-gradient(to bottom, rgb(126, 255, 245) 0%, rgba(126, 255, 245, 0.2) 100%);
  border: 0.125rem solid var(--colorpicker-details-color-selected);
}

.main_ui_workspace_colorpicker__radial-gradient-btn {
  background: radial-gradient(transparent, var(--color-foreground-secondary));
}
.main_ui_workspace_colorpicker__radial-gradient-btn.main_ui_workspace_colorpicker__selected {
  background: radial-gradient(rgb(126, 255, 245) 0%, rgba(126, 255, 245, 0.2) 100%);
  border: 0.125rem solid var(--colorpicker-details-color-selected);
}

.main_ui_workspace_colorpicker__actions {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_colorpicker__accept-color {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  width: 100%;
  height: var(--sp-xxxl);
  margin-top: var(--sp-s);
}

.main_ui_workspace_colorpicker__picker-detail-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  margin: var(--sp-m) 0 var(--sp-s) 0;
}

.main_ui_workspace_colorpicker__center-circle {
  width: var(--sp-xxl);
  height: var(--sp-xxl);
  border: 0.125rem solid var(--colorpicker-details-color);
  border-radius: 50%;
  position: absolute;
  left: 50%;
  top: 50%;
  transform: translate(calc(-1 * var(--sp-m)), calc(-1 * var(--sp-m)));
}

.main_ui_workspace_colorpicker__picker-detail {
  image-rendering: crisp-edges;
  image-rendering: pixelated;
}

.main_ui_workspace_colorpicker__select {
  width: 7.25rem;
}

.main_ui_workspace_colorpicker__select-image {
  margin-top: var(--sp-xs);
}

.main_ui_workspace_colorpicker__content {
  border-radius: 0.5rem;
  display: flex;
  justify-content: center;
  background-image: url("/images/colorpicker-no-image.png");
  background-position: center;
  background-size: auto 8.75rem;
  height: 8.75rem;
  margin-bottom: 0.375rem;
  margin-right: 0.0625rem;
}
.main_ui_workspace_colorpicker__content img {
  height: -moz-fit-content;
  height: fit-content;
  width: -moz-fit-content;
  width: fit-content;
  max-height: 100%;
  max-width: 100%;
  margin: auto;
}

.main_ui_workspace_colorpicker__choose-image {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  width: 100%;
  margin-top: var(--sp-m);
  height: var(--sp-xxxl);
}

.main_ui_workspace_colorpicker__checkbox-option {
  margin: var(--sp-l) 0 0 0;
}

.main_ui_workspace_colorpicker__token-color-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
  display: flex;
  align-items: center;
  height: var(--sp-xxxl);
}
@keyframes main_ui_workspace_comments__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_comments__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_comments__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_comments__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_comments__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_comments__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_comments__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_comments__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_comments__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_comments__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_comments__arrow-icon svg, .main_ui_workspace_comments__dropdown-item .main_ui_workspace_comments__icon svg, .main_ui_workspace_comments__dropdown-item span svg, .main_ui_workspace_comments__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_comments__arrow-icon svg, .main_ui_workspace_comments__dropdown-item .main_ui_workspace_comments__icon svg, .main_ui_workspace_comments__dropdown-item span svg, .main_ui_workspace_comments__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_comments__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_comments__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_comments__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_comments__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_comments__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_comments__mode-dropdown-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  padding: 0.5rem 0.75rem;
  background-color: var(--assets-item-background-color);
  color: var(--assets-item-name-foreground-color-hover);
}
.main_ui_workspace_comments__mode-dropdown-wrapper:hover {
  background-color: var(--assets-item-background-color-hover);
  color: var(--assets-item-name-foreground-color-hover);
}

.main_ui_workspace_comments__dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_comments__dropdown-item span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_comments__dropdown-item span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_comments__dropdown-item:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_comments__dropdown-item:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_comments__comment-mode-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_workspace_comments__comments-section {
  position: relative;
  background-color: var(--panel-background-color);
  display: grid;
  grid-template-rows: 2.5rem 3rem 1fr;
}

.main_ui_workspace_comments__from-viewer {
  padding: 0 0.5rem;
}

.main_ui_workspace_comments__comments-title {
  margin: var(--sp-s) var(--sp-s) 0 var(--sp-s);
}

.main_ui_workspace_comments__mode-dropdown-wrapper {
  border: none;
  background: none;
  cursor: pointer;
  background-color: var(--color-background-tertiary);
  display: flex;
  width: 100%;
  max-width: 16rem;
  height: 2rem;
  padding: 0.5rem;
  border-radius: 8px;
  margin: 1rem auto 0 auto;
  cursor: pointer;
  position: relative;
}

.main_ui_workspace_comments__mode-label {
  padding-right: 8px;
  flex-grow: 1;
  display: flex;
  justify-content: flex-start;
}

.main_ui_workspace_comments__arrow-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
}
.main_ui_workspace_comments__arrow-icon svg {
  transform: rotate(90deg);
  stroke: var(--icon-foreground);
}

.main_ui_workspace_comments__comment-mode-dropdown {
  top: 5.75rem;
  left: 0.75rem;
  max-width: 16rem;
  width: 100%;
}

.main_ui_workspace_comments__viewer-dropdown {
  left: 0.5rem;
}

.main_ui_workspace_comments__dropdown-item {
  justify-content: space-between;
}
.main_ui_workspace_comments__dropdown-item .main_ui_workspace_comments__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
}
.main_ui_workspace_comments__dropdown-item .main_ui_workspace_comments__icon svg {
  stroke: transparent;
}
.main_ui_workspace_comments__dropdown-item .main_ui_workspace_comments__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_workspace_comments__dropdown-item:hover .main_ui_workspace_comments__icon svg {
  stroke: transparent;
}
.main_ui_workspace_comments__dropdown-item.main_ui_workspace_comments__selected .main_ui_workspace_comments__label {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_comments__dropdown-item.main_ui_workspace_comments__selected .main_ui_workspace_comments__icon svg {
  stroke: var(--icon-foreground-hover);
}

.main_ui_workspace_comments__separator {
  height: 0.75rem;
}

.main_ui_workspace_comments__comments-section-content {
  height: 100%;
  overflow-y: auto;
}

.main_ui_workspace_comments__thread-groups {
  display: flex;
  flex-direction: column;
}

.main_ui_workspace_comments__thread-group-placeholder {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) auto;
  inline-size: 12.5rem;
}
@keyframes main_ui_workspace_context_menu__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_context_menu__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_context_menu__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_context_menu__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_context_menu__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_context_menu__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_context_menu__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_context_menu__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_context_menu__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_context_menu__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_context_menu__context-menu-item .main_ui_workspace_context_menu__submenu-icon svg, .main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__selected-icon svg, .main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__shape-icon svg, .main_ui_workspace_context_menu__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_context_menu__context-menu-item .main_ui_workspace_context_menu__submenu-icon svg, .main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__selected-icon svg, .main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__shape-icon svg, .main_ui_workspace_context_menu__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_context_menu__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_context_menu__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_context_menu__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_context_menu__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_context_menu__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_context_menu__workspace-context-menu {
  position: absolute;
  top: 2.5rem;
  left: 46rem;
  z-index: 4;
}

.main_ui_workspace_context_menu__context-list,
.main_ui_workspace_context_menu__workspace-context-submenu {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: grid;
  width: 15rem;
  padding: 0.25rem;
  border-radius: 8px;
  border: 0.125rem solid var(--panel-border-color);
  background-color: var(--menu-background-color);
  max-height: 100vh;
  overflow-y: auto;
}

.main_ui_workspace_context_menu__workspace-context-submenu {
  position: absolute;
}

.main_ui_workspace_context_menu__separator {
  height: 0.75rem;
}

.main_ui_workspace_context_menu__context-menu-item {
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_workspace_context_menu__context-menu-item .main_ui_workspace_context_menu__title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--menu-foreground-color);
}
.main_ui_workspace_context_menu__context-menu-item .main_ui_workspace_context_menu__shortcut {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 0.125rem;
  color: var(--menu-shortcut-foreground-color);
}
.main_ui_workspace_context_menu__context-menu-item .main_ui_workspace_context_menu__shortcut .main_ui_workspace_context_menu__shortcut-key {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.25rem;
  padding: 0.125rem 0.375rem;
  border-radius: 6px;
  background-color: var(--menu-shortcut-background-color);
}
.main_ui_workspace_context_menu__context-menu-item .main_ui_workspace_context_menu__submenu-icon svg {
  stroke: var(--menu-foreground-color);
}
.main_ui_workspace_context_menu__context-menu-item:hover {
  background-color: var(--menu-background-color-hover);
}
.main_ui_workspace_context_menu__context-menu-item:hover .main_ui_workspace_context_menu__title {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_context_menu__context-menu-item:hover .main_ui_workspace_context_menu__shortcut {
  color: var(--menu-shortcut-foreground-color-hover);
}
.main_ui_workspace_context_menu__context-menu-item:focus {
  border: 1px solid var(--menu-border-color-focus);
  background-color: var(--menu-background-color-focus);
}

.main_ui_workspace_context_menu__icon-menu-item {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  height: 1.75rem;
  padding: 0.375rem;
  border-radius: 8px;
}
.main_ui_workspace_context_menu__icon-menu-item:hover {
  background-color: var(--menu-background-color-hover);
}
.main_ui_workspace_context_menu__icon-menu-item span.main_ui_workspace_context_menu__title {
  margin-left: 0.375rem;
}
.main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__selected-icon svg {
  stroke: var(--menu-foreground-color);
}
.main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__shape-icon {
  margin-left: 0.125rem;
}
.main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__shape-icon svg {
  stroke: var(--menu-foreground-color);
}
.main_ui_workspace_context_menu__icon-menu-item .main_ui_workspace_context_menu__icon-wrapper {
  display: grid;
  grid-template-columns: 1fr 1fr;
  margin: 0;
}

.main_ui_workspace_context_menu__icon-menu-item[disabled],
.main_ui_workspace_context_menu__context-menu-item[disabled] {
  pointer-events: none;
  opacity: 0.6;
}

.main_ui_workspace_context_menu__guide-color-label {
  cursor: default;
  pointer-events: none;
}

.main_ui_workspace_context_menu__guide-color-swatches {
  display: flex;
  flex-wrap: wrap;
  gap: 0.375rem;
  padding: 0.25rem 0.375rem 0.5rem;
  list-style: none;
}

.main_ui_workspace_context_menu__guide-color-swatch {
  width: 1.25rem;
  height: 1.25rem;
  border-radius: 50%;
  cursor: pointer;
  flex-shrink: 0;
  box-sizing: border-box;
  border: 0.125rem solid var(--panel-border-color);
}
.main_ui_workspace_context_menu__guide-color-swatch.main_ui_workspace_context_menu__selected {
  border: 0.125rem solid var(--menu-foreground-color);
}
@keyframes main_ui_workspace_coordinates__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_coordinates__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_coordinates__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_coordinates__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_coordinates__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_coordinates__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_coordinates__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_coordinates__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_coordinates__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_coordinates__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_coordinates__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_coordinates__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_coordinates__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_coordinates__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_coordinates__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_coordinates__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_coordinates__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_coordinates__container {
  background-color: var(--color-background-primary);
  border-radius: 4px;
  bottom: 0;
  padding: 0.125rem 0.5rem;
  position: fixed;
  right: calc(256px + 1.5rem);
  text-align: center;
  white-space: nowrap;
  transition: bottom 0.5s;
  z-index: 2;
  display: flex;
  -moz-column-gap: 0.5rem;
       column-gap: 0.5rem;
}

.main_ui_workspace_coordinates__container-color-palette-open {
  bottom: 4rem;
}

.main_ui_workspace_coordinates__coordinate {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
}
@keyframes main_ui_workspace_left_header__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_left_header__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_left_header__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_left_header__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_left_header__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_left_header__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_left_header__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_left_header__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_left_header__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_left_header__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_left_header__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_left_header__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_left_header__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_left_header__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_left_header__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_left_header__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_left_header__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_left_header__workspace-header-left {
  display: flex;
  align-items: center;
  padding: 0.75rem 0.75rem 0.5rem 0.75rem;
  min-height: 3.25rem;
}

.main_ui_workspace_left_header__main-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 2rem;
  height: 2rem;
  min-height: 2rem;
  margin-right: 0.25rem;
}
.main_ui_workspace_left_header__main-icon svg {
  min-height: 2rem;
  width: 2rem;
  fill: var(--icon-foreground-hover);
}

.main_ui_workspace_left_header__project-tree {
  position: relative;
  flex-grow: 1;
  flex-shrink: 1;
  min-width: 0;
  height: 2rem;
  min-height: 2rem;
}

.main_ui_workspace_left_header__project-name,
.main_ui_workspace_left_header__file-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1rem;
  width: 100%;
  padding-bottom: 0.125rem;
  color: var(--title-foreground-color);
  cursor: pointer;
}

.main_ui_workspace_left_header__file-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-transform: none;
  color: var(--title-foreground-color-hover);
  align-items: center;
  display: flex;
  flex-direction: row;
}

.main_ui_workspace_left_header__file-name-label {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_workspace_left_header__file-name-input {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
  margin: 0;
  border: 0;
  padding: 0;
  border-radius: 4px;
  background-color: var(--input-background-color);
  font-size: 0.875rem;
  color: var(--input-foreground-color);
  z-index: 20;
  white-space: break-spaces;
}
.main_ui_workspace_left_header__file-name-input:focus {
  outline: none;
}

.main_ui_workspace_left_header__shared-badge {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 2rem;
  margin-right: 0.25rem;
}
.main_ui_workspace_left_header__shared-badge svg {
  stroke: var(--button-secondary-foreground-color-rest);
  fill: none;
  height: 1rem;
  width: 1rem;
}

.main_ui_workspace_left_header__status-notification {
  width: 0.375rem;
  height: 0.375rem;
  border-radius: 50%;
  margin-right: 0.25rem;
  flex-shrink: 0;
  background-color: var(--status-widget-background-color-pending);
}
.main_ui_workspace_left_header__status-notification.main_ui_workspace_left_header__pending-status {
  background-color: var(--status-widget-background-color-warning);
}
.main_ui_workspace_left_header__status-notification.main_ui_workspace_left_header__saving-status {
  background-color: var(--status-widget-background-color-pending);
}
.main_ui_workspace_left_header__status-notification.main_ui_workspace_left_header__saved-status {
  background-color: var(--status-widget-background-color-success);
  animation: main_ui_workspace_left_header__jump 0.3s ease-out;
}
.main_ui_workspace_left_header__status-notification.main_ui_workspace_left_header__error-status {
  background-color: var(--status-widget-background-color-error);
}

@keyframes main_ui_workspace_left_header__jump {
  0% {
    transform: translateY(0);
  }
  50% {
    transform: translateY(-4px);
  }
  100% {
    transform: translateY(0);
  }
}
@charset "UTF-8";
:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_workspace_libraries__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: var(--z-index-set);
  background-color: var(--overlay-color);
}

.main_ui_workspace_libraries__modal-dialog {
  position: relative;
  padding: var(--sp-xxxl);
  border-radius: 0.5rem;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  display: grid;
  grid-template-rows: 0 auto 1fr;
  min-width: 22.75rem;
  min-height: 12rem;
  height: 32.5rem;
  max-height: 32.5rem;
  width: 44.5rem;
  max-width: 44.5rem;
}

.main_ui_workspace_libraries__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  margin-block-end: var(--sp-l);
  color: var(--color-foreground-primary);
}

.main_ui_workspace_libraries__libraries-content,
.main_ui_workspace_libraries__updates-content {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: var(--sp-xxxl);
  max-height: 25rem;
  padding-block-start: var(--sp-l);
}

.main_ui_workspace_libraries__lib-section,
.main_ui_workspace_libraries__update-section,
.main_ui_workspace_libraries__shared-section {
  display: grid;
  grid-template-rows: auto 1fr;
  gap: var(--sp-s);
}

.main_ui_workspace_libraries__shared-section {
  grid-template-rows: auto auto 1fr;
  row-gap: var(--sp-l);
}

.main_ui_workspace_libraries__title-spacing-lib {
  margin: 0 0 0 calc(-1 * var(--sp-s));
}

.main_ui_workspace_libraries__section-list,
.main_ui_workspace_libraries__section-list-shared {
  display: grid;
  grid-auto-rows: min-content;
  gap: var(--sp-s);
  max-height: 20rem;
  overflow-y: auto;
}

.main_ui_workspace_libraries__section-list-item-double-icon, .main_ui_workspace_libraries__section-list-item, .main_ui_workspace_libraries__section-list-publish {
  display: grid;
  grid-template-columns: 1fr auto;
  gap: var(--sp-s);
  border: 0.0625rem solid var(--color-background-quaternary);
  padding: var(--sp-s) var(--sp-s) var(--sp-m) var(--sp-m);
  border-radius: 0.5rem;
}

.main_ui_workspace_libraries__section-list-publish {
  border: none;
}

.main_ui_workspace_libraries__section-list-item-double-icon {
  grid-template-columns: 1fr auto auto;
}

.main_ui_workspace_libraries__item-content {
  height: -moz-fit-content;
  height: fit-content;
}

.main_ui_workspace_libraries__close-btn {
  position: absolute;
  inset-block-start: var(--sp-s);
  inset-inline-end: var(--sp-s);
}

.main_ui_workspace_libraries__section-list-shared {
  max-height: 17rem;
}

.main_ui_workspace_libraries__section-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  margin-block-end: var(--sp-m);
  color: var(--title-foreground-color);
}

.main_ui_workspace_libraries__section-list-empty {
  display: grid;
  grid-template-rows: auto 1fr;
  justify-items: center;
  gap: var(--sp-s);
  text-align: center;
  height: -moz-fit-content;
  height: fit-content;
  margin-block: var(--sp-l);
}

.main_ui_workspace_libraries__libraries-updates-see-all {
  background: unset;
  border: none;
  color: var(--link-foreground-color);
  cursor: pointer;
  text-decoration: none;
  direction: rtl;
  grid-column: span 3;
  margin-block-start: var(--sp-s);
  margin-inline-start: var(--sp-s);
  margin: 0;
}

.main_ui_workspace_libraries__updates-content {
  grid-template-columns: 1fr;
}

.main_ui_workspace_libraries__libraries-updates {
  display: grid;
  grid-column: span 3;
  grid-template-columns: repeat(auto-fill, minmax(10rem, 1fr));
  gap: var(--sp-xxl);
  margin-block-start: var(--sp-l);
}

.main_ui_workspace_libraries__libraries-updates-column {
  display: grid;
  gap: var(--sp-xs);
}

.main_ui_workspace_libraries__libraries-updates-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  display: grid;
  grid-template-columns: auto 1fr;
  align-items: start;
  gap: var(--sp-s);
  color: var(--library-content-foreground-color);
}

.main_ui_workspace_libraries__component-svg {
  background-color: var(--color-canvas);
  border-radius: 0.25rem;
  border: 0.125rem solid transparent;
  height: 1.5rem;
  width: 1.5rem;
  min-height: 1.5rem;
  min-width: 1.5rem;
}

.main_ui_workspace_libraries__name-block {
  color: var(--library-content-foreground-color);
  width: 10.5rem;
}

.main_ui_workspace_libraries__ellipsis {
  padding-inline-start: calc(var(--sp-xxl) + var(--sp-s));
}

.main_ui_workspace_libraries__item-name-long, .main_ui_workspace_libraries__item-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin: 0;
  max-width: 14.75rem;
  color: var(--library-name-foreground-color);
}

.main_ui_workspace_libraries__item-name-short {
  max-width: 12.875rem;
}

.main_ui_workspace_libraries__item-name-long {
  max-width: 28.125rem;
}

.main_ui_workspace_libraries__item-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  margin: 0;
  color: var(--library-name-foreground-color);
}

.main_ui_workspace_libraries__item-update {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  height: 2rem;
  min-width: 5.75rem;
  padding: var(--sp-s) var(--sp-xxl);
  margin-inline-end: var(--sp-xxs);
  border-radius: 0.5rem;
}

.main_ui_workspace_libraries__item-contents {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--library-content-foreground-color);
  display: flex;
  flex-wrap: wrap;
  margin: 0;
}

.main_ui_workspace_libraries__library-actions {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_libraries__element-count {
  white-space: nowrap;
}
.main_ui_workspace_libraries__element-count:not(:last-child)::after {
  content: "·";
  margin-inline: var(--sp-xs);
}

.main_ui_workspace_libraries__connected-to-wrapper {
  display: block;
}

.main_ui_workspace_libraries__connected-to-values {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_libraries__modal-v2-info {
  width: 41.5rem;
  height: -moz-fit-content;
  height: fit-content;
  max-height: -moz-fit-content;
  max-height: fit-content;
}

.main_ui_workspace_libraries__modal-v2-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_workspace_libraries__info-content {
  display: grid;
  grid-template-rows: repeat(4, 1fr);
  margin-top: var(--sp-xxxl);
  gap: var(--sp-xxl);
}

.main_ui_workspace_libraries__info-block {
  display: grid;
  -moz-column-gap: var(--sp-xl);
       column-gap: var(--sp-xl);
  grid-template: "icon title" auto "icon content" auto/auto 1fr;
}

.main_ui_workspace_libraries__info-icon {
  grid-area: icon;
  width: 3.25rem;
  height: 3.25rem;
  margin-top: var(--sp-s);
  border-radius: 50%;
  background: var(--color-background-quaternary);
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_libraries__info-icon svg {
  width: 2rem;
  height: 2rem;
  fill: var(--icon-foreground-active);
}

.main_ui_workspace_libraries__info-block-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  grid-area: title;
  color: var(--modal-title-foreground-color);
}

.main_ui_workspace_libraries__info-block-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  grid-area: content;
  color: var(--library-content-foreground-color);
}

.main_ui_workspace_libraries__info-bottom {
  display: flex;
  justify-content: flex-end;
  margin-block-start: var(--sp-xxl);
  margin-inline-end: var(--sp-s);
}

.main_ui_workspace_libraries__primary-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 var(--sp-l);
}

.main_ui_workspace_libraries__sample-libraries-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  flex-direction: column;
  margin: var(--sp-xxxl);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_libraries__sample-libraries-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-accent-primary);
}
.main_ui_workspace_libraries__sample-libraries-link:hover {
  text-decoration: underline;
}

.main_ui_workspace_libraries__sample-libraries-container {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  flex-direction: column;
  width: 100%;
  align-items: start;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_libraries__sample-library-item {
  display: flex;
  justify-content: space-between;
  align-items: center;
  width: 100%;
  margin-top: var(--sp-s);
}

.main_ui_workspace_libraries__sample-library-item-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 14.5rem;
}

.main_ui_workspace_libraries__sample-library-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  height: 2rem;
  width: 5rem;
  margin: 0;
  border-radius: 0.5rem;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_workspace_main_menu__base-menu {
  position: absolute;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  padding: var(--sp-xs);
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
}

.main_ui_workspace_main_menu__menu {
  top: 3rem;
  left: calc(var(--right-sidebar-width) - 2.5rem);
  inline-size: 12rem;
}

.main_ui_workspace_main_menu__sub-menu {
  left: calc(var(--right-sidebar-width) + 9.625rem);
  min-width: 17.75rem;
  width: 115%;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-1 {
  top: 3rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-2 {
  top: 5rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-3 {
  top: 7rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-4 {
  top: 9rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-5 {
  top: 11rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-6 {
  top: 13rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-final-5 {
  top: 12rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-final-6 {
  top: 14rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__pos-final-7 {
  top: 16rem;
}
.main_ui_workspace_main_menu__sub-menu.main_ui_workspace_main_menu__plugins {
  max-height: calc(100vh - 12.5rem);
  overflow: hidden auto;
}

.main_ui_workspace_main_menu__base-menu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: grid;
  align-items: center;
  grid-template-columns: auto 1rem 1rem;
  grid-template-areas: "name indicator arrow";
  block-size: 1.75rem;
  inline-size: 100%;
  padding: 0.375rem;
  border-radius: 0.5rem;
  color: var(--menu-foreground-color);
  background-color: var(--menu-background-color);
}
.main_ui_workspace_main_menu__base-menu-item:hover {
  --menu-foreground-color: var(--menu-foreground-color-hover);
  --menu-background-color: var(--menu-background-color-hover);
  --menu-shortcut-foreground-color: var(--menu-shortcut-foreground-color-hover);
  --menu-icon-foreground-color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_main_menu__base-menu-item.main_ui_workspace_main_menu__disabled {
  --menu-foreground-color: var(--color-foreground-secondary);
  pointer-events: none;
}

.main_ui_workspace_main_menu__menu-item {
  display: grid;
  align-items: center;
  grid-template-columns: auto 1rem 1rem;
  grid-template-areas: "name indicator arrow";
}

.main_ui_workspace_main_menu__submenu-item {
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.main_ui_workspace_main_menu__item-name {
  grid-area: name;
}

.main_ui_workspace_main_menu__item-indicator {
  --menu-indicator-color: var(--color-foreground-secondary);
  grid-area: indicator;
  display: flex;
  align-items: center;
  justify-content: center;
  inline-size: 0.5rem;
  block-size: 0.5rem;
  border-radius: 50%;
  background-color: var(--menu-indicator-color);
}
.main_ui_workspace_main_menu__item-indicator.main_ui_workspace_main_menu__active {
  --menu-indicator-color: var(--color-accent-primary);
}
.main_ui_workspace_main_menu__item-indicator.main_ui_workspace_main_menu__failed {
  --menu-indicator-color: var(--color-foreground-error);
}

.main_ui_workspace_main_menu__item-arrow {
  grid-area: arrow;
  color: var(--menu-icon-foreground-color);
}

.main_ui_workspace_main_menu__item-icon {
  color: var(--menu-icon-foreground-color);
  display: flex;
  align-items: center;
  justify-content: center;
}

.main_ui_workspace_main_menu__separator {
  position: relative;
  block-size: var(--sp-xs);
  inline-size: calc(100% + var(--sp-s));
  border-top: 0.0625rem solid var(--color-background-quaternary);
  left: calc(-1 * var(--sp-xs));
  margin-top: var(--sp-s);
}

.main_ui_workspace_main_menu__shortcut {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: var(--sp-xxs);
  color: var(--menu-shortcut-foreground-color);
}

.main_ui_workspace_main_menu__shortcut-key {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 1.25rem;
  padding: var(--sp-xxs) 0.375rem;
  border-radius: 0.375rem;
  background-color: var(--menu-shortcut-background-color);
}
@keyframes main_ui_workspace_nudge__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_nudge__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_nudge__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_nudge__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_nudge__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_nudge__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_nudge__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_nudge__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_nudge__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_nudge__modal-close-btn.disabled, [disabled].main_ui_workspace_nudge__modal-close-btn, .main_ui_workspace_nudge__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_nudge__modal-close-btn.disabled svg, [disabled].main_ui_workspace_nudge__modal-close-btn svg, .main_ui_workspace_nudge__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_nudge__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_nudge__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_nudge__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_nudge__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_nudge__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_nudge__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_nudge__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_nudge__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_nudge__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_nudge__modal-close-btn svg, .main_ui_workspace_nudge__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_nudge__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_nudge__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_nudge__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_nudge__input-wrapper input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_nudge__input-wrapper input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_nudge__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_nudge__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_nudge__input-wrapper.disabled {
  background-color: var(--input-background-color-disabled);
  border: 1px solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_nudge__input-wrapper.disabled input {
  pointer-events: none;
  cursor: default;
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_nudge__input-wrapper.disabled svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_workspace_nudge__input-wrapper {
  display: flex;
  flex-direction: column;
}
.main_ui_workspace_nudge__input-wrapper label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  min-height: 1rem;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_nudge__input-wrapper input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border-radius: 8px;
  height: 2rem;
  min-height: 2rem;
  margin-top: 0.5rem;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_nudge__input-wrapper input:focus-within input, .main_ui_workspace_nudge__input-wrapper input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_nudge__input-wrapper input:focus-within, .main_ui_workspace_nudge__input-wrapper input:active {
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_nudge__input-wrapper.invalid input {
  border: 1px solid var(--input-border-color-error);
}

.main_ui_workspace_nudge__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_nudge__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_nudge__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_nudge__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_nudge__modal-container {
  min-width: 25.5rem;
}

.main_ui_workspace_nudge__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_workspace_nudge__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.4;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_workspace_nudge__modal-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  gap: 1.5rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  margin-bottom: 1.5rem;
}

.main_ui_workspace_nudge__input-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_workspace_nudge__input-wrapper label {
  text-transform: none;
}

.main_ui_workspace_nudge__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  line-height: 1.5;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

@keyframes main_ui_workspace_palette__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_palette__help-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_palette__help-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_palette__help-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_palette__help-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_palette__help-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_palette__help-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_palette__help-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_palette__help-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_palette__help-btn.disabled, [disabled].main_ui_workspace_palette__help-btn, .main_ui_workspace_palette__help-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:focus-visible, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:focus-visible svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:hover, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:hover svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:active, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:active svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn.disabled, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions.disabled, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item [disabled].main_ui_workspace_palette__palette-btn, .main_ui_workspace_palette__palettes [disabled].main_ui_workspace_palette__palette-actions, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:disabled, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn.disabled svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions.disabled svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item [disabled].main_ui_workspace_palette__palette-btn svg, .main_ui_workspace_palette__palettes [disabled].main_ui_workspace_palette__palette-actions svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn:disabled svg, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn.main_ui_workspace_palette__selected, .main_ui_workspace_palette__help-btn.main_ui_workspace_palette__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn.main_ui_workspace_palette__selected svg, .main_ui_workspace_palette__help-btn.main_ui_workspace_palette__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_palette__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_palette__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_palette__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_palette__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_palette__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_palette__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_palette__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_palette__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_palette__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions svg, .main_ui_workspace_palette__icon-help, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn svg, .main_ui_workspace_palette__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn svg, .main_ui_workspace_palette__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_palette__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_palette__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_palette__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_palette__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_palette__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_palette__palette-wrapper {
  position: absolute;
  width: 100vw;
  left: 0;
  bottom: 0;
  padding-bottom: 0.25rem;
  /** Aligns AI Chat button **/
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: var(--sp-s);
}

.main_ui_workspace_palette__palettes {
  z-index: 2;
  position: relative;
  right: 0;
  grid-area: color-palette;
  display: grid;
  grid-template: "resize resize resize" 0.5rem "buttons actions palette" 1fr/2rem auto 1fr;
  max-height: 5rem;
  height: var(--height);
  width: -moz-fit-content;
  width: fit-content;
  padding: 0px 0px 0.5rem 0.5rem;
  border-radius: 8px;
  background-color: var(--palette-background-color);
  border: 0.125rem solid var(--panel-border-color);
  transition: right 0.3s, opacity 0.2s, width 0.3s;
}
.main_ui_workspace_palette__palettes.main_ui_workspace_palette__wide {
  width: 100%;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__resize-area {
  grid-area: resize;
  height: 0.5rem;
  z-index: 4;
  width: calc(100% - 0.5rem);
  border-radius: 50%;
  cursor: ns-resize;
  background-color: var(--palette-background-color);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list {
  grid-area: buttons;
  background-color: var(--palette-background-color);
  height: calc(var(--height) - 1rem);
  width: 2rem;
  margin: 0px;
  list-style: none;
  z-index: 2;
  gap: 0.125rem;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list.main_ui_workspace_palette__mid-palette, .main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list.main_ui_workspace_palette__small-palette {
  display: flex;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  opacity: 1;
  transition: opacity 1s ease;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn {
  height: 2rem;
  width: 2rem;
  border-radius: 8px;
  background-clip: padding-box;
  padding: 0;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item .main_ui_workspace_palette__palette-btn svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions {
  grid-area: actions;
  height: calc(var(--height) - 1rem);
  width: 2rem;
  padding: 0;
  margin-left: 0.25rem;
  border-radius: 8px;
  background-color: var(--palette-background-color);
  z-index: 2;
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette-actions svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_palette__palettes .main_ui_workspace_palette__palette {
  grid-area: palette;
  width: 100%;
  min-width: 0;
}

.main_ui_workspace_palette__handler {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 0.75rem;
  height: 100%;
}
.main_ui_workspace_palette__handler .main_ui_workspace_palette__handler-btn {
  width: 0.25rem;
  height: 100%;
  max-height: 2.5rem;
  margin: 0.5rem 0.25rem;
  padding: 0;
  border-radius: 0.25rem;
  background-color: var(--palette-handler-background-color);
}

.main_ui_workspace_palette__mid-palette,
.main_ui_workspace_palette__small-palette {
  grid-template-columns: 4rem auto 1fr;
}

.main_ui_workspace_palette__hidden-bts {
  right: 0.125rem;
  z-index: 1;
  width: 22px;
  grid-template-columns: 0.5rem auto 1fr;
  padding: 0;
  border-inline-start: 0;
  border-start-start-radius: 0;
  border-end-start-radius: 0;
}
.main_ui_workspace_palette__hidden-bts .main_ui_workspace_palette__palette-btn-list {
  opacity: 0;
  visibility: hidden;
  width: 0;
}
.main_ui_workspace_palette__hidden-bts .main_ui_workspace_palette__palette-btn-list .main_ui_workspace_palette__palette-item {
  opacity: 0;
  visibility: hidden;
  z-index: 0;
}
.main_ui_workspace_palette__hidden-bts .main_ui_workspace_palette__resize-area {
  visibility: hidden;
  z-index: 0;
  width: 0;
}
.main_ui_workspace_palette__hidden-bts .main_ui_workspace_palette__palette-actions {
  visibility: hidden;
  z-index: 0;
}
.main_ui_workspace_palette__hidden-bts .main_ui_workspace_palette__palette {
  visibility: hidden;
  z-index: 0;
}
.main_ui_workspace_palette__hidden-bts .main_ui_workspace_palette__handler {
  padding-bottom: 0.5rem;
}

/** AI Chat button styles **/
.main_ui_workspace_palette__help-btn {
  z-index: var(--z-index-panels);
  flex-shrink: 0;
  inline-size: 2.5rem;
  block-size: 2.5rem;
  border-radius: 50%;
  border: none;
}
.main_ui_workspace_palette__help-btn:hover {
  border: none;
}

.main_ui_workspace_palette__icon-help {
  stroke: var(--icon-foreground);
  inline-size: var(--sp-xxl);
  block-size: var(--sp-xxl);
}
@keyframes main_ui_workspace_plugins__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_plugins__primary-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_workspace_plugins__primary-button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_workspace_plugins__primary-button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_plugins__primary-button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_plugins__primary-button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_plugins__primary-button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_workspace_plugins__primary-button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_workspace_plugins__primary-button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_workspace_plugins__primary-button.disabled, [disabled].main_ui_workspace_plugins__primary-button, .main_ui_workspace_plugins__primary-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_plugins__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_plugins__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_plugins__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_plugins__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_plugins__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_plugins__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_plugins__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_plugins__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_plugins__cancel-button.disabled, [disabled].main_ui_workspace_plugins__cancel-button, .main_ui_workspace_plugins__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_plugins__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_plugins__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_plugins__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_plugins__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_plugins__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_plugins__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_plugins__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_plugins__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_plugins__close-btn.disabled, [disabled].main_ui_workspace_plugins__close-btn, .main_ui_workspace_plugins__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_plugins__close-btn.disabled svg, [disabled].main_ui_workspace_plugins__close-btn svg, .main_ui_workspace_plugins__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_plugins__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_plugins__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_plugins__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_plugins__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_plugins__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_plugins__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_plugins__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_plugins__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_plugins__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_plugins__close-icon, .main_ui_workspace_plugins__close-btn svg, .main_ui_workspace_plugins__search-icon svg, .main_ui_workspace_plugins__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_plugins__search-icon svg, .main_ui_workspace_plugins__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_plugins__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_plugins__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_plugins__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_plugins__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_plugins__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_plugins__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_plugins__close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_plugins__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_plugins__modal-dialog {
  display: grid;
  grid-template-rows: auto 1fr auto;
  max-height: initial;
}
.main_ui_workspace_plugins__modal-dialog.main_ui_workspace_plugins__plugin-permissions {
  width: 25.75rem;
  max-width: 25.75rem;
}
.main_ui_workspace_plugins__modal-dialog.main_ui_workspace_plugins__plugin-management {
  width: 29.5rem;
  max-width: 29.5rem;
}
.main_ui_workspace_plugins__modal-dialog.main_ui_workspace_plugins__plugin-try-out {
  width: 28.25rem;
  max-width: 28.25rem;
}
.main_ui_workspace_plugins__modal-dialog hr {
  border-color: var(--color-background-tertiary);
}

.main_ui_workspace_plugins__modal-footer {
  margin-top: 2rem;
}

.main_ui_workspace_plugins__close-icon {
  stroke: var(--icon-foreground);
}

.main_ui_workspace_plugins__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.4;
  text-transform: uppercase;
  font-weight: 400;
  margin-block-end: 2rem;
  color: var(--modal-title-foreground-color);
  display: flex;
  gap: 0.75rem;
}

.main_ui_workspace_plugins__modal-content {
  display: flex;
  flex-direction: column;
}
.main_ui_workspace_plugins__plugin-permissions .main_ui_workspace_plugins__modal-content {
  gap: 1.25rem;
}
.main_ui_workspace_plugins__plugin-management .main_ui_workspace_plugins__modal-content {
  height: 23.75rem;
  max-height: 23.75rem;
}

.main_ui_workspace_plugins__modal-message {
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_plugins__modal-paragraph {
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_plugins__primary-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  padding: 0px 1rem;
}

.main_ui_workspace_plugins__button-expand {
  width: 100%;
  margin: 0;
}

.main_ui_workspace_plugins__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  padding: 0px 1rem;
}

.main_ui_workspace_plugins__search-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding: 0 0 0 0.5rem;
}
.main_ui_workspace_plugins__search-icon svg {
  stroke: var(--icon-foreground);
}

.main_ui_workspace_plugins__top-bar {
  display: flex;
  gap: 0.5rem;
}

.main_ui_workspace_plugins__open-button {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 4.25rem;
  min-width: 4.25rem;
  height: 2rem;
  text-transform: uppercase;
}

.main_ui_workspace_plugins__plugins-list {
  padding-top: 1.25rem;
  overflow: hidden auto;
  flex: 1;
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
}

.main_ui_workspace_plugins__plugins-list-element {
  display: flex;
  gap: 0.75rem;
}

.main_ui_workspace_plugins__plugin-icon {
  min-width: 2rem;
  min-height: 2rem;
  width: 2rem;
  height: 2rem;
  background: var(--button-secondary-background-color-rest);
  padding: 0.125rem;
  border-radius: 0.25rem;
}

.main_ui_workspace_plugins__plugin-description {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
  width: 100%;
}

.main_ui_workspace_plugins__plugin-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_plugins__plugin-summary {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_plugins__plugins-empty {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 1.25rem;
  height: 100%;
  justify-content: center;
  padding: 2.25rem 0;
}

.main_ui_workspace_plugins__plugins-empty-logo {
  width: 2.75rem;
  height: 2.75rem;
  border-radius: 50%;
  display: flex;
  justify-content: center;
  align-items: center;
  background: var(--color-background-tertiary);
}
.main_ui_workspace_plugins__plugins-empty-logo svg {
  width: 1rem;
  height: 1rem;
  stroke: var(--color-foreground-secondary);
  fill: none;
}

.main_ui_workspace_plugins__plugins-empty-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
}

div.main_ui_workspace_plugins__input-error {
  border: 1px solid var(--input-border-color-error);
}

.main_ui_workspace_plugins__info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-top: 0.25rem;
}
.main_ui_workspace_plugins__info.main_ui_workspace_plugins__error {
  color: var(--input-border-color-error);
}
.main_ui_workspace_plugins__info.main_ui_workspace_plugins__success {
  color: var(--input-border-color-success);
}

.main_ui_workspace_plugins__plugins-link {
  color: var(--color-accent-primary);
  font-size: 0.75rem;
  display: inline-flex;
  align-items: center;
  gap: 0.25rem;
}
.main_ui_workspace_plugins__plugins-link svg {
  margin-top: -0.125rem;
  width: 0.75rem;
  height: 0.75rem;
  stroke: var(--color-accent-primary);
  fill: none;
}

.main_ui_workspace_plugins__permissions-list {
  display: flex;
  flex-direction: column;
  gap: 1.5rem;
}

.main_ui_workspace_plugins__permissions-list-entry {
  display: grid;
  grid-template-columns: 24px 1fr;
  gap: 1rem;
  align-items: center;
}
.main_ui_workspace_plugins__permissions-list-entry svg {
  width: 1.5rem;
  height: 1.5rem;
  stroke: var(--color-accent-primary);
  fill: none;
}

.main_ui_workspace_plugins__permissions-list-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin: 0;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_plugins__permissions-disclaimer {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  padding: 1rem;
  background: var(--color-background-quaternary);
  color: var(--color-foreground-primary);
  border-radius: 4px;
}

.main_ui_workspace_plugins__action-buttons {
  display: flex;
  gap: 0.75rem;
}

.main_ui_workspace_plugins__discover {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-secondary);
  margin-top: 1.5rem;
}
.main_ui_workspace_plugins__discover a {
  color: var(--color-accent-primary);
}
.main_ui_workspace_presence__active-users,
.main_ui_workspace_presence__active-users-opened {
  background: none;
  cursor: pointer;
  display: flex;
  flex-direction: row-reverse;
  justify-content: flex-end;
  align-items: center;
  margin: 0;
  padding: 0 var(--sp-xs);
  border: none;
  border-radius: 0.5rem;
}

.main_ui_workspace_presence__active-users-list {
  display: flex;
  flex-direction: row-reverse;
  justify-content: flex-end;
  margin: 0;
  gap: var(--user-list-gap, 0);
}

.main_ui_workspace_presence__session-icon, .main_ui_workspace_presence__users-num {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: grid;
  place-content: center;
  height: 1.5rem;
  width: 1.5rem;
  border-radius: 50%;
  margin-inline-start: calc(-1 * var(--sp-xs));
}
.main_ui_workspace_presence__session-icon img, .main_ui_workspace_presence__users-num img {
  border-radius: 50%;
  border: 0.125rem solid var(--user-count-foreground-color);
}

.main_ui_workspace_presence__users-num {
  background-color: var(--user-count-background-color);
  color: var(--user-count-foreground-color);
  z-index: 3;
  border: 0.125rem solid var(--user-count-foreground-color);
  margin-inline-start: var(--user-list-inline-margin, calc(-1 * var(--sp-xs)));
}

.main_ui_workspace_presence__session-icon {
  margin-inline-start: var(--user-list-inline-margin, calc(-1 * var(--sp-xs)));
}

.main_ui_workspace_presence__active-users-opened {
  position: absolute;
  right: calc(-1 * var(--sp-xxs));
  top: calc(-1 * var(--sp-xxs));
  padding: var(--sp-s);
  margin: calc(-1 * var(--sp-xxs)) calc(-1 * var(--sp-xs)) 0 0;
  background-color: var(--menu-background-color);
  z-index: 4;
  --user-list-gap: var(--sp-xs);
  --user-list-inline-margin: 0;
}
@keyframes main_ui_workspace_right_header__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_right_header__reset-btn, .main_ui_workspace_right_header__comments-btn, .main_ui_workspace_right_header__history-button, .main_ui_workspace_right_header__share-btn,
.main_ui_workspace_right_header__viewer-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_right_header__reset-btn svg, .main_ui_workspace_right_header__comments-btn svg, .main_ui_workspace_right_header__history-button svg, .main_ui_workspace_right_header__share-btn svg,
.main_ui_workspace_right_header__viewer-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_right_header__reset-btn:focus-visible, .main_ui_workspace_right_header__comments-btn:focus-visible, .main_ui_workspace_right_header__history-button:focus-visible, .main_ui_workspace_right_header__share-btn:focus-visible,
.main_ui_workspace_right_header__viewer-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_right_header__reset-btn:focus-visible svg, .main_ui_workspace_right_header__comments-btn:focus-visible svg, .main_ui_workspace_right_header__history-button:focus-visible svg, .main_ui_workspace_right_header__share-btn:focus-visible svg,
.main_ui_workspace_right_header__viewer-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_right_header__reset-btn:hover, .main_ui_workspace_right_header__comments-btn:hover, .main_ui_workspace_right_header__history-button:hover, .main_ui_workspace_right_header__share-btn:hover,
.main_ui_workspace_right_header__viewer-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_right_header__reset-btn:hover svg, .main_ui_workspace_right_header__comments-btn:hover svg, .main_ui_workspace_right_header__history-button:hover svg, .main_ui_workspace_right_header__share-btn:hover svg,
.main_ui_workspace_right_header__viewer-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_right_header__reset-btn:active, .main_ui_workspace_right_header__comments-btn:active, .main_ui_workspace_right_header__history-button:active, .main_ui_workspace_right_header__share-btn:active,
.main_ui_workspace_right_header__viewer-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_right_header__reset-btn:active svg, .main_ui_workspace_right_header__comments-btn:active svg, .main_ui_workspace_right_header__history-button:active svg, .main_ui_workspace_right_header__share-btn:active svg,
.main_ui_workspace_right_header__viewer-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_right_header__reset-btn.disabled, .main_ui_workspace_right_header__comments-btn.disabled, .main_ui_workspace_right_header__history-button.disabled, .main_ui_workspace_right_header__share-btn.disabled,
.main_ui_workspace_right_header__viewer-btn.disabled, [disabled].main_ui_workspace_right_header__reset-btn, [disabled].main_ui_workspace_right_header__comments-btn, [disabled].main_ui_workspace_right_header__history-button, [disabled].main_ui_workspace_right_header__share-btn,
[disabled].main_ui_workspace_right_header__viewer-btn, .main_ui_workspace_right_header__reset-btn:disabled, .main_ui_workspace_right_header__comments-btn:disabled, .main_ui_workspace_right_header__history-button:disabled, .main_ui_workspace_right_header__share-btn:disabled,
.main_ui_workspace_right_header__viewer-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_right_header__reset-btn.disabled svg, .main_ui_workspace_right_header__comments-btn.disabled svg, .main_ui_workspace_right_header__history-button.disabled svg, .main_ui_workspace_right_header__share-btn.disabled svg,
.main_ui_workspace_right_header__viewer-btn.disabled svg, [disabled].main_ui_workspace_right_header__reset-btn svg, [disabled].main_ui_workspace_right_header__comments-btn svg, [disabled].main_ui_workspace_right_header__history-button svg, [disabled].main_ui_workspace_right_header__share-btn svg,
[disabled].main_ui_workspace_right_header__viewer-btn svg, .main_ui_workspace_right_header__reset-btn:disabled svg, .main_ui_workspace_right_header__comments-btn:disabled svg, .main_ui_workspace_right_header__history-button:disabled svg, .main_ui_workspace_right_header__share-btn:disabled svg,
.main_ui_workspace_right_header__viewer-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_right_header__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_right_header__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_right_header__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_right_header__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_right_header__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_right_header__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_right_header__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_right_header__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_right_header__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_right_header__comments-btn svg, .main_ui_workspace_right_header__history-button svg, .main_ui_workspace_right_header__status-icon svg, .main_ui_workspace_right_header__share-btn svg,
.main_ui_workspace_right_header__viewer-btn svg, .main_ui_workspace_right_header__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_right_header__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_right_header__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_right_header__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_right_header__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_right_header__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_right_header__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_right_header__zoom-option .main_ui_workspace_right_header__shortcuts {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 0.125rem;
  color: var(--menu-shortcut-foreground-color);
}

.main_ui_workspace_right_header__zoom-option .main_ui_workspace_right_header__shortcuts .main_ui_workspace_right_header__shortcut-key {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.25rem;
  padding: 0.125rem 0.375rem;
  border-radius: 6px;
  background-color: var(--menu-shortcut-background-color);
}

.main_ui_workspace_right_header__dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_workspace_right_header__zoom-option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_workspace_right_header__zoom-option:hover {
  background-color: var(--menu-background-color-hover);
}

.main_ui_workspace_right_header__workspace-header-right {
  display: flex;
  justify-content: space-between;
  align-items: center;
  min-width: 16rem;
  padding: 0.5rem;
  gap: 0.5rem;
  background-color: var(--panel-background-color);
}

.main_ui_workspace_right_header__users-section {
  position: relative;
  min-width: 2rem;
  max-width: 4.5rem;
  padding: 0.25rem 0.375rem;
}

.main_ui_workspace_right_header__separator {
  flex: 1;
}

.main_ui_workspace_right_header__zoom-widget {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 1.75rem;
  max-width: 3rem;
  width: 3rem;
  border-radius: 8px;
}
.main_ui_workspace_right_header__zoom-widget .main_ui_workspace_right_header__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  height: 100%;
  padding: 0.5rem 0;
  color: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_right_header__zoom-widget:hover .main_ui_workspace_right_header__label {
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_right_header__zoom-widget.main_ui_workspace_right_header__selected .main_ui_workspace_right_header__label {
  color: var(--button-tertiary-foreground-color-focus);
}

.main_ui_workspace_right_header__dropdown {
  right: 0.125rem;
  top: calc(0.125rem + 3rem);
  width: 17rem;
}

.main_ui_workspace_right_header__basic-zoom-bar {
  display: flex;
  justify-content: space-between;
  padding: 0.375rem;
  cursor: auto;
}

.main_ui_workspace_right_header__zoom-btns {
  display: flex;
}

.main_ui_workspace_right_header__zoom-text {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  min-width: 3rem;
  padding: 0;
  margin: 0 0.125rem;
  color: var(--modal-title-foreground-color);
}

.main_ui_workspace_right_header__reset-btn {
  color: var(--button-tertiary-foreground-color-hover);
  height: 1.75rem;
  border-radius: 8px;
}

.main_ui_workspace_right_header__zoom-option:hover {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_right_header__zoom-option:hover .main_ui_workspace_right_header__shortcuts .main_ui_workspace_right_header__shortcut-key {
  color: var(--menu-foreground-color-hover);
}

.main_ui_workspace_right_header__comments-btn {
  border-radius: 8px;
  margin: 0;
  height: 1.75rem;
  width: 1.75rem;
  border: none;
}
.main_ui_workspace_right_header__comments-btn svg {
  stroke: var(--icon-foreground);
  height: 1rem;
  width: 1rem;
}
.main_ui_workspace_right_header__comments-btn:hover {
  background-color: transparent;
  border: none;
}
.main_ui_workspace_right_header__comments-btn.main_ui_workspace_right_header__selected {
  background-color: var(--button-tertiary-background-color-selected);
}
.main_ui_workspace_right_header__comments-btn.main_ui_workspace_right_header__selected svg {
  stroke: var(--button-tertiary-foreground-color-active);
}

.main_ui_workspace_right_header__history-button {
  border-radius: 8px;
  margin: 0;
  height: 1.75rem;
  width: 1.75rem;
  border: none;
}
.main_ui_workspace_right_header__history-button svg {
  stroke: var(--icon-foreground);
  height: 1rem;
  width: 1rem;
}
.main_ui_workspace_right_header__history-button:hover {
  background-color: transparent;
  border: none;
}
.main_ui_workspace_right_header__history-button.main_ui_workspace_right_header__selected {
  background-color: var(--button-tertiary-background-color-selected);
}
.main_ui_workspace_right_header__history-button.main_ui_workspace_right_header__selected svg {
  stroke: var(--button-tertiary-foreground-color-active);
}

.main_ui_workspace_right_header__persistence-status-widget {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.75rem;
  height: 1.75rem;
}

.main_ui_workspace_right_header__status-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.5rem;
  height: 1.5rem;
  margin: 0;
  border-radius: 50%;
}
.main_ui_workspace_right_header__status-icon svg {
  stroke: var(--status-widget-icon-foreground-color);
}

.main_ui_workspace_right_header__pending-status {
  background-color: var(--status-widget-background-color-warning);
}

.main_ui_workspace_right_header__saving-status {
  background-color: var(--status-widget-background-color-pending);
}
.main_ui_workspace_right_header__saving-status svg {
  animation: main_ui_workspace_right_header__spin-animation 1s infinite;
  animation-timing-function: linear;
}

.main_ui_workspace_right_header__saved-status {
  background-color: var(--status-widget-background-color-success);
}

.main_ui_workspace_right_header__error-status {
  background-color: var(--status-widget-background-color-error);
}

.main_ui_workspace_right_header__share-btn,
.main_ui_workspace_right_header__viewer-btn {
  border-radius: 8px;
  margin: 0;
  width: 1.75rem;
  height: 1.75rem;
  border: none;
}
.main_ui_workspace_right_header__share-btn svg,
.main_ui_workspace_right_header__viewer-btn svg {
  height: 1rem;
  width: 1rem;
  stroke: var(--icon-foreground);
}
.main_ui_workspace_right_header__share-btn:hover,
.main_ui_workspace_right_header__viewer-btn:hover {
  background-color: transparent;
  border: none;
}

.main_ui_workspace_right_header__unread {
  position: absolute;
  width: 8px;
  height: 8px;
  border: 2px solid var(--color-background-tertiary);
  border-radius: 50%;
  background: var(--color-foreground-error);
  top: 6px;
  right: 6px;
}
@keyframes main_ui_workspace_sidebar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar__left-settings-bar {
  display: grid;
  grid-template: "header header" 3.25rem "content resize" 1fr/1fr 0;
  position: relative;
  grid-area: left-sidebar;
  min-width: var(--left-sidebar-width);
  max-width: var(--left-sidebar-width-max);
  width: var(--right-sidebar-width);
  background-color: var(--panel-background-color);
  height: 100vh;
  max-height: 100vh;
  z-index: 1;
}
.main_ui_workspace_sidebar__left-settings-bar .main_ui_workspace_sidebar__resize-area {
  grid-area: resize;
}

.main_ui_workspace_sidebar__layers-tab {
  padding-top: 0.25rem;
  overflow-x: hidden;
}

.main_ui_workspace_sidebar__left-header {
  grid-area: header;
}

.main_ui_workspace_sidebar__settings-bar-content {
  grid-area: content;
  right: calc(-1 * 0.5rem);
}

.main_ui_workspace_sidebar__resize-area {
  position: absolute;
  top: 0;
  left: unset;
  z-index: 4;
  width: 0.5rem;
  cursor: ew-resize;
  height: 100%;
}

.main_ui_workspace_sidebar__tab-spacing {
  margin-inline: 0.75rem;
}

.main_ui_workspace_sidebar__right-settings-bar {
  grid-area: right-sidebar;
  display: grid;
  grid-template-rows: auto minmax(0, 1fr);
  height: 100vh;
  width: var(--right-sidebar-width);
  background-color: var(--panel-background-color);
  z-index: 1;
}
.main_ui_workspace_sidebar__right-settings-bar.main_ui_workspace_sidebar__not-expand {
  max-width: var(--right-sidebar-width);
}
.main_ui_workspace_sidebar__right-settings-bar.main_ui_workspace_sidebar__expanded {
  width: var(--right-sidebar-width, var(--right-sidebar-width));
}
.main_ui_workspace_sidebar__right-settings-bar .main_ui_workspace_sidebar__settings-bar-inside {
  display: grid;
  grid-template-columns: 100%;
  grid-template-rows: 100%;
  height: calc(100vh - 3.25rem);
  overflow: hidden;
}

.main_ui_workspace_sidebar__resize-area-horiz {
  background-color: var(--panel-background-color);
  position: absolute;
  left: 0;
  width: 100%;
  padding: calc(1px + 0.125rem) 0 1px 0;
  height: 0.375rem;
  cursor: ns-resize;
}

.main_ui_workspace_sidebar__resize-handle-horiz {
  border-bottom: 0.125rem solid var(--resize-area-border-color);
  cursor: ns-resize;
}

.main_ui_workspace_sidebar__left-sidebar-tabs {
  --tabs-nav-padding-inline-start: var(--sp-m);
  --tabs-nav-padding-inline-end: var(--sp-m);
}

.main_ui_workspace_sidebar__collapse-sidebar-button {
  --collapse-icon-color: var(--color-foreground-secondary);
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  background: none;
  cursor: pointer;
  height: 100%;
  width: 1.5rem;
  border-radius: 0.313rem;
  color: var(--collapse-icon-color);
  transform: rotate(180deg);
}
.main_ui_workspace_sidebar__collapse-sidebar-button:hover {
  --collapse-icon-color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar__collapsed-sidebar {
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  top: 3rem;
  left: 0;
  padding: 0.25rem;
  border-radius: 8px;
  background: var(--color-background-primary);
  margin-inline-start: var(--sp-m);
}

.main_ui_workspace_sidebar__collapsed-title {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2.25rem;
  width: 1.5rem;
  border-radius: 8px;
  background: var(--color-background-secondary);
}

.main_ui_workspace_sidebar__collapsed-button {
  border: none;
  background: none;
  cursor: pointer;
  height: 1.5rem;
  width: 1rem;
  padding: 0;
  border-radius: 0.313rem;
}
.main_ui_workspace_sidebar__collapsed-button svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar__collapsed-button:hover svg {
  stroke: var(--icon-foreground-hover);
}

.main_ui_workspace_sidebar__versions-tab {
  width: 100%;
  overflow: hidden;
  height: calc(100vh - 5.5rem);
}

.main_ui_workspace_sidebar__history-tab {
  overflow-y: auto;
}
@keyframes main_ui_workspace_text_palette__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_text_palette__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_text_palette__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_text_palette__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_text_palette__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_text_palette__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_text_palette__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_text_palette__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_text_palette__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_text_palette__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_text_palette__left-arrow svg,
.main_ui_workspace_text_palette__right-arrow svg, .main_ui_workspace_text_palette__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_text_palette__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_text_palette__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_text_palette__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_text_palette__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_text_palette__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_text_palette__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_text_palette__text-palette {
  height: 100%;
  display: flex;
}

.main_ui_workspace_text_palette__left-arrow,
.main_ui_workspace_text_palette__right-arrow {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  height: 100%;
  width: 1.5rem;
  padding: 0;
  z-index: 2;
}
.main_ui_workspace_text_palette__left-arrow::after,
.main_ui_workspace_text_palette__right-arrow::after {
  content: "";
  position: absolute;
  bottom: 0;
  left: calc(-1 * 5rem);
  height: 100%;
  width: 5rem;
  z-index: 1;
  background-image: linear-gradient(to left, var(--palette-button-shadow-initial) 0%, var(--palette-button-shadow-final) 100%);
  pointer-events: none;
}
.main_ui_workspace_text_palette__left-arrow:hover svg,
.main_ui_workspace_text_palette__right-arrow:hover svg {
  stroke: var(--button-foreground-hover);
}
.main_ui_workspace_text_palette__left-arrow:disabled svg,
.main_ui_workspace_text_palette__right-arrow:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}
.main_ui_workspace_text_palette__left-arrow:disabled::after,
.main_ui_workspace_text_palette__right-arrow:disabled::after {
  background-image: none;
}

.main_ui_workspace_text_palette__left-arrow::after {
  left: 1.5rem;
  background-image: linear-gradient(to right, var(--palette-button-shadow-initial) 0%, var(--palette-button-shadow-final) 100%);
}
.main_ui_workspace_text_palette__left-arrow.main_ui_workspace_text_palette__disabled ::after {
  background-image: none;
}
.main_ui_workspace_text_palette__left-arrow svg {
  transform: rotate(180deg);
}

.main_ui_workspace_text_palette__text-palette-content {
  display: flex;
  overflow: hidden;
}

.main_ui_workspace_text_palette__text-palette-inside {
  display: flex;
  gap: 0.5rem;
}

.main_ui_workspace_text_palette__typography-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: flex-start;
  height: 100%;
  width: 8.5rem;
  padding: 0.5rem;
  border-radius: 8px;
  background-color: var(--palette-text-background-color);
}
.main_ui_workspace_text_palette__typography-item:first-child {
  margin-left: 0.5rem;
}
.main_ui_workspace_text_palette__typography-item .main_ui_workspace_text_palette__typography-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1rem;
  width: 7.5rem;
  color: var(--palette-text-color-selected);
}
.main_ui_workspace_text_palette__typography-item .main_ui_workspace_text_palette__typography-font {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1rem;
  width: 7.5rem;
  color: var(--palette-text-color);
}
.main_ui_workspace_text_palette__typography-item .main_ui_workspace_text_palette__typography-data {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1rem;
  width: 7.5rem;
  color: var(--palette-text-color);
}
.main_ui_workspace_text_palette__typography-item.main_ui_workspace_text_palette__mid-item .main_ui_workspace_text_palette__typography-name {
  height: 1rem;
}
.main_ui_workspace_text_palette__typography-item.main_ui_workspace_text_palette__mid-item .main_ui_workspace_text_palette__typography-data {
  display: none;
}
.main_ui_workspace_text_palette__typography-item.main_ui_workspace_text_palette__small-item .main_ui_workspace_text_palette__typography-data,
.main_ui_workspace_text_palette__typography-item.main_ui_workspace_text_palette__small-item .main_ui_workspace_text_palette__typography-font {
  display: none;
}
.main_ui_workspace_text_palette__typography-item:hover {
  background-color: var(--palette-text-background-color-hover);
}

.main_ui_workspace_text_palette__text-palette-empty {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--palette-text-color);
}
@keyframes main_ui_workspace_text_palette_ctx_menu__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_text_palette_ctx_menu__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_text_palette_ctx_menu__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_text_palette_ctx_menu__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_text_palette_ctx_menu__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_text_palette_ctx_menu__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_text_palette_ctx_menu__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_text_palette_ctx_menu__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_text_palette_ctx_menu__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_text_palette_ctx_menu__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_text_palette_ctx_menu__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_text_palette_ctx_menu__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_text_palette_ctx_menu__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_text_palette_ctx_menu__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_text_palette_ctx_menu__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_text_palette_ctx_menu__text-context-menu {
  position: absolute;
  left: auto;
  bottom: var(--height);
  max-width: 30rem;
  padding: 0.25rem;
  margin: 0 0 0.25rem 0;
  z-index: 4;
  border-radius: 10px;
  background-color: var(--context-menu-background-color);
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library {
  position: relative;
  display: flex;
  justify-content: space-between;
  width: 100%;
  gap: 0.5rem;
  padding: 0.5rem;
  margin-bottom: 0.25rem;
  border-radius: 8px;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:last-child,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:last-child {
  margin-bottom: 0;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__library-name,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__library-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--context-menu-foreground-color);
  display: grid;
  grid-template-columns: 1fr 1.5rem;
  max-width: 25rem;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__library-name .main_ui_workspace_text_palette_ctx_menu__lib-name,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__library-name .main_ui_workspace_text_palette_ctx_menu__lib-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-width: 23.75rem;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__library-name .main_ui_workspace_text_palette_ctx_menu__lib-num,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__library-name .main_ui_workspace_text_palette_ctx_menu__lib-num {
  margin-left: 0.25rem;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper {
  margin-left: 0.25rem;
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg {
  display: flex;
  justify-content: center;
  align-items: center;
  stroke: var(--icon-foreground);
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:hover .main_ui_workspace_text_palette_ctx_menu__icon-wrapper svg {
  display: flex;
  justify-content: center;
  align-items: center;
  stroke: var(--context-menu-foreground-color-selected);
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__library-name, .main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:hover .main_ui_workspace_text_palette_ctx_menu__library-name,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library.main_ui_workspace_text_palette_ctx_menu__selected .main_ui_workspace_text_palette_ctx_menu__library-name,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:hover .main_ui_workspace_text_palette_ctx_menu__library-name {
  color: var(--context-menu-foreground-color-selected);
}
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__palette-library:hover,
.main_ui_workspace_text_palette_ctx_menu__text-context-menu .main_ui_workspace_text_palette_ctx_menu__file-library:hover {
  background-color: var(--context-menu-background-color-selected);
}
@keyframes main_ui_workspace_top_toolbar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button.disabled, [disabled].main_ui_workspace_top_toolbar__main-toolbar-options-button, .main_ui_workspace_top_toolbar__main-toolbar-options-button:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button.disabled svg, [disabled].main_ui_workspace_top_toolbar__main-toolbar-options-button svg, .main_ui_workspace_top_toolbar__main-toolbar-options-button:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_top_toolbar__main-toolbar-options-button.main_ui_workspace_top_toolbar__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button.main_ui_workspace_top_toolbar__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_top_toolbar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_top_toolbar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_top_toolbar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_top_toolbar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_top_toolbar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_top_toolbar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_top_toolbar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_top_toolbar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_top_toolbar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_top_toolbar__main-toolbar-options-button svg, .main_ui_workspace_top_toolbar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_top_toolbar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_top_toolbar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_top_toolbar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_top_toolbar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_top_toolbar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_top_toolbar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_top_toolbar__main-toolbar {
  cursor: initial;
  position: absolute;
  left: 50%;
  transform: translateX(-50%);
  display: flex;
  align-items: center;
  flex-direction: column;
  height: 3.5rem;
  padding: 0.5rem 1rem;
  border-radius: 0.5rem;
  border: 0.125rem solid var(--panel-border-color);
  z-index: 1;
  background-color: var(--color-background-primary);
  transition: top 0.3s, height 0.3s, opacity 0.3s;
  --toolbar-position-y: 1.75rem;
  --toolbar-offset-y: 0px;
  top: calc(var(--toolbar-position-y) + var(--toolbar-offset-y));
}

.main_ui_workspace_top_toolbar__main-toolbar-no-rulers {
  --toolbar-position-y: 0px;
  --toolbar-offset-y: 0.5rem;
}

.main_ui_workspace_top_toolbar__main-toolbar-hidden {
  --toolbar-offset-y: calc(-1 * 0.25rem);
  height: 1rem;
  z-index: 1;
  border-radius: 0 0 0.5rem 0.5rem;
  border-block-start: 0;
}
.main_ui_workspace_top_toolbar__main-toolbar-hidden .main_ui_workspace_top_toolbar__main-toolbar-options {
  opacity: 0;
  visibility: hidden;
}

.main_ui_workspace_top_toolbar__main-toolbar-options {
  position: relative;
  display: flex;
  align-items: center;
  margin: 0;
  opacity: 1;
  transition: opacity 0.3s ease;
}
.main_ui_workspace_top_toolbar__main-toolbar-options li {
  position: relative;
}

.main_ui_workspace_top_toolbar__main-toolbar-options-button {
  height: 2.25rem;
  width: 2.25rem;
  flex-shrink: 0;
  border-radius: 0.5rem;
  margin: 0 0.125rem;
}
.main_ui_workspace_top_toolbar__main-toolbar-options-button svg {
  stroke: var(--color-foreground-secondary);
}
.main_ui_workspace_top_toolbar__mcp-button {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  width: -moz-fit-content;
  width: fit-content;
  margin-inline-start: var(--sp-xs);
  padding-inline: var(--sp-s);
}

.main_ui_workspace_top_toolbar__mcp-button-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}
.main_ui_workspace_top_toolbar__mcp-button-label.main_ui_workspace_top_toolbar__connected {
  color: var(--color-accent-primary);
}

.main_ui_workspace_top_toolbar__mcp-status-dot {
  position: relative;
  flex-shrink: 0;
  inline-size: 0.375rem;
  block-size: 0.375rem;
  border-radius: 50%;
  background-color: var(--color-background-disabled);
}
.main_ui_workspace_top_toolbar__mcp-status-dot.main_ui_workspace_top_toolbar__connected {
  background-color: var(--color-accent-primary);
}
.main_ui_workspace_top_toolbar__mcp-status-dot.main_ui_workspace_top_toolbar__connected::after {
  content: "";
  position: absolute;
  inset: 0;
  border-radius: 50%;
  background-color: var(--color-accent-primary);
  opacity: 0;
  animation: main_ui_workspace_top_toolbar__mcp-status-blob 0.5s ease-out;
}

@keyframes main_ui_workspace_top_toolbar__mcp-status-blob {
  from {
    opacity: 0.5;
    transform: scale(1);
  }
  to {
    opacity: 0;
    transform: scale(2.5);
  }
}
.main_ui_workspace_top_toolbar__mcp-menu {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  inset-block-start: calc(100% + var(--sp-xs));
  inset-inline-start: var(--sp-xs);
  z-index: var(--z-index-dropdown);
  margin: 0;
  padding: var(--sp-xs);
  list-style: none;
  border: 0.0625rem solid var(--panel-border-color);
  border-radius: 0.5rem;
  background-color: var(--menu-background-color);
}

.main_ui_workspace_top_toolbar__mcp-menu-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding: var(--sp-s) var(--sp-m);
  color: var(--color-foreground-secondary);
  white-space: nowrap;
}

.main_ui_workspace_top_toolbar__mcp-menu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  padding: var(--sp-s) var(--sp-m);
  border-radius: 0.5rem;
  color: var(--menu-foreground-color);
  white-space: nowrap;
}
.main_ui_workspace_top_toolbar__mcp-menu-item:hover {
  background-color: var(--menu-background-color-hover);
}

.main_ui_workspace_top_toolbar__toolbar-handler {
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  background: none;
  cursor: pointer;
  position: absolute;
  left: 0;
  bottom: 0;
  height: 0.75rem;
  width: 100%;
}
.main_ui_workspace_top_toolbar__toolbar-handler .main_ui_workspace_top_toolbar__toolbar-handler-btn {
  height: 0.25rem;
  width: 100%;
  max-width: 4rem;
  padding: 0;
  border-radius: 0.25rem;
  background-color: var(--palette-handler-background-color);
}

ul.main_ui_workspace_top_toolbar__main-toolbar-panels {
  display: none;
}
@keyframes main_ui_workspace_viewport__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_viewport__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_viewport__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_viewport__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_viewport__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_viewport__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_viewport__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_viewport__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_viewport__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_viewport__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_viewport__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_viewport__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_viewport__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_viewport__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_viewport__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_viewport__viewport {
  cursor: none;
  grid-column: 1/span 2;
  grid-row: 1/span 2;
  overflow: hidden;
  position: relative;
}

.main_ui_workspace_viewport__viewport-controls {
  position: absolute;
  width: 100%;
  height: 100%;
}

.main_ui_workspace_viewport__render-shapes {
  height: 100%;
  position: absolute;
  width: 100%;
}

.main_ui_workspace_viewport__viewport-overlays {
  cursor: initial;
  overflow: hidden;
  pointer-events: none;
  position: absolute;
  inset: 0;
  z-index: 1;
}
.main_ui_workspace_viewport_wasm__viewport {
  cursor: none;
  grid-column: 1/span 2;
  grid-row: 1/span 2;
  overflow: hidden;
  position: relative;
}

.main_ui_workspace_viewport_wasm__viewport-controls {
  position: absolute;
  width: 100%;
  height: 100%;
}

.main_ui_workspace_viewport_wasm__render-shapes {
  height: 100%;
  position: absolute;
  width: 100%;
}

.main_ui_workspace_viewport_wasm__viewport-overlays {
  cursor: initial;
  overflow: hidden;
  pointer-events: none;
  position: absolute;
  inset: 0;
  z-index: 10;
}

.main_ui_workspace_viewport_wasm__context-lost {
  position: fixed;
  inset: 0;
  z-index: 100;
  background-color: rgba(0, 0, 0, 0.5);
  display: grid;
  place-items: center;
  cursor: default;
}
@keyframes main_ui_workspace_webgl_unavailable_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_webgl_unavailable_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_webgl_unavailable_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_webgl_unavailable_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_webgl_unavailable_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_webgl_unavailable_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_webgl_unavailable_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_webgl_unavailable_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_webgl_unavailable_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_webgl_unavailable_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_webgl_unavailable_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_webgl_unavailable_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_webgl_unavailable_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_webgl_unavailable_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_webgl_unavailable_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_webgl_unavailable_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_webgl_unavailable_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_webgl_unavailable_modal__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_webgl_unavailable_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_webgl_unavailable_modal__modal-dialog {
  color: var(--color-foreground-secondary);
  display: grid;
  gap: var(--sp-s);
  padding: 4.5rem;
  max-width: 42.625rem;
}

.main_ui_workspace_webgl_unavailable_modal__modal-header {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_webgl_unavailable_modal__modal-close-btn {
  position: absolute;
  top: 2.375rem;
  right: 2.375rem;
}

.main_ui_workspace_webgl_unavailable_modal__modal-content {
  display: grid;
  grid-template-rows: auto;
  gap: var(--sp-s);
}
.main_ui_workspace_webgl_unavailable_modal__modal-content > * {
  margin: 0;
}

.main_ui_workspace_webgl_unavailable_modal__modal-divider {
  border: 0.0625rem solid var(--color-background-quaternary);
  margin: var(--sp-xs) 0;
}

.main_ui_workspace_webgl_unavailable_modal__modal-footer {
  margin-block-start: var(--sp-l);
  justify-self: end;
  display: flex;
  flex-direction: row;
  gap: var(--sp-s);
}

.main_ui_workspace_webgl_unavailable_modal__link {
  color: var(--color-accent-primary);
}
@keyframes main_ui_workspace_viewport_comments__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_viewport_comments__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_viewport_comments__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_viewport_comments__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_comments__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_comments__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_viewport_comments__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_viewport_comments__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_viewport_comments__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_viewport_comments__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_viewport_comments__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_viewport_comments__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_viewport_comments__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_viewport_comments__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_viewport_comments__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_viewport_comments__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_viewport_comments__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_viewport_comments__workspace-comments-container {
  width: 100%;
  height: 100%;
  grid-column: 1/span 2;
  grid-row: 1/span 2;
  z-index: 1000;
  pointer-events: none;
  overflow: hidden;
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
  position: absolute;
}

.main_ui_workspace_viewport_comments__threads {
  position: absolute;
}
@keyframes main_ui_workspace_viewport_grid_layout_editor__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_workspace_viewport_grid_layout_editor__done-btn.disabled, [disabled].main_ui_workspace_viewport_grid_layout_editor__done-btn, .main_ui_workspace_viewport_grid_layout_editor__done-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_viewport_grid_layout_editor__locate-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_viewport_grid_layout_editor__locate-btn.disabled, [disabled].main_ui_workspace_viewport_grid_layout_editor__locate-btn, .main_ui_workspace_viewport_grid_layout_editor__locate-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_viewport_grid_layout_editor__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn.disabled, [disabled].main_ui_workspace_viewport_grid_layout_editor__close-btn, .main_ui_workspace_viewport_grid_layout_editor__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_viewport_grid_layout_editor__close-btn.disabled svg, [disabled].main_ui_workspace_viewport_grid_layout_editor__close-btn svg, .main_ui_workspace_viewport_grid_layout_editor__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_viewport_grid_layout_editor__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_viewport_grid_layout_editor__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_viewport_grid_layout_editor__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_viewport_grid_layout_editor__close-btn svg, .main_ui_workspace_viewport_grid_layout_editor__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_viewport_grid_layout_editor__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_viewport_grid_layout_editor__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_viewport_grid_layout_editor__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_viewport_grid_layout_editor__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_viewport_grid_layout_editor__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_viewport_grid_layout_editor__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_viewport_grid_layout_editor__grid-track-marker .main_ui_workspace_viewport_grid_layout_editor__marker-shape {
  fill: var(--grid-editor-marker-color);
}
.main_ui_workspace_viewport_grid_layout_editor__grid-track-marker .main_ui_workspace_viewport_grid_layout_editor__marker-text {
  fill: var(--app-white);
  font-size: calc(0.75rem / var(--zoom));
  font-family: "worksans", "vazirmatn", sans-serif;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-editor-wrapper {
  cursor: grab;
  position: relative;
  width: 100%;
  height: 80%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-editor-header-hover {
  fill: var(--grid-editor-marker-color);
}

.main_ui_workspace_viewport_grid_layout_editor__grid-editor-label {
  flex: 1;
  background: none;
  border: 0;
  color: var(--grid-editor-marker-text);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: calc(0.75rem / var(--zoom));
  font-weight: 400;
  margin: 0;
  max-width: calc(3.75rem / var(--zoom));
  padding: 0;
  padding: calc(0.25rem / var(--zoom));
  text-align: center;
}
.main_ui_workspace_viewport_grid_layout_editor__grid-editor-label:focus {
  outline: none;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-editor-button {
  background: none;
  border: none;
  cursor: pointer;
  margin: 0;
  padding: 0;
  position: absolute;
  top: calc(0.375rem / var(--zoom));
  right: calc(1.25rem / var(--zoom));
  width: calc(1.25rem / var(--zoom));
  height: calc(1.25rem / var(--zoom));
  opacity: 0;
  pointer-events: none;
}
.main_ui_workspace_viewport_grid_layout_editor__grid-editor-button svg {
  position: absolute;
  top: 0;
  left: 0;
  width: calc(1rem / var(--zoom));
  height: auto;
  stroke: var(--grid-editor-marker-color);
}

.main_ui_workspace_viewport_grid_layout_editor__grid-editor-wrapper:hover .main_ui_workspace_viewport_grid_layout_editor__grid-editor-button {
  opacity: 1;
  pointer-events: auto;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-frame {
  fill: var(--grid-editor-marker-color);
  fill-opacity: 0.1;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-plus-button {
  cursor: pointer;
  opacity: 0.5;
}
.main_ui_workspace_viewport_grid_layout_editor__grid-plus-button .main_ui_workspace_viewport_grid_layout_editor__grid-plus-shape {
  fill: var(--grid-editor-plus-btn-background);
  stroke: var(--grid-editor-plus-btn-background);
  stroke-width: calc(1px / var(--zoom));
}
.main_ui_workspace_viewport_grid_layout_editor__grid-plus-button .main_ui_workspace_viewport_grid_layout_editor__grid-plus-icon {
  stroke: var(--grid-editor-plus-btn-foreground);
}
.main_ui_workspace_viewport_grid_layout_editor__grid-plus-button:hover {
  opacity: 1;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-cell-outline {
  fill: transparent;
  stroke: var(--grid-editor-line-color);
  stroke-opacity: 0.5;
  stroke-width: calc(1 / var(--zoom));
}
.main_ui_workspace_viewport_grid_layout_editor__grid-cell-outline.main_ui_workspace_viewport_grid_layout_editor__hover, .main_ui_workspace_viewport_grid_layout_editor__grid-cell-outline.main_ui_workspace_viewport_grid_layout_editor__selected {
  stroke-opacity: 1;
  stroke-width: calc(2 / var(--zoom));
}

.main_ui_workspace_viewport_grid_layout_editor__grid-actions {
  pointer-events: none;
  position: absolute;
  top: 2.75rem;
  left: 50%;
  z-index: 20;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-actions-container {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  background: var(--panel-background-color);
  border-radius: 12px;
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  gap: 0.5rem;
  height: 3rem;
  margin-left: -50%;
  padding: 0.5rem;
  cursor: initial;
  pointer-events: initial;
  width: 32rem;
}

.main_ui_workspace_viewport_grid_layout_editor__grid-actions-title {
  flex: 1;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  padding-left: 0.5rem;
}

.main_ui_workspace_viewport_grid_layout_editor__locate-btn {
  text-transform: uppercase;
  padding: 0.5rem 1.25rem;
  font-size: 0.688rem;
}

.main_ui_workspace_viewport_grid_layout_editor__done-btn {
  text-transform: uppercase;
  padding: 0.5rem 1.25rem;
  font-size: 0.688rem;
}
@keyframes main_ui_workspace_viewport_path_actions__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_viewport_path_actions__topbar-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_viewport_path_actions__topbar-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_viewport_path_actions__topbar-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_viewport_path_actions__topbar-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_viewport_path_actions__topbar-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_viewport_path_actions__topbar-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_viewport_path_actions__topbar-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_viewport_path_actions__topbar-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_viewport_path_actions__topbar-btn.disabled, [disabled].main_ui_workspace_viewport_path_actions__topbar-btn, .main_ui_workspace_viewport_path_actions__topbar-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_viewport_path_actions__topbar-btn.disabled svg, [disabled].main_ui_workspace_viewport_path_actions__topbar-btn svg, .main_ui_workspace_viewport_path_actions__topbar-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_viewport_path_actions__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_viewport_path_actions__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_viewport_path_actions__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_path_actions__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_path_actions__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_viewport_path_actions__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_viewport_path_actions__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_viewport_path_actions__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_viewport_path_actions__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_viewport_path_actions__topbar-btn .main_ui_workspace_viewport_path_actions__pathbar-icon, .main_ui_workspace_viewport_path_actions__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_viewport_path_actions__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_viewport_path_actions__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_viewport_path_actions__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_viewport_path_actions__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_viewport_path_actions__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_viewport_path_actions__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_viewport_path_actions__sub-actions {
  cursor: initial;
  pointer-events: initial;
  position: absolute;
  top: 0.75rem;
  left: 50%;
  transform: translateX(-50%);
  display: flex;
  align-items: center;
  height: 3.5rem;
  padding: 0.5rem 1rem;
  border-radius: 0.5rem;
  gap: 1rem;
  border: 0.125rem solid var(--panel-border-color);
  z-index: 3;
  background-color: var(--color-background-primary);
  transition: top 0.3s, height 0.3s, opacity 0.3s;
}

.main_ui_workspace_viewport_path_actions__sub-actions-group {
  position: relative;
  display: flex;
  align-items: center;
  margin: 0;
  opacity: 1;
  transition: opacity 0.3s ease;
}

.main_ui_workspace_viewport_path_actions__topbar-btn {
  --pathbar-icon-color: var(--color-foreground-secondary);
  height: 2.25rem;
  width: 2.25rem;
  flex-shrink: 0;
  background-color: transparent;
  border-radius: 0.5rem;
  border: none;
  margin: 0 0.125rem;
}
.main_ui_workspace_viewport_path_actions__topbar-btn.main_ui_workspace_viewport_path_actions__is-toggled {
  --pathbar-icon-color: var(--button-radio-foreground-color-active);
  background-color: var(--button-radio-background-color-active);
}
.main_ui_workspace_viewport_path_actions__topbar-btn .main_ui_workspace_viewport_path_actions__pathbar-icon {
  stroke: var(--pathbar-icon-color);
}
.main_ui_workspace_viewport_pixel_overlay__pixel-overlay {
  inset: 0;
  pointer-events: initial;
  position: absolute;
  z-index: 1;
}
@keyframes main_ui_workspace_viewport_presence__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_viewport_presence__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_viewport_presence__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_viewport_presence__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_presence__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_presence__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_viewport_presence__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_viewport_presence__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_viewport_presence__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_viewport_presence__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_viewport_presence__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_viewport_presence__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_viewport_presence__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_viewport_presence__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_viewport_presence__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_viewport_presence__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_viewport_presence__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_viewport_presence__profile-name {
  width: -moz-fit-content;
  width: fit-content;
  font-family: "worksans", "vazirmatn", sans-serif;
  padding: 2px 12px;
  border-radius: 4px;
  display: flex;
  align-items: center;
  height: 20px;
  font-size: 0.75rem;
  line-height: 1.5;
}

.main_ui_workspace_viewport_presence__multiuser-cursor {
  z-index: 10000;
  pointer-events: none;
}
@keyframes main_ui_workspace_viewport_top_bar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_viewport_top_bar__done-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_workspace_viewport_top_bar__done-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_workspace_viewport_top_bar__done-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_viewport_top_bar__done-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_viewport_top_bar__done-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_viewport_top_bar__done-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_workspace_viewport_top_bar__done-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_workspace_viewport_top_bar__done-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_workspace_viewport_top_bar__done-btn.disabled, [disabled].main_ui_workspace_viewport_top_bar__done-btn, .main_ui_workspace_viewport_top_bar__done-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_viewport_top_bar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_viewport_top_bar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_viewport_top_bar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_top_bar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_viewport_top_bar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_viewport_top_bar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_viewport_top_bar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_viewport_top_bar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_viewport_top_bar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_viewport_top_bar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_viewport_top_bar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_viewport_top_bar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_viewport_top_bar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_viewport_top_bar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_viewport_top_bar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_viewport_top_bar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_viewport_top_bar__viewport-actions,
.main_ui_workspace_viewport_top_bar__viewport-actions-path {
  pointer-events: none;
  position: absolute;
  --actions-toolbar-position-y: 1.75rem;
  --actions-toolbar-offset-y: 0.375rem;
  top: calc(var(--actions-toolbar-position-y) + var(--actions-toolbar-offset-y));
  left: 50%;
  transform: translateX(-50%);
  z-index: 20;
}

.main_ui_workspace_viewport_top_bar__viewport-actions-path {
  z-index: 3;
}

.main_ui_workspace_viewport_top_bar__viewport-actions-container {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  background: var(--panel-background-color);
  border-radius: 12px;
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  gap: 0.5rem;
  height: 3rem;
  padding: 0.5rem;
  cursor: initial;
  pointer-events: initial;
  min-width: 25rem;
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_workspace_viewport_top_bar__viewport-actions-title {
  flex: 1;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  padding-left: 0.5rem;
  width: -moz-max-content;
  width: max-content;
}

.main_ui_workspace_viewport_top_bar__done-btn {
  text-transform: uppercase;
  padding: 0.5rem 1.25rem;
  font-size: 0.688rem;
}

.main_ui_workspace_viewport_top_bar__viewport-actions-no-rulers {
  --actions-toolbar-position-y: 0px;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_workspace_viewport_widgets__frame-flow-badge-wrapper {
  --frame-flow-badge-background-color: var(--color-background-tertiary);
  --frame-flow-badge-background-color-hover: var(--color-background-quaternary);
  --frame-flow-badge-foreground-color: var(--color-foreground-secondary);
  --frame-flow-badge-foreground-color-hover: var(--color-accent-primary);
  cursor: pointer;
  display: flex;
}

.main_ui_workspace_viewport_widgets__frame-flow-badge-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: center;
  gap: var(--sp-xs);
  border-radius: 0.375rem;
  padding-inline: var(--sp-xs) var(--sp-s);
  height: var(--sp-xxl);
  background-color: var(--frame-flow-badge-background-color);
  color: var(--frame-flow-badge-foreground-color);
}
.main_ui_workspace_viewport_widgets__frame-flow-badge-content:hover, .main_ui_workspace_viewport_widgets__frame-flow-badge-content.main_ui_workspace_viewport_widgets__selected {
  --frame-flow-badge-foreground-color: var(--frame-flow-badge-foreground-color-hover);
  --frame-flow-badge-background-color: var(--frame-flow-badge-background-color-hover);
}

.main_ui_workspace_viewport_widgets__frame-title-wrapper {
  --frame-title-input-border-color-focus: var(--color-accent-primary);
  pointer-events: none;
}

.main_ui_workspace_viewport_widgets__frame-title-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
  max-width: -moz-fit-content;
  max-width: fit-content;
  pointer-events: all;
}

.main_ui_workspace_viewport_widgets__frame-title-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  flex-grow: 1;
  width: 100%;
  max-width: initial;
  background: none;
  outline: none;
  height: var(--sp-xl);
  padding-inline-start: var(--sp-s);
  border: 0.0625rem solid var(--frame-title-input-border-color-focus);
}

.main_ui_workspace_viewport_widgets__button-add-wrapper {
  --button-add-background-color: var(--color-accent-action);
  --button-add-background-color-hover: var(--color-accent-action-hover);
  --button-add-icon-color: var(--color-static-white);
  cursor: pointer;
  fill: var(--button-add-background-color);
}
.main_ui_workspace_viewport_widgets__button-add-wrapper:hover {
  --button-add-background-color: var(--button-add-background-color-hover);
}

.main_ui_workspace_viewport_widgets__button-add-icon {
  stroke: var(--button-add-icon-color);
}
@keyframes main_ui_workspace_tokens_export__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_export__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_export__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_export__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_export__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_export__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_export__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_export__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_export__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_export__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_export__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_export__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_export__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_export__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_export__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_export__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_export__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_export__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_tokens_export__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_export__modal-dialog {
  --modal-width: 32rem;
  --modal-padding: var(--sp-xxxl);
  --container-max-height: 16rem;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  width: var(--modal-width);
  max-width: 100%;
}

.main_ui_workspace_tokens_export__close-btn {
  position: absolute;
  inset-block-start: var(--sp-s);
  inset-inline-end: var(--sp-s);
}
@keyframes main_ui_workspace_tokens_import__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_import__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_import__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_import__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_import__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_import__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_import__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_import__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_import__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_import__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_import__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_import__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_import__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_import__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_import__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_import__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_import__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_import__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_tokens_import__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_import__modal-dialog {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_workspace_tokens_import__close-btn {
  position: absolute;
  inset-block-start: var(--sp-s);
  inset-inline-end: var(--sp-s);
}
@keyframes main_ui_workspace_tokens_import_from_library__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_import_from_library__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_import_from_library__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_import_from_library__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_import_from_library__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_import_from_library__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_import_from_library__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_import_from_library__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_import_from_library__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_import_from_library__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_import_from_library__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_import_from_library__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_import_from_library__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_import_from_library__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_import_from_library__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_import_from_library__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_import_from_library__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_import_from_library__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_tokens_import_from_library__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_import_from_library__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_workspace_tokens_import_from_library__close-btn {
  position: absolute;
  inset-block-start: var(--sp-s);
  inset-inline-end: var(--sp-s);
}

.main_ui_workspace_tokens_import_from_library__modal-overlay {
  --modal-title-foreground-color: var(--color-foreground-primary);
  --modal-text-foreground-color: var(--color-foreground-secondary);
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  inset-inline-start: 0;
  inset-block-start: 0;
  block-size: 100%;
  inline-size: 100%;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_import_from_library__modal-dialog {
  inline-size: 100%;
  max-inline-size: 32rem;
  max-block-size: unset;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  position: relative;
}

.main_ui_workspace_tokens_import_from_library__modal-header {
  margin-block-end: var(--sp-xxl);
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.main_ui_workspace_tokens_import_from_library__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
  overflow-wrap: break-word;
}

.main_ui_workspace_tokens_import_from_library__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
}

.main_ui_workspace_tokens_import_from_library__modal-footer {
  margin-block-start: var(--sp-xxl);
  gap: var(--sp-s);
}

.main_ui_workspace_tokens_import_from_library__action-buttons {
  gap: var(--sp-s);
}
.main_ui_workspace_tokens_management__sets-header-container {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: var(--sp-s);
  color: var(--title-foreground-color);
  overflow-wrap: break-word;
  display: flex;
  align-items: flex-start;
  justify-content: space-between;
  gap: var(--sp-xs);
  margin-block-start: var(--sp-s);
}

.main_ui_workspace_tokens_management__sets-header {
  flex: 1;
}

.main_ui_workspace_tokens_management__sets-header-status {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  text-transform: none;
  color: var(--color-foreground-secondary);
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_management__sets-header-status-text {
  font-style: italic;
}
@keyframes main_ui_workspace_tokens_remapping_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_remapping_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_remapping_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_remapping_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_remapping_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_remapping_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_remapping_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_remapping_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_remapping_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_remapping_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_remapping_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_remapping_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_remapping_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_remapping_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_remapping_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_remapping_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_remapping_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_remapping_modal__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_tokens_remapping_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_remapping_modal__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_workspace_tokens_remapping_modal__modal-overlay {
  --modal-title-foreground-color: var(--color-foreground-primary);
  --modal-text-foreground-color: var(--color-foreground-secondary);
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  inset-inline-start: 0;
  inset-block-start: 0;
  block-size: 100%;
  inline-size: 100%;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_remapping_modal__close-btn {
  position: absolute;
  inset-block-start: 0.375rem;
  inset-inline-end: 0.375rem;
}

.main_ui_workspace_tokens_remapping_modal__modal-dialog {
  inline-size: 100%;
  max-inline-size: 32rem;
  max-block-size: unset;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  position: relative;
}

.main_ui_workspace_tokens_remapping_modal__modal-header {
  margin-block-end: var(--sp-xxl);
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.main_ui_workspace_tokens_remapping_modal__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
  overflow-wrap: anywhere;
}

.main_ui_workspace_tokens_remapping_modal__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
}

.main_ui_workspace_tokens_remapping_modal__modal-footer {
  margin-block-start: var(--sp-xxl);
  gap: var(--sp-s);
}

.main_ui_workspace_tokens_remapping_modal__action-buttons {
  gap: var(--sp-s);
}

.main_ui_workspace_tokens_remapping_modal__modal-scd-msg,
.main_ui_workspace_tokens_remapping_modal__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
}
@keyframes main_ui_workspace_tokens_sets__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_sets__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_sets__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_sets__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sets__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sets__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_sets__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_sets__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_sets__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_sets__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_sets__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_sets__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_sets__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_sets__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_sets__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_sets__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_sets__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_sets__sets-list {
  width: 100%;
  margin-bottom: 0;
  overflow-y: auto;
}

.main_ui_workspace_tokens_sets__empty-sets-wrapper {
  padding: 0.75rem;
  padding-inline-start: 1.5rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_sets__create-set-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  background-color: transparent;
  border: none;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  color: var(--color-accent-primary);
  cursor: pointer;
}

.main_ui_workspace_tokens_sets__set-item-container {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  width: 100%;
  min-height: 2rem;
  cursor: pointer;
  color: var(--layer-row-foreground-color);
  padding-left: calc(1.5rem * var(--tree-depth, 0) + 0.5rem);
  border: 0.125rem solid transparent;
  gap: 0.125rem;
}
.main_ui_workspace_tokens_sets__set-item-container.main_ui_workspace_tokens_sets__dnd-over-bot {
  border-bottom: 0.125rem solid var(--layer-row-foreground-color-hover);
}
.main_ui_workspace_tokens_sets__set-item-container.main_ui_workspace_tokens_sets__dnd-over-top {
  border-top: 0.125rem solid var(--layer-row-foreground-color-hover);
}
.main_ui_workspace_tokens_sets__set-item-container.main_ui_workspace_tokens_sets__dnd-over {
  border: 0.125rem solid var(--layer-row-foreground-color-hover);
}

.main_ui_workspace_tokens_sets__set-item-group {
  cursor: unset;
  padding-left: calc(1.5rem * var(--tree-depth, 0));
  gap: 0;
}

.main_ui_workspace_tokens_sets__set-item-group-collapse-button {
  cursor: pointer;
  width: auto;
  height: 1.75rem;
}

.main_ui_workspace_tokens_sets__set-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  padding-left: 0.125rem;
}

.main_ui_workspace_tokens_sets__icon {
  flex-shrink: 0;
  display: flex;
  align-items: center;
  width: 1.25rem;
  height: 1.25rem;
  padding-right: 0.25rem;
}

.main_ui_workspace_tokens_sets__root-icon {
  margin-left: 0.5rem;
}

.main_ui_workspace_tokens_sets__checkbox-style {
  flex-shrink: 0;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  margin-inline: 0.375rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 0.25rem;
  padding: 0;
}

.main_ui_workspace_tokens_sets__checkbox-checked-style {
  background-color: var(--input-border-color-active);
  color: var(--color-background-secondary);
}

.main_ui_workspace_tokens_sets__checkbox-disabled {
  border: 1px solid var(--color-background-quaternary);
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_tokens_sets__checkbox-disabled-checked {
  background-color: var(--color-accent-primary-muted);
  color: var(--color-background-quaternary);
}

.main_ui_workspace_tokens_sets__check-icon {
  color: currentcolor;
}

.main_ui_workspace_tokens_sets__set-item-container:hover {
  background-color: var(--layer-row-background-color-hover);
  color: var(--layer-row-foreground-color-hover);
  box-shadow: -100px 0 0 0 var(--layer-row-background-color-hover);
}

.main_ui_workspace_tokens_sets__empty-state-message-sets {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
  padding: 0.75rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_sets__selected-set {
  background-color: var(--layer-row-background-color-selected);
  color: var(--layer-row-foreground-color-selected);
  box-shadow: -100px 0 0 0 var(--layer-row-background-color-selected);
}

.main_ui_workspace_tokens_sets__collapsabled-icon {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  border-radius: 8px;
}
.main_ui_workspace_tokens_sets__collapsabled-icon:hover {
  color: var(--title-foreground-color-hover);
}

.main_ui_workspace_tokens_sets__editing-node {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border: none;
  background: none;
  outline: none;
  border: 1px solid var(--input-border-color-focus);
  border-radius: 8px;
  color: var(--layer-row-foreground-color-focus);
  flex-grow: 1;
  height: 1.75rem;
  margin: 0;
  padding-left: 0.375rem;
}
.main_ui_workspace_tokens_sets__editing-node::-moz-placeholder {
  color: var(--layer-row-foreground-color-placeholder);
}
.main_ui_workspace_tokens_sets__editing-node::placeholder {
  color: var(--layer-row-foreground-color-placeholder);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

@keyframes main_ui_workspace_tokens_sidebar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_sidebar__import-export-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_tokens_sidebar__import-export-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_tokens_sidebar__import-export-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_tokens_sidebar__import-export-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_tokens_sidebar__import-export-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_tokens_sidebar__import-export-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_tokens_sidebar__import-export-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_tokens_sidebar__import-export-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_tokens_sidebar__import-export-button.disabled, [disabled].main_ui_workspace_tokens_sidebar__import-export-button, .main_ui_workspace_tokens_sidebar__import-export-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_tokens_sidebar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_sidebar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_sidebar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sidebar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sidebar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_sidebar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_sidebar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_sidebar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_sidebar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_sidebar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_sidebar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_sidebar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_sidebar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_sidebar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_sidebar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_sidebar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_sidebar__import-export-menu {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_workspace_tokens_sidebar__import-export-menu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_workspace_tokens_sidebar__import-export-menu-item:hover {
  background-color: var(--menu-background-color-hover);
}

.main_ui_workspace_tokens_sidebar__sidebar-wrapper {
  display: grid;
  grid-template-rows: auto 1fr auto;
  height: calc(100vh - 5.75rem);
  overflow: hidden;
}

.main_ui_workspace_tokens_sidebar__token-management-section-wrapper {
  display: flex;
  flex: 1;
  height: var(--resize-height);
  flex-direction: column;
  overflow-y: auto;
  scrollbar-gutter: stable;
  position: relative;
  padding-block-end: var(--sp-l);
}

.main_ui_workspace_tokens_sidebar__tokens-section-wrapper {
  height: 100%;
  padding-left: var(--sp-m);
  overflow-y: auto;
  scrollbar-gutter: stable;
}

.main_ui_workspace_tokens_sidebar__sidebar-header {
  display: flex;
  align-items: center;
  justify-content: space-between;
  margin-left: var(--sp-m);
  padding-top: var(--sp-m);
  color: var(--layer-row-foreground-color);
}

.main_ui_workspace_tokens_sidebar__section-text-icon {
  font-size: 0.75rem;
  width: var(--sp-l);
  height: var(--sp-l);
  display: flex;
  place-content: center;
}

.main_ui_workspace_tokens_sidebar__section-icon {
  margin-right: var(--sp-xs);
  translate: 0 -1px;
}

.main_ui_workspace_tokens_sidebar__import-export-button-wrapper {
  position: relative;
  display: flex;
  gap: var(--sp-s);
  flex-direction: row;
  align-items: end;
  justify-content: end;
  padding: var(--sp-s);
  background-color: var(--color-background-primary);
  box-shadow: var(--el-shadow-dark);
}

.main_ui_workspace_tokens_sidebar__import-export-button {
  display: flex;
  align-items: center;
  justify-content: end;
  padding: 0.375rem var(--sp-s);
  text-transform: uppercase;
  gap: var(--sp-s);
  background-color: var(--color-background-primary);
  box-shadow: var(--el-shadow-dark);
}

.main_ui_workspace_tokens_sidebar__import-export-menu {
  top: -0.375rem;
  right: 0;
  translate: 0 -100%;
  width: 12rem;
  margin: 0;
}

.main_ui_workspace_tokens_sidebar__import-export-menu-item {
  cursor: pointer;
}
.main_ui_workspace_tokens_sidebar__import-export-menu-item:hover {
  color: var(--menu-foreground-color-hover);
}

.main_ui_workspace_tokens_sidebar__import-export-menu-item-icon {
  display: flex;
  align-items: center;
  justify-content: center;
}

.main_ui_workspace_tokens_sidebar__import-menu-item {
  display: flex;
  justify-content: space-between;
  align-items: center;
  flex: 1;
}

.main_ui_workspace_tokens_sidebar__resize-area-horiz {
  background-color: var(--panel-background-color);
  position: absolute;
  left: 0;
  width: 100%;
  padding: calc(1px + 0.125rem) 0 1px 0;
  height: 0.375rem;
  cursor: ns-resize;
  z-index: 1;
}

.main_ui_workspace_tokens_sidebar__resize-handle-horiz {
  border-bottom: 0.125rem solid var(--resize-area-border-color);
  cursor: ns-resize;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_workspace_tokens_themes__themes-wrapper {
  padding: var(--sp-m) 0 0 var(--sp-m);
}

.main_ui_workspace_tokens_themes__themes-header {
  padding: var(--sp-s);
  color: var(--title-foreground-color);
  overflow-wrap: break-word;
}

.main_ui_workspace_tokens_themes__empty-theme-wrapper {
  padding: var(--sp-m);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes__empty-state-message {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes__create-theme-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  background-color: transparent;
  border: none;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  color: var(--color-accent-primary);
  cursor: pointer;
}

.main_ui_workspace_tokens_themes__theme-selector-wrapper {
  display: grid;
  grid-template-columns: 1fr 0.28fr;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_themes__edit-theme-button {
  justify-content: center;
}
:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_workspace_tokens_themes_create_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  inset-inline-start: 0;
  inset-block-start: 0;
  block-size: 100%;
  inline-size: 100%;
  z-index: var(--z-index-set);
  background-color: var(--color-overlay-default);
}

.main_ui_workspace_tokens_themes_create_modal__modal-dialog {
  position: relative;
  inline-size: 100%;
  min-inline-size: 22.75rem;
  min-block-size: 12rem;
  max-inline-size: 32rem;
  max-block-size: calc(100dvh - 12rem);
  padding: var(--sp-xxxl);
  border-radius: 0.5rem;
  border: 0.125rem solid var(--color-background-quaternary);
  background-color: var(--color-background-primary);
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_workspace_tokens_themes_create_modal__empty-themes-message {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  gap: var(--sp-m);
  padding-block: 4.5rem;
  padding-inline: 0;
}

.main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_workspace_tokens_themes_create_modal__edit-theme-form {
  display: flex;
}

.main_ui_workspace_tokens_themes_create_modal__themes-modal-title {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_themes_create_modal__themes-modal-description {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes_create_modal__back-btn {
  background-color: transparent;
  border: none;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  color: var(--color-foreground-secondary);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  display: grid;
  grid-template-columns: auto auto;
  gap: var(--sp-xs);
  align-items: center;
  padding: 0;
}
.main_ui_workspace_tokens_themes_create_modal__back-btn:hover {
  color: var(--color-accent-primary);
}

.main_ui_workspace_tokens_themes_create_modal__button-footer {
  display: flex;
  margin-inline-start: auto;
  justify-content: flex-end;
  gap: 0.375rem;
}

.main_ui_workspace_tokens_themes_create_modal__edit-theme-footer {
  display: flex;
  justify-content: space-between;
}

.main_ui_workspace_tokens_themes_create_modal__empty-themes-wrapper {
  display: flex;
  flex-direction: column;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes_create_modal__empty-theme-subtitle {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes_create_modal__empty-theme-title {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_themes_create_modal__select-sets-message {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes_create_modal__create-theme-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
}

.main_ui_workspace_tokens_themes_create_modal__close-btn {
  position: absolute;
  inset-block-start: var(--sp-s);
  inset-inline-end: 0.375rem;
}

.main_ui_workspace_tokens_themes_create_modal__theme-group-label {
  color: var(--color-foreground-secondary);
  margin-block: 0 var(--sp-m);
  margin-inline: 0;
  padding: 0;
}

.main_ui_workspace_tokens_themes_create_modal__group-title {
  display: flex;
  align-items: center;
  justify-content: flex-start;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_themes_create_modal__group-title-icon {
  flex-shrink: 0;
}

.main_ui_workspace_tokens_themes_create_modal__group-title-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
}

.main_ui_workspace_tokens_themes_create_modal__theme-group-rows-wrapper {
  display: flex;
  flex-direction: column;
  gap: 0.375rem;
  margin: 0;
}

.main_ui_workspace_tokens_themes_create_modal__theme-group-wrapper {
  display: flex;
  flex-direction: column;
  margin-block-start: 0.375rem;
  overflow-y: auto;
  gap: var(--sp-xxxl);
  max-block-size: calc(100dvh - 28rem);
}

.main_ui_workspace_tokens_themes_create_modal__theme-row {
  align-items: center;
  display: flex;
  justify-content: space-between;
  gap: var(--sp-l);
}

.main_ui_workspace_tokens_themes_create_modal__theme-name-row {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
}

.main_ui_workspace_tokens_themes_create_modal__theme-name {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_themes_create_modal__theme-actions-row {
  align-items: center;
  display: flex;
  gap: 0.375rem;
  flex-shrink: 0;
}

.main_ui_workspace_tokens_themes_create_modal__sets-count-button {
  padding: 0.375rem;
  padding-inline-start: var(--sp-m);
}

.main_ui_workspace_tokens_themes_create_modal__label-wrapper {
  display: flex;
  align-items: center;
  justify-content: center;
  text-transform: lowercase;
}

.main_ui_workspace_tokens_themes_create_modal__edit-theme-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
  inline-size: 100%;
}

.main_ui_workspace_tokens_themes_create_modal__sets-list-wrapper {
  border: 0.0625rem solid color-mix(in hsl, var(--color-foreground-secondary) 30%, transparent);
  border-radius: 0.5rem;
  overflow-y: auto;
  max-block-size: 28.25rem;
}

.main_ui_workspace_tokens_themes_create_modal__sets-count-empty-button {
  text-transform: lowercase;
  padding: 0.375rem;
  padding-inline-start: var(--sp-m);
}

.main_ui_workspace_tokens_themes_create_modal__group-input-wrapper {
  position: relative;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_themes_create_modal__edit-theme-inputs-wrapper {
  display: grid;
  grid-template-columns: 0.6fr 1fr;
  gap: var(--sp-m);
}
@keyframes main_ui_workspace_tokens_themes_theme_selector__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3) transparent;
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7) transparent;
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-webkit-scrollbar {
  background-color: transparent;
  cursor: pointer;
  height: 0.75rem;
  width: 0.75rem;
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-webkit-scrollbar-track,
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-webkit-scrollbar-corner {
  background-color: transparent;
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 8px;
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7);
  outline: none;
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-moz-selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::selection {
  background: var(--text-editor-selection-background-color);
  color: var(--text-editor-selection-foreground-color);
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal ::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}

.main_ui_workspace_tokens_themes_theme_selector__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_themes_theme_selector__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_themes_theme_selector__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_themes_theme_selector__checked-element-button span svg, .main_ui_workspace_tokens_themes_theme_selector__checked-element span svg, .main_ui_workspace_tokens_themes_theme_selector__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_themes_theme_selector__checked-element-button span svg, .main_ui_workspace_tokens_themes_theme_selector__checked-element span svg, .main_ui_workspace_tokens_themes_theme_selector__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_themes_theme_selector__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_themes_theme_selector__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_themes_theme_selector__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_themes_theme_selector__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_themes_theme_selector__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_themes_theme_selector__checked-element-button, .main_ui_workspace_tokens_themes_theme_selector__checked-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_tokens_themes_theme_selector__checked-element-button span, .main_ui_workspace_tokens_themes_theme_selector__checked-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_tokens_themes_theme_selector__checked-element-button span svg, .main_ui_workspace_tokens_themes_theme_selector__checked-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_tokens_themes_theme_selector__checked-element-button:hover, .main_ui_workspace_tokens_themes_theme_selector__checked-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_tokens_themes_theme_selector__checked-element-button:hover svg, .main_ui_workspace_tokens_themes_theme_selector__checked-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_tokens_themes_theme_selector__custom-select-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_workspace_tokens_themes_theme_selector__custom-select {
  --custom-select-border-color: var(--menu-background-color);
  --custom-select-bg-color: var(--menu-background-color);
  --custom-select-icon-color: var(--color-foreground-secondary);
  --custom-select-text-color: var(--menu-foreground-color);
  position: relative;
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  height: 2rem;
  width: 100%;
  margin: 0;
  padding: 0.5rem;
  border-radius: 8px;
  background-color: var(--custom-select-bg-color);
  border: 1px solid var(--custom-select-border-color);
  color: var(--custom-select-text-color);
  cursor: pointer;
}
.main_ui_workspace_tokens_themes_theme_selector__custom-select:hover {
  --custom-select-bg-color: var(--menu-background-color-hover);
  --custom-select-border-color: var(--menu-background-color);
  --custom-select-icon-color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_tokens_themes_theme_selector__custom-select:focus {
  --custom-select-bg-color: var(--menu-background-color-focus);
  --custom-select-border-color: var(--menu-background-focus);
}

.main_ui_workspace_tokens_themes_theme_selector__theme-options {
  margin-bottom: 0;
}

.main_ui_workspace_tokens_themes_theme_selector__group {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  display: block;
  padding: 0.5rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes_theme_selector__disabled-select {
  --custom-select-bg-color: var(--menu-background-color-disabled);
  --custom-select-border-color: var(--menu-border-color-disabled);
  --custom-select-icon-color: var(--menu-foreground-color-disabled);
  --custom-select-text-color: var(--menu-foreground-color-disabled);
  pointer-events: none;
  cursor: default;
}

.main_ui_workspace_tokens_themes_theme_selector__dropdown-button {
  display: flex;
  justify-content: center;
  align-items: center;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_themes_theme_selector__current-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.5rem;
  padding-right: 0.25rem;
}

.main_ui_workspace_tokens_themes_theme_selector__separator {
  margin: 0;
  height: 0.125rem;
  border-block-start: 1px solid color-mix(in hsl, var(--color-foreground-secondary) 20%, transparent);
}

.main_ui_workspace_tokens_themes_theme_selector__custom-select-dropdown[data-direction=up] {
  bottom: 2rem;
  top: auto;
}

.main_ui_workspace_tokens_themes_theme_selector__sub-item {
  padding-left: 1rem;
}

.main_ui_workspace_tokens_themes_theme_selector__checked-element-button {
  position: relative;
  display: flex;
  justify-content: space-between;
  padding-right: 0;
}

.main_ui_workspace_tokens_themes_theme_selector__checked-element.main_ui_workspace_tokens_themes_theme_selector__is-selected {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_tokens_themes_theme_selector__checked-element.main_ui_workspace_tokens_themes_theme_selector__disabled {
  display: none;
}

.main_ui_workspace_tokens_themes_theme_selector__check-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  color: var(--icon-foreground-primary);
  visibility: hidden;
}

.main_ui_workspace_tokens_themes_theme_selector__label {
  flex-grow: 1;
  width: 100%;
}

.main_ui_workspace_tokens_themes_theme_selector__check-icon-visible {
  visibility: visible;
}

.main_ui_workspace_tokens_themes_theme_selector__current-label {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_workspace_tokens_themes_theme_selector__dropdown-portal {
  --menu-max-height: 25rem;
  position: absolute;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

@keyframes main_ui_workspace_tokens_settings_menu__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_settings_menu__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_tokens_settings_menu__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_tokens_settings_menu__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_tokens_settings_menu__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_tokens_settings_menu__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_tokens_settings_menu__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_tokens_settings_menu__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_tokens_settings_menu__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_tokens_settings_menu__close-btn.disabled, [disabled].main_ui_workspace_tokens_settings_menu__close-btn, .main_ui_workspace_tokens_settings_menu__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_tokens_settings_menu__close-btn.disabled svg, [disabled].main_ui_workspace_tokens_settings_menu__close-btn svg, .main_ui_workspace_tokens_settings_menu__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_tokens_settings_menu__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_settings_menu__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_settings_menu__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_settings_menu__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_settings_menu__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_settings_menu__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_settings_menu__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_settings_menu__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_settings_menu__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_settings_menu__close-btn svg, .main_ui_workspace_tokens_settings_menu__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_settings_menu__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_settings_menu__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_settings_menu__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_settings_menu__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_settings_menu__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_settings_menu__setting-modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_settings_menu__setting-modal {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_tokens_settings_menu__close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_tokens_settings_menu__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_settings_menu__settings-modal-layout {
  display: grid;
  grid-template-rows: auto 1fr;
  gap: var(--sp-xxl);
}

.main_ui_workspace_tokens_settings_menu__settings-modal-title {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_settings_menu__settings-modal-content {
  display: grid;
  grid-template-rows: auto 1fr auto;
  gap: var(--sp-m);
}

.main_ui_workspace_tokens_settings_menu__settings-modal-subtitle-wrapper {
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_workspace_tokens_settings_menu__settings-modal-description,
.main_ui_workspace_tokens_settings_menu__settings-modal-resume {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_settings_menu__settings-modal-actions {
  display: flex;
  justify-content: flex-end;
  gap: var(--sp-s);
}
@keyframes main_ui_workspace_tokens_sets_context_menu__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_sets_context_menu__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_sets_context_menu__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_sets_context_menu__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sets_context_menu__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sets_context_menu__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_sets_context_menu__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_sets_context_menu__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_sets_context_menu__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_sets_context_menu__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_sets_context_menu__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_sets_context_menu__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_sets_context_menu__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_sets_context_menu__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_sets_context_menu__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_sets_context_menu__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_sets_context_menu__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_sets_context_menu__token-set-context-menu {
  position: absolute;
  z-index: 4;
}

.main_ui_workspace_tokens_sets_context_menu__context-list {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: grid;
  width: 15rem;
  padding: 0.25rem;
  border-radius: 8px;
  border: 0.125rem solid var(--panel-border-color);
  background-color: var(--menu-background-color);
  max-height: 100vh;
  overflow-y: auto;
}

.main_ui_workspace_tokens_sets_context_menu__context-menu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--menu-foreground-color);
  display: flex;
  align-items: center;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_workspace_tokens_sets_context_menu__context-menu-item:hover {
  background-color: var(--menu-background-color-hover);
}
@keyframes main_ui_workspace_tokens_sets_lists__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_sets_lists__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_sets_lists__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_sets_lists__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sets_lists__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_sets_lists__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_sets_lists__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_sets_lists__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_sets_lists__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_sets_lists__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_sets_lists__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_sets_lists__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_sets_lists__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_sets_lists__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_sets_lists__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_sets_lists__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_sets_lists__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_sets_lists__sets-list {
  width: 100%;
  margin-bottom: 0;
  overflow-y: auto;
}

.main_ui_workspace_tokens_sets_lists__empty-sets-wrapper {
  padding: 0.75rem;
  padding-inline-start: 1.5rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_sets_lists__create-set-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  background-color: transparent;
  border: none;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  color: var(--color-accent-primary);
  cursor: pointer;
}

.main_ui_workspace_tokens_sets_lists__set-item-container {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  width: 100%;
  min-height: 2rem;
  cursor: pointer;
  color: var(--layer-row-foreground-color);
  padding-left: calc(1.5rem * var(--tree-depth, 0) + 0.5rem);
  border: 0.125rem solid transparent;
  gap: 0.125rem;
}
.main_ui_workspace_tokens_sets_lists__set-item-container.main_ui_workspace_tokens_sets_lists__dnd-over-bot {
  border-bottom: 0.125rem solid var(--layer-row-foreground-color-hover);
}
.main_ui_workspace_tokens_sets_lists__set-item-container.main_ui_workspace_tokens_sets_lists__dnd-over-top {
  border-top: 0.125rem solid var(--layer-row-foreground-color-hover);
}
.main_ui_workspace_tokens_sets_lists__set-item-container.main_ui_workspace_tokens_sets_lists__dnd-over {
  border: 0.125rem solid var(--layer-row-foreground-color-hover);
}

.main_ui_workspace_tokens_sets_lists__set-item-group {
  cursor: unset;
  padding-left: calc(1.5rem * var(--tree-depth, 0));
  gap: 0;
}

.main_ui_workspace_tokens_sets_lists__set-item-group-collapse-button {
  cursor: pointer;
  width: auto;
  height: 1.75rem;
}

.main_ui_workspace_tokens_sets_lists__set-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  padding-left: 0.125rem;
}

.main_ui_workspace_tokens_sets_lists__icon {
  flex-shrink: 0;
  display: flex;
  align-items: center;
  width: 1.25rem;
  height: 1.25rem;
  padding-right: 0.25rem;
}

.main_ui_workspace_tokens_sets_lists__root-icon {
  margin-left: 0.5rem;
}

.main_ui_workspace_tokens_sets_lists__checkbox-style {
  flex-shrink: 0;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  margin-inline: 0.375rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 0.25rem;
  padding: 0;
}

.main_ui_workspace_tokens_sets_lists__checkbox-checked-style {
  background-color: var(--input-border-color-active);
  color: var(--color-background-secondary);
}

.main_ui_workspace_tokens_sets_lists__checkbox-disabled {
  border: 1px solid var(--color-background-quaternary);
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_tokens_sets_lists__checkbox-disabled-checked {
  background-color: var(--color-accent-primary-muted);
  color: var(--color-background-quaternary);
}

.main_ui_workspace_tokens_sets_lists__check-icon {
  color: currentcolor;
}

.main_ui_workspace_tokens_sets_lists__set-item-container:hover {
  background-color: var(--layer-row-background-color-hover);
  color: var(--layer-row-foreground-color-hover);
  box-shadow: -100px 0 0 0 var(--layer-row-background-color-hover);
}

.main_ui_workspace_tokens_sets_lists__empty-state-message-sets {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
  padding: 0.75rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_sets_lists__selected-set {
  background-color: var(--layer-row-background-color-selected);
  color: var(--layer-row-foreground-color-selected);
  box-shadow: -100px 0 0 0 var(--layer-row-background-color-selected);
}

.main_ui_workspace_tokens_sets_lists__collapsabled-icon {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  border-radius: 8px;
}
.main_ui_workspace_tokens_sets_lists__collapsabled-icon:hover {
  color: var(--title-foreground-color-hover);
}

.main_ui_workspace_tokens_sets_lists__editing-node {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border: none;
  background: none;
  outline: none;
  border: 1px solid var(--input-border-color-focus);
  border-radius: 8px;
  color: var(--layer-row-foreground-color-focus);
  flex-grow: 1;
  height: 1.75rem;
  margin: 0;
  padding-left: 0.375rem;
}
.main_ui_workspace_tokens_sets_lists__editing-node::-moz-placeholder {
  color: var(--layer-row-foreground-color-placeholder);
}
.main_ui_workspace_tokens_sets_lists__editing-node::placeholder {
  color: var(--layer-row-foreground-color-placeholder);
}
@keyframes main_ui_workspace_tokens_management_context_menu__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_management_context_menu__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_management_context_menu__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_management_context_menu__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_management_context_menu__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_management_context_menu__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_management_context_menu__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_management_context_menu__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_management_context_menu__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_management_context_menu__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_management_context_menu__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_management_context_menu__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_management_context_menu__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_management_context_menu__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_management_context_menu__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_management_context_menu__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_management_context_menu__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_management_context_menu__token-context-menu {
  position: absolute;
  z-index: 4;
}

.main_ui_workspace_tokens_management_context_menu__token-context-menu[data-direction=up] {
  bottom: var(--bottom);
}

.main_ui_workspace_tokens_management_context_menu__token-context-menu[data-direction=down] {
  top: var(--top);
}

.main_ui_workspace_tokens_management_context_menu__context-list,
.main_ui_workspace_tokens_management_context_menu__token-context-submenu {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: grid;
  width: 15rem;
  padding: 0.25rem;
  border-radius: 8px;
  border: 0.125rem solid var(--color-background-quaternary);
  background-color: var(--color-background-tertiary);
  max-height: 100vh;
  overflow-y: auto;
}

.main_ui_workspace_tokens_management_context_menu__token-context-submenu {
  display: none;
}

.main_ui_workspace_tokens_management_context_menu__token-context-submenu-top {
  bottom: 80px;
}

.main_ui_workspace_tokens_management_context_menu__token-context-submenu {
  position: absolute;
  padding: 0.25rem;
  margin-left: 0.375rem;
}

.main_ui_workspace_tokens_management_context_menu__separator {
  margin: 0.375rem;
  border-block-start: 1px solid var(--panel-border-color);
}

.main_ui_workspace_tokens_management_context_menu__context-menu-item {
  --context-menu-item-bg-color: none;
  --context-menu-item-fg-color: var(--color-foreground-primary);
  --context-menu-item-border-color: none;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  height: 2rem;
  width: 100%;
  padding: 0.5rem;
  border-radius: 8px;
  color: var(--context-menu-item-fg-color);
  background-color: var(--context-menu-item-bg-color);
  border: 1px solid var(--context-menu-item-border-color);
  cursor: pointer;
}
.main_ui_workspace_tokens_management_context_menu__context-menu-item:hover {
  --context-menu-item-bg-color: var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_context_menu__context-menu-item:focus {
  --context-menu-item-bg-color: var(--menu-background-color-focus);
  --context-menu-item-border-color: var(--color-background-tertiary);
}
.main_ui_workspace_tokens_management_context_menu__context-menu-item[aria-selected=true] {
  --context-menu-item-bg-color: var(--color-background-quaternary);
}

.main_ui_workspace_tokens_management_context_menu__context-menu-item-hint-wrapper {
  position: relative;
}

.main_ui_workspace_tokens_management_context_menu__context-menu-item-selected .main_ui_workspace_tokens_management_context_menu__icon-wrapper {
  color: var(--color-accent-primary);
}

.main_ui_workspace_tokens_management_context_menu__context-menu-item-unselected {
  color: var(--color-foreground-secondary);
}
.main_ui_workspace_tokens_management_context_menu__context-menu-item-unselected .main_ui_workspace_tokens_management_context_menu__icon-wrapper {
  color: var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_context_menu__context-menu-item-unselected:hover {
  color: var(--color-foreground-primary);
}
.main_ui_workspace_tokens_management_context_menu__context-menu-item-unselected:hover .main_ui_workspace_tokens_management_context_menu__icon-wrapper {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_management_context_menu__context-menu-item-hint {
  position: absolute;
  background-color: var(--color-background-primary);
  border-radius: 6px;
  padding: 0.25rem;
  inset-inline-end: 0.25rem;
  inset-block-start: 0.25rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_management_context_menu__item-text {
  flex-grow: 1;
}

.main_ui_workspace_tokens_management_context_menu__item-with-icon-space {
  padding-left: 1.25rem;
}

.main_ui_workspace_tokens_management_context_menu__icon-wrapper {
  margin-right: 0.25rem;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu {
  --menu-inline-size: 15rem;
  position: absolute;
  z-index: var(--z-index-dropdown);
}

.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu[data-direction=up] {
  bottom: var(--bottom);
}

.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu[data-direction=down] {
  top: var(--top);
}

.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-list {
  inline-size: var(--menu-inline-size);
  padding: var(--sp-xs);
  border-radius: 0.5rem;
  border: 0.125rem solid var(--color-background-quaternary);
  background-color: var(--color-background-tertiary);
  max-block-size: 100vh;
  overflow-y: auto;
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
}

.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action {
  --context-menu-item-bg-color: none;
  --context-menu-item-fg-color: var(--color-foreground-primary);
  --context-menu-item-border-color: none;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background: var(--context-menu-item-bg-color);
  border: 0.0625rem solid var(--context-menu-item-border-color);
  color: var(--context-menu-item-fg-color);
  border-radius: 0.5rem;
  cursor: pointer;
  block-size: 2rem;
  inline-size: 100%;
  display: flex;
  align-items: center;
  padding: var(--sp-xs);
}
.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action:hover {
  --context-menu-item-bg-color: var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action:focus {
  --context-menu-item-bg-color: var(--menu-background-color-focus);
  --context-menu-item-border-color: var(--color-background-tertiary);
}
.main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action[aria-selected=true] {
  --context-menu-item-bg-color: var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_token_pill__token-pill {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  cursor: pointer;
  display: grid;
  grid-template-columns: auto 1fr;
  align-items: center;
  gap: 0.375rem;
  border: 0.0625rem solid var(--token-pill-border);
  outline: 0.125rem solid var(--token-pill-outline);
  height: var(--sp-xxl);
  border-radius: 0.5rem;
  padding: var(--sp-xxs) var(--sp-s) var(--sp-xxs) var(--sp-xs);
  color: var(--token-pill-foreground);
  background: var(--token-pill-background);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-no-icon {
  grid-template-columns: 1fr;
  padding: var(--sp-xxs) var(--sp-s);
}

.main_ui_workspace_tokens_management_token_pill__name-wrapper {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_workspace_tokens_management_token_pill__divided-name-wrapper {
  height: var(--sp-l);
  display: flex;
  align-items: center;
  white-space: nowrap;
  overflow: hidden;
}

.main_ui_workspace_tokens_management_token_pill__first-name-wrapper {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-width: 100%;
}

.main_ui_workspace_tokens_management_token_pill__last-name-wrapper {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  flex-shrink: 0;
}

.main_ui_workspace_tokens_management_token_pill__token-pill-icon {
  color: var(--token-pill-accent);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-default {
  --token-pill-background: var(--color-background-tertiary);
  --token-pill-foreground: var(--color-foreground-secondary);
  --token-pill-border: var(--color-background-tertiary);
  --token-pill-outline: none;
  --token-pill-accent: var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-default:hover {
  --token-pill-background: var(--color-token-background);
  --token-pill-foreground: var(--color-foreground-primary);
  --token-pill-border: var(--color-token-background);
  --token-pill-outline: none;
  --token-pill-accent: var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-default:focus-visible {
  --token-pill-outline: var(--color-background-primary);
  --token-pill-border: var(--color-accent-primary);
  outline-offset: -3px;
}

.main_ui_workspace_tokens_management_token_pill__token-pill-disabled {
  opacity: 0.4;
  cursor: default;
}

.main_ui_workspace_tokens_management_token_pill__token-pill-applied {
  --token-pill-background: var(--color-token-background);
  --token-pill-foreground: var(--color-token-foreground);
  --token-pill-border: var(--color-token-border);
  --token-pill-accent: var(--color-token-accent);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-applied:hover {
  --token-pill-background: var(--color-token-background);
  --token-pill-foreground: var(--color-foreground-primary);
  --token-pill-border: var(--color-token-foreground);
  --token-pill-accent: var(--color-token-accent);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-applied:focus-visible {
  --token-pill-background: var(--color-token-background);
  --token-pill-foreground: var(--color-token-foreground);
  --token-pill-accent: var(--color-token-accent);
  --token-pill-outline: var(--color-background-primary);
  --token-pill-border: var(--color-accent-primary);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-invalid {
  --token-pill-background: var(--color-background-tertiary);
  --token-pill-foreground: var(--color-foreground-error);
  --token-pill-border: var(--color-background-tertiary);
  --token-pill-outline: none;
  --token-pill-accent: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-invalid:hover, .main_ui_workspace_tokens_management_token_pill__token-pill-invalid:focus-visible {
  --token-pill-background: var(--color-background-tertiary);
  --token-pill-accent: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-invalid:hover {
  --token-pill-foreground: var(--color-foreground-primary);
  --token-pill-outline: none;
  --token-pill-border: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-invalid:focus-visible {
  --token-pill-foreground: var(--color-foreground-error);
  --token-pill-border: var(--color-accent-primary);
  --token-pill-outline: var(--color-foreground-error);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied {
  --token-pill-border: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied:hover, .main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied:focus-visible {
  --token-pill-border: var(--color-foreground-error);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-viewer {
  --token-pill-background: var(--color-background-primary);
  --token-pill-foreground: var(--color-foreground-secondary);
  --token-pill-border: var(--color-background-tertiary);
  --token-pill-outline: none;
  --token-pill-accent: var(--color-background-quaternary);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-applied-viewer {
  --token-pill-background: var(--color-background-primary);
  --token-pill-foreground: var(--color-token-foreground);
  --token-pill-border: var(--color-token-accent);
  --token-pill-outline: none;
  --token-pill-accent: var(--color-token-accent);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-invalid-viewer {
  --token-pill-border: var(--color-token-background);
  --token-pill-foreground: var(--color-foreground-error);
  --token-pill-accent: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-invalid-viewer:hover, .main_ui_workspace_tokens_management_token_pill__token-pill-invalid-viewer:focus-visible {
  --token-pill-border: var(--color-token-background);
  --token-pill-foreground: var(--color-foreground-error);
  --token-pill-accent: var(--color-foreground-error);
}

.main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied-viewer {
  --token-pill-border: var(--color-accent-error);
  --token-pill-foreground: var(--color-foreground-error);
  --token-pill-accent: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied-viewer:hover, .main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied-viewer:focus-visible {
  --token-pill-border: var(--color-accent-error);
  --token-pill-foreground: var(--color-foreground-error);
  --token-pill-accent: var(--color-foreground-error);
}
.main_ui_workspace_tokens_management_token_tree__token-tree-wrapper {
  --node-spacing: var(--sp-s);
  padding-block-end: var(--sp-s);
  display: flex;
  flex-wrap: wrap;
  padding-inline-start: calc(var(--node-spacing));
  gap: var(--sp-xs);
}
.main_ui_workspace_tokens_management_token_tree__token-tree-wrapper .main_ui_workspace_tokens_management_token_tree__node-parent {
  flex: 1 0 100%;
}
.main_ui_workspace_tokens_management_token_tree__token-tree-wrapper .main_ui_workspace_tokens_management_token_tree__node-parent:last-of-type + * {
  margin-block-end: var(--sp-s);
}
.main_ui_workspace_tokens_management_token_tree__token-tree-wrapper .main_ui_workspace_tokens_management_token_tree__token-pill {
  flex: 0 0 auto;
}

.main_ui_workspace_tokens_management_token_tree__node-parent {
  margin-block-end: 0;
}

.main_ui_workspace_tokens_management_token_tree__folder-children-wrapper {
  margin-inline-start: var(--sp-s);
  padding-inline-start: var(--sp-s);
  border-inline-start: 0.125rem solid var(--color-background-quaternary);
}
.main_ui_workspace_tokens_management_token_tree__folder-children-wrapper:has(> button) {
  display: flex;
  flex-wrap: wrap;
  gap: var(--sp-xs);
}
.main_ui_workspace_tokens_management_token_tree__folder-children-wrapper .main_ui_workspace_tokens_management_token_tree__node-parent {
  flex: 1 0 100%;
}
.main_ui_workspace_tokens_management_token_tree__folder-children-wrapper .main_ui_workspace_tokens_management_token_tree__node-parent:last-of-type {
  margin-block-end: var(--sp-s);
}
.main_ui_workspace_tokens_management_token_tree__folder-children-wrapper .main_ui_workspace_tokens_management_token_tree__token-pill {
  flex: 0 0 auto;
}
.main_ui_workspace_tokens_management_forms_generic_form__form-wrapper {
  width: 24rem;
  position: relative;
}

.main_ui_workspace_tokens_management_forms_generic_form__token-rows {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_workspace_tokens_management_forms_generic_form__input-row {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: relative;
}

.main_ui_workspace_tokens_management_forms_generic_form__title-bar {
  display: grid;
  grid-template-columns: 1fr auto;
}

.main_ui_workspace_tokens_management_forms_generic_form__form-modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
}

.main_ui_workspace_tokens_management_forms_generic_form__button-row {
  display: grid;
  grid-template-columns: auto auto;
  justify-content: end;
  gap: var(--sp-m);
  padding-block-start: var(--sp-s);
}

.main_ui_workspace_tokens_management_forms_generic_form__with-delete {
  grid-template-columns: 1fr auto auto;
}

.main_ui_workspace_tokens_management_forms_generic_form__delete-btn {
  justify-self: start;
}
:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_workspace_tokens_management_forms_modals__token-modal-wrapper {
  border-radius: 0.25rem;
  background-color: var(--color-background-primary);
  border: 0.125rem solid var(--color-background-quaternary);
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
  box-shadow: 0 0 0.75rem 0 var(--color-shadow-dark);
  position: absolute;
  width: auto;
  min-width: auto;
  z-index: var(--z-index-set);
  overflow: hidden auto;
  padding: var(--sp-xxxl);
}
.main_ui_workspace_tokens_management_forms_modals__token-modal-wrapper.main_ui_workspace_tokens_management_forms_modals__token-modal-large {
  max-block-size: 95vh;
}

.main_ui_workspace_tokens_management_forms_modals__close-btn {
  position: absolute;
  top: 0.375rem;
  right: 0.375rem;
}
@keyframes main_ui_workspace_tokens_management_forms_rename_node_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_tokens_management_forms_rename_node_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__modal-overlay {
  --modal-title-foreground-color: var(--color-foreground-primary);
  --modal-text-foreground-color: var(--color-foreground-secondary);
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  inset-inline-start: 0;
  inset-block-start: 0;
  block-size: 100%;
  inline-size: 100%;
  background-color: var(--overlay-color);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__close-btn {
  position: absolute;
  inset-block-start: 0.375rem;
  inset-inline-end: 0.375rem;
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__modal-dialog {
  inline-size: 100%;
  max-inline-size: 32rem;
  max-block-size: unset;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  position: relative;
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__form-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__form-modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_management_forms_rename_node_modal__form-actions {
  display: flex;
  justify-content: flex-end;
  gap: var(--sp-m);
}
.main_ui_workspace_tokens_management_forms_shadow__inputs-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
  padding-inline-start: var(--sp-m);
}

.main_ui_workspace_tokens_management_forms_shadow__input-row {
  position: relative;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_management_forms_shadow__input-row-reference {
  position: relative;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
  padding-inline-start: var(--sp-m);
}

.main_ui_workspace_tokens_management_forms_shadow__title-bar {
  display: grid;
  grid-template-columns: 1fr auto auto;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_management_forms_shadow__title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
}

.main_ui_workspace_tokens_management_forms_shadow__delete-btn {
  justify-self: start;
}

.main_ui_workspace_tokens_management_forms_shadow__visible-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--color-foreground-secondary);
  line-height: 2rem;
}

.main_ui_workspace_tokens_management_forms_shadow__select-wrapper {
  display: grid;
  grid-template-columns: 1fr auto;
}
.main_ui_workspace_tokens_management_forms_typography__inputs-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
  border-inline-start: 0.0625rem solid var(--color-accent-primary-muted);
  padding-inline-start: var(--sp-m);
}

.main_ui_workspace_tokens_management_forms_typography__input-row {
  position: relative;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_tokens_management_forms_typography__title-bar {
  display: grid;
  grid-template-columns: 1fr auto;
}

.main_ui_workspace_tokens_management_forms_typography__title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown {
  position: fixed;
  max-block-size: 25rem;
  overflow-y: auto;
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3019607843) transparent;
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7019607843) transparent;
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-webkit-scrollbar {
  background: transparent;
  cursor: pointer;
  width: 0.75rem;
  height: 0.75rem;
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-webkit-scrollbar-track, .main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-webkit-scrollbar-corner {
  background: transparent;
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3019607843);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 0.5rem;
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7019607843);
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-moz-selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_workspace_tokens_management_forms_controls_combobox__dropdown::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper,
.main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper-composite {
  position: absolute;
  width: 100%;
  height: 7.1875rem;
  top: 3.375rem;
}

.main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper-composite {
  top: 2.25rem;
}
.main_ui_workspace_tokens_import_modal__import-modal-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
}

.main_ui_workspace_tokens_import_modal__import-modal-title {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_import_modal__import-description {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
  padding-inline-start: var(--sp-m);
  margin: 0;
  color: var(--color-foreground-secondary);
  list-style: disc;
}

.main_ui_workspace_tokens_import_modal__import-actions {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  justify-content: flex-end;
  gap: var(--sp-s);
}

.main_ui_workspace_tokens_import_modal__dropdown-trigger-btn {
  border-start-start-radius: 0;
  border-end-start-radius: 0;
  border-inline-start: 0.0625rem solid var(--color-accent-tertiary);
  width: var(--sp-xxxl);
  padding-inline: 0;
  justify-content: center;
}

.main_ui_workspace_tokens_import_modal__dropdown-btn {
  border-end-end-radius: 0;
  border-start-end-radius: 0;
}

.main_ui_workspace_tokens_import_modal__dropdown-btn-wrapper {
  position: relative;
  display: flex;
}
.main_ui_workspace_tokens_export_modal__export-modal-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
}

.main_ui_workspace_tokens_export_modal__export-modal-title {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_tokens_export_modal__export-preview {
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
  padding-top: var(--sp-m);
  max-width: calc(var(--modal-width) - var(--modal-padding) * 2);
}

.main_ui_workspace_tokens_export_modal__preview-label {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_tokens_export_modal__preview-container {
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: 0.5rem;
  overflow-y: auto;
  padding: var(--sp-xs) var(--sp-m);
  max-height: var(--container-max-height);
}

.main_ui_workspace_tokens_export_modal__file-list {
  width: 100%;
  margin-bottom: 0;
  overflow-y: auto;
}

.main_ui_workspace_tokens_export_modal__file-item {
  display: flex;
  align-items: center;
  width: 100%;
  cursor: default;
  color: var(--color-foreground-secondary);
  border: 0.125rem solid transparent;
}

.main_ui_workspace_tokens_export_modal__file-icon {
  flex-shrink: 0;
  display: flex;
  align-items: center;
}

.main_ui_workspace_tokens_export_modal__file-name {
  display: block;
  max-width: 99%;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  flex-grow: 1;
  padding: var(--sp-xs);
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_workspace_tokens_export_modal__export-actions {
  display: flex;
  justify-content: flex-end;
  gap: var(--sp-s);
}

.main_ui_workspace_tokens_export_modal__json-preview {
  width: 100%;
}

.main_ui_workspace_tokens_export_modal__json-preview pre {
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: 0.5rem;
  margin: 0;
  max-height: var(--container-max-height);
  overflow: auto;
  overflow-wrap: normal;
  white-space: pre;
}

.main_ui_workspace_tokens_export_modal__disabled-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  display: flex;
  align-items: center;
  justify-content: center;
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: 0.5rem;
  overflow-y: auto;
  padding: var(--sp-s) var(--sp-m);
  max-height: var(--container-max-height);
}
@keyframes main_ui_workspace_sidebar_assets__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_assets__add-library-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_workspace_sidebar_assets__add-library-button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets__add-library-button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__add-library-button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__add-library-button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_assets__add-library-button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets__add-library-button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_workspace_sidebar_assets__add-library-button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets__add-library-button.disabled, [disabled].main_ui_workspace_sidebar_assets__add-library-button, .main_ui_workspace_sidebar_assets__add-library-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_assets__libraries-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets__libraries-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets__libraries-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__libraries-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__libraries-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_assets__libraries-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets__libraries-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets__libraries-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets__libraries-button.disabled, [disabled].main_ui_workspace_sidebar_assets__libraries-button, .main_ui_workspace_sidebar_assets__libraries-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_assets__section-button.main_ui_workspace_sidebar_assets__opened {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_sidebar_assets__section-button.main_ui_workspace_sidebar_assets__opened svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_sidebar_assets__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_assets__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_assets__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_assets__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_assets__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_assets__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_assets__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_assets__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_assets__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_assets__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_assets__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_assets__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_assets__assets-bar {
  display: grid;
  grid-auto-rows: max-content;
  height: calc(100vh - 5.75rem);
  scrollbar-gutter: stable;
  overflow-y: auto;
  padding-top: 0.5rem;
}

.main_ui_workspace_sidebar_assets__libraries-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  gap: 0.125rem;
  height: 2rem;
  width: 100%;
  margin-bottom: 0.25rem;
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_assets__libraries-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_assets__libraries-button:focus {
  background-color: var(--button-secondary-background-color-focus);
  color: var(--button-secondary-foreground-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
}

.main_ui_workspace_sidebar_assets__add-library-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  gap: 0.125rem;
  height: 2rem;
  width: 100%;
  margin-bottom: 0.25rem;
  border-radius: 0.5rem;
}

.main_ui_workspace_sidebar_assets__section-button {
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  background: none;
  cursor: pointer;
  height: 2rem;
  width: 2rem;
  margin: 0;
  border: 1px solid var(--input-border-color-rest);
  border-radius: 8px 2px 2px 8px;
  background-color: var(--input-background-color-rest);
}
.main_ui_workspace_sidebar_assets__section-button svg {
  height: 1rem;
  width: 1rem;
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_assets__section-button:focus {
  border: 1px solid var(--input-border-color-focus);
  outline: 0;
  background-color: var(--input-background-color-focus);
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__section-button:focus svg {
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_assets__section-button:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_assets__section-button:hover svg {
  background-color: var(--input-background-color-hover);
  stroke: var(--button-foreground-hover);
}
.main_ui_workspace_sidebar_assets__section-button:hover:focus {
  border: 1px solid var(--input-border-color-focus);
  outline: 0;
  background-color: var(--input-background-color-focus);
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets__section-button:hover:focus svg {
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_assets__sections-container {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  top: 5.25rem;
  left: 0.75rem;
  width: 12rem;
  padding: 0.25rem;
  border-radius: 8px;
  background-color: var(--menu-background-color);
  z-index: 2;
}

.main_ui_workspace_sidebar_assets__section-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
}

.main_ui_workspace_sidebar_assets__section-btn {
  border: none;
  background: none;
  cursor: pointer;
}

.main_ui_workspace_sidebar_assets__assets-header {
  padding: 0 0 1.5rem 0.75rem;
}

.main_ui_workspace_sidebar_assets__search-wrapper {
  display: flex;
  gap: 0.25rem;
}
@keyframes main_ui_workspace_sidebar_debug__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_debug__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_debug__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_debug__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_debug__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_debug__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_debug__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_debug__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_debug__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_debug__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_debug__checkbox-icon.intermediate svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.intermediate svg, .main_ui_workspace_sidebar_debug__checkbox-icon.checked svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.checked svg, .main_ui_workspace_sidebar_debug__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_debug__checkbox-icon.intermediate svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.intermediate svg, .main_ui_workspace_sidebar_debug__checkbox-icon.checked svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.checked svg, .main_ui_workspace_sidebar_debug__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_debug__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_debug__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_debug__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_debug__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_debug__checkbox-icon, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_workspace_sidebar_debug__checkbox-icon svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_workspace_sidebar_debug__checkbox-icon:hover, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_sidebar_debug__checkbox-icon:focus, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_workspace_sidebar_debug__checkbox-icon.checked, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_workspace_sidebar_debug__checkbox-icon.checked svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_workspace_sidebar_debug__checkbox-icon.intermediate, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_workspace_sidebar_debug__checkbox-icon.intermediate svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_workspace_sidebar_debug__checkbox-icon.unchecked, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_workspace_sidebar_debug__checkbox-icon.unchecked svg, .main_ui_workspace_sidebar_debug__checkbox-wrapper label span.unchecked svg {
  display: none;
}

.main_ui_workspace_sidebar_debug__checkbox-wrapper {
  display: flex;
  align-items: center;
}
.main_ui_workspace_sidebar_debug__checkbox-wrapper label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_workspace_sidebar_debug__checkbox-wrapper label input {
  margin: 0;
}
.main_ui_workspace_sidebar_debug__checkbox-wrapper label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_sidebar_debug__checkbox-wrapper label:focus span, .main_ui_workspace_sidebar_debug__checkbox-wrapper label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_workspace_sidebar_debug__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_debug__debug-panel {
  display: flex;
  flex-direction: column;
  background-color: var(--panel-background-color);
}

.main_ui_workspace_sidebar_debug__debug-panel-title {
  margin: var(--sp-s) var(--sp-s) 0 var(--sp-s);
}

.main_ui_workspace_sidebar_debug__debug-panel-inner {
  padding: 1rem 0.5rem;
}

.main_ui_workspace_sidebar_debug__checkbox-wrapper {
  height: 2rem;
  padding: 0;
}

.main_ui_workspace_sidebar_debug__checkbox-icon {
  cursor: pointer;
}
@keyframes main_ui_workspace_sidebar_debug_shape_info__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_debug_shape_info__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_debug_shape_info__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_debug_shape_info__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_debug_shape_info__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_debug_shape_info__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_debug_shape_info__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_debug_shape_info__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_debug_shape_info__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_debug_shape_info__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_debug_shape_info__shape-info {
  display: flex;
  flex-direction: column;
  background-color: var(--panel-background-color);
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
}

.main_ui_workspace_sidebar_debug_shape_info__shape-info-title {
  margin: var(--sp-s) var(--sp-s) 0 var(--sp-s);
}

.main_ui_workspace_sidebar_debug_shape_info__attrs-container {
  padding: 1rem 0.5rem;
  overflow: hidden;
}

.main_ui_workspace_sidebar_debug_shape_info__shape-title {
  font-size: 0.875rem;
  background: var(--color-background-quaternary);
  color: var(--color-foreground-primary);
  padding: 0.5rem;
  border-radius: 0.5rem;
  display: flex;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_debug_shape_info__shape-name {
  flex: 1;
}

.main_ui_workspace_sidebar_debug_shape_info__attrs-container-attr {
  display: grid;
  grid-template-columns: 25% auto;
  padding: 0.25rem 0;
}
.main_ui_workspace_sidebar_debug_shape_info__attrs-container-attr.main_ui_workspace_sidebar_debug_shape_info__vertical-layout {
  grid-template-columns: auto;
  grid-template-rows: auto 1fr;
}

.main_ui_workspace_sidebar_debug_shape_info__shape-attrs {
  overflow: auto;
  height: calc(100% - 8px);
  padding-bottom: 8px;
}

.main_ui_workspace_sidebar_debug_shape_info__shape-link {
  color: var(--color-foreground-primary);
  text-decoration: underline;
}

.main_ui_workspace_sidebar_debug_shape_info__shape-list {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_debug_shape_info__point-list {
  display: flex;
  gap: 0.5rem;
}

.main_ui_workspace_sidebar_debug_shape_info__cell-container {
  display: grid;
  grid-template-columns: 100px 1fr;
}
@keyframes main_ui_workspace_sidebar_history__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_history__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_history__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_history__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_history__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_history__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_history__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_history__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_history__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_history__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-icon svg, .main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button svg, .main_ui_workspace_sidebar_history__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-icon svg, .main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button svg, .main_ui_workspace_sidebar_history__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_history__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_history__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_history__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_history__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_history__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_history__history-toolbox {
  display: flex;
  flex-direction: column;
  background-color: var(--panel-background-color);
}

.main_ui_workspace_sidebar_history__history-entry-empty {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) auto;
  inline-size: 12.5rem;
}

.main_ui_workspace_sidebar_history__history-entries {
  height: calc(100vh - 6.25rem);
  padding: 0.75rem;
  overflow: hidden auto;
  font-size: 0.75rem;
}

.main_ui_workspace_sidebar_history__history-entry {
  display: flex;
  justify-content: center;
  flex-direction: column;
  min-height: 2rem;
  margin: 0.25rem;
  padding: 0.25rem 0.5rem;
  border: 0.125rem solid transparent;
  border-radius: 0.5rem;
  background-color: var(--entry-background-color);
  cursor: pointer;
  transition: border 0.2s;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary {
  display: flex;
  align-items: center;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-icon svg {
  stroke: var(--entry-foreground-color);
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-text {
  display: flex;
  flex-direction: column;
  gap: 0.125rem;
  margin: 0 0.5rem;
  color: var(--color-foreground-primary);
  min-inline-size: 0;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-title {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-meta {
  color: var(--color-foreground-secondary);
  font-size: 0.625rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-hash {
  font-family: monospace;
  letter-spacing: 0.03em;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-meta-sep {
  opacity: 0.6;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-time {
  white-space: nowrap;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-author {
  white-space: nowrap;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button {
  opacity: 0;
  margin-left: auto;
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button.main_ui_workspace_sidebar_history__button-opened svg {
  transform: rotate(90deg);
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button svg {
  stroke: var(--entry-foreground-color);
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-detail {
  display: block;
  padding-top: 1rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_workspace_sidebar_history__history-entry .main_ui_workspace_sidebar_history__history-entry-detail .main_ui_workspace_sidebar_history__history-entry-details-list {
  margin: 0;
}
.main_ui_workspace_sidebar_history__history-entry.main_ui_workspace_sidebar_history__disabled {
  border-color: var(--entry-border-color-disabled);
  background-color: var(--entry-background-color-disabled);
}
.main_ui_workspace_sidebar_history__history-entry.main_ui_workspace_sidebar_history__hover, .main_ui_workspace_sidebar_history__history-entry:hover {
  background-color: var(--entry-background-color-hover);
  color: var(--entry-foreground-color-hover);
}
.main_ui_workspace_sidebar_history__history-entry.main_ui_workspace_sidebar_history__hover .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-icon svg, .main_ui_workspace_sidebar_history__history-entry:hover .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-icon svg {
  stroke: var(--entry-foreground-color-hover);
}
.main_ui_workspace_sidebar_history__history-entry.main_ui_workspace_sidebar_history__hover .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button, .main_ui_workspace_sidebar_history__history-entry:hover .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button {
  opacity: 1;
}
.main_ui_workspace_sidebar_history__history-entry.main_ui_workspace_sidebar_history__hover .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button.main_ui_workspace_sidebar_history__button-opened svg, .main_ui_workspace_sidebar_history__history-entry:hover .main_ui_workspace_sidebar_history__history-entry-summary .main_ui_workspace_sidebar_history__history-entry-summary-button.main_ui_workspace_sidebar_history__button-opened svg {
  transform: rotate(90deg);
}
.main_ui_workspace_sidebar_layer_item__layer-row {
  --layer-indentation-size: var(--sp-xxl);
  --layer-background-color: var(--color-background-primary);
  --layer-foreground-color: inherit;
  --shadow-color: transparent;
  box-shadow: 1rem 0rem 0rem 0rem var(--shadow-color);
  display: flex;
  flex-direction: row;
  align-items: center;
  inline-size: 100%;
  background-color: var(--layer-background-color);
  border: 0.125rem solid transparent;
  color: var(--layer-foreground-color);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight, .main_ui_workspace_sidebar_layer_item__layer-row:hover {
  --layer-background-color: var(--color-background-secondary);
  --shadow-color: var(--color-background-secondary);
  --context-hover-color: var(--layer-row-foreground-color-hover);
  --context-hover-opacity: 1;
  --layer-foreground-color: var(--layer-row-foreground-color-hover);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight.main_ui_workspace_sidebar_layer_item__hidden, .main_ui_workspace_sidebar_layer_item__layer-row:hover.main_ui_workspace_sidebar_layer_item__hidden {
  opacity: 1;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected {
  --layer-background-color: var(--color-background-quaternary);
  --shadow-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected.main_ui_workspace_sidebar_layer_item__highlight, .main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected:hover {
  --layer-background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_layer_item__parent-selected .main_ui_workspace_sidebar_layer_item__layer-row {
  --layer-background-color: var(--color-background-tertiary);
  --shadow-color: var(--color-background-tertiary);
}
.main_ui_workspace_sidebar_layer_item__parent-selected .main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight, .main_ui_workspace_sidebar_layer_item__parent-selected .main_ui_workspace_sidebar_layer_item__layer-row:hover {
  --layer-background-color: var(--color-background-secondary);
  --shadow-color: var(--color-background-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__dnd-over-bot {
  border-block-end: 0.125rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__dnd-over-top {
  border-block-start: 0.125rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__dnd-over {
  border: 0.125rem solid var(--color-accent-primary);
}

.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__element-children, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__element-children {
  --layer-background-color: var(--color-background-quaternary);
  --shadow-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__type-comp .main_ui_workspace_sidebar_layer_item__element-children {
  --layer-foreground-color: var(--color-accent-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__element-children {
  --layer-background-color: transparent;
  --layer-foreground-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_layer_item__element-list-body {
  align-items: center;
  display: grid;
  grid-template-columns: auto 1fr auto;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  block-size: 2rem;
  inline-size: calc(100% - var(--depth) * var(--layer-indentation-size));
  cursor: pointer;
  min-inline-size: 8.75rem;
}
.main_ui_workspace_sidebar_layer_item__element-list-body.main_ui_workspace_sidebar_layer_item__filtered {
  inline-size: calc(100% - 0.75rem);
}

.main_ui_workspace_sidebar_layer_item__element-actions {
  display: flex;
  align-items: end;
  position: sticky;
  inset-inline-end: 0;
  block-size: 2rem;
}
.main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected {
  display: flex;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__element-actions, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__element-actions {
  display: flex;
}

.main_ui_workspace_sidebar_layer_item__button-content {
  display: flex;
  block-size: 100%;
}

.main_ui_workspace_sidebar_layer_item__icon-shape {
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  background: none;
  cursor: pointer;
  position: relative;
  justify-self: flex-end;
  block-size: 100%;
  inline-size: 1.5rem;
  padding-inline-start: var(--sp-xs);
  color: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__icon-shape {
  color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__type-comp .main_ui_workspace_sidebar_layer_item__icon-shape {
  color: var(--color-accent-secondary);
}
.main_ui_workspace_sidebar_layer_item__inverse .main_ui_workspace_sidebar_layer_item__icon-shape {
  transform: rotate(-90deg);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__hidden .main_ui_workspace_sidebar_layer_item__icon-shape {
  opacity: 0.7;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__icon-shape, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__icon-shape {
  opacity: 1;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__icon-shape svg, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__icon-shape svg {
  stroke: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_layer_item__absolute {
  position: absolute;
  background-color: var(--color-foreground-secondary);
  opacity: 0.4;
  inline-size: 0.75rem;
  block-size: 0.75rem;
  border-radius: 0.125rem;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__hidden .main_ui_workspace_sidebar_layer_item__absolute {
  opacity: 0.1;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__type-comp .main_ui_workspace_sidebar_layer_item__absolute {
  background-color: var(--color-accent-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__absolute, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__absolute {
  opacity: 0.4;
  background-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__absolute {
  background-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_layer_item__toggle-content {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  grid-template-columns: 1fr 1fr;
  align-items: center;
  block-size: 100%;
  inline-size: 1.5rem;
  padding-inline-start: var(--sp-s);
}
.main_ui_workspace_sidebar_layer_item__toggle-content svg {
  display: flex;
  justify-content: center;
  align-items: center;
  color: transparent;
  fill: none;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke-width: 1.33px;
  stroke: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__hidden .main_ui_workspace_sidebar_layer_item__toggle-content svg {
  opacity: 0.7;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-content svg {
  stroke: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__type-comp .main_ui_workspace_sidebar_layer_item__toggle-content svg {
  stroke: var(--color-accent-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__toggle-content svg, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__toggle-content svg {
  opacity: 1;
  stroke: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-content {
  background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_layer_item__toggle-content.main_ui_workspace_sidebar_layer_item__inverse svg {
  transform: rotate(90deg);
}

.main_ui_workspace_sidebar_layer_item__toggle-element,
.main_ui_workspace_sidebar_layer_item__block-element {
  --layer-row-action-btn-background: none;
  border: none;
  cursor: pointer;
  justify-content: center;
  align-items: center;
  block-size: 100%;
  inline-size: 1.5rem;
  margin: 0;
  display: none;
  background: var(--layer-row-action-btn-background);
  padding-inline-end: 0.375rem;
}
.main_ui_workspace_sidebar_layer_item__toggle-element svg,
.main_ui_workspace_sidebar_layer_item__block-element svg {
  display: flex;
  justify-content: center;
  align-items: center;
  color: transparent;
  fill: none;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke-width: 1.33px;
  stroke: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__hidden .main_ui_workspace_sidebar_layer_item__toggle-element svg,
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__hidden .main_ui_workspace_sidebar_layer_item__block-element svg {
  opacity: 0.7;
}
.main_ui_workspace_sidebar_layer_item__type-comp .main_ui_workspace_sidebar_layer_item__toggle-element svg,
.main_ui_workspace_sidebar_layer_item__type-comp .main_ui_workspace_sidebar_layer_item__block-element svg {
  stroke: var(--color-accent-secondary);
}
.main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-element,
.main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__block-element {
  display: flex;
  opacity: 0;
}
.main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-element.main_ui_workspace_sidebar_layer_item__selected,
.main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__block-element.main_ui_workspace_sidebar_layer_item__selected {
  opacity: 1;
}
.main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-element,
.main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__element-actions.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__block-element {
  opacity: 1;
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__toggle-element, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__toggle-element,
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__block-element,
.main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__block-element {
  display: flex;
  --layer-row-action-btn-background: var(--color-background-secondary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__toggle-element svg, .main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__toggle-element svg,
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__highlight .main_ui_workspace_sidebar_layer_item__block-element svg,
.main_ui_workspace_sidebar_layer_item__layer-row:hover .main_ui_workspace_sidebar_layer_item__block-element svg {
  opacity: 1;
  stroke: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-element,
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__block-element {
  display: flex;
  --layer-row-action-btn-background: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__toggle-element svg,
.main_ui_workspace_sidebar_layer_item__layer-row.main_ui_workspace_sidebar_layer_item__selected .main_ui_workspace_sidebar_layer_item__block-element svg {
  stroke: var(--color-accent-primary);
}

.sticky {
  position: sticky;
  inset-block-start: 0;
  z-index: 4;
}

.main_ui_workspace_sidebar_layer_item__tab-indentation {
  display: block;
  block-size: 1rem;
  min-inline-size: calc(var(--depth) * var(--layer-indentation-size));
}

.main_ui_workspace_sidebar_layer_item__filtered {
  min-inline-size: 0.75rem;
}

.main_ui_workspace_sidebar_layer_item__lazy-load-sentinel {
  min-height: 1px;
  pointer-events: none;
}

.main_ui_workspace_sidebar_layer_item__lazy-load-sentinel {
  min-height: 1px;
  pointer-events: none;
}
@keyframes main_ui_workspace_sidebar_layer_name__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_layer_name__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_layer_name__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_layer_name__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_layer_name__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_layer_name__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_layer_name__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_layer_name__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_layer_name__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_layer_name__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_layer_name__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_layer_name__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_layer_name__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_layer_name__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_layer_name__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_layer_name__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_layer_name__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_layer_name__element-name {
  --element-name-color: var(--context-hover-color, var(--layer-row-foreground-color));
  --element-name-comp-color: var(--context-hover-color, var(--layer-row-component-foreground-color));
  --element-name-opacity: var(--context-hover-opacity, deprecated.$op-7);
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--element-name-color);
  flex-grow: 1;
  block-size: 100%;
  align-content: center;
  min-inline-size: var(--sp-xl);
}
.main_ui_workspace_sidebar_layer_name__element-name.main_ui_workspace_sidebar_layer_name__selected {
  color: var(--layer-row-foreground-color-selected);
}
.main_ui_workspace_sidebar_layer_name__element-name.main_ui_workspace_sidebar_layer_name__type-comp {
  color: var(--element-name-comp-color);
}
.main_ui_workspace_sidebar_layer_name__element-name.main_ui_workspace_sidebar_layer_name__type-comp.main_ui_workspace_sidebar_layer_name__hidden {
  opacity: var(--element-name-opacity);
}
.main_ui_workspace_sidebar_layer_name__element-name.main_ui_workspace_sidebar_layer_name__hidden {
  opacity: var(--element-name-opacity);
}

.main_ui_workspace_sidebar_layer_name__element-name-input {
  --element-name-input-border-color: var(--input-border-color-focus);
  --element-name-input-color: var(--layer-row-foreground-color);
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border: none;
  background: none;
  outline: none;
  flex-grow: 1;
  height: 1.75rem;
  max-inline-size: calc(var(--parent-size) - var(--depth) * var(--layer-indentation-size));
  margin: 0;
  padding-inline-start: 0.375rem;
  border-radius: 8px;
  border: 1px solid var(--element-name-input-border-color);
  color: var(--element-name-input-color);
}
.main_ui_workspace_sidebar_layer_name__element-name-input.main_ui_workspace_sidebar_layer_name__selected {
  min-inline-size: 6.25rem;
}

.main_ui_workspace_sidebar_layer_name__element-name-touched {
  --element-name-touched-color: var(--layer-row-component-foreground-color);
  color: var(--element-name-touched-color);
}
@keyframes main_ui_workspace_sidebar_layers__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_layers__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_layers__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_layers__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_layers__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_layers__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_layers__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_layers__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_layers__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_layers__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_layers__layer-filter {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_sidebar_layers__layer-filter:focus-visible {
  outline: none;
  background-color: var(--button-background-color-focus);
  border: 1px solid var(--button-border-color-focus);
  color: var(--button-foreground-color-focus);
}
.main_ui_workspace_sidebar_layers__layer-filter:focus-visible svg {
  stroke: var(--button-foreground-color-focus);
}
.main_ui_workspace_sidebar_layers__layer-filter:hover svg {
  stroke: var(--title-foreground-color-hover);
}
.main_ui_workspace_sidebar_layers__layer-filter:active {
  border: none;
  background-color: transparent;
}

.main_ui_workspace_sidebar_layers__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_layers__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_layers__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_layers__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_layers__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_layers__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_layers__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_layers__filters-container {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_workspace_sidebar_layers__element-list {
  display: grid;
  position: relative;
}

.main_ui_workspace_sidebar_layers__tool-window-bar {
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: var(--sp-xs);
  margin: var(--sp-m) var(--sp-m) 0 var(--sp-m);
}

.main_ui_workspace_sidebar_layers__tool-window-bar-title {
  margin-block-end: var(--sp-s);
}

.main_ui_workspace_sidebar_layers__tool-window-content {
  --calculated-height: calc(8.5rem + var(--height, 12.5rem));
  display: flex;
  flex-direction: column;
  block-size: calc(100vh - var(--calculated-height));
  inline-size: calc(var(--left-sidebar-width) + var(--depth) * var(--layer-indentation-size));
  overflow: auto;
  scrollbar-gutter: stable;
}

.main_ui_workspace_sidebar_layers__filter-button {
  border-start-end-radius: 0;
  border-end-end-radius: 0;
}

.main_ui_workspace_sidebar_layers__focus-title {
  border: none;
  background: none;
  block-size: var(--sp-xxxl);
  inline-size: 100%;
  display: grid;
  grid-template-columns: auto 1fr auto;
  align-items: center;
  margin-block-end: var(--sp-s);
  padding: 0;
}

.main_ui_workspace_sidebar_layers__focus-back-button {
  display: flex;
  align-items: center;
  justify-content: center;
  block-size: var(--sp-xxxl);
  padding-inline-start: var(--sp-s);
  color: var(--icon-foreground);
}

.main_ui_workspace_sidebar_layers__focus-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  padding-inline-end: var(--sp-xs);
  color: var(--title-foreground-color);
}

.main_ui_workspace_sidebar_layers__focus-mode-tag-wrapper {
  display: flex;
  align-items: center;
  justify-content: center;
  block-size: 100%;
  margin-inline-end: var(--sp-m);
}

.main_ui_workspace_sidebar_layers__active-filters {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  flex-wrap: wrap;
  margin: 0 var(--sp-m);
}

.main_ui_workspace_sidebar_layers__layer-filter {
  gap: 0.375rem;
  block-size: var(--sp-xxl);
  margin: var(--sp-xxs) 0;
  border-radius: 0.375rem;
  background-color: var(--pill-background-color);
}

.main_ui_workspace_sidebar_layers__layer-filter-icon,
.main_ui_workspace_sidebar_layers__layer-filter-close {
  color: var(--pill-foreground-color);
}

.main_ui_workspace_sidebar_layers__layer-filter-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: center;
  color: var(--pill-foreground-color);
}

.main_ui_workspace_sidebar_layers__layers {
  position: relative;
}

.main_ui_workspace_sidebar_layers__replace-wrapper {
  display: flex;
  flex-direction: column;
  padding: var(--sp-xs) var(--sp-m);
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_layers__replace-row {
  display: flex;
  flex-direction: row;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_layers__replace-scope-row {
  display: flex;
  gap: var(--sp-l);
  align-items: center;
  block-size: 2rem;
}

.main_ui_workspace_sidebar_layers__replace-actions-row {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_layers__replace-actions-button {
  justify-content: center;
  flex: 1 1 0;
}

.main_ui_workspace_sidebar_layers__replace-match-navigation {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  flex-shrink: 0;
}

.main_ui_workspace_sidebar_layers__replace-match-count {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  white-space: nowrap;
  display: flex;
  align-items: center;
  padding: 0 var(--sp-xs);
}

.main_ui_workspace_sidebar_layers__radio-label {
  display: flex;
  align-items: center;
  gap: 0.375rem;
}
.main_ui_workspace_sidebar_layers__radio-label.main_ui_workspace_sidebar_layers__selected .main_ui_workspace_sidebar_layers__radio-text {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_layers__radio-icon {
  block-size: var(--sp-m);
  inline-size: var(--sp-m);
  border: 0.0625rem solid var(--color-foreground-secondary);
  border-radius: 50%;
  background-color: transparent;
  flex-shrink: 0;
}
.main_ui_workspace_sidebar_layers__radio-icon.main_ui_workspace_sidebar_layers__checked {
  border-color: var(--color-accent-primary);
  background-color: var(--color-accent-primary);
  box-shadow: inset 0 0 0 var(--sp-xxs) var(--color-background-primary);
}

.main_ui_workspace_sidebar_layers__radio-input {
  display: none;
}

.main_ui_workspace_sidebar_layers__radio-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_layers__filters-container {
  position: absolute;
  inline-size: 12rem;
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: space-between;
  inline-size: 100%;
  padding: 0.375rem;
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper .main_ui_workspace_sidebar_layers__filter-menu-item-icon {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper .main_ui_workspace_sidebar_layers__filter-menu-item-name {
  padding-block-start: var(--sp-xxs);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item .main_ui_workspace_sidebar_layers__filter-menu-item-tick {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item.main_ui_workspace_sidebar_layers__selected {
  background-color: var(--menu-background-color-selected);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item.main_ui_workspace_sidebar_layers__selected .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper .main_ui_workspace_sidebar_layers__filter-menu-item-icon {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item.main_ui_workspace_sidebar_layers__selected .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper .main_ui_workspace_sidebar_layers__filter-menu-item-name {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item.main_ui_workspace_sidebar_layers__selected .main_ui_workspace_sidebar_layers__filter-menu-item-tick {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item:hover {
  background-color: var(--menu-background-color-hover);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item:hover .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper .main_ui_workspace_sidebar_layers__filter-menu-item-icon {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item:hover .main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper .main_ui_workspace_sidebar_layers__filter-menu-item-name {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_layers__filters-container .main_ui_workspace_sidebar_layers__filter-menu-item:hover .main_ui_workspace_sidebar_layers__filter-menu-item-tick {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options__tool-window {
  position: relative;
  display: grid;
  width: 100%;
  height: 100%;
}

.main_ui_workspace_sidebar_options__tab-spacing {
  margin-inline-end: var(--sp-m);
}

.main_ui_workspace_sidebar_options__content-class {
  overflow: hidden auto;
  height: calc(100vh - 6rem);
  scrollbar-gutter: stable;
}

.main_ui_workspace_sidebar_options__element-options {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
  width: 100%;
  /* FIXME: This is hacky and prone to break, we should tackle the whole layout
            of the sidebar differently */
  --sidebar-element-options-height: calc(100vh - 5.5rem);
  height: var(--sidebar-element-options-height);
  padding-block-start: var(--sp-s);
}

.main_ui_workspace_sidebar_options__read-only {
  grid-template-areas: "right-sidebar";
  padding: var(--sp-s);
}

.main_ui_workspace_sidebar_options__design-options,
.main_ui_workspace_sidebar_options__interaction-options {
  overflow: auto;
  scrollbar-gutter: stable;
}

.main_ui_workspace_sidebar_options__design-options {
  padding-inline: var(--sp-m);
}

.main_ui_workspace_sidebar_options__inspect {
  scrollbar-gutter: unset;
}

.main_ui_workspace_sidebar_options__options-tab-switcher {
  --tabs-nav-padding-inline-start: var(--sp-m);
  --tabs-nav-padding-inline-end: var(--sp-m);
}
@keyframes main_ui_workspace_sidebar_shortcuts__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_shortcuts__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_shortcuts__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_shortcuts__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_shortcuts__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_shortcuts__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_shortcuts__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_shortcuts__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_shortcuts__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_shortcuts__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_shortcuts__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_shortcuts__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_shortcuts__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_shortcuts__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_shortcuts__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_shortcuts__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_shortcuts__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_shortcuts__shortcuts {
  display: grid;
  grid-template-rows: auto auto 1fr;
  height: calc(100vh - 3.75rem);
}

.main_ui_workspace_sidebar_shortcuts__search-field {
  margin: 1rem 0.75rem 0.25rem 0.75rem;
}

.main_ui_workspace_sidebar_shortcuts__shortcuts-title {
  margin: var(--sp-s) var(--sp-s) 0 var(--sp-s);
}

.main_ui_workspace_sidebar_shortcuts__section {
  margin: 0;
}

.main_ui_workspace_sidebar_shortcuts__not-found {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--empty-message-foreground-color);
  margin: 0.75rem;
}

.main_ui_workspace_sidebar_shortcuts__shortcuts-list {
  display: flex;
  flex-direction: column;
  height: 100%;
  padding: 0.75rem;
  overflow-y: auto;
  font-size: 0.75rem;
  color: var(--title-foreground-color);
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__section-title,
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__subsection-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  display: flex;
  align-items: center;
  margin: 0;
  padding: 0.5rem 0;
  cursor: pointer;
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__section-title .main_ui_workspace_sidebar_shortcuts__subsection-name,
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__section-title .main_ui_workspace_sidebar_shortcuts__section-name,
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__subsection-title .main_ui_workspace_sidebar_shortcuts__subsection-name,
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__subsection-title .main_ui_workspace_sidebar_shortcuts__section-name {
  padding-left: 0.25rem;
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__section-title:hover,
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__subsection-title:hover {
  color: var(--title-foreground-color-hover);
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__subsection-title {
  text-transform: none;
  padding-left: 0.75rem;
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__subsection-menu {
  margin-bottom: 0.25rem;
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__sub-menu {
  margin-bottom: 0.25rem;
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__sub-menu .main_ui_workspace_sidebar_shortcuts__shortcuts-name {
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  min-height: 2rem;
  padding: 0.375rem;
  margin-bottom: 0.25rem;
  border-radius: 8px;
  background-color: var(--pill-background-color);
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__sub-menu .main_ui_workspace_sidebar_shortcuts__shortcuts-name .main_ui_workspace_sidebar_shortcuts__command-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-left: 0.125rem;
  color: var(--pill-foreground-color);
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__sub-menu .main_ui_workspace_sidebar_shortcuts__shortcuts-name .main_ui_workspace_sidebar_shortcuts__keys {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 0.125rem;
  color: var(--pill-foreground-color);
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__sub-menu .main_ui_workspace_sidebar_shortcuts__shortcuts-name .main_ui_workspace_sidebar_shortcuts__keys .main_ui_workspace_sidebar_shortcuts__key {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  justify-content: center;
  align-items: center;
  text-transform: capitalize;
  height: 1.25rem;
  padding: 0.125rem 0.375rem;
  border-radius: 0.375rem;
  background-color: var(--menu-shortcut-background-color);
}
.main_ui_workspace_sidebar_shortcuts__shortcuts-list .main_ui_workspace_sidebar_shortcuts__sub-menu .main_ui_workspace_sidebar_shortcuts__shortcuts-name .main_ui_workspace_sidebar_shortcuts__keys .main_ui_workspace_sidebar_shortcuts__space {
  margin: 0 0.125rem;
}
@keyframes main_ui_workspace_sidebar_sitemap__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_sitemap__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_sitemap__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_sitemap__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_sitemap__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_sitemap__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_sitemap__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_sitemap__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_sitemap__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_sitemap__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_sitemap__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_sitemap__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_sitemap__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_sitemap__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_sitemap__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_sitemap__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_sitemap__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_sitemap__sitemap {
  position: relative;
  display: flex;
  flex-direction: column;
  flex: 1;
  width: 100%;
  height: var(--height, 12.5rem);
}

.main_ui_workspace_sidebar_sitemap__title {
  margin-left: 0.125rem;
  color: var(--title-foreground-color-hover);
}

.main_ui_workspace_sidebar_sitemap__resize-area {
  position: absolute;
  bottom: calc(-1 * 0.5rem);
  left: 0;
  width: 100%;
  height: 0.75rem;
  border-top: 0.125rem solid var(--resize-area-border-color);
  background-color: var(--resize-area-background-color);
  cursor: ns-resize;
}
.main_ui_workspace_sidebar_sitemap__resize-area:hover {
  border-color: var(--resize-area-border-color);
}

.main_ui_workspace_sidebar_sitemap__tool-window-content {
  display: flex;
  flex-direction: column;
  height: calc(-38px + var(--height, 12.5rem));
  width: var(--left-sidebar-width);
  overflow: hidden auto;
  scrollbar-gutter: stable;
}
.main_ui_workspace_sidebar_sitemap__tool-window-content .main_ui_workspace_sidebar_sitemap__element-list {
  display: grid;
}

.main_ui_workspace_sidebar_sitemap__pages-list {
  width: 100%;
  max-height: 9.5rem;
  margin-bottom: 0.75rem;
}

.main_ui_workspace_sidebar_sitemap__page-delete-button {
  --delete-button-display: none;
}

.main_ui_workspace_sidebar_sitemap__page-delete-button-icon {
  display: var(--delete-button-display);
}

.main_ui_workspace_sidebar_sitemap__page-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  min-height: 2rem;
  width: 100%;
  cursor: pointer;
}
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__dnd-over-top {
  border-top: 1px solid var(--layer-row-foreground-color-drag);
}
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__dnd-over-bot {
  border-bottom: 1px solid var(--layer-row-foreground-color-drag);
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__dnd-over > .main_ui_workspace_sidebar_sitemap__element-list-body {
  border: 1px solid var(--layer-row-foreground-color-drag);
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__element-list-body {
  display: flex;
  align-items: center;
  height: 2rem;
  width: 100%;
  padding: 0 0.75rem 0 0;
  transition: none;
  color: var(--layer-row-foreground-color);
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  padding-left: 0.125rem;
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 0 0.25rem 0 0.5rem;
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-actions {
  height: 2rem;
  display: flex;
  align-items: center;
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__element-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--layer-row-foreground-color-focus);
}
.main_ui_workspace_sidebar_sitemap__page-element .main_ui_workspace_sidebar_sitemap__element-list-body input.main_ui_workspace_sidebar_sitemap__element-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border: none;
  background: none;
  outline: none;
  flex-grow: 1;
  height: 1.75rem;
  max-width: calc(var(--parent-size) - var(--depth) * var(--layer-indentation-size));
  padding-left: 0.375rem;
  margin: 0;
  border-radius: 8px;
  border: 1px solid var(--input-border-color-focus);
  color: var(--layer-row-foreground-color);
}
.main_ui_workspace_sidebar_sitemap__page-element:active .main_ui_workspace_sidebar_sitemap__element-list-body, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__on-drag .main_ui_workspace_sidebar_sitemap__element-list-body {
  color: var(--layer-row-foreground-color-drag);
  background-color: var(--layer-row-background-color-drag);
}
.main_ui_workspace_sidebar_sitemap__page-element:active .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__on-drag .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg {
  stroke: var(--layer-row-foreground-color-drag);
}
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__selected .main_ui_workspace_sidebar_sitemap__element-list-body, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__selected:hover .main_ui_workspace_sidebar_sitemap__element-list-body {
  color: var(--layer-row-foreground-color-selected);
  background-color: var(--layer-row-background-color-selected);
  box-shadow: 1rem 0px 0px 0px var(--layer-row-background-color-selected);
}
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__selected .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__selected:hover .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg {
  stroke: var(--layer-row-foreground-color-selected);
}
.main_ui_workspace_sidebar_sitemap__page-element:hover .main_ui_workspace_sidebar_sitemap__element-list-body, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__hover .main_ui_workspace_sidebar_sitemap__element-list-body {
  color: var(--layer-row-foreground-color-hover);
  background-color: var(--layer-row-background-color-hover);
  box-shadow: 1rem 0px 0px 0px var(--layer-row-background-color-hover);
}
.main_ui_workspace_sidebar_sitemap__page-element:hover .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-actions button, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__hover .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-actions button {
  opacity: 1;
  --delete-button-display: initial;
}
.main_ui_workspace_sidebar_sitemap__page-element:hover .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg, .main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__hover .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg {
  stroke: var(--layer-row-foreground-color-hover);
}
.main_ui_workspace_sidebar_sitemap__page-element:focus .main_ui_workspace_sidebar_sitemap__element-list-body {
  color: var(--layer-row-foreground-color-focus);
  border: 1px solid var(--layer-row-border-color-focus);
  outline: none;
}
.main_ui_workspace_sidebar_sitemap__page-element:focus .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-actions button {
  opacity: 1;
}
.main_ui_workspace_sidebar_sitemap__page-element:focus-within .main_ui_workspace_sidebar_sitemap__element-list-body {
  outline: none;
}
.main_ui_workspace_sidebar_sitemap__page-element:focus-within .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-actions button {
  opacity: 1;
}
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__hidden .main_ui_workspace_sidebar_sitemap__element-list-body {
  color: var(--layer-row-foreground-color-hidden);
  background-color: var(--layer-row-background-color-hidden);
  opacity: 0.7;
}
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__hidden .main_ui_workspace_sidebar_sitemap__element-list-body .main_ui_workspace_sidebar_sitemap__page-icon svg {
  stroke: var(--layer-row-foreground-color-hidden);
}

.main_ui_workspace_sidebar_sitemap__element-list-body.main_ui_workspace_sidebar_sitemap__separator-body {
  height: auto;
  min-height: var(--sp-xxxl);
  padding: 0;
}

.main_ui_workspace_sidebar_sitemap__page-separator {
  width: 100%;
  height: 0.0625rem;
  margin: var(--sp-s);
  background-color: var(--color-background-quaternary);
}

.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__separator:hover .main_ui_workspace_sidebar_sitemap__element-list-body,
.main_ui_workspace_sidebar_sitemap__page-element.main_ui_workspace_sidebar_sitemap__separator.main_ui_workspace_sidebar_sitemap__hover .main_ui_workspace_sidebar_sitemap__element-list-body {
  color: var(--layer-row-foreground-color);
  background-color: transparent;
  box-shadow: none;
}

.main_ui_workspace_sidebar_sitemap__title-spacing-sitemap {
  padding-inline-start: 0.5rem;
  margin-block: 0.5rem 0.25rem;
}
@keyframes main_ui_workspace_sidebar_versions__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_versions__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_versions__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_versions__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_versions__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_versions__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_versions__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_versions__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_versions__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_versions__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option span svg, .main_ui_workspace_sidebar_versions__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option span svg, .main_ui_workspace_sidebar_versions__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_versions__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_versions__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_versions__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_versions__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_versions__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_versions__version-options-dropdown .main_ui_workspace_sidebar_versions__menu-option:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_versions__version-options-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_workspace_sidebar_versions__version-toolbox {
  padding: 0.5rem;
  height: 100%;
  display: grid;
  overflow: hidden;
  grid-template-rows: auto auto 1fr;
}

.main_ui_workspace_sidebar_versions__versions-empty {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) auto;
  inline-size: 12.5rem;
}

.main_ui_workspace_sidebar_versions__version-save-version {
  font-weight: 600;
  text-transform: uppercase;
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  padding: 1rem 0 1rem 1rem;
  justify-content: space-between;
  width: 100%;
  display: flex;
  align-items: center;
}

.main_ui_workspace_sidebar_versions__version-save-button {
  background: none;
  border: none;
  cursor: pointer;
}

.main_ui_workspace_sidebar_versions__versions-entries {
  display: flex;
  flex-direction: column;
  gap: 0.375rem;
  overflow: auto;
  margin: 0;
}

.main_ui_workspace_sidebar_versions__version-entry {
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_versions__version-entry p {
  margin: 0;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.main_ui_workspace_sidebar_versions__version-entry:hover .main_ui_workspace_sidebar_versions__version-entry-options {
  visibility: initial;
}

.main_ui_workspace_sidebar_versions__version-entry {
  display: flex;
  padding: 0.25rem 0.25rem 0.25rem 1rem;
  gap: 0.5rem;
  border-radius: 8px;
  align-items: center;
}
.main_ui_workspace_sidebar_versions__version-entry:hover {
  border-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_versions__version-entry.main_ui_workspace_sidebar_versions__is-autosave {
  flex-direction: column;
  align-items: start;
  padding-left: 3rem;
  gap: 0;
}

.main_ui_workspace_sidebar_versions__version-entry-wrap {
  position: relative;
}

.main_ui_workspace_sidebar_versions__version-entry-avatar {
  border-radius: 50%;
  width: 1.5rem;
  height: 1.5rem;
}

.main_ui_workspace_sidebar_versions__version-entry-data {
  width: 100%;
  overflow: hidden;
  display: flex;
  flex-direction: column;
}

.main_ui_workspace_sidebar_versions__version-entry-name {
  color: var(--color-foreground-primary);
  border-bottom: 1px solid transparent;
}

.main_ui_workspace_sidebar_versions__version-entry-name-edit {
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
  background: none;
  margin: 0;
  padding: 0;
  border: none;
  outline: none;
  border-bottom: 1px solid var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_versions__version-entry-time {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_versions__version-entry-options {
  background: none;
  border: 0;
  cursor: pointer;
  visibility: hidden;
  padding: 0;
  height: 2.5rem;
  width: 2rem;
}

.main_ui_workspace_sidebar_versions__version-options-dropdown {
  position: absolute;
  width: -moz-fit-content;
  width: fit-content;
  max-width: 12.5rem;
  right: 0;
  left: unset;
  top: var(--offset);
}
.main_ui_workspace_sidebar_versions__version-entry-snapshots {
  display: flex;
  align-items: center;
  gap: 0.375rem;
  color: var(--color-foreground-secondary);
  background: none;
  border: 0;
  cursor: pointer;
  padding: 0;
}
.main_ui_workspace_sidebar_versions__version-entry-snapshots .main_ui_workspace_sidebar_versions__icon-clock {
  stroke: var(--color-accent-warning);
}
.main_ui_workspace_sidebar_versions__version-entry-snapshots .main_ui_workspace_sidebar_versions__icon-arrow {
  stroke: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_versions__version-entry-snapshots:hover {
  color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_versions__version-entry-snapshots:hover .main_ui_workspace_sidebar_versions__icon-arrow {
  stroke: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_versions__is-expanded .main_ui_workspace_sidebar_versions__version-entry-snapshots .main_ui_workspace_sidebar_versions__icon-arrow {
  transform: rotate(90deg);
}

.main_ui_workspace_sidebar_versions__version-snapshot-list {
  display: none;
  margin-top: 0.5rem;
  flex-direction: column;
  width: 100%;
}
.main_ui_workspace_sidebar_versions__version-entry.main_ui_workspace_sidebar_versions__is-expanded .main_ui_workspace_sidebar_versions__version-snapshot-list {
  display: flex;
}

.main_ui_workspace_sidebar_versions__version-snapshot-entry-wrapper {
  display: flex;
  justify-content: space-between;
  align-items: center;
  position: relative;
}
.main_ui_workspace_sidebar_versions__version-snapshot-entry-wrapper:hover .main_ui_workspace_sidebar_versions__version-snapshot-menu-btn {
  visibility: initial;
}

.main_ui_workspace_sidebar_versions__version-snapshot-entry {
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  background: none;
  border: none;
  cursor: pointer;
  padding: 0;
  display: flex;
  justify-content: space-between;
  width: 100%;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_versions__version-snapshot-entry:hover {
  color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_versions__version-snapshot-entry:active {
  color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_versions__version-snapshot-entry:active .icon-pin {
  visibility: initial;
  fill: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_versions__version-snapshot-menu-btn {
  visibility: hidden;
}

.main_ui_workspace_sidebar_versions__cta {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_versions__cta a {
  color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_common__advanced-options-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}
@keyframes main_ui_workspace_sidebar_options_page__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_page__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_page__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_page__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_page__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_page__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_page__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_page__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_page__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_page__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_page__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_page__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_page__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_page__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_page__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_page__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_page__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}
@keyframes main_ui_workspace_sidebar_options_shapes_group__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_shapes_group__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_shapes_group__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_shapes_group__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_shapes_group__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_shapes_group__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_shapes_group__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_shapes_group__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_shapes_group__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_shapes_group__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_shapes_group__options {
  width: 100%;
  display: flex;
  flex-direction: column;
  gap: 1rem;
}
@keyframes main_ui_workspace_sidebar_options_shapes_multiple__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_shapes_multiple__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_shapes_multiple__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_shapes_multiple__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_shapes_multiple__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_shapes_multiple__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_shapes_multiple__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_shapes_multiple__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_shapes_multiple__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_shapes_multiple__options {
  width: 100%;
  display: flex;
  flex-direction: column;
  gap: 1rem;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-data {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  position: relative;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-data:hover {
  --reorder-icon-visibility: visible;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-data.main_ui_workspace_sidebar_options_rows_color_row__dnd-over-top {
  --reorder-top-display: block;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-data.main_ui_workspace_sidebar_options_rows_color_row__dnd-over-bot {
  --reorder-bottom-display: block;
}

.main_ui_workspace_sidebar_options_rows_color_row__hidden {
  display: none;
}

.main_ui_workspace_sidebar_options_rows_color_row__color-info {
  --detach-icon-foreground-color: none;
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  flex: 1;
  gap: var(--sp-xxs);
  block-size: 2rem;
  border-radius: 0.5rem;
  background-color: var(--color-background-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-info:hover {
  --detach-icon-foreground-color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper {
  --color-name-wrapper-background-color: var(--color-background-tertiary);
  --color-name-wrapper-foreground-color: var(--color-foreground-primary);
  --color-name-wrapper-boder-color: var(--color-background-tertiary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  display: flex;
  align-items: center;
  flex-grow: 1;
  gap: var(--sp-xs);
  block-size: 2rem;
  min-inline-size: 0;
  inline-size: 100%;
  max-inline-size: 100%;
  padding: 0;
  margin-inline-end: 0;
  border: 0.0625rem solid var(--color-name-wrapper-boder-color);
  background-color: var(--color-name-wrapper-background-color);
  color: var(--color-name-wrapper-foreground-color);
  border-radius: 0.5rem 0 0 0.5rem;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper.main_ui_workspace_sidebar_options_rows_color_row__no-opacity {
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper.main_ui_workspace_sidebar_options_rows_color_row__no-opacity .main_ui_workspace_sidebar_options_rows_color_row__color-input-wrapper {
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:hover {
  --detach-icon-foreground-color: var(--input-foreground-color-active);
  --color-name-wrapper-background-color: var(--color-background-quaternary);
  --color-name-wrapper-boder-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:hover .main_ui_workspace_sidebar_options_rows_color_row__detach-btn {
  display: grid;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:hover.main_ui_workspace_sidebar_options_rows_color_row__editing {
  --color-name-wrapper-background-color: var(--color-background-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:hover:focus, .main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:hover:focus-within {
  --color-name-wrapper-background-color: var(--color-background-tertiary);
  --color-name-wrapper-boder-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:focus, .main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:focus-within {
  --color-name-wrapper-background-color: var(--color-background-tertiary);
  --color-name-wrapper-boder-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:focus:hover, .main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper:focus-within:hover {
  --color-name-wrapper-background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper.main_ui_workspace_sidebar_options_rows_color_row__editing {
  --color-name-wrapper-background-color: var(--color-background-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper.main_ui_workspace_sidebar_options_rows_color_row__editing:hover {
  --color-name-wrapper-boder-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_options_rows_color_row__detach-btn {
  display: none;
  background: var(--color-name-wrapper-background-color);
}

.main_ui_workspace_sidebar_options_rows_color_row__color-input-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  block-size: 1.75rem;
  inline-size: 100%;
  padding: 0;
  margin: 0;
  background-color: var(--color-name-wrapper-background-color);
  color: var(--color-name-wrapper-foreground-color);
  border-radius: 0;
}

.main_ui_workspace_sidebar_options_rows_color_row__color-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  padding-inline: 0.375rem;
  border-radius: 0.5rem;
  color: var(--color-name-wrapper-foreground-color);
}

.main_ui_workspace_sidebar_options_rows_color_row__color-bullet-wrapper {
  display: flex;
  align-items: center;
  position: relative;
  block-size: 2rem;
  padding: 0 var(--sp-xxs) 0 var(--sp-s);
  border-radius: 0.5rem 0 0 0.5rem;
  background-color: transparent;
}
.main_ui_workspace_sidebar_options_rows_color_row__color-bullet-wrapper:hover {
  background-color: transparent;
}

.main_ui_workspace_sidebar_options_rows_color_row__color-input {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  border: none;
  background: none;
  outline: none;
  block-size: 1.75rem;
  inline-size: 100%;
  flex-grow: 1;
  margin: var(--sp-xxs) 0;
  padding: 0 0 0 0.375rem;
  border-radius: 0.5rem;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_color_row__color-input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_rows_color_row__library-name-wrapper {
  border-radius: 0.5rem;
}

.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper {
  --opacity-input-background-color: var(--color-background-tertiary);
  --opacity-input-boder-color: var(--color-background-tertiary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  block-size: 2rem;
  inline-size: 3.75rem;
  padding-inline-start: var(--sp-xs);
  border-radius: 0 0.5rem 0.5rem 0;
  border: 0.0625rem solid var(--opacity-input-boder-color);
  background-color: var(--opacity-input-background-color);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:hover {
  --opacity-input-background-color: var(--color-background-quaternary);
  --opacity-input-boder-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:hover .main_ui_workspace_sidebar_options_rows_color_row__detach-btn {
  display: grid;
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:hover.main_ui_workspace_sidebar_options_rows_color_row__editing {
  --opacity-input-background-color: var(--color-background-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:hover:focus, .main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:hover:focus-within {
  --opacity-input-background-color: var(--color-background-tertiary);
  --opacity-input-boder-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:focus, .main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:focus-within {
  --opacity-input-background-color: var(--color-background-tertiary);
  --opacity-input-boder-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:focus:hover, .main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper:focus-within:hover {
  --opacity-input-background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper.main_ui_workspace_sidebar_options_rows_color_row__editing {
  --opacity-input-background-color: var(--color-background-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper.main_ui_workspace_sidebar_options_rows_color_row__editing:hover {
  --opacity-input-boder-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_options_rows_color_row__opacity-input {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  block-size: 1.75rem;
  min-inline-size: 1.75rem;
  flex-grow: 1;
  inline-size: 100%;
  border-radius: 0 0.5rem 0.5rem 0;
  border: none;
  background: none;
  outline: none;
  margin: var(--sp-xxs) 0;
  padding: 0 0 0 0.375rem;
  color: var(--color-foreground-primary);
}
.main_ui_workspace_sidebar_options_rows_color_row__opacity-input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_rows_color_row__icon-text {
  display: flex;
  justify-content: center;
  align-items: center;
  block-size: 2rem;
  margin-inline-end: var(--sp-xs);
  margin-block-start: var(--sp-xxs);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_rows_color_row__token-color-wrapper {
  --token-color-wrapper-background-color: var(--color-background-tertiary);
  --token-color-wrapper-foreground-color: var(--color-token-foreground);
  --token-color-wrapper-border-color: var(--color-token-border);
  --token-actions-display: none;
  display: grid;
  grid-template-columns: auto 1fr auto;
  gap: var(--sp-xs);
  block-size: 2rem;
  min-inline-size: 0;
  inline-size: 100%;
  padding: 0;
  margin-inline-end: 0;
  background: var(--token-color-wrapper-background-color);
  border: 0.0625rem solid var(--token-color-wrapper-border-color);
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_rows_color_row__token-color-wrapper:hover {
  --token-color-wrapper-background-color: var(--color-token-background);
  --token-color-wrapper-foreground-color: var(--color-foreground-primary);
  --token-color-wrapper-border-color: var(--color-token-accent);
  --token-actions-display: flex;
}

.main_ui_workspace_sidebar_options_rows_color_row__token-color-with-errors,
.main_ui_workspace_sidebar_options_rows_color_row__token-color-not-active {
  --token-color-wrapper-background-color: var(--color-background-primary);
  --token-color-wrapper-foreground-color: var(--color-foreground-secondary);
  --token-color-wrapper-border-color: var(--color-token-border);
}
.main_ui_workspace_sidebar_options_rows_color_row__token-color-with-errors:hover,
.main_ui_workspace_sidebar_options_rows_color_row__token-color-not-active:hover {
  --token-color-wrapper-background-color: var(--color-background-primary);
  --token-color-wrapper-foreground-color: var(--color-foreground-secondary);
  --token-color-wrapper-border-color: var(--color-token-background);
  --token-actions-display: flex;
}

.main_ui_workspace_sidebar_options_rows_color_row__token-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--token-color-wrapper-foreground-color);
  block-size: 2rem;
  line-height: 2rem;
}

.main_ui_workspace_sidebar_options_rows_color_row__token-tooltip {
  min-width: 0;
  inline-size: inherit;
}

.main_ui_workspace_sidebar_options_rows_color_row__token-name-tooltip {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_rows_color_row__token-actions {
  display: var(--token-actions-display);
  justify-self: flex-end;
  align-items: center;
}

.main_ui_workspace_sidebar_options_rows_color_row__error-dot {
  inline-size: 0.25rem;
  block-size: 0.25rem;
  border-radius: 50%;
  background-color: var(--color-foreground-error);
  margin-inline-start: var(--sp-xs);
  position: absolute;
  inset-inline-end: 0.0625rem;
  inset-block-start: 0.3125rem;
}
@keyframes main_ui_workspace_sidebar_options_rows_shadow_row__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y label svg, .main_ui_workspace_sidebar_options_rows_shadow_row__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y label svg, .main_ui_workspace_sidebar_options_rows_shadow_row__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x input[disabled],
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur input[disabled],
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread input[disabled],
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x label,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur label,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread label,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y label, .main_ui_workspace_sidebar_options_rows_shadow_row__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y span svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread label svg,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x ::-moz-placeholder, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur ::-moz-placeholder, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread ::-moz-placeholder, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x ::placeholder,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur ::placeholder,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread ::placeholder,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:active,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:active,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:active,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:active span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:active span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:active span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:active input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:active input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:active input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus span, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus input, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus:hover, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within:hover,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus:hover span, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within:hover span,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus:hover input, .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x:focus-within:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur:focus-within:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread:focus-within:hover input,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-element {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: relative;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-element:hover {
  --reorder-icon-visibility: visible;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-element.main_ui_workspace_sidebar_options_rows_shadow_row__dnd-over-top {
  --reorder-top-display: block;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-element.main_ui_workspace_sidebar_options_rows_shadow_row__dnd-over-bot {
  --reorder-bottom-display: block;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-info {
  grid-column: span 6;
  display: flex;
  align-items: center;
  gap: 0.0625rem;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-button {
  border-radius: 0.5rem 0 0 0.5rem;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-button.main_ui_workspace_sidebar_options_rows_shadow_row__selected {
  --button-bg-color: var(--color-background-quaternary);
  --button-fg-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-button:disabled {
  border: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-select {
  flex-grow: 1;
  border-radius: 0 0.5rem 0.5rem 0;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-actions {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-row {
  display: grid;
  grid-column: 1/-1;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label,
.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y .main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label {
  padding-inline-start: var(--sp-s);
  inline-size: 3.75rem;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x {
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur {
  grid-column: span 3;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread {
  grid-column: span 3;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y {
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-color {
  grid-column: span 6;
}
@keyframes main_ui_workspace_sidebar_options_rows_stroke_row__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input span svg,
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input label svg, .main_ui_workspace_sidebar_options_rows_stroke_row__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input span svg,
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input label svg, .main_ui_workspace_sidebar_options_rows_stroke_row__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input span,
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input label, .main_ui_workspace_sidebar_options_rows_stroke_row__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input span svg,
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus, .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus span, .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus input, .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus:hover, .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus:hover span, .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus:hover input, .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: relative;
  --reorder-left-position: calc(-1 * var(--sp-l));
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data:hover {
  --reorder-icon-visibility: visible;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data.main_ui_workspace_sidebar_options_rows_stroke_row__dnd-over-top {
  --reorder-top-display: block;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data.main_ui_workspace_sidebar_options_rows_stroke_row__dnd-over-bot {
  --reorder-bottom-display: block;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data.main_ui_workspace_sidebar_options_rows_stroke_row__hidden .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options,
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data.main_ui_workspace_sidebar_options_rows_stroke_row__hidden .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options-tokens,
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data.main_ui_workspace_sidebar_options_rows_stroke_row__hidden .main_ui_workspace_sidebar_options_rows_stroke_row__stroke-caps-options {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-color-actions {
  display: flex;
  align-items: center;
}
.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-color-actions > :first-child {
  flex: 1;
  min-width: 0;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  align-items: center;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input {
  grid-column: span 2;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding-inline-start: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-alignment-select {
  grid-column: span 3;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-style-select {
  grid-column: span 3;
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-caps-options {
  display: grid;
  grid-template-columns: 1fr auto 1fr;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-dash-options {
  display: grid;
  grid-template-columns: 1fr 1fr;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options-tokens {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  grid-template-columns: var(--three-columns-width) var(--grid-exception-input-width-small) var(--grid-exception-input-width-small);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-align-icon-select {
  --dropdown-width: var(--four-columns-width);
}

.main_ui_workspace_sidebar_options_rows_stroke_row__stroke-style-icon-select {
  --dropdown-width: var(--four-columns-width);
}
@keyframes main_ui_workspace_sidebar_options_menus_align__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_align__align-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_align__align-button svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_align__align-button:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_align__align-button:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_align__align-button:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_align__align-button:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_align__align-button:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_align__align-button:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_align__align-button.disabled, [disabled].main_ui_workspace_sidebar_options_menus_align__align-button, .main_ui_workspace_sidebar_options_menus_align__align-button:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_align__align-button.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_align__align-button svg, .main_ui_workspace_sidebar_options_menus_align__align-button:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_align__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_align__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_align__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_align__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_align__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_align__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_align__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_align__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_align__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_align__align-button svg, .main_ui_workspace_sidebar_options_menus_align__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_align__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_align__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_align__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_align__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_align__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_align__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_align__align-options {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  height: 2rem;
}

.main_ui_workspace_sidebar_options_menus_align__align-group-horizontal,
.main_ui_workspace_sidebar_options_menus_align__align-group-vertical {
  display: grid;
  grid-template-columns: subgrid;
  place-items: center center;
}

.main_ui_workspace_sidebar_options_menus_align__align-group-horizontal {
  grid-column: 1/span 4;
}

.main_ui_workspace_sidebar_options_menus_align__align-group-vertical {
  grid-column: 5/span 4;
}

.main_ui_workspace_sidebar_options_menus_align__align-button {
  height: 2rem;
  width: 2rem;
  padding: 0;
  border-radius: 8px;
}
.main_ui_workspace_sidebar_options_menus_align__align-button svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_menus_align__align-button.main_ui_workspace_sidebar_options_menus_align__disabled {
  cursor: default;
}
.main_ui_workspace_sidebar_options_menus_align__align-button.main_ui_workspace_sidebar_options_menus_align__disabled svg {
  stroke: var(--button-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_align__align-button.main_ui_workspace_sidebar_options_menus_align__disabled:hover {
  background-color: var(--panel-background-color);
}
.main_ui_workspace_sidebar_options_menus_align__align-button.main_ui_workspace_sidebar_options_menus_align__disabled:hover svg {
  stroke: var(--button-foreground-color-disabled);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_blur__element-set {
  max-width: var(--options-width);
}

.main_ui_workspace_sidebar_options_menus_blur__title-spacing-blur {
  padding-left: var(--sp-xxs);
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_blur__long-title {
  height: auto;
}

.main_ui_workspace_sidebar_options_menus_blur__element-set-content {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  margin-bottom: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_blur__first-row {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_blur__show-more {
  background-color: var(--color-background-tertiary);
  border: 0.0625rem solid var(--color-background-tertiary);
  border-radius: 0.5rem 0 0 0.5rem;
}
.main_ui_workspace_sidebar_options_menus_blur__show-more:hover {
  background-color: var(--color-background-quaternary);
  border: 0.0625rem solid var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_menus_blur__show-more:disabled {
  background-color: var(--color-background-primary);
  border-block-start: 0.0625rem solid var(--color-background-quaternary);
  border-block-end: 0.0625rem solid var(--color-background-quaternary);
  border-inline-start: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_workspace_sidebar_options_menus_blur__blur-info {
  grid-column: span 6;
  display: flex;
  align-items: center;
  flex-grow: 1;
  gap: 1px;
  border-radius: 0.5rem;
  background-color: var(--color-background-primary);
}

.main_ui_workspace_sidebar_options_menus_blur__mixed-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-column: span 7;
  gap: 1px;
  border-radius: 0.5rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  height: 2rem;
  padding: 0 var(--sp-s);
  background-color: var(--color-background-tertiary);
  border: 0.0625rem solid var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  box-sizing: border-box;
}

.main_ui_workspace_sidebar_options_menus_blur__disabled-label-tooltip {
  flex-grow: 1;
}

.main_ui_workspace_sidebar_options_menus_blur__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  height: 2rem;
  padding: 0 var(--sp-s);
  border-radius: 0 0.5rem 0.5rem 0;
  background-color: var(--color-background-tertiary);
  border: 0.0625rem solid var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  box-sizing: border-box;
}

.main_ui_workspace_sidebar_options_menus_blur__blur-type-select {
  flex-grow: 1;
  border-radius: 0 0.5rem 0.5rem 0;
}

.main_ui_workspace_sidebar_options_menus_blur__actions {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_blur__hidden .main_ui_workspace_sidebar_options_menus_blur__blur-info,
.main_ui_workspace_sidebar_options_menus_blur__hidden .main_ui_workspace_sidebar_options_menus_blur__blur-info .main_ui_workspace_sidebar_options_menus_blur__label {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--color-foreground-secondary);
  stroke: var(--color-foreground-secondary);
  background-color: transparent;
}

.main_ui_workspace_sidebar_options_menus_blur__hidden .main_ui_workspace_sidebar_options_menus_blur__blur-info .main_ui_workspace_sidebar_options_menus_blur__label {
  border: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_workspace_sidebar_options_menus_blur__second-row {
  width: var(--three-columns-width);
}

.main_ui_workspace_sidebar_options_menus_blur__disabled-label {
  color: var(--color-foreground-secondary);
  background-color: var(--color-background-primary);
  border-top: 0.0625rem solid var(--color-background-quaternary);
  border-bottom: 0.0625rem solid var(--color-background-quaternary);
  border-right: 0.0625rem solid var(--color-background-quaternary);
  border-left: 0.0625rem solid transparent;
}
@keyframes main_ui_workspace_sidebar_options_menus_bool__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button.disabled, [disabled].main_ui_workspace_sidebar_options_menus_bool__flatten-button, .main_ui_workspace_sidebar_options_menus_bool__flatten-button:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_bool__flatten-button svg, .main_ui_workspace_sidebar_options_menus_bool__flatten-button:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_bool__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_bool__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_bool__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_bool__flatten-icon, .main_ui_workspace_sidebar_options_menus_bool__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_bool__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_bool__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_bool__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_bool__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_bool__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_bool__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_bool__boolean-options {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  height: var(--sp-xxxl);
}

.main_ui_workspace_sidebar_options_menus_bool__bool-group {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/span 4;
}

.main_ui_workspace_sidebar_options_menus_bool__flatten-button {
  height: 2rem;
  width: 2rem;
  border-radius: 8px;
  grid-column: 5/span 1;
  --flatten-icon-foreground-color: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button.main_ui_workspace_sidebar_options_menus_bool__disabled {
  cursor: default;
  --flatten-icon-foreground-color: var(--button-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_bool__flatten-button.main_ui_workspace_sidebar_options_menus_bool__disabled:hover {
  background-color: var(--panel-background-color);
  --flatten-icon-foreground-color: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_bool__flatten-icon {
  stroke: var(--flatten-icon-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_bool__boolean-radio-btn {
  background-color: transparent;
  gap: var(--sp-xs);
}
@keyframes main_ui_workspace_sidebar_options_menus_border_radius__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_border_radius__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 span svg,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input span svg,
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 label svg,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input label svg, .main_ui_workspace_sidebar_options_menus_border_radius__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 span svg,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input span svg,
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 label svg,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input label svg, .main_ui_workspace_sidebar_options_menus_border_radius__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_border_radius__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_border_radius__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 input[disabled],
.main_ui_workspace_sidebar_options_menus_border_radius__small-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_border_radius__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input span,
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 label,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input label, .main_ui_workspace_sidebar_options_menus_border_radius__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-1,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 span svg,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input span svg,
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 label svg,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_border_radius__small-input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1 ::placeholder,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:hover,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:hover span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:hover input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:active,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:active span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:active input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus, .main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus span, .main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus input, .main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus:hover,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus:hover, .main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus:hover span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus:hover span, .main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus:hover input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus:hover input, .main_ui_workspace_sidebar_options_menus_border_radius__radius-1:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_border_radius__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius {
  display: grid;
  grid-template-columns: subgrid;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-1,
.main_ui_workspace_sidebar_options_menus_border_radius__small-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-4 {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_border_radius__selected {
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_options_menus_border_radius__icon {
  margin-inline: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input {
  padding-inline-start: 0.375rem;
}

.main_ui_workspace_sidebar_options_menus_border_radius__dropdown-offset {
  --dropdown-offset: -4.0625rem;
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-token {
  display: grid;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-first-row {
  display: grid;
  grid-template-columns: 1fr auto;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_border_radius__radius-4-token {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: var(--sp-xs);
}
@keyframes main_ui_workspace_sidebar_options_menus_color_selection__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn.disabled, [disabled].main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn, .main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_options_menus_color_selection__add-fill {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill.disabled, [disabled].main_ui_workspace_sidebar_options_menus_color_selection__add-fill, .main_ui_workspace_sidebar_options_menus_color_selection__add-fill:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_color_selection__add-fill.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_color_selection__add-fill svg, .main_ui_workspace_sidebar_options_menus_color_selection__add-fill:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_color_selection__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_color_selection__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_color_selection__add-fill svg, .main_ui_workspace_sidebar_options_menus_color_selection__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_color_selection__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_color_selection__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_color_selection__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_color_selection__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_color_selection__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_color_selection__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_color_selection__element-set {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_color_selection__element-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_color_selection__title-spacing-selected-colors {
  padding-left: 0.125rem;
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_color_selection__add-fill {
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_sidebar_options_menus_color_selection__element-content {
  grid-column: span 8;
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  margin-bottom: 0.5rem;
}

.main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2rem;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

@keyframes main_ui_workspace_sidebar_options_menus_component__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn.disabled, [disabled].main_ui_workspace_sidebar_options_menus_component__pill-actions-btn, .main_ui_workspace_sidebar_options_menus_component__pill-actions-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn.main_ui_workspace_sidebar_options_menus_component__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn.main_ui_workspace_sidebar_options_menus_component__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_sidebar_options_menus_component__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_component__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_component__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_component__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_component__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_component__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_component__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_component__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_component__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item span svg, .main_ui_workspace_sidebar_options_menus_component__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item span svg, .main_ui_workspace_sidebar_options_menus_component__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_component__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_component__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_component__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_component__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_component__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_workspace_sidebar_options_menus_component__annotation {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-column: span 8;
  color: var(--color-foreground-secondary);
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__editing {
  border: 0.0625rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__editing .main_ui_workspace_sidebar_options_menus_component__annotation-title {
  border-bottom: 0.0625rem solid var(--entry-border-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__editing .main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action {
  display: flex;
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__editing .main_ui_workspace_sidebar_options_menus_component__annotation-title-name {
  margin-inline-start: var(--sp-m);
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__editing .main_ui_workspace_sidebar_options_menus_component__annotation-textarea {
  min-block-size: 15.75rem;
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__creating {
  border: 0.0625rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__creating .main_ui_workspace_sidebar_options_menus_component__annotation-title .main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action {
  display: flex;
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__creating .main_ui_workspace_sidebar_options_menus_component__annotation-title-name {
  margin-inline-start: var(--sp-m);
}
.main_ui_workspace_sidebar_options_menus_component__annotation.main_ui_workspace_sidebar_options_menus_component__creating .main_ui_workspace_sidebar_options_menus_component__annotation-textarea {
  min-block-size: 15.75rem;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title {
  display: flex;
  align-items: center;
  block-size: 2rem;
}
.main_ui_workspace_sidebar_options_menus_component__annotation-title.main_ui_workspace_sidebar_options_menus_component__expanded {
  border-bottom: 0.0625rem solid var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_menus_component__annotation-title.main_ui_workspace_sidebar_options_menus_component__expandeable {
  cursor: pointer;
}
.main_ui_workspace_sidebar_options_menus_component__annotation-title:hover .main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action {
  display: flex;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title-name {
  flex-grow: 1;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-arrow {
  margin: 0 var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title-actions {
  display: flex;
  align-items: center;
  line-height: 2.5;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action {
  cursor: pointer;
  display: none;
  justify-content: center;
  align-items: center;
  inline-size: 1.75rem;
  block-size: 2rem;
  border-radius: 0.5rem;
  margin: 0;
  padding: 0;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-ok:hover {
  color: var(--color-accent-success);
}
.main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-ok:hover.main_ui_workspace_sidebar_options_menus_component__disabled {
  cursor: default;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-nok:hover {
  color: var(--color-accent-error);
}

.main_ui_workspace_sidebar_options_menus_component__annotation-body-hidden {
  display: none;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-body {
  display: grid;
}
.main_ui_workspace_sidebar_options_menus_component__annotation-body::after {
  content: attr(data-replicated-value) " ";
  white-space: pre-wrap;
  visibility: hidden;
  /* Identical styling required!! */
  font: inherit;
  overflow-wrap: anywhere;
  padding: var(--sp-m);
  /* Place on top of each other */
  grid-area: 1/1/2/2;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-textarea {
  background-color: var(--color-background-primary);
  color: var(--color-foreground-primary);
  border: none;
  overflow: hidden;
  outline: none;
  box-shadow: none;
  resize: none;
  /* Identical styling required!! */
  font: inherit;
  overflow-wrap: anywhere;
  padding: var(--sp-m);
  /* Place on top of each other */
  grid-area: 1/1/2/2;
}

.main_ui_workspace_sidebar_options_menus_component__annotation-counter {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  text-align: right;
  color: var(--color-foreground-secondary);
  margin: 0 var(--sp-s) var(--sp-s) 0;
}

.main_ui_workspace_sidebar_options_menus_component__swap-item-list {
  --swap-item-foreground-color: var(--color-foreground-primary);
  --swap-item-foreground-color-hover: var(--color-foreground-primary);
  --swap-item-foreground-color-disabled: var(--color-foreground-disabled);
  --swap-item-background-color: var(--color-background-tertiary);
  --swap-item-background-color-hover: var(--color-background-quaternary);
  --swap-item-border-color: transparent;
  --swap-item-border-color-selected: var(--color-accent-primary);
  --swap-item-thumbnail-background-color: var(--color-canvas);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  padding: 0.0625rem var(--sp-m) 0.0625rem 0.0625rem;
  gap: var(--sp-s);
  block-size: 2.75rem;
  border-radius: 0.5rem;
  background-color: var(--swap-item-background-color);
  color: var(--swap-item-foreground-color);
  border: 0.0625rem solid var(--swap-item-border-color);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-list .main_ui_workspace_sidebar_options_menus_component__swap-item-thumbnail {
  flex: 0 0 2.5rem;
  background-color: var(--swap-item-thumbnail-background-color);
  border-radius: 0.375rem;
  block-size: 2.5rem;
  inline-size: 2.5rem;
  padding: var(--sp-xxs);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-list .main_ui_workspace_sidebar_options_menus_component__swap-item-name {
  flex: 1;
  text-align: left;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-list .main_ui_workspace_sidebar_options_menus_component__swap-item-variant-icon {
  flex: 0 0 1rem;
  background-color: none;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-list.main_ui_workspace_sidebar_options_menus_component__selected {
  --swap-item-border-color: var(--swap-item-border-color-selected);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-list:hover:not(:disabled) {
  --swap-item-foreground-color: var(--swap-item-foreground-color-hover);
  --swap-item-background-color: var(--swap-item-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-list:disabled {
  --swap-item-foreground-color: var(--swap-item-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_component__swap-item-grid {
  --swap-item-foreground-color: var(--color-foreground-primary);
  --swap-item-foreground-color-hover: var(--color-foreground-primary);
  --swap-item-background-color: var(--color-background-primary);
  --swap-item-border-color: var(--color-accent-primary);
  --swap-item-border-inner-color-selected: var(--color-background-primary);
  --swap-item-thumbnail-background-color: var(--color-canvas);
  --swap-item-thumbnail-background-color-disabled: var(--color-foreground-secondary);
  display: flex;
  place-items: center;
  aspect-ratio: 1/1;
  flex-wrap: wrap;
  position: relative;
  padding: var(--sp-s);
  border: none;
  border-radius: 0.5rem;
  background-color: var(--swap-item-thumbnail-background-color);
  overflow: hidden;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid .main_ui_workspace_sidebar_options_menus_component__swap-item-thumbnail {
  block-size: 100%;
  inline-size: 100%;
  -o-object-fit: contain;
     object-fit: contain;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid .main_ui_workspace_sidebar_options_menus_component__swap-item-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  text-align: left;
  display: none;
  position: absolute;
  inset-inline-start: var(--sp-xs);
  inset-block-end: var(--sp-xs);
  block-size: var(--sp-xxl);
  inline-size: calc(100% - var(--sp-s));
  padding: var(--sp-xs);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  border-radius: 0.25rem;
  border: 0.0625rem solid transparent;
  background-color: var(--swap-item-background-color);
  color: var(--swap-item-foreground-color);
  direction: rtl;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid .main_ui_workspace_sidebar_options_menus_component__swap-item-variant-icon {
  position: absolute;
  inset-inline-end: var(--sp-xxs);
  inset-block-start: var(--sp-xxs);
  background-color: var(--color-background-tertiary);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid:hover .main_ui_workspace_sidebar_options_menus_component__swap-item-name {
  display: block;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid.main_ui_workspace_sidebar_options_menus_component__selected {
  border: 0.125rem solid var(--swap-item-border-color);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid.main_ui_workspace_sidebar_options_menus_component__selected::before {
  content: " ";
  position: absolute;
  inset-inline: 0;
  inset-block: 0;
  border: 0.25rem solid var(--swap-item-border-inner-color-selected);
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid.main_ui_workspace_sidebar_options_menus_component__selected .main_ui_workspace_sidebar_options_menus_component__swap-item-name {
  color: var(--swap-item-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid:disabled {
  background: var(--swap-item-thumbnail-background-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_component__swap-item-grid:disabled .main_ui_workspace_sidebar_options_menus_component__swap-item-name {
  background: linear-gradient(to top, var(--swap-item-thumbnail-background-color-disabled) 0%, transparent 100%);
  color: var(--swap-item-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_component__swap-item-variant-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  block-size: 1.5rem;
  inline-size: 1.5rem;
  color: var(--color-accent-secondary);
  border-radius: 0.5rem;
}

.main_ui_workspace_sidebar_options_menus_component__swap-group {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  cursor: pointer;
  display: grid;
  grid-template-columns: 1fr var(--sp-m);
  block-size: 2rem;
  align-items: center;
}
.main_ui_workspace_sidebar_options_menus_component__swap-group:hover .main_ui_workspace_sidebar_options_menus_component__swap-group-icon {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_component__swap-group-name {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_component__swap-group-icon {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__swap {
  padding-block-start: var(--sp-m);
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_component__swap-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  display: flex;
  align-items: center;
  block-size: 2rem;
  padding-inline-start: var(--sp-xxs);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__swap-content {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_workspace_sidebar_options_menus_component__swap-filters {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-title {
  display: grid;
  grid-template-columns: 1fr auto;
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--color-foreground-secondary);
  padding: var(--sp-s) 0 var(--sp-s) var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-back {
  cursor: pointer;
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  inline-size: 100%;
  block-size: 2rem;
  padding: 0;
  border: 0;
  background-color: var(--color-background-primary);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-back-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  direction: rtl;
  block-size: 2rem;
  padding: var(--sp-s) 0 var(--sp-s) var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-empty {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  margin: 0 var(--sp-xs) 0 var(--sp-s);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-grid {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(6rem, 1fr));
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__swap-library-list {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__component-section {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__component-title {
  grid-column: span 8;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  display: flex;
}

.main_ui_workspace_sidebar_options_menus_component__component-title-swap {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  cursor: pointer;
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  inline-size: 100%;
  block-size: 2rem;
  padding: 0;
  border: 0;
  border-radius: 0.5rem;
  background-color: var(--color-background-primary);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__component-title-bar {
  justify-content: flex-start;
  gap: var(--sp-s);
  flex-grow: 1;
}

.main_ui_workspace_sidebar_options_menus_component__component-title-bar-title {
  flex-grow: 0;
}

.main_ui_workspace_sidebar_options_menus_component__component-title-bar-type {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  block-size: 100%;
  display: flex;
  align-items: center;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__component-title-actions {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__component-content {
  grid-column: span 8;
  display: flex;
  flex-direction: column;
  row-gap: var(--sp-m);
  padding-block: var(--sp-xs) var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_component__component-pill {
  border-radius: 0.5rem;
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__component-combine {
  justify-content: center;
}

.main_ui_workspace_sidebar_options_menus_component__pill {
  display: flex;
  flex-grow: 1;
  gap: 0.0625rem;
}

.main_ui_workspace_sidebar_options_menus_component__pill-btn {
  flex-grow: 1;
  display: grid;
  grid-template-columns: var(--sp-l) 1fr;
  gap: var(--sp-xs);
  padding: 0 var(--sp-m) 0 var(--sp-s);
  border: none;
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_workspace_sidebar_options_menus_component__pill-btn.main_ui_workspace_sidebar_options_menus_component__with-menu {
  border-radius: 0.5rem 0 0 0.5rem;
}
.main_ui_workspace_sidebar_options_menus_component__pill-btn:focus {
  outline: 0.0625rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_component__pill-btn:hover:not(:disabled) {
  background-color: var(--color-background-quaternary);
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_component__pill-btn-icon {
  display: flex;
  block-size: 2rem;
  align-items: center;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__pill-btn-name {
  display: flex;
  flex-direction: column;
  min-block-size: 2rem;
  padding: var(--sp-s) 0 var(--sp-s) var(--sp-xxs);
  border-radius: 0.5rem 0 0 0.5rem;
  overflow: hidden;
  gap: 0;
}

.main_ui_workspace_sidebar_options_menus_component__pill-btn-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  direction: rtl;
  text-align: left;
  block-size: 1rem;
}

.main_ui_workspace_sidebar_options_menus_component__pill-btn-subtext {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  direction: rtl;
  text-align: left;
  block-size: 1rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions {
  flex: 0 0 2rem;
  position: relative;
}

.main_ui_workspace_sidebar_options_menus_component__pill-actions-btn {
  cursor: unset;
  block-size: 100%;
  inline-size: 100%;
  border-radius: 0 0.5rem 0.5rem 0;
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown {
  inline-size: 15.75rem;
  inset-inline-end: 0;
  inset-inline-start: unset;
}
.main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown.main_ui_workspace_sidebar_options_menus_component__extended {
  inset-block-start: 3rem;
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-list {
  grid-column: span 8;
  display: grid;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__variant-property {
  display: flex;
  flex-direction: column;
  position: relative;
  --reorder-left-position: calc(-1 * var(--sp-m) - var(--sp-xxs));
}
.main_ui_workspace_sidebar_options_menus_component__variant-property:hover {
  --reorder-icon-visibility: visible;
}
.main_ui_workspace_sidebar_options_menus_component__variant-property.main_ui_workspace_sidebar_options_menus_component__dnd-over-top {
  --reorder-top-display: block;
}
.main_ui_workspace_sidebar_options_menus_component__variant-property.main_ui_workspace_sidebar_options_menus_component__dnd-over-bot {
  --reorder-bottom-display: block;
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-row {
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-container {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-name-wrapper {
  grid-column: span 3;
  align-self: center;
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-value-wrapper {
  grid-column: span 5;
  align-self: center;
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-value-switch-wrapper {
  grid-column: span 5;
  display: flex;
  align-items: center;
  block-size: 2rem;
  padding-inline-start: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_component__variant-property-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  margin-inline-start: var(--sp-s);
  color: var(--color-foreground-secondary);
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.main_ui_workspace_sidebar_options_menus_component__variant-warning {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-column: span 8;
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: 0.5rem;
  padding: var(--sp-m);
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_component__variant-warning-darken {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_component__variant-warning-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  cursor: pointer;
  background-color: transparent;
  border: none;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  color: var(--color-accent-primary);
  padding: 0;
  text-align: start;
}
@keyframes main_ui_workspace_sidebar_options_menus_constraints__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_constraints__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_constraints__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark.main_ui_workspace_sidebar_options_menus_constraints__checked svg, .main_ui_workspace_sidebar_options_menus_constraints__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark.main_ui_workspace_sidebar_options_menus_constraints__checked svg, .main_ui_workspace_sidebar_options_menus_constraints__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_constraints__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_constraints__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_constraints__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_constraints__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_constraints__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_constraints__element-set {
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_constraints__element-set-content {
  display: flex;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-widget {
  background-color: var(--constraint-widget-background-color);
  display: grid;
  grid-template: "top top top" 1.5rem "left center right" 3.75rem "bottom bottom bottom" 1.5rem/1.5rem 3.75rem 1.5rem;
  height: 6.75rem;
  width: 6.75rem;
  border-radius: 8px;
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-top,
.main_ui_workspace_sidebar_options_menus_constraints__constraints-left,
.main_ui_workspace_sidebar_options_menus_constraints__constraints-center,
.main_ui_workspace_sidebar_options_menus_constraints__constraints-right,
.main_ui_workspace_sidebar_options_menus_constraints__constraints-bottom {
  display: flex;
  justify-content: center;
  align-items: center;
  grid-area: top;
}

.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
  height: 100%;
  --resalted-area-background-color: var(--button-constraint-background-color-rest);
  --resalted-area-border-color: none;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn.main_ui_workspace_sidebar_options_menus_constraints__active,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special.main_ui_workspace_sidebar_options_menus_constraints__active,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated.main_ui_workspace_sidebar_options_menus_constraints__active {
  --resalted-area-border-color: var(--button-constraint-border-color-hover);
  --resalted-area-background-color: var(--button-constraint-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn:hover, .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn:focus-visible,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special:hover,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special:focus-visible,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated:hover,
.main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated:focus-visible {
  --resalted-area-border-color: var(--button-constraint-border-color-hover);
  --resalted-area-background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_constraints__resalted-area {
  width: 2rem;
  height: calc(1px + 0.125rem);
  border-radius: 8px;
  background-color: var(--resalted-area-background-color);
  outline: 0.25rem solid var(--resalted-area-border-color);
  padding: 0;
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-left {
  grid-area: left;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-left .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated {
  height: 3.75rem;
  width: 1.5rem;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-left .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated .main_ui_workspace_sidebar_options_menus_constraints__resalted-area {
  height: 2rem;
  width: calc(1px + 0.125rem);
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-center {
  grid-area: center;
  position: relative;
  background-color: var(--constraint-center-area-background-color);
  border-radius: 8px;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-center .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn {
  width: 3.75rem;
  height: 1.5rem;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-center .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn .main_ui_workspace_sidebar_options_menus_constraints__resalted-area {
  width: 2rem;
  height: calc(1px + 0.125rem);
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-center .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special {
  position: absolute;
  height: 3.75rem;
  width: 1.5rem;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-center .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special .main_ui_workspace_sidebar_options_menus_constraints__resalted-area {
  height: 2rem;
  width: calc(1px + 0.125rem);
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-right {
  grid-area: right;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-right .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated {
  height: 4.5rem;
  width: 1.5rem;
}
.main_ui_workspace_sidebar_options_menus_constraints__constraints-right .main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated .main_ui_workspace_sidebar_options_menus_constraints__resalted-area {
  height: 2rem;
  width: calc(1px + 0.125rem);
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-bottom {
  grid-area: bottom;
}

.main_ui_workspace_sidebar_options_menus_constraints__constraints-selects {
  display: flex;
  flex-direction: column;
  gap: 4px;
}

.main_ui_workspace_sidebar_options_menus_constraints__horizontal-select,
.main_ui_workspace_sidebar_options_menus_constraints__vertical-select {
  width: 7.75rem;
  padding: 0;
}

.main_ui_workspace_sidebar_options_menus_constraints__checkbox {
  display: flex;
  align-items: center;
  margin-bottom: 0.5rem;
  margin-top: 0.5rem;
  padding-left: 0;
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox input {
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.125rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  border-radius: 6px;
  background-color: var(--input-checkbox-inactive-background-color);
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark.main_ui_workspace_sidebar_options_menus_constraints__checked {
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark.main_ui_workspace_sidebar_options_menus_constraints__checked svg {
  stroke: var(--input-details-color);
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_constraints__checkbox label .main_ui_workspace_sidebar_options_menus_constraints__check-mark:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
@keyframes main_ui_workspace_sidebar_options_menus_exports__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__export-btn.disabled, [disabled].main_ui_workspace_sidebar_options_menus_exports__export-btn, .main_ui_workspace_sidebar_options_menus_exports__export-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_options_menus_exports__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_exports__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_exports__suffix-input span svg,
.main_ui_workspace_sidebar_options_menus_exports__suffix-input label svg, .main_ui_workspace_sidebar_options_menus_exports__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_exports__suffix-input span svg,
.main_ui_workspace_sidebar_options_menus_exports__suffix-input label svg, .main_ui_workspace_sidebar_options_menus_exports__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_exports__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_exports__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_exports__suffix-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_exports__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input span,
.main_ui_workspace_sidebar_options_menus_exports__suffix-input label, .main_ui_workspace_sidebar_options_menus_exports__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_exports__suffix-input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input span svg,
.main_ui_workspace_sidebar_options_menus_exports__suffix-input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus, .main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus span, .main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus input, .main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus:hover, .main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus:hover span, .main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus:hover input, .main_ui_workspace_sidebar_options_menus_exports__suffix-input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_exports__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_exports__multiple-exports .main_ui_workspace_sidebar_options_menus_exports__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  flex-grow: 1;
  border-radius: 8px;
  height: 2rem;
  padding: 0.5rem;
  background-color: var(--input-background-color);
  color: var(--input-foreground-color-active);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_exports__element-set {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_exports__element-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_exports__title-spacing-export {
  padding-left: 0.125rem;
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_exports__element-set-content {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_exports__multiple-exports {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  grid-column: 1/span 9;
}
.main_ui_workspace_sidebar_options_menus_exports__multiple-exports .main_ui_workspace_sidebar_options_menus_exports__actions {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_exports__element-group {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_exports__input-wrapper {
  grid-column: span 7;
  display: grid;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_menus_exports__format-select {
  grid-column: span 2;
  padding: 0;
}
.main_ui_workspace_sidebar_options_menus_exports__format-select .main_ui_workspace_sidebar_options_menus_exports__dropdown-upwards {
  bottom: 2.25rem;
  width: 5rem;
  top: unset;
}

.main_ui_workspace_sidebar_options_menus_exports__size-select {
  grid-column: span 2;
  padding: 0;
}
.main_ui_workspace_sidebar_options_menus_exports__size-select .main_ui_workspace_sidebar_options_menus_exports__dropdown-upwards {
  bottom: 2.25rem;
  top: unset;
  width: 5rem;
}

.main_ui_workspace_sidebar_options_menus_exports__suffix-input {
  grid-column: span 3;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_workspace_sidebar_options_menus_exports__export-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  grid-column: 1/span 9;
  height: 2rem;
}
@keyframes main_ui_workspace_sidebar_options_menus_fill__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_fill__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_fill__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox span.main_ui_workspace_sidebar_options_menus_fill__checked svg, .main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.intermediate svg, .main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.checked svg, .main_ui_workspace_sidebar_options_menus_fill__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox span.main_ui_workspace_sidebar_options_menus_fill__checked svg, .main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.intermediate svg, .main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.checked svg, .main_ui_workspace_sidebar_options_menus_fill__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_fill__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_fill__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_fill__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_fill__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label span.unchecked svg {
  display: none;
}

.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox {
  display: flex;
  align-items: center;
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label input {
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label:focus span, .main_ui_workspace_sidebar_options_menus_fill__fill-checkbox label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_workspace_sidebar_options_menus_fill__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-section {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_fill__fill-title-bar {
  padding-inline-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-content {
  grid-column: span 8;
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
  margin: var(--sp-xs) 0 var(--sp-s) 0;
}

.main_ui_workspace_sidebar_options_menus_fill__fill-multiple {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-multiple-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  border-radius: 0.5rem;
  block-size: 2rem;
  padding: var(--sp-s);
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox {
  padding-inline-start: var(--sp-s);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox span.main_ui_workspace_sidebar_options_menus_fill__checked {
  background-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_fill__fill-checkbox span.main_ui_workspace_sidebar_options_menus_fill__checked svg {
  stroke: var(--color-background-primary);
}
@keyframes main_ui_workspace_sidebar_options_menus_frame_grid__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options.disabled, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row [disabled].main_ui_workspace_sidebar_options_menus_frame_grid__show-options, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options.disabled, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row [disabled].main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options.disabled svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row [disabled].main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options.main_ui_workspace_sidebar_options_menus_frame_grid__selected, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options.main_ui_workspace_sidebar_options_menus_frame_grid__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options.main_ui_workspace_sidebar_options_menus_frame_grid__selected svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options.main_ui_workspace_sidebar_options_menus_frame_grid__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options svg, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select span svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options svg, .main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options span svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height span svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter span svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin span svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height label svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter label svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin label svg, .main_ui_workspace_sidebar_options_menus_frame_grid__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options span svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height span svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter span svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin span svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height label svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter label svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin label svg, .main_ui_workspace_sidebar_options_menus_frame_grid__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size [disabled].main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select [disabled].main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height input[disabled], .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter input[disabled],
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height label,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter label,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin label, .main_ui_workspace_sidebar_options_menus_frame_grid__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height span svg, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter span svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin span svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height label svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter label svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height ::placeholder, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter ::placeholder,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:hover, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:hover,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:hover span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:hover span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:hover input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:hover input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:active, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:active,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:active span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:active span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:active input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:active input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus:hover, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus:hover,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus:hover, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within:hover, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus:hover span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus:hover span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus:hover span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus:hover input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus:hover input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus:hover input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  padding: 0.5rem 0.75rem;
  background-color: var(--assets-item-background-color);
  color: var(--assets-item-name-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size:hover, .main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper:hover {
  background-color: var(--assets-item-background-color-hover);
  color: var(--assets-item-name-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__second-row {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__element-set {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__element-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__title-spacing-board-grid {
  padding-left: 0.125rem;
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__element-set-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  grid-column: span 8;
  margin: 0.25rem 0 0.5rem 0;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__grid-title {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__option-row {
  grid-column: span 6;
  display: flex;
  align-items: center;
  gap: 1px;
  border-radius: 8px;
  background-color: var(--input-details-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-options {
  height: 2rem;
  width: 1.75rem;
  border-radius: 8px 0 0 8px;
  box-sizing: border-box;
  border: 1px solid var(--input-border-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper {
  flex-grow: 1;
  width: 6rem;
  padding: 0;
  border-radius: 0;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__grid-type-select {
  border-radius: 0;
  height: 100%;
  box-sizing: border-box;
  border: 1px solid var(--input-border-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__grid-type-select:hover {
  border: 1px solid var(--input-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size {
  width: 3.75rem;
  margin: 0;
  padding: 0;
  padding-left: 0.5rem;
  border-radius: 0 8px 8px 0;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper {
  width: 3.75rem;
  margin: 0;
  padding: 0;
  position: relative;
  border-radius: 0 8px 8px 0;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select {
  height: 2rem;
  border-radius: 0 8px 8px 0;
  box-sizing: border-box;
  border: 1px solid var(--input-border-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin: 0;
  padding: 0;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select span {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__show-options {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border: 1px solid var(--input-border-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__grid-type-select,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__grid-type-select {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border: 1px solid var(--input-border-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border-radius: 0 8px 8px 0;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper .main_ui_workspace_sidebar_options_menus_frame_grid__column-select .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border: 1px solid var(--input-border-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size .main_ui_workspace_sidebar_options_menus_frame_grid__icon {
  stroke: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__grid-size .main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input {
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__actions .main_ui_workspace_sidebar_options_menus_frame_grid__hidden-btn,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__actions .main_ui_workspace_sidebar_options_menus_frame_grid__lock-btn {
  background-color: transparent;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__actions .main_ui_workspace_sidebar_options_menus_frame_grid__hidden-btn svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__option-row.main_ui_workspace_sidebar_options_menus_frame_grid__hidden .main_ui_workspace_sidebar_options_menus_frame_grid__actions .main_ui_workspace_sidebar_options_menus_frame_grid__lock-btn svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__actions {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__grid-advanced-options {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  margin-top: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__column-row,
.main_ui_workspace_sidebar_options_menus_frame_grid__square-row {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: relative;
}

.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row {
  position: relative;
  display: flex;
  gap: 0.25rem;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__orientation-select-wrapper {
  width: 5.75rem;
  padding: 0;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__color-wrapper {
  width: 9.75rem;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options {
  height: 2rem;
  width: 2rem;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__height .main_ui_workspace_sidebar_options_menus_frame_grid__icon-text {
  padding-top: 1px;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__gutter .main_ui_workspace_sidebar_options_menus_frame_grid__icon.main_ui_workspace_sidebar_options_menus_frame_grid__rotated svg,
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__margin .main_ui_workspace_sidebar_options_menus_frame_grid__icon.main_ui_workspace_sidebar_options_menus_frame_grid__rotated svg {
  transform: rotate(90deg);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__more-options {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  top: calc(0.125rem + 1.75rem);
  right: 0;
  width: 9.75rem;
  max-height: 18.75rem;
  padding: 0.125rem;
  margin: 0 0 2.5rem 0;
  margin-top: 0.25rem;
  border-radius: 8px;
  z-index: 4;
  overflow-y: auto;
  background-color: var(--menu-background-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__more-options .main_ui_workspace_sidebar_options_menus_frame_grid__option-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row .main_ui_workspace_sidebar_options_menus_frame_grid__more-options .main_ui_workspace_sidebar_options_menus_frame_grid__option-btn:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_frame_grid__second-row {
  left: unset;
  right: 0;
  width: 6.75rem;
}
.main_ui_workspace_sidebar_options_menus_frame_grid__second-row .main_ui_workspace_sidebar_options_menus_frame_grid__btn-options {
  border: none;
  background: none;
  cursor: pointer;
  width: 100%;
}
@keyframes main_ui_workspace_sidebar_options_menus_grid_cell__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn.disabled, [disabled].main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn, .main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__icon svg, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input span svg, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input span svg,
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input label svg,
.main_ui_workspace_sidebar_options_menus_grid_cell__coord-input label svg, .main_ui_workspace_sidebar_options_menus_grid_cell__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__area-input span svg, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input span svg,
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input label svg,
.main_ui_workspace_sidebar_options_menus_grid_cell__coord-input label svg, .main_ui_workspace_sidebar_options_menus_grid_cell__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_grid_cell__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__area-input input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input input[disabled], .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input span,
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input label,
.main_ui_workspace_sidebar_options_menus_grid_cell__coord-input label, .main_ui_workspace_sidebar_options_menus_grid_cell__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__area-input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input span svg, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input span svg,
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input label svg,
.main_ui_workspace_sidebar_options_menus_grid_cell__coord-input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input ::placeholder, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:hover, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:hover span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:hover input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:active, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:active span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:active input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus span, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus input, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus:hover, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus:hover, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within:hover, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus:hover span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus:hover span, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus:hover input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus:hover input, .main_ui_workspace_sidebar_options_menus_grid_cell__area-input:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_grid_cell__coord-input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-container {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  margin-top: 0.5rem;
  gap: 1rem;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-title {
  grid-column: span 8;
  font-size: 0.688rem;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-container {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__row {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__cell-mode label {
  padding: 0 0.75rem;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  width: 100%;
  padding: 0.5rem;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__area-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  width: 100%;
  padding: 0.5rem;
}

.main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  border-radius: 8px;
  padding-left: 0.25rem;
  background-color: var(--input-background-color);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__icon svg {
  stroke: var(--icon-foreground);
}

.main_ui_workspace_sidebar_options_menus_grid_cell__coord-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border-radius: 0 8px 8px 0;
  border-left: 1px solid var(--panel-background-color);
}
.main_ui_workspace_sidebar_options_menus_input_wrapper_tokens__numeric-input-wrapper {
  --dropdown-width: var(--seven-columns-width);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_interactions__wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
  padding-inline-start: var(--sp-m);
}

.main_ui_workspace_sidebar_options_menus_interactions__section {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_interactions__title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_interactions__title-bar {
  padding-inline-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_interactions__content {
  grid-column: span 8;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  margin-block-start: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_interactions__content-interactions {
  gap: var(--sp-l);
}

.main_ui_workspace_sidebar_options_menus_interactions__empty {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) auto;
  inline-size: 12.5rem;
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-item {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill {
  display: flex;
  align-items: center;
  gap: 0.0625rem;
  border-radius: 0.5rem;
  block-size: 2rem;
  padding: 0;
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill.main_ui_workspace_sidebar_options_menus_interactions__double {
  block-size: 3rem;
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill.main_ui_workspace_sidebar_options_menus_interactions__double .main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button {
  block-size: 3rem;
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill:has(.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input:focus) {
  outline: 0.0625rem solid var(--color-accent-primary);
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button.main_ui_workspace_sidebar_options_menus_interactions__left {
  border-end-end-radius: 0;
  border-start-end-radius: 0;
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button.main_ui_workspace_sidebar_options_menus_interactions__right {
  border-start-start-radius: 0;
  border-end-start-radius: 0;
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-main {
  display: flex;
  flex-grow: 1;
  block-size: 100%;
  inline-size: 100%;
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-center {
  flex-grow: 1;
  display: flex;
  align-items: center;
  block-size: 100%;
  padding: 0 var(--sp-s);
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-info {
  display: grid;
  inline-size: 100%;
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  border: none;
  background: none;
  outline: none;
  block-size: 100%;
  flex-grow: 1;
  padding: 0 0 0 var(--sp-s);
  margin: 0;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  display: grid;
  inline-size: 100%;
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input:hover {
  background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input:hover:active {
  background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input:focus {
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-description {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label {
  grid-column: span 3;
  display: flex;
  align-items: center;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name {
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select {
  grid-column: span 5;
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox {
  grid-column: 4/span 5;
  min-block-size: 2rem;
  display: flex;
  align-items: center;
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input {
  grid-column: span 5;
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-radio {
  grid-column: 4/span 5;
}

.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position {
  grid-column: 4/span 5;
  display: grid;
  grid-template-areas: "topleft top topright" "left center right" "bottomleft bottom bottomright";
  grid-template-rows: 1fr 1fr 1fr;
  grid-template-columns: 1fr 1fr 1fr;
  inline-size: 6rem;
  block-size: 6rem;
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__center {
  grid-area: center;
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__top-left {
  grid-area: topleft;
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__top-center {
  grid-area: top;
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__top-right {
  grid-area: topright;
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__bottom-left {
  grid-area: bottomleft;
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__bottom-center {
  grid-area: bottom;
}
.main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position .main_ui_workspace_sidebar_options_menus_interactions__bottom-right {
  grid-area: bottomright;
}
@keyframes main_ui_workspace_sidebar_options_menus_layer__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layer__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_layer__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input span svg,
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input label svg, .main_ui_workspace_sidebar_options_menus_layer__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input span svg,
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input label svg, .main_ui_workspace_sidebar_options_menus_layer__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_layer__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_layer__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_layer__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input span,
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input label, .main_ui_workspace_sidebar_options_menus_layer__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input span svg,
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus, .main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus span, .main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus input, .main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus:hover, .main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus:hover span, .main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus:hover input, .main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_layer__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_layer__element-set-content {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  block-size: 2rem;
  margin-block-end: var(--sp-s);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__select {
  grid-column: span 4;
  padding: 0;
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-column: span 2;
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content .main_ui_workspace_sidebar_options_menus_layer__actions {
  grid-column: span 2;
  display: grid;
  grid-template-columns: subgrid;
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content.main_ui_workspace_sidebar_options_menus_layer__hidden .main_ui_workspace_sidebar_options_menus_layer__hidden-select {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border: 0.0625rem solid var(--input-border-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content.main_ui_workspace_sidebar_options_menus_layer__hidden .main_ui_workspace_sidebar_options_menus_layer__input {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border: 0.0625rem solid var(--input-border-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content.main_ui_workspace_sidebar_options_menus_layer__hidden .main_ui_workspace_sidebar_options_menus_layer__input .main_ui_workspace_sidebar_options_menus_layer__icon {
  stroke: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_layer__element-set-content.main_ui_workspace_sidebar_options_menus_layer__hidden .main_ui_workspace_sidebar_options_menus_layer__input .main_ui_workspace_sidebar_options_menus_layer__numeric-input {
  color: var(--input-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_layer__element-set-content-token {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  block-size: 2rem;
  margin-block-end: var(--sp-s);
  grid-template-columns: var(--grid-exception-input-width) var(--grid-exception-input-width-small) auto auto;
}

.main_ui_workspace_sidebar_options_menus_layer__hidden-select {
  cursor: default;
  pointer-events: none;
  box-sizing: border-box;
  color: var(--input-foreground-color-disabled);
  stroke: var(--input-foreground-color-disabled);
  background-color: transparent;
  border: 0.0625rem solid var(--input-border-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_layer__numeric-input-wrapper {
  --dropdown-offset: -2.1875rem;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

@keyframes main_ui_workspace_sidebar_options_menus_layout_container__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn svg, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn svg, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:focus-visible, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:focus-visible, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:focus-visible svg, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:focus-visible svg, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:hover, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:hover, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:hover svg, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:hover svg, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:active, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:active, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:active svg, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:active svg, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn.disabled, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn.disabled, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon.disabled, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__exit-btn, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__expand-icon, .main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn:disabled, .main_ui_workspace_sidebar_options_menus_layout_container__exit-btn:disabled, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle, .main_ui_workspace_sidebar_options_menus_layout_container__add-column {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle svg, .main_ui_workspace_sidebar_options_menus_layout_container__add-column svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:focus-visible, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:focus-visible, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:focus-visible svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:focus-visible svg, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:hover, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:hover, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:hover svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:hover svg, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:active, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:active, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:active svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:active svg, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button.disabled, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle.disabled, .main_ui_workspace_sidebar_options_menus_layout_container__add-column.disabled, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__wrap-button, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__add-column, .main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:disabled, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:disabled, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button.disabled svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle.disabled svg, .main_ui_workspace_sidebar_options_menus_layout_container__add-column.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__wrap-button svg, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle svg, [disabled].main_ui_workspace_sidebar_options_menus_layout_container__add-column svg, .main_ui_workspace_sidebar_options_menus_layout_container__wrap-button:disabled svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle:disabled svg, .main_ui_workspace_sidebar_options_menus_layout_container__add-column:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button.main_ui_workspace_sidebar_options_menus_layout_container__selected, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle.main_ui_workspace_sidebar_options_menus_layout_container__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button.main_ui_workspace_sidebar_options_menus_layout_container__selected svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle.main_ui_workspace_sidebar_options_menus_layout_container__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_sidebar_options_menus_layout_container__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_layout_container__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle svg, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-dir-icon svg, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon svg, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap span svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple span svg, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-simple label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__track-info-value label svg, .main_ui_workspace_sidebar_options_menus_layout_container__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_layout_container__column-gap span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap span svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple span svg, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-simple label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__track-info-value label svg, .main_ui_workspace_sidebar_options_menus_layout_container__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_layout_container__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_layout_container__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_layout_container__column-gap input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap input[disabled], .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple input[disabled], .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_layout_container__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value span,
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap label,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap label,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-simple label,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple label,
.main_ui_workspace_sidebar_options_menus_layout_container__track-info-value label, .main_ui_workspace_sidebar_options_menus_layout_container__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_layout_container__column-gap,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap span svg, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple span svg, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value span svg,
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-simple label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple label svg,
.main_ui_workspace_sidebar_options_menus_layout_container__track-info-value label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_container__row-gap ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap ::placeholder, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple ::placeholder, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:hover,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:hover, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:hover,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:hover, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:hover span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:hover span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:hover input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:hover input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:active,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:active, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:active,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:active, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:active span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:active span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:active span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:active span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:active input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:active input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:active input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:active input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus span, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus input, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within:hover, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within:hover, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__column-gap:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__padding-simple:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_layout_container__track-info-value:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_layout_container__column-gap.main_ui_workspace_sidebar_options_menus_layout_container__disabled,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap.main_ui_workspace_sidebar_options_menus_layout_container__disabled {
  background-color: var(--input-background-color-disabled);
  border: 1px solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap.main_ui_workspace_sidebar_options_menus_layout_container__disabled input,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap.main_ui_workspace_sidebar_options_menus_layout_container__disabled input {
  pointer-events: none;
  cursor: default;
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_layout_container__column-gap.main_ui_workspace_sidebar_options_menus_layout_container__disabled svg,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap.main_ui_workspace_sidebar_options_menus_layout_container__disabled svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_layout_container__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_layout_container__element-set {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_container__element-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_layout_container__title-spacing-layout {
  padding-inline-start: var(--sp-xxs);
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_layout_container__title-actions {
  position: relative;
  display: flex;
  gap: var(--sp-xs);
  block-size: 2rem;
  padding: 0;
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_layout_container__layout-option {
  white-space: nowrap;
}

.main_ui_workspace_sidebar_options_menus_layout_container__flex-layout-menu {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  margin-block-end: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_layout_container__first-row {
  grid-column: 1/-1;
  display: grid;
  grid-template-columns: subgrid;
  margin-block: var(--sp-xs) var(--sp-m);
}

.main_ui_workspace_sidebar_options_menus_layout_container__align-row {
  grid-column: span 3;
}

.main_ui_workspace_sidebar_options_menus_layout_container__direction-row-flex {
  grid-column: span 4;
}

.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button {
  border-radius: 0.5rem;
  block-size: 2rem;
  inline-size: 2rem;
}
.main_ui_workspace_sidebar_options_menus_layout_container__wrap-button svg {
  stroke: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_options_menus_layout_container__second-row,
.main_ui_workspace_sidebar_options_menus_layout_container__third-row {
  grid-column: 1/-1;
  display: grid;
  grid-template-columns: subgrid;
  margin-block-end: var(--sp-m);
}

.main_ui_workspace_sidebar_options_menus_layout_container__align-content-row,
.main_ui_workspace_sidebar_options_menus_layout_container__justify-content-row {
  grid-column: span 6;
}

.main_ui_workspace_sidebar_options_menus_layout_container__forth-row {
  display: grid;
  grid-template-columns: var(--grid-exception-input-width) var(--grid-exception-input-width) var(--sp-xxxl); /* action button */
  gap: var(--sp-xs);
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_layout_container__help-button-wrapper {
  grid-column: 1/-1;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
}

.main_ui_workspace_sidebar_options_menus_layout_container__gap-group {
  grid-column: span 3;
  display: grid;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_menus_layout_container__column-gap,
.main_ui_workspace_sidebar_options_menus_layout_container__row-gap {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}
.main_ui_workspace_sidebar_options_menus_layout_container__padding-simple,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_workspace_sidebar_options_menus_layout_container__padding-group {
  display: grid;
  grid-column: span 3;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_menus_layout_container__padding-inputs,
.main_ui_workspace_sidebar_options_menus_layout_container__paddings-simple {
  grid-column: span 2;
  display: grid;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_menus_layout_container__paddings-multiple {
  display: grid;
  grid-column: span 2;
  grid-template-columns: subgrid;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle {
  block-size: 2rem;
  inline-size: 2rem;
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle svg {
  stroke: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_container__edit-grid-wrapper,
.main_ui_workspace_sidebar_options_menus_layout_container__first-row,
.main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-align,
.main_ui_workspace_sidebar_options_menus_layout_container__gap-row,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-row {
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_layout_container__first-row {
  margin-block-end: var(--sp-s);
  display: grid;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-align {
  display: grid;
  grid-template-columns: subgrid;
  align-items: flex-start;
  position: relative;
  gap: var(--sp-xs);
  margin-block-end: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_layout_container__locate-button {
  grid-row: 1;
  grid-column: 8;
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  flex: 1;
  color: var(--color-foreground-primary);
  grid-column: span 5;
}

.main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  inline-size: 100%;
  padding: var(--sp-s);
  grid-column: span 7;
}

.main_ui_workspace_sidebar_options_menus_layout_container__exit-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: var(--sp-s) var(--sp-xl);
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks-info-container {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
  gap: var(--sp-xs);
  margin-block-start: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_container__padding-section {
  margin-block-start: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks-row {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_layout_container__edit-grid-wrapper {
  display: grid;
  grid-template-columns: subgrid;
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-info {
  grid-column: 1/-1;
  display: grid;
  grid-template-columns: subgrid;
}
.main_ui_workspace_sidebar_options_menus_layout_container__track-info.main_ui_workspace_sidebar_options_menus_layout_container__dnd-over-top {
  border-block-start: 0.125rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_layout_container__track-info.main_ui_workspace_sidebar_options_menus_layout_container__dnd-over-bot {
  border-block-end: 0.125rem solid var(--color-accent-primary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-info-container {
  display: flex;
  grid-column: 1/span 7;
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-info-dir-icon {
  cursor: pointer;
  border-radius: 0.5rem 0 0 0.5rem;
  background-color: var(--color-background-tertiary);
  padding: 0 var(--sp-s);
}
.main_ui_workspace_sidebar_options_menus_layout_container__track-info-dir-icon svg {
  stroke: var(--color-foreground-secondary);
  block-size: 100%;
}
.main_ui_workspace_sidebar_options_menus_layout_container__track-info-dir-icon:hover svg {
  stroke: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-info-value {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  border-radius: 0;
  border-inline-end: 0.0625rem solid var(--color-background-primary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-info-unit-selector {
  border-radius: 0 0.5rem 0.5rem 0;
  inline-size: 6rem;
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
  margin-block-start: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-track-header {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
  border-radius: 0.5rem;
  overflow: hidden;
  background: var(--color-background-tertiary);
  block-size: 3.25rem;
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-title {
  display: grid;
  flex-grow: 1;
  padding: var(--sp-s);
  gap: 0;
  overflow: hidden;
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-name {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__track-detail {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  inline-size: 100%;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__expand-icon {
  block-size: 3.25rem;
  border-radius: 0.5rem 0 0 0.5rem;
  border-inline-end: 0.0625rem solid var(--color-background-primary);
}
.main_ui_workspace_sidebar_options_menus_layout_container__expand-icon svg {
  stroke: var(--color-foreground-secondary);
  fill: var(--color-foreground-secondary);
}
.main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:hover svg, .main_ui_workspace_sidebar_options_menus_layout_container__expand-icon:active svg {
  stroke: var(--color-accent-primary);
  fill: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__add-column {
  block-size: 3.25rem;
}
.main_ui_workspace_sidebar_options_menus_layout_container__add-column svg {
  display: flex;
  justify-content: center;
  align-items: center;
  color: transparent;
  stroke-width: 0.0625rem;
  block-size: 0.75rem;
  inline-size: 0.75rem;
  stroke: var(--color-foreground-secondary);
  fill: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__layout-options {
  box-shadow: 0 0 0.75rem 0 var(--color-shadow-dark);
  position: absolute;
  display: flex;
  flex-direction: column;
  inset-block-start: 2rem;
  inset-inline-start: initial;
  inset-inline-end: var(--sp-s);
  max-block-size: var(--menu-max-height, 18.75rem);
  padding: var(--sp-xxs);
  margin: 0;
  margin-block-start: 0.0625rem;
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  overflow: hidden auto;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: 0.125rem solid var(--color-background-quaternary);
  gap: var(--sp-xs);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
}
.main_ui_workspace_sidebar_options_menus_layout_container__layout-options button {
  border: none;
  background: none;
  cursor: pointer;
  padding: var(--sp-s);
  color: var(--color-foreground-primary);
  border-radius: 0.375rem;
}
.main_ui_workspace_sidebar_options_menus_layout_container__layout-options button:hover {
  background: var(--color-background-quaternary);
}

.main_ui_workspace_sidebar_options_menus_layout_container__direction-edit {
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_menus_layout_container__align-grid-row {
  grid-column: span 3;
}

.main_ui_workspace_sidebar_options_menus_layout_container__justify-grid-row {
  grid-column: 1/span 6;
}

.main_ui_workspace_sidebar_options_menus_layout_container__gap-row,
.main_ui_workspace_sidebar_options_menus_layout_container__padding-row {
  display: grid;
  grid-template-columns: var(--grid-exception-input-width) var(--grid-exception-input-width) var(--sp-xxxl); /* action button */
  gap: var(--sp-xs);
  margin-block-end: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_container__grid-first-row {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
  align-items: center;
}
@keyframes main_ui_workspace_sidebar_options_menus_layout_item__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode.disabled, [disabled].main_ui_workspace_sidebar_options_menus_layout_item__margin-mode, .main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_layout_item__margin-mode svg, .main_ui_workspace_sidebar_options_menus_layout_item__margin-mode:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode.main_ui_workspace_sidebar_options_menus_layout_item__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode.main_ui_workspace_sidebar_options_menus_layout_item__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_sidebar_options_menus_layout_item__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_layout_item__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode svg, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper span svg, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin span svg, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin span svg, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__top-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h label svg, .main_ui_workspace_sidebar_options_menus_layout_item__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper span svg, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin span svg, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin span svg, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__top-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h label svg, .main_ui_workspace_sidebar_options_menus_layout_item__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_layout_item__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_layout_item__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper input[disabled], .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin input[disabled], .main_ui_workspace_sidebar_options_menus_layout_item__top-margin input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin input[disabled], .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w input[disabled],
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_layout_item__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h span,
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper label,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin label,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin label,
.main_ui_workspace_sidebar_options_menus_layout_item__top-margin label,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin label,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin label,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin label,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w label,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h label,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w label,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h label, .main_ui_workspace_sidebar_options_menus_layout_item__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper span svg, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin span svg, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin span svg, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h span svg,
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__top-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w label svg,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__left-margin ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__right-margin ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper ::placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin ::placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin ::placeholder, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w ::placeholder,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:hover, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:hover, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:hover, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:active, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:active,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:active, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:active,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:active,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:active,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:active, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:active,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:active,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:active,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:active span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:active span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:active span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:active span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:active input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:active input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:active input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:active input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus span, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus input, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus:hover, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within:hover, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within:hover, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within:hover, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within:hover span, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__top-margin:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin:focus-within:hover input, .main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_layout_item__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_layout_item__element-set {
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_layout_item__title-spacing-layout-element {
  margin: 0 0 var(--sp-xs) 0;
}

.main_ui_workspace_sidebar_options_menus_layout_item__title-spacing-empty {
  padding-inline-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__flex-element-menu {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__behaviour-menu {
  display: grid;
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  grid-template-columns: auto auto;
}

.main_ui_workspace_sidebar_options_menus_layout_item__vertical-behaviour .main_ui_workspace_sidebar_options_menus_layout_item__rotated {
  transform: rotate(90deg);
}

.main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  grid-column: 6/span 3;
}

.main_ui_workspace_sidebar_options_menus_layout_item__row {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__position-row,
.main_ui_workspace_sidebar_options_menus_layout_item__behavior-row,
.main_ui_workspace_sidebar_options_menus_layout_item__align-row,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-row {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_layout_item__position-options {
  inline-size: 100%;
  grid-column: 1/span 5;
}

.main_ui_workspace_sidebar_options_menus_layout_item__margin-row {
  display: grid;
  grid-template-columns: var(--grid-exception-input-width) var(--grid-exception-input-width) var(--sp-xxxl); /* action button */
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__margin-mode {
  grid-column: 3;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple {
  display: grid;
  gap: var(--sp-xs);
  grid-template-columns: subgrid;
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin {
  grid-column: 1;
}
.main_ui_workspace_sidebar_options_menus_layout_item__margin-simple .main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin {
  grid-column: 2;
}

.main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin-wrapper {
  grid-column: 1;
}

.main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin-wrapper {
  grid-column: 2;
}

.main_ui_workspace_sidebar_options_menus_layout_item__margin-multiple {
  display: grid;
  grid-template-columns: subgrid;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__top-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_workspace_sidebar_options_menus_layout_item__top-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__top-margin-wrapper {
  grid-column: 1;
  grid-row: 1;
}

.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin-wrapper {
  grid-column: 2;
  grid-row: 1;
}

.main_ui_workspace_sidebar_options_menus_layout_item__left-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__left-margin-wrapper {
  grid-column: 1;
  grid-row: 2;
}

.main_ui_workspace_sidebar_options_menus_layout_item__right-margin,
.main_ui_workspace_sidebar_options_menus_layout_item__right-margin-wrapper {
  grid-column: 2;
  grid-row: 2;
}

.main_ui_workspace_sidebar_options_menus_layout_item__advanced-options {
  display: grid;
  grid-template-columns: var(--grid-exception-input-width) var(--grid-exception-input-width) var(--sp-xxxl); /* action button */
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__horizontal-fill,
.main_ui_workspace_sidebar_options_menus_layout_item__vertical-fill {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w .main_ui_workspace_sidebar_options_menus_layout_item__icon-text,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h .main_ui_workspace_sidebar_options_menus_layout_item__icon-text,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w .main_ui_workspace_sidebar_options_menus_layout_item__icon-text,
.main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h .main_ui_workspace_sidebar_options_menus_layout_item__icon-text {
  justify-content: flex-start;
  inline-size: 5rem;
  padding-block-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_layout_item__inputs-wrapper {
  grid-column: 1/span 2;
}

.main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper {
  inline-size: 100%;
}
@keyframes main_ui_workspace_sidebar_options_menus_measures__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn svg, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:focus-visible, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:focus-visible svg, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:hover, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:hover svg, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:active, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:active svg, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn.disabled, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label.disabled, [disabled].main_ui_workspace_sidebar_options_menus_measures__lock-size-btn, [disabled].main_ui_workspace_sidebar_options_menus_measures__clip-content-label, .main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:disabled, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn.disabled svg, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_measures__lock-size-btn svg, [disabled].main_ui_workspace_sidebar_options_menus_measures__clip-content-label svg, .main_ui_workspace_sidebar_options_menus_measures__lock-size-btn:disabled svg, .main_ui_workspace_sidebar_options_menus_measures__clip-content-label:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn.main_ui_workspace_sidebar_options_menus_measures__selected, .main_ui_workspace_sidebar_options_menus_measures__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn.main_ui_workspace_sidebar_options_menus_measures__selected svg, .main_ui_workspace_sidebar_options_menus_measures__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_workspace_sidebar_options_menus_measures__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_measures__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_measures__lock-ratio-icon, .main_ui_workspace_sidebar_options_menus_measures__checkbox-button, .main_ui_workspace_sidebar_options_menus_measures__presets-wrapper .main_ui_workspace_sidebar_options_menus_measures__collapsed-icon svg, .main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__check-icon svg, .main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element span svg, .main_ui_workspace_sidebar_options_menus_measures__height span svg,
.main_ui_workspace_sidebar_options_menus_measures__width span svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position span svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position span svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation span svg,
.main_ui_workspace_sidebar_options_menus_measures__height label svg,
.main_ui_workspace_sidebar_options_menus_measures__width label svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position label svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position label svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation label svg, .main_ui_workspace_sidebar_options_menus_measures__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper .main_ui_workspace_sidebar_options_menus_measures__collapsed-icon svg, .main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__check-icon svg, .main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element span svg, .main_ui_workspace_sidebar_options_menus_measures__height span svg,
.main_ui_workspace_sidebar_options_menus_measures__width span svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position span svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position span svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation span svg,
.main_ui_workspace_sidebar_options_menus_measures__height label svg,
.main_ui_workspace_sidebar_options_menus_measures__width label svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position label svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position label svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation label svg, .main_ui_workspace_sidebar_options_menus_measures__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_measures__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_measures__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_measures__height input,
.main_ui_workspace_sidebar_options_menus_measures__width input,
.main_ui_workspace_sidebar_options_menus_measures__x-position input,
.main_ui_workspace_sidebar_options_menus_measures__y-position input,
.main_ui_workspace_sidebar_options_menus_measures__rotation input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__height input[disabled],
.main_ui_workspace_sidebar_options_menus_measures__width input[disabled],
.main_ui_workspace_sidebar_options_menus_measures__x-position input[disabled],
.main_ui_workspace_sidebar_options_menus_measures__y-position input[disabled],
.main_ui_workspace_sidebar_options_menus_measures__rotation input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_measures__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_measures__height span,
.main_ui_workspace_sidebar_options_menus_measures__width span,
.main_ui_workspace_sidebar_options_menus_measures__x-position span,
.main_ui_workspace_sidebar_options_menus_measures__y-position span,
.main_ui_workspace_sidebar_options_menus_measures__rotation span,
.main_ui_workspace_sidebar_options_menus_measures__height label,
.main_ui_workspace_sidebar_options_menus_measures__width label,
.main_ui_workspace_sidebar_options_menus_measures__x-position label,
.main_ui_workspace_sidebar_options_menus_measures__y-position label,
.main_ui_workspace_sidebar_options_menus_measures__rotation label, .main_ui_workspace_sidebar_options_menus_measures__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_measures__height,
.main_ui_workspace_sidebar_options_menus_measures__width,
.main_ui_workspace_sidebar_options_menus_measures__x-position,
.main_ui_workspace_sidebar_options_menus_measures__y-position,
.main_ui_workspace_sidebar_options_menus_measures__rotation {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_measures__height span svg,
.main_ui_workspace_sidebar_options_menus_measures__width span svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position span svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position span svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation span svg,
.main_ui_workspace_sidebar_options_menus_measures__height label svg,
.main_ui_workspace_sidebar_options_menus_measures__width label svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position label svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position label svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_measures__height ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_measures__width ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_measures__x-position ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_measures__y-position ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_measures__rotation ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_measures__height ::placeholder,
.main_ui_workspace_sidebar_options_menus_measures__width ::placeholder,
.main_ui_workspace_sidebar_options_menus_measures__x-position ::placeholder,
.main_ui_workspace_sidebar_options_menus_measures__y-position ::placeholder,
.main_ui_workspace_sidebar_options_menus_measures__rotation ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__height:hover,
.main_ui_workspace_sidebar_options_menus_measures__width:hover,
.main_ui_workspace_sidebar_options_menus_measures__x-position:hover,
.main_ui_workspace_sidebar_options_menus_measures__y-position:hover,
.main_ui_workspace_sidebar_options_menus_measures__rotation:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__height:hover span,
.main_ui_workspace_sidebar_options_menus_measures__width:hover span,
.main_ui_workspace_sidebar_options_menus_measures__x-position:hover span,
.main_ui_workspace_sidebar_options_menus_measures__y-position:hover span,
.main_ui_workspace_sidebar_options_menus_measures__rotation:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__height:hover input,
.main_ui_workspace_sidebar_options_menus_measures__width:hover input,
.main_ui_workspace_sidebar_options_menus_measures__x-position:hover input,
.main_ui_workspace_sidebar_options_menus_measures__y-position:hover input,
.main_ui_workspace_sidebar_options_menus_measures__rotation:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__height:active,
.main_ui_workspace_sidebar_options_menus_measures__width:active,
.main_ui_workspace_sidebar_options_menus_measures__x-position:active,
.main_ui_workspace_sidebar_options_menus_measures__y-position:active,
.main_ui_workspace_sidebar_options_menus_measures__rotation:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__height:active span,
.main_ui_workspace_sidebar_options_menus_measures__width:active span,
.main_ui_workspace_sidebar_options_menus_measures__x-position:active span,
.main_ui_workspace_sidebar_options_menus_measures__y-position:active span,
.main_ui_workspace_sidebar_options_menus_measures__rotation:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__height:active input,
.main_ui_workspace_sidebar_options_menus_measures__width:active input,
.main_ui_workspace_sidebar_options_menus_measures__x-position:active input,
.main_ui_workspace_sidebar_options_menus_measures__y-position:active input,
.main_ui_workspace_sidebar_options_menus_measures__rotation:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus,
.main_ui_workspace_sidebar_options_menus_measures__width:focus,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus, .main_ui_workspace_sidebar_options_menus_measures__height:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus span,
.main_ui_workspace_sidebar_options_menus_measures__width:focus span,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus span,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus span,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus span, .main_ui_workspace_sidebar_options_menus_measures__height:focus-within span,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within span,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within span,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within span,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus input,
.main_ui_workspace_sidebar_options_menus_measures__width:focus input,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus input,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus input,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus input, .main_ui_workspace_sidebar_options_menus_measures__height:focus-within input,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within input,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within input,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within input,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus:hover,
.main_ui_workspace_sidebar_options_menus_measures__width:focus:hover,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus:hover,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus:hover,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus:hover, .main_ui_workspace_sidebar_options_menus_measures__height:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus:hover span,
.main_ui_workspace_sidebar_options_menus_measures__width:focus:hover span,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus:hover span,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus:hover span,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus:hover span, .main_ui_workspace_sidebar_options_menus_measures__height:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_measures__height:focus:hover input,
.main_ui_workspace_sidebar_options_menus_measures__width:focus:hover input,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus:hover input,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus:hover input,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus:hover input, .main_ui_workspace_sidebar_options_menus_measures__height:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_measures__width:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_measures__x-position:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_measures__y-position:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_measures__rotation:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_measures__height.main_ui_workspace_sidebar_options_menus_measures__disabled,
.main_ui_workspace_sidebar_options_menus_measures__width.main_ui_workspace_sidebar_options_menus_measures__disabled,
.main_ui_workspace_sidebar_options_menus_measures__x-position.main_ui_workspace_sidebar_options_menus_measures__disabled,
.main_ui_workspace_sidebar_options_menus_measures__y-position.main_ui_workspace_sidebar_options_menus_measures__disabled,
.main_ui_workspace_sidebar_options_menus_measures__rotation.main_ui_workspace_sidebar_options_menus_measures__disabled {
  background-color: var(--input-background-color-disabled);
  border: 1px solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_measures__height.main_ui_workspace_sidebar_options_menus_measures__disabled input,
.main_ui_workspace_sidebar_options_menus_measures__width.main_ui_workspace_sidebar_options_menus_measures__disabled input,
.main_ui_workspace_sidebar_options_menus_measures__x-position.main_ui_workspace_sidebar_options_menus_measures__disabled input,
.main_ui_workspace_sidebar_options_menus_measures__y-position.main_ui_workspace_sidebar_options_menus_measures__disabled input,
.main_ui_workspace_sidebar_options_menus_measures__rotation.main_ui_workspace_sidebar_options_menus_measures__disabled input {
  pointer-events: none;
  cursor: default;
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_options_menus_measures__height.main_ui_workspace_sidebar_options_menus_measures__disabled svg,
.main_ui_workspace_sidebar_options_menus_measures__width.main_ui_workspace_sidebar_options_menus_measures__disabled svg,
.main_ui_workspace_sidebar_options_menus_measures__x-position.main_ui_workspace_sidebar_options_menus_measures__disabled svg,
.main_ui_workspace_sidebar_options_menus_measures__y-position.main_ui_workspace_sidebar_options_menus_measures__disabled svg,
.main_ui_workspace_sidebar_options_menus_measures__rotation.main_ui_workspace_sidebar_options_menus_measures__disabled svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_measures__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  padding: 0.5rem 0.75rem;
  background-color: var(--assets-item-background-color);
  color: var(--assets-item-name-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper:hover {
  background-color: var(--assets-item-background-color-hover);
  color: var(--assets-item-name-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_measures__custom-select-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_measures__element-set {
  display: grid;
  grid-template-columns: var(--grid-exception-input-width) var(--grid-exception-input-width) var(--sp-xxxl); /* action button */
  gap: var(--sp-xs);
  margin-bottom: var(--sp-s);
}

.main_ui_workspace_sidebar_options_menus_measures__presets {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper {
  position: relative;
  grid-column: span 5;
  display: flex;
  height: 2rem;
  padding: 0.5rem;
  border-radius: 8px;
}
.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper .main_ui_workspace_sidebar_options_menus_measures__collapsed-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  cursor: pointer;
}
.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper .main_ui_workspace_sidebar_options_menus_measures__collapsed-icon svg {
  stroke: var(--icon-foreground);
  transform: rotate(90deg);
}
.main_ui_workspace_sidebar_options_menus_measures__presets-wrapper:hover .main_ui_workspace_sidebar_options_menus_measures__collapsed-icon svg {
  stroke: var(--input-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_measures__radio-buttons {
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_menus_measures__select-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  justify-content: flex-start;
  align-items: center;
  flex-grow: 1;
  cursor: pointer;
}

.main_ui_workspace_sidebar_options_menus_measures__custom-select-dropdown {
  margin-top: 0.125rem;
  max-height: 70vh;
  width: 15.75rem;
  display: flex;
  flex-direction: column;
  overflow: hidden;
}

.main_ui_workspace_sidebar_options_menus_measures__preset-search {
  padding: 0.25rem;
  border-bottom: 1px solid var(--menu-border-color-rest, transparent);
}

.main_ui_workspace_sidebar_options_menus_measures__preset-list {
  flex: 1 1 auto;
  min-height: 0;
  overflow-y: auto;
  margin: 0;
  padding: 0;
  list-style: none;
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__name-wrapper {
  display: flex;
  gap: 0.5rem;
  flex-grow: 1;
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__name-wrapper .main_ui_workspace_sidebar_options_menus_measures__preset-name {
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__name-wrapper .main_ui_workspace_sidebar_options_menus_measures__preset-size {
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__check-icon {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element .main_ui_workspace_sidebar_options_menus_measures__check-icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element.main_ui_workspace_sidebar_options_menus_measures__disabled {
  pointer-events: none;
  cursor: default;
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element.main_ui_workspace_sidebar_options_menus_measures__disabled .main_ui_workspace_sidebar_options_menus_measures__preset-name {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element.main_ui_workspace_sidebar_options_menus_measures__match .main_ui_workspace_sidebar_options_menus_measures__name-wrapper .main_ui_workspace_sidebar_options_menus_measures__preset-name {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element.main_ui_workspace_sidebar_options_menus_measures__match .main_ui_workspace_sidebar_options_menus_measures__check-icon svg {
  stroke: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element:hover .main_ui_workspace_sidebar_options_menus_measures__name-wrapper .main_ui_workspace_sidebar_options_menus_measures__preset-name {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_measures__preset-list .main_ui_workspace_sidebar_options_menus_measures__dropdown-element:hover .main_ui_workspace_sidebar_options_menus_measures__check-icon svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_measures__size,
.main_ui_workspace_sidebar_options_menus_measures__position,
.main_ui_workspace_sidebar_options_menus_measures__rotation-radius {
  display: grid;
  grid-template-columns: subgrid;
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_menus_measures__height,
.main_ui_workspace_sidebar_options_menus_measures__width,
.main_ui_workspace_sidebar_options_menus_measures__x-position,
.main_ui_workspace_sidebar_options_menus_measures__y-position,
.main_ui_workspace_sidebar_options_menus_measures__rotation {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_workspace_sidebar_options_menus_measures__height .main_ui_workspace_sidebar_options_menus_measures__icon-text,
.main_ui_workspace_sidebar_options_menus_measures__width .main_ui_workspace_sidebar_options_menus_measures__icon-text,
.main_ui_workspace_sidebar_options_menus_measures__x-position .main_ui_workspace_sidebar_options_menus_measures__icon-text,
.main_ui_workspace_sidebar_options_menus_measures__y-position .main_ui_workspace_sidebar_options_menus_measures__icon-text,
.main_ui_workspace_sidebar_options_menus_measures__rotation .main_ui_workspace_sidebar_options_menus_measures__icon-text {
  padding-top: 1px;
}
.main_ui_workspace_sidebar_options_menus_measures__border-radius {
  grid-column: 2/-1;
}

.main_ui_workspace_sidebar_options_menus_measures__lock-size-btn {
  border-radius: 8px;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_sidebar_options_menus_measures__lock-ratio-icon {
  stroke: var(--icon-foreground);
}

.main_ui_workspace_sidebar_options_menus_measures__clip-show {
  display: flex;
  align-items: flex-start;
  justify-content: flex-start;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_measures__clip-content .main_ui_workspace_sidebar_options_menus_measures__clip-content-input,
.main_ui_workspace_sidebar_options_menus_measures__show-in-viewer .main_ui_workspace_sidebar_options_menus_measures__clip-content-input {
  display: none;
}

.main_ui_workspace_sidebar_options_menus_measures__clip-content-label {
  height: var(--sp-xxxl);
  width: var(--sp-xxxl);
  border-radius: 8px;
}

.main_ui_workspace_sidebar_options_menus_measures__numeric-input-measures {
  --dropdown-width: var(--seven-columns-width);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_shadow__shadow-section {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_shadow__shadow-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_shadow__shadow-title-bar {
  padding-inline-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_shadow__shadow-content {
  grid-column: span 8;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  margin-block-start: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_shadow__shadow-multiple {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_shadow__shadow-multiple-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  border-radius: 0.5rem;
  block-size: 2rem;
  padding: var(--sp-s);
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_stroke__stroke-section {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_stroke__stroke-title {
  grid-column: span 8;
}

.main_ui_workspace_sidebar_options_menus_stroke__stroke-title-bar {
  padding-inline-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_stroke__stroke-content {
  grid-column: span 8;
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
  margin: var(--sp-xs) 0 var(--sp-s) 0;
}
.main_ui_workspace_sidebar_options_menus_stroke__stroke-content.main_ui_workspace_sidebar_options_menus_stroke__stroke-content-empty {
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_stroke__stroke-multiple {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_stroke__stroke-multiple-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  border-radius: 0.5rem;
  block-size: 2rem;
  padding: var(--sp-s);
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
@keyframes main_ui_workspace_sidebar_options_menus_svg_attrs__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn.disabled, [disabled].main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn svg, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn svg, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input span svg,
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input label svg, .main_ui_workspace_sidebar_options_menus_svg_attrs__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input span svg,
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input label svg, .main_ui_workspace_sidebar_options_menus_svg_attrs__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input span,
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input label, .main_ui_workspace_sidebar_options_menus_svg_attrs__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input span svg,
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus span, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus input, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus:hover, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus:hover span, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus:hover input, .main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__element-set {
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__title-spacing-svg-attrs {
  padding-left: 0.125rem;
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__element-set-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  margin: 0.25rem 0 0 0;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-content {
  display: flex;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.5rem;
  margin: auto 0.25rem;
  margin-right: 0;
  display: inline-block;
  color: var(--title-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  width: 7.75rem;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-actions {
  display: flex;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn {
  width: 1.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-nested-content {
  display: grid;
  row-gap: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.625rem;
  text-transform: uppercase;
  margin-inline-start: 0.25rem;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_svg_attrs__attr-row {
  display: flex;
  gap: 0.25rem;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

.main_ui_workspace_sidebar_options_menus_text__element-set {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_text__element-title {
  grid-column: span 8;
  position: relative;
}

.main_ui_workspace_sidebar_options_menus_text__element-content {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  grid-column: span 8;
  margin-block-start: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_text__multiple-typography {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  flex-grow: 1;
  border-radius: 0.5rem;
  block-size: 2rem;
  padding-block: var(--sp-s);
  padding-inline: var(--sp-s) 0;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_text__multiple-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  flex-grow: 1;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_text__text-align-options {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_text__align-options,
.main_ui_workspace_sidebar_options_menus_text__text-direction-options,
.main_ui_workspace_sidebar_options_menus_text__vertical-align-options,
.main_ui_workspace_sidebar_options_menus_text__grow-options,
.main_ui_workspace_sidebar_options_menus_text__text-decoration-options {
  block-size: 2rem;
}

.main_ui_workspace_sidebar_options_menus_text__text-decoration-options {
  display: flex;
  gap: var(--sp-xs);
}
.main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row {
  --token-typography-row-background-color: var(--color-background-tertiary);
  --token-typography-row-foreground-color: var(--color-token-foreground);
  --token-typography-row-border-color: var(--color-token-border);
  display: flex;
  align-items: center;
  position: relative;
  gap: var(--sp-xs);
  block-size: 2rem;
  min-inline-size: 0;
  inline-size: 100%;
  padding: var(--sp-s);
  margin-inline-end: 0;
  background: var(--token-typography-row-background-color);
  border: 0.0625rem solid var(--token-typography-row-border-color);
  border-radius: 0.5rem;
}
.main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row:hover {
  --token-typography-row-background-color: var(--color-token-background);
  --token-typography-row-foreground-color: var(--color-foreground-primary);
  --token-typography-row-border-color: var(--color-token-accent);
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row-with-errors {
  --token-typography-row-background-color: var(--color-background-primary);
  --token-typography-row-foreground-color: var(--color-foreground-secondary);
  --token-typography-row-border-color: var(--color-token-border);
}
.main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row-with-errors:hover {
  --token-typography-row-background-color: var(--color-background-primary);
  --token-typography-row-foreground-color: var(--color-foreground-secondary);
  --token-typography-row-border-color: var(--color-token-background);
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__icon {
  display: block;
  min-inline-size: 1rem;
  color: var(--token-typography-row-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__token-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--token-typography-row-foreground-color);
  block-size: 2rem;
  flex: 1;
  line-height: 2rem;
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__token-tooltip {
  min-inline-size: 0;
  inline-size: inherit;
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__detach-button {
  flex-shrink: 0;
  inline-size: 0;
  max-inline-size: 0;
  overflow: hidden;
  opacity: 0;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row:hover .main_ui_workspace_sidebar_options_menus_token_typography_row__detach-button {
  inline-size: auto;
  opacity: 1;
  pointer-events: auto;
  max-inline-size: 2rem;
}

.main_ui_workspace_sidebar_options_menus_token_typography_row__error-dot {
  inline-size: 0.25rem;
  block-size: 0.25rem;
  border-radius: 50%;
  background-color: var(--color-foreground-error);
  margin-inline-start: var(--sp-xs);
  position: absolute;
  inset-inline-end: 0.0625rem;
  inset-block-start: 0.3125rem;
}
@keyframes main_ui_workspace_sidebar_options_menus_typography__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_typography__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_typography__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_typography__line-height .main_ui_workspace_sidebar_options_menus_typography__icon svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing .main_ui_workspace_sidebar_options_menus_typography__icon svg, .main_ui_workspace_sidebar_options_menus_typography__line-height span svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing span svg,
.main_ui_workspace_sidebar_options_menus_typography__line-height label svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing label svg, .main_ui_workspace_sidebar_options_menus_typography__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_typography__line-height .main_ui_workspace_sidebar_options_menus_typography__icon svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing .main_ui_workspace_sidebar_options_menus_typography__icon svg, .main_ui_workspace_sidebar_options_menus_typography__line-height span svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing span svg,
.main_ui_workspace_sidebar_options_menus_typography__line-height label svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing label svg, .main_ui_workspace_sidebar_options_menus_typography__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_typography__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_typography__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_typography__font-size-select .main_ui_workspace_sidebar_options_menus_typography__numeric-input, .main_ui_workspace_sidebar_options_menus_typography__line-height input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_typography__font-size-select [disabled].main_ui_workspace_sidebar_options_menus_typography__numeric-input, .main_ui_workspace_sidebar_options_menus_typography__line-height input[disabled],
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_options_menus_typography__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_typography__line-height span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing span,
.main_ui_workspace_sidebar_options_menus_typography__line-height label,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing label, .main_ui_workspace_sidebar_options_menus_typography__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_typography__line-height,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height span svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing span svg,
.main_ui_workspace_sidebar_options_menus_typography__line-height label svg,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height ::-moz-placeholder, .main_ui_workspace_sidebar_options_menus_typography__letter-spacing ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height ::placeholder,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:hover,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:hover span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:hover input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:active,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:active span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:active input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus, .main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus span, .main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus input, .main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus:hover,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus:hover, .main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within:hover,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus:hover span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus:hover span, .main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within:hover span,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_typography__line-height:focus:hover input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus:hover input, .main_ui_workspace_sidebar_options_menus_typography__line-height:focus-within:hover input,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_sidebar_options_menus_typography__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-name-wrapper, .main_ui_workspace_sidebar_options_menus_typography__font-option, .main_ui_workspace_sidebar_options_menus_typography__font-size-options, .main_ui_workspace_sidebar_options_menus_typography__text-transform, .main_ui_workspace_sidebar_options_menus_typography__font-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  padding: 0.5rem 0.75rem;
  background-color: var(--assets-item-background-color);
  color: var(--assets-item-name-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_typography__typography-name-wrapper:hover, .main_ui_workspace_sidebar_options_menus_typography__font-option:hover, .main_ui_workspace_sidebar_options_menus_typography__font-size-options:hover, .main_ui_workspace_sidebar_options_menus_typography__text-transform:hover, .main_ui_workspace_sidebar_options_menus_typography__font-item:hover {
  background-color: var(--assets-item-background-color-hover);
  color: var(--assets-item-name-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-entry {
  --actions-visibility: hidden;
  --typography-entry-background-color: var(--color-background-tertiary);
  --typography-entry-foreground-color: var(--color-foreground-primary);
  --typography-entry-border-color: transparent;
  display: flex;
  flex-direction: row;
  align-items: center;
  block-size: 2rem;
  inline-size: 100%;
  border-radius: 0.5rem;
  background-color: var(--typography-entry-background-color);
  color: var(--typography-entry-foreground-color);
  border: 0.0625rem solid var(--typography-entry-border-color);
}
.main_ui_workspace_sidebar_options_menus_typography__typography-entry:hover, .main_ui_workspace_sidebar_options_menus_typography__typography-entry:focus-within {
  --typography-entry-background-color: var(--color-background-quaternary);
  --typography-entry-foreground-color: var(--color-foreground-primary);
}
.main_ui_workspace_sidebar_options_menus_typography__typography-entry.main_ui_workspace_sidebar_options_menus_typography__selected {
  --typography-entry-border-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_typography__typography-entry:hover {
  --typography-entry-background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_menus_typography__typography-entry:hover .main_ui_workspace_sidebar_options_menus_typography__element-set-actions {
  --actions-visibility: visible;
}

.main_ui_workspace_sidebar_options_menus_typography__element-set-actions {
  display: flex;
  visibility: var(--actions-visibility);
}

.main_ui_workspace_sidebar_options_menus_typography__font-family-mixed {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-selection-wrapper {
  display: grid;
  grid-template-columns: 1.5rem auto 1fr;
  flex: 1;
  block-size: 100%;
  inline-size: 100%;
  padding-inline-start: var(--sp-m);
}
.main_ui_workspace_sidebar_options_menus_typography__typography-selection-wrapper.main_ui_workspace_sidebar_options_menus_typography__is-selectable {
  cursor: pointer;
}

.main_ui_workspace_sidebar_options_menus_typography__typography-sample {
  display: flex;
  justify-content: center;
  align-items: center;
  min-inline-size: 1.5rem;
  block-size: 2rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-name {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper {
  --font-name-wrapper-foreground-color: var(--color-foreground-primary);
  --font-name-wrapper-background-color: var(--color-background-tertiary);
  --font-name-wrapper-border-color: transparent;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  block-size: 2rem;
  inline-size: 100%;
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--font-name-wrapper-border-color);
  box-sizing: border-box;
  background-color: var(--font-name-wrapper-background-color);
  margin-block-end: var(--sp-s);
  padding: var(--sp-s) 0 var(--sp-s) var(--sp-m);
}
.main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper:focus-within {
  --font-name-wrapper-border-color: var(--color-accent-primary);
}
.main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper:hover {
  --font-name-wrapper-background-color: var(--color-background-quaternary);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-sample-input {
  display: flex;
  justify-content: center;
  align-items: center;
  inline-size: 1.5rem;
  block-size: 100%;
  font-size: 1rem;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__adv-typography-name {
  font-size: 0.75rem;
  color: var(--font-name-wrapper-foreground-color);
  flex-grow: 1;
  padding-inline-start: 0.375rem;
  margin: 0;
  border: none;
  background: none;
  outline: none;
}

.main_ui_workspace_sidebar_options_menus_typography__action-btns {
  display: flex;
  align-items: center;
  gap: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_typography__advanced-options-wrapper {
  block-size: 100%;
  inline-size: 100%;
  background-color: var(--color-background-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-info-wrapper {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxs);
  margin-block-end: var(--sp-m);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-name-wrapper {
  display: grid;
  grid-template-columns: 1.5rem auto 1fr 1.75rem;
  flex: 1;
  block-size: 2rem;
  inline-size: 100%;
  padding: 0 0 0 var(--sp-m);
  background-color: var(--color-background-quaternary);
  margin-block-end: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-sample {
  display: flex;
  justify-content: center;
  align-items: center;
  min-inline-size: 1.5rem;
  font-size: 1rem;
  block-size: 2rem;
  padding: 0;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__name-block {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin: 0;
  min-inline-size: 0.375rem;
  padding: 8px 0 8px 6px;
  max-width: 100%;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-name,
.main_ui_workspace_sidebar_options_menus_typography__typography-font {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  min-inline-size: 0;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__typography-font {
  margin-inline-start: 0.375rem;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_options_menus_typography__info-row {
  --calculated-width: calc(var(--right-sidebar-width) - $sz-48);
  display: grid;
  grid-template-columns: 50% 50%;
  block-size: 2rem;
  padding-left: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_typography__info-label,
.main_ui_workspace_sidebar_options_menus_typography__info-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  inline-size: calc(var(--calculated-width) / 2);
  padding-block-start: var(--sp-s);
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__text-options {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  max-inline-size: var(--options-width);
}
.main_ui_workspace_sidebar_options_menus_typography__text-options:not(.main_ui_workspace_sidebar_options_menus_typography__text-options-full-size) {
  position: relative;
}

.main_ui_workspace_sidebar_options_menus_typography__font-option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding: var(--sp-s);
  cursor: pointer;
}

.main_ui_workspace_sidebar_options_menus_typography__font-option-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  inline-size: 100%;
}

.main_ui_workspace_sidebar_options_menus_typography__font-modifiers {
  display: flex;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_typography__font-size-options {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  flex-grow: 1;
  inline-size: 3.75rem;
  margin: 0;
  padding: 0;
  border: 0.0625rem solid var(--color-background-tertiary);
  position: relative;
}

.main_ui_workspace_sidebar_options_menus_typography__font-variant-options {
  padding: 0;
  flex-grow: 2;
}

.main_ui_workspace_sidebar_options_menus_typography__typography-variations {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_typography__spacing-options {
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_options_menus_typography__line-height,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}
.main_ui_workspace_sidebar_options_menus_typography__line-height .main_ui_workspace_sidebar_options_menus_typography__icon,
.main_ui_workspace_sidebar_options_menus_typography__letter-spacing .main_ui_workspace_sidebar_options_menus_typography__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  inline-size: 1.75rem;
}
.main_ui_workspace_sidebar_options_menus_typography__text-transform {
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  padding: 0;
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_sidebar_options_menus_typography__font-size-select {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  block-size: 100%;
  inline-size: 100%;
  margin: 0;
  padding: var(--sp-s);
  border: none;
  background: none;
  outline: none;
}
.main_ui_workspace_sidebar_options_menus_typography__font-size-select .main_ui_workspace_sidebar_options_menus_typography__numeric-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding: 0;
}

.main_ui_workspace_sidebar_options_menus_typography__font-selector {
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  top: calc(-1 * 1.125rem);
  left: 0;
  right: 0;
  block-size: 100%;
  inline-size: 100%;
  z-index: var(--z-index-dropdown);
}

.main_ui_workspace_sidebar_options_menus_typography__fonts-on-modal {
  top: 0;
}

.main_ui_workspace_sidebar_options_menus_typography__show-recent {
  border-radius: 0.5rem 0.5rem 0 0;
  background: var(--color-background-tertiary);
  border: 0.0625rem solid var(--color-background-quaternary);
  border-block-end: none;
}

.main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown {
  inline-size: 100%;
}
.main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown:not(.main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown-full-size) {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  block-size: 100%;
}

.main_ui_workspace_sidebar_options_menus_typography__header {
  display: grid;
  row-gap: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_typography__header-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--color-foreground-secondary);
  margin: 0;
  padding: var(--sp-m);
}

.main_ui_workspace_sidebar_options_menus_typography__font-wrapper {
  padding-bottom: var(--sp-xs);
  cursor: pointer;
}

.main_ui_workspace_sidebar_options_menus_typography__font-item {
  margin-bottom: var(--sp-xs);
  border-radius: 0.5rem;
  display: flex;
}
.main_ui_workspace_sidebar_options_menus_typography__font-item.main_ui_workspace_sidebar_options_menus_typography__selected {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_options_menus_typography__font-item-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  min-inline-size: 0;
}

.main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown-full-size {
  block-size: var(--sidebar-element-options-height);
  display: grid;
  grid-template-rows: auto 1fr;
  padding: var(--sp-xxs) var(--sp-m) var(--sp-m) var(--sp-m);
}

.main_ui_workspace_sidebar_options_menus_typography__fonts-list {
  position: relative;
  display: flex;
  flex-direction: column;
  flex: 1 1 auto;
  min-block-size: 100%;
  inline-size: 100%;
  block-size: 100%;
  padding: var(--sp-xxs);
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
  overflow: hidden;
}
.main_ui_workspace_sidebar_options_menus_typography__fonts-list:not(.main_ui_workspace_sidebar_options_menus_typography__fonts-list-full-size) {
  margin-block-start: var(--sp-xxs);
}

.main_ui_workspace_sidebar_options_menus_typography__fonts-list-full-size {
  border-start-start-radius: 0;
  border-start-end-radius: 0;
  border: 0.0625rem solid var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_options_menus_typography__fonts-list-full-size .main_ui_workspace_sidebar_options_menus_typography__selected {
  padding-inline-end: 0;
}

.main_ui_workspace_sidebar_options_menus_typography__dropdown-icon {
  color: var(--color-foreground-secondary);
}
@keyframes main_ui_workspace_sidebar_options_menus_variants_help_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn.disabled, [disabled].main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn, .main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn.disabled svg, [disabled].main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn svg, .main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn svg, .main_ui_workspace_sidebar_options_menus_variants_help_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-dialog {
  max-width: 55.5rem;
  width: 100%;
  max-height: unset;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-title {
  color: var(--modal-title-foreground-color);
  margin-bottom: 2rem;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-content {
  display: flex;
  color: var(--color-foreground-secondary);
  padding-block-end: 2rem;
  gap: 2rem;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-list {
  margin: 2rem 0;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item {
  display: flex;
  gap: 1rem;
  align-items: center;
  margin-bottom: 1rem;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item:last-child {
  margin-bottom: 0;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight {
  color: var(--color-foreground-primary);
  margin-inline-end: 0.25rem;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  width: 2rem;
  height: 2rem;
  background: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
  border-radius: 90px;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text {
  margin: 0;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__button-row {
  display: flex;
  justify-content: end;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__help-text {
  flex: 0 1 50%;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__help-text :last-child {
  margin-block-end: 0;
}

.main_ui_workspace_sidebar_options_menus_variants_help_modal__help-image {
  flex: 0 1 50%;
}
.main_ui_workspace_sidebar_options_menus_variants_help_modal__help-image img {
  border-radius: 8px;
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}

@keyframes main_ui_workspace_sidebar_options_drawing_frame__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_options_drawing_frame__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_options_drawing_frame__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper .main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon svg, .main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__check-icon svg, .main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element span svg, .main_ui_workspace_sidebar_options_drawing_frame__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper .main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon svg, .main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__check-icon svg, .main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element span svg, .main_ui_workspace_sidebar_options_drawing_frame__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_options_drawing_frame__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_options_drawing_frame__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_options_drawing_frame__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_options_drawing_frame__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_options_drawing_frame__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  padding: 0.5rem 0.75rem;
  background-color: var(--assets-item-background-color);
  color: var(--assets-item-name-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper:hover {
  background-color: var(--assets-item-background-color-hover);
  color: var(--assets-item-name-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_workspace_sidebar_options_drawing_frame__custom-select-dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  position: absolute;
  top: 2rem;
  left: 0;
  width: 100%;
  max-height: var(--menu-max-height, 18.75rem);
  padding: 0.125rem;
  margin: 0;
  margin-top: 1px;
  border-radius: 8px;
  z-index: 4;
  overflow: hidden auto;
  background-color: var(--menu-background-color);
  color: var(--menu-foreground-color);
  border: 0.125rem solid var(--panel-border-color);
}

.main_ui_workspace_sidebar_options_drawing_frame__presets {
  display: grid;
  grid-template-columns: repeat(8, 2rem);
  -moz-column-gap: var(--sp-xs);
       column-gap: var(--sp-xs);
  grid-column: 1/-1;
}

.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper {
  position: relative;
  grid-column: span 6;
  display: flex;
  height: 2rem;
  padding: 0.5rem;
  border-radius: 8px;
}
.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper .main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  cursor: pointer;
}
.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper .main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon svg {
  stroke: var(--icon-foreground);
  transform: rotate(90deg);
}
.main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper:hover .main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon svg {
  stroke: var(--input-foreground-color-active);
}

.main_ui_workspace_sidebar_options_drawing_frame__radio-buttons {
  grid-column: span 2;
}

.main_ui_workspace_sidebar_options_drawing_frame__select-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  justify-content: flex-start;
  align-items: center;
  flex-grow: 1;
  cursor: pointer;
}

.main_ui_workspace_sidebar_options_drawing_frame__custom-select-dropdown {
  margin-top: 0.125rem;
  max-height: 70vh;
  width: 15.75rem;
  display: flex;
  flex-direction: column;
  overflow: hidden;
}

.main_ui_workspace_sidebar_options_drawing_frame__preset-search {
  padding: 0.25rem;
  border-bottom: 1px solid var(--menu-border-color-rest, transparent);
}

.main_ui_workspace_sidebar_options_drawing_frame__preset-list {
  flex: 1 1 auto;
  min-height: 0;
  overflow-y: auto;
  margin: 0;
  padding: 0;
  list-style: none;
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__name-wrapper {
  display: flex;
  gap: 0.5rem;
  flex-grow: 1;
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__name-wrapper .main_ui_workspace_sidebar_options_drawing_frame__preset-name {
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__name-wrapper .main_ui_workspace_sidebar_options_drawing_frame__preset-size {
  color: var(--menu-foreground-color-rest);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__check-icon {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element .main_ui_workspace_sidebar_options_drawing_frame__check-icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element.main_ui_workspace_sidebar_options_drawing_frame__disabled {
  pointer-events: none;
  cursor: default;
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element.main_ui_workspace_sidebar_options_drawing_frame__disabled .main_ui_workspace_sidebar_options_drawing_frame__preset-name {
  color: var(--menu-foreground-color);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element.main_ui_workspace_sidebar_options_drawing_frame__match .main_ui_workspace_sidebar_options_drawing_frame__name-wrapper .main_ui_workspace_sidebar_options_drawing_frame__preset-name {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element.main_ui_workspace_sidebar_options_drawing_frame__match .main_ui_workspace_sidebar_options_drawing_frame__check-icon svg {
  stroke: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element:hover .main_ui_workspace_sidebar_options_drawing_frame__name-wrapper .main_ui_workspace_sidebar_options_drawing_frame__preset-name {
  color: var(--menu-foreground-color-hover);
}
.main_ui_workspace_sidebar_options_drawing_frame__preset-list .main_ui_workspace_sidebar_options_drawing_frame__dropdown-element:hover .main_ui_workspace_sidebar_options_drawing_frame__check-icon svg {
  stroke: var(--menu-foreground-color-hover);
}
:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --left-sidebar-width: 19.875rem;
  --left-sidebar-width-max: 31.25rem;
  --right-sidebar-width: 19.875rem;
  --right-sidebar-width-max: 48rem;
  --two-columns-width: calc(2rem * 2 + var(--sp-xs) * 1);
  --three-columns-width: calc(2rem * 3 + var(--sp-xs) * 2);
  --four-columns-width: calc(2rem * 4 + var(--sp-xs) * 3);
  --seven-columns-width: calc(2rem * 7 + var(--sp-xs) * 6);
  --options-width: calc(2rem * 8 + var(--sp-xs) * 7);
  --grid-exception-input-width: calc(2rem * 3.5 + 3 * var(--sp-xs) - var(--sp-xs) / 2);
  --grid-exception-input-width-small: calc(2rem * 2.5 + 2 * var(--sp-xs) - var(--sp-xs) / 2);
}
@keyframes main_ui_workspace_sidebar_assets_colors__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_assets_colors__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_assets_colors__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_colors__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_colors__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_colors__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_assets_colors__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_colors__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_colors__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_assets_colors__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_assets_colors__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_assets_colors__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_assets_colors__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_assets_colors__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_assets_colors__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_assets_colors__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_assets_colors__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_assets_colors__colors-group {
  margin-top: 0.25rem;
}

.main_ui_workspace_sidebar_assets_colors__asset-list {
  padding: 0 0 0 0.25rem;
}

.main_ui_workspace_sidebar_assets_colors__asset-list-item {
  position: relative;
  display: grid;
  grid-template-columns: auto 1fr 1.75rem;
  align-items: center;
  height: 2rem;
  padding: 0.5rem;
  padding-inline-end: 0;
  margin-bottom: 0.25rem;
  border-radius: 8px;
  background-color: var(--assets-item-background-color);
  cursor: pointer;
}
.main_ui_workspace_sidebar_assets_colors__asset-list-item.main_ui_workspace_sidebar_assets_colors__selected {
  border: 1px solid var(--assets-item-border-color);
}
.main_ui_workspace_sidebar_assets_colors__asset-list-item.main_ui_workspace_sidebar_assets_colors__editing {
  border: 1px solid var(--input-border-color-focus);
}
.main_ui_workspace_sidebar_assets_colors__asset-list-item.main_ui_workspace_sidebar_assets_colors__editing input.main_ui_workspace_sidebar_assets_colors__element-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border: none;
  background: none;
  outline: none;
  flex-grow: 1;
  margin: 0;
  color: var(--layer-row-foreground-color);
}
.main_ui_workspace_sidebar_assets_colors__asset-list-item:hover {
  background-color: var(--assets-item-background-color-hover);
}

.main_ui_workspace_sidebar_assets_colors__bullet-block {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  justify-content: flex-start;
  margin-inline-end: 0.25rem;
}

.main_ui_workspace_sidebar_assets_colors__name-block {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin: 0;
  color: var(--assets-item-name-foreground-color);
}

.main_ui_workspace_sidebar_assets_colors__default-name {
  margin-inline-start: 0.25rem;
  color: var(--assets-item-name-foreground-color-rest);
}

.main_ui_workspace_sidebar_assets_colors__default-name-with-color {
  margin-left: 0.375rem;
}

.main_ui_workspace_sidebar_assets_colors__element-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--color-foreground-primary);
}

.main_ui_workspace_sidebar_assets_colors__grid-placeholder {
  height: 0.125rem;
  margin-bottom: 0.125rem;
  background-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_assets_colors__drop-space {
  height: 0.75rem;
}

.main_ui_workspace_sidebar_assets_colors__dragging {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border-radius: 0.5rem;
  background-color: var(--assets-item-background-color-drag);
  border: 0.125rem solid var(--assets-item-border-color-drag);
}
@keyframes main_ui_workspace_sidebar_assets_common__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_assets_common__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_assets_common__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_common__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_common__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_common__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_assets_common__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_common__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_common__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_assets_common__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_assets_common__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_assets_common__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_assets_common__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_assets_common__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_assets_common__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_assets_common__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_assets_common__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_assets_common__title-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  display: flex;
  align-items: center;
  flex-grow: 1;
  width: 100%;
}

.main_ui_workspace_sidebar_assets_common__title-tokens {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  text-transform: capitalize;
}

.main_ui_workspace_sidebar_assets_common__title-tokens-active {
  color: var(--assets-item-name-foreground-color, --color-foreground-primary);
}

.main_ui_workspace_sidebar_assets_common__section-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  padding-right: 0.125rem;
}
.main_ui_workspace_sidebar_assets_common__section-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  fill: none;
  stroke: currentcolor;
}

.main_ui_workspace_sidebar_assets_common__section-name {
  display: flex;
  align-items: center;
  margin: 0 0.125rem;
}

.main_ui_workspace_sidebar_assets_common__num-assets {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  padding-left: 0.5rem;
}

.main_ui_workspace_sidebar_assets_common__title-spacing {
  padding-block-start: 0.25rem;
}

.main_ui_workspace_sidebar_assets_common__asset-section.main_ui_workspace_sidebar_assets_common__opened {
  margin-bottom: 0.75rem;
}

.main_ui_workspace_sidebar_assets_common__drag-counter {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100%;
  height: calc(1.5rem - 0.125rem);
  background-color: var(--assets-item-name-background-color);
  color: var(--assets-item-name-foreground-color);
  display: flex;
  justify-content: flex-start;
  align-items: center;
  margin: 0.25rem;
  padding-inline: 0.25rem;
  z-index: 2;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_workspace_sidebar_assets_components__component-item {
  position: relative;
  cursor: pointer;
}

.main_ui_workspace_sidebar_assets_components__component-item-grid {
  aspect-ratio: 1/1;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  background-color: var(--color-canvas);
  overflow: hidden;
}
.main_ui_workspace_sidebar_assets_components__component-item-grid:hover .main_ui_workspace_sidebar_assets_components__component-item-grid-name {
  display: flex;
}
.main_ui_workspace_sidebar_assets_components__component-item-grid.main_ui_workspace_sidebar_assets_components__component-item-selected {
  border: 0.125rem solid var(--color-accent-primary);
}
.main_ui_workspace_sidebar_assets_components__component-item-grid.main_ui_workspace_sidebar_assets_components__component-item-selected::before {
  content: " ";
  position: absolute;
  inset: 0;
  border: 0.25rem solid var(--color-background-primary);
  border-radius: 0.5rem;
}

.main_ui_workspace_sidebar_assets_components__component-item-grid-name {
  display: none;
  align-items: center;
  position: absolute;
  height: 1.5rem;
  left: var(--sp-xs);
  right: var(--sp-xs);
  bottom: var(--sp-xs);
  border-radius: 0.25rem;
  background-color: var(--color-background-primary);
  color: var(--color-foreground-primary);
  padding: 0;
}
.main_ui_workspace_sidebar_assets_components__component-item-grid-name.main_ui_workspace_sidebar_assets_components__component-item-editing {
  display: flex;
}

.main_ui_workspace_sidebar_assets_components__component-item-grid-input {
  border-radius: 0.25rem;
}

.main_ui_workspace_sidebar_assets_components__component-item-grid-label {
  padding: 0 var(--sp-s);
}

.main_ui_workspace_sidebar_assets_components__component-item-list {
  display: grid;
  grid-template-columns: auto 1fr auto;
  align-items: center;
  -moz-column-gap: var(--sp-s);
       column-gap: var(--sp-s);
  padding: var(--sp-xxs);
  margin-inline-end: var(--sp-xxs);
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
}
.main_ui_workspace_sidebar_assets_components__component-item-list:hover {
  background-color: var(--color-background-quaternary);
}
.main_ui_workspace_sidebar_assets_components__component-item-list.main_ui_workspace_sidebar_assets_components__component-item-selected {
  outline: 0.0625rem solid var(--color-accent-primary);
}

.main_ui_workspace_sidebar_assets_components__component-item-list-name {
  overflow: hidden;
  order: 2;
  display: flex;
  align-items: center;
  color: var(--color-foreground-primary);
  padding: 0;
}

.main_ui_workspace_sidebar_assets_components__component-item-list-input {
  border-radius: 0.5rem;
  height: 2rem;
}

.main_ui_workspace_sidebar_assets_components__component-item-list-label {
  padding: 0;
}

.main_ui_workspace_sidebar_assets_components__component-item-thumbnail {
  width: 100%;
  height: 100%;
  -o-object-fit: contain;
     object-fit: contain;
  pointer-events: none;
  border: 0;
}

.main_ui_workspace_sidebar_assets_components__component-item-list-thumbnail {
  flex-shrink: 0;
  padding: var(--sp-xxs);
  height: 2.5rem;
  width: 2.5rem;
  border-radius: 0.375rem;
  background-color: var(--color-canvas);
}

.main_ui_workspace_sidebar_assets_components__component-item-variant-mark {
  margin-right: var(--sp-xs);
  display: flex;
  align-items: center;
  justify-content: center;
  height: 1.5rem;
  width: 1.5rem;
  color: var(--color-accent-secondary);
  order: 3;
}

.main_ui_workspace_sidebar_assets_components__component-item-grid-variant-mark {
  margin: 0;
  position: absolute;
  right: var(--sp-xxs);
  top: var(--sp-xxs);
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_sidebar_assets_components__component-item-dragging {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border-radius: var(--sp-s);
  border: 0.125rem solid var(--color-accent-primary-muted);
}

.main_ui_workspace_sidebar_assets_components__component-group {
  display: grid;
  grid-template-columns: 1fr;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_assets_components__component-group-grid {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(6rem, 1fr));
  max-width: 100%;
  gap: var(--sp-xs);
  margin-inline: var(--sp-s);
}

.main_ui_workspace_sidebar_assets_components__component-group-list {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_sidebar_assets_components__component-group-placeholder {
  width: 100%;
  height: var(--sp-xxs);
  border-radius: 0.5rem;
  background-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_assets_components__component-group-drop-space {
  height: var(--sp-m);
}

.main_ui_workspace_sidebar_assets_components__component-group-drop-space-small {
  height: var(--sp-xxs);
}
@keyframes main_ui_workspace_sidebar_assets_file_library__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_assets_file_library__file-link {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_assets_file_library__file-link svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_file_library__file-link:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_file_library__file-link:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_file_library__file-link:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_assets_file_library__file-link:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_file_library__file-link:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_file_library__file-link:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_file_library__file-link.disabled, [disabled].main_ui_workspace_sidebar_assets_file_library__file-link, .main_ui_workspace_sidebar_assets_file_library__file-link:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_assets_file_library__file-link.disabled svg, [disabled].main_ui_workspace_sidebar_assets_file_library__file-link svg, .main_ui_workspace_sidebar_assets_file_library__file-link:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_assets_file_library__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_assets_file_library__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_file_library__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_file_library__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_file_library__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_assets_file_library__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_file_library__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_file_library__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_assets_file_library__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_assets_file_library__file-link svg, .main_ui_workspace_sidebar_assets_file_library__no-found-icon svg, .main_ui_workspace_sidebar_assets_file_library__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_assets_file_library__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_assets_file_library__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_assets_file_library__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_assets_file_library__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_assets_file_library__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_assets_file_library__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_assets_file_library__tool-window {
  padding: 0 0 1.5rem 0.75rem;
  display: grid;
  grid-auto-rows: max-content;
  gap: 0.25rem;
  height: 100%;
}

.main_ui_workspace_sidebar_assets_file_library__file-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  justify-content: flex-start;
  align-items: center;
  flex-grow: 100;
  height: 100%;
}

.main_ui_workspace_sidebar_assets_file_library__loading {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: flex-start;
  height: 2rem;
  padding-left: calc(0.75rem + 0.125rem);
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_sidebar_assets_file_library__special-title {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--title-foreground-color-hover);
  margin-left: 0.125rem;
  text-align: left;
}

.main_ui_workspace_sidebar_assets_file_library__file-link {
  height: 2rem;
  width: 1.75rem;
  border-radius: 8px;
}
.main_ui_workspace_sidebar_assets_file_library__file-link svg {
  stroke: var(--icon-foreground);
  fill: var(--title-foreground-color-hover);
}

.main_ui_workspace_sidebar_assets_file_library__library-content {
  width: 100%;
  display: grid;
  grid-auto-rows: max-content;
  gap: 0.25rem;
}

.main_ui_workspace_sidebar_assets_file_library__asset-title {
  margin-left: 1.75rem;
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 0.5rem;
}

.main_ui_workspace_sidebar_assets_file_library__no-found-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--not-found-background-color);
  border-radius: 50%;
  height: 3rem;
  width: 3rem;
}
.main_ui_workspace_sidebar_assets_file_library__no-found-icon svg {
  height: 1.5rem;
  width: 1.5rem;
  stroke: var(--not-found-foreground-color);
}

.main_ui_workspace_sidebar_assets_file_library__no-found-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--not-found-foreground-color);
}
@keyframes main_ui_workspace_sidebar_assets_groups__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_sidebar_assets_groups__accept-btn.main_ui_workspace_sidebar_assets_groups__danger, .main_ui_workspace_sidebar_assets_groups__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_workspace_sidebar_assets_groups__accept-btn.main_ui_workspace_sidebar_assets_groups__danger svg, .main_ui_workspace_sidebar_assets_groups__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_groups__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_assets_groups__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_groups__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_workspace_sidebar_assets_groups__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__accept-btn.disabled, [disabled].main_ui_workspace_sidebar_assets_groups__accept-btn, .main_ui_workspace_sidebar_assets_groups__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_assets_groups__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_workspace_sidebar_assets_groups__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__cancel-button.disabled, [disabled].main_ui_workspace_sidebar_assets_groups__cancel-button, .main_ui_workspace_sidebar_assets_groups__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_workspace_sidebar_assets_groups__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn.disabled, [disabled].main_ui_workspace_sidebar_assets_groups__modal-close-btn, .main_ui_workspace_sidebar_assets_groups__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_workspace_sidebar_assets_groups__modal-close-btn.disabled svg, [disabled].main_ui_workspace_sidebar_assets_groups__modal-close-btn svg, .main_ui_workspace_sidebar_assets_groups__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_workspace_sidebar_assets_groups__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_sidebar_assets_groups__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_sidebar_assets_groups__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_sidebar_assets_groups__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_sidebar_assets_groups__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_sidebar_assets_groups__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_sidebar_assets_groups__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_sidebar_assets_groups__modal-close-btn svg, .main_ui_workspace_sidebar_assets_groups__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_sidebar_assets_groups__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_sidebar_assets_groups__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_sidebar_assets_groups__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_sidebar_assets_groups__input-wrapper input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_sidebar_assets_groups__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_sidebar_assets_groups__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_sidebar_assets_groups__input-wrapper.disabled {
  background-color: var(--input-background-color-disabled);
  border: 1px solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper.disabled input {
  pointer-events: none;
  cursor: default;
  color: var(--input-foreground-color-disabled);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper.disabled svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_workspace_sidebar_assets_groups__input-wrapper {
  display: flex;
  flex-direction: column;
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  min-height: 1rem;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border-radius: 8px;
  height: 2rem;
  min-height: 2rem;
  margin-top: 0.5rem;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper input:focus-within input, .main_ui_workspace_sidebar_assets_groups__input-wrapper input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper input:focus-within, .main_ui_workspace_sidebar_assets_groups__input-wrapper input:active {
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_sidebar_assets_groups__input-wrapper.invalid input {
  border: 1px solid var(--input-border-color-error);
}

.main_ui_workspace_sidebar_assets_groups__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_workspace_sidebar_assets_groups__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_workspace_sidebar_assets_groups__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_workspace_sidebar_assets_groups__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_sidebar_assets_groups__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_workspace_sidebar_assets_groups__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_workspace_sidebar_assets_groups__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_workspace_sidebar_assets_groups__accept-btn.main_ui_workspace_sidebar_assets_groups__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_workspace_sidebar_assets_groups__group-title-wrapper {
  width: 100%;
  display: flex;
  justify-content: space-between;
}
.main_ui_workspace_sidebar_assets_groups__group-title-wrapper:hover {
  cursor: pointer;
}
.main_ui_workspace_sidebar_assets_groups__group-title-wrapper:hover .main_ui_workspace_sidebar_assets_groups__title-menu {
  visibility: visible;
}

.main_ui_workspace_sidebar_assets_groups__group-title-wrapper > :first-child {
  flex: 1 1 auto;
}

.main_ui_workspace_sidebar_assets_groups__title-menu {
  display: flex;
  visibility: hidden;
}

.main_ui_workspace_sidebar_assets_groups__group-title {
  padding-left: 0.25rem;
}

.main_ui_workspace_sidebar_assets_groups__pre-path {
  margin-left: 0.125rem;
  text-transform: initial;
  color: var(--title-foreground-color);
}

.main_ui_workspace_sidebar_assets_groups__path {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin-left: 0.125rem;
  text-transform: initial;
  color: var(--title-foreground-color-hover);
}

.main_ui_workspace_sidebar_assets_groups__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_workspace_sidebar_assets_groups__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_workspace_sidebar_assets_groups__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-bottom: 1.5rem;
}

.main_ui_workspace_sidebar_assets_groups__input-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-bottom: 0.5rem;
}
.main_ui_workspace_sidebar_assets_typographies__assets-list {
  padding: 0 0 0 var(--sp-xs);
}

.main_ui_workspace_sidebar_assets_typographies__drop-space {
  block-size: 0.75rem;
}

.main_ui_workspace_sidebar_assets_typographies__grid-placeholder {
  block-size: 0.125rem;
  inline-size: 100%;
  background-color: var(--color-accent-primary);
}

.main_ui_workspace_sidebar_assets_typographies__typography-item {
  position: relative;
  display: flex;
  align-items: center;
  margin-block-end: var(--sp-xs);
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
  inline-size: var(--options-width);
}

.main_ui_workspace_sidebar_assets_typographies__dragging {
  position: absolute;
  inset-block-start: 0;
  inset-inline-start: 0;
  block-size: 100%;
  inline-size: 100%;
  border: 0.125rem solid var(--color-accent-primary-muted);
  border-radius: 0.5rem;
  background-color: transparent;
}
.selection-imposter-rect {
  position: absolute;
  background-color: var(--text-editor-selection-background-color);
}

.main_ui_workspace_shapes_text_v2_editor__text-editor-container {
  height: 100%;
  position: relative;
  cursor: text;
}

.main_ui_workspace_shapes_text_v2_editor__text-editor-selection-imposter {
  position: relative;
}

.main_ui_workspace_shapes_text_v2_editor__text-editor-content {
  height: 100%;
  font-family: "sourcesanspro", sans-serif;
  outline: none;
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
  white-space: pre-wrap;
  overflow-wrap: break-word;
  caret-color: var(--text-editor-caret-color);
  color: transparent;
  -webkit-text-size-adjust: none;
     -moz-text-size-adjust: none;
          text-size-adjust: none;
  font-kerning: normal;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content::-moz-selection, .main_ui_workspace_shapes_text_v2_editor__text-editor-content *::-moz-selection {
  color: transparent;
  -webkit-text-fill-color: transparent;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content::selection,
.main_ui_workspace_shapes_text_v2_editor__text-editor-content *::selection {
  color: transparent;
  -webkit-text-fill-color: transparent;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content::-moz-selection, .main_ui_workspace_shapes_text_v2_editor__text-editor-content *::-moz-selection {
  color: transparent;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content::selection,
.main_ui_workspace_shapes_text_v2_editor__text-editor-content *::selection {
  color: transparent;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content [data-itype=paragraph] {
  line-height: inherit;
  -webkit-user-select: text;
     -moz-user-select: text;
          user-select: text;
  margin: 0;
  font-size: 0;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content [data-itype=span] {
  box-sizing: content-box;
  display: inline;
  line-height: inherit;
  caret-color: var(--text-editor-caret-color);
  word-break: normal;
  overflow-wrap: break-word;
  -moz-tab-size: 2;
    -o-tab-size: 2;
       tab-size: 2;
}
.main_ui_workspace_shapes_text_v2_editor__text-editor-content [data-itype=root] {
  display: flex;
  flex-direction: column;
  height: 100%;
}

.main_ui_workspace_shapes_text_v2_editor__grow-type-auto-width [data-itype=span],
.main_ui_workspace_shapes_text_v2_editor__grow-type-auto-width [data-itype=paragraph] {
  white-space: pre;
  overflow-wrap: normal;
  word-break: keep-all;
}

.main_ui_workspace_shapes_text_v2_editor__align-top [data-itype=root] {
  justify-content: start;
}

.main_ui_workspace_shapes_text_v2_editor__align-center [data-itype=root] {
  justify-content: center;
}

.main_ui_workspace_shapes_text_v2_editor__align-bottom [data-itype=root] {
  justify-content: end;
}
.main_ui_workspace_shapes_text_v3_editor__text-editor {
  height: 100%;
}

.main_ui_workspace_shapes_text_v3_editor__text-editor-container {
  width: 100%;
  height: 100%;
  position: absolute;
  opacity: 0;
  overflow: hidden;
  white-space: pre;
}
@keyframes main_ui_workspace_colorpicker_color_inputs__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker_color_inputs__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker_color_inputs__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker_color_inputs__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_color_inputs__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_color_inputs__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker_color_inputs__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker_color_inputs__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker_color_inputs__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker_color_inputs__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker_color_inputs__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker_color_inputs__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker_color_inputs__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker_color_inputs__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker_color_inputs__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker_color_inputs__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker_color_inputs__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_workspace_colorpicker_color_inputs__color-values {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  padding: 0 1px;
  margin-block-start: var(--sp-s);
}
.main_ui_workspace_colorpicker_color_inputs__color-values.main_ui_workspace_colorpicker_color_inputs__disable-opacity {
  grid-template-columns: 3.5rem repeat(3, 1fr);
}

.main_ui_workspace_colorpicker_color_inputs__model-switcher {
  display: flex;
  align-self: flex-start;
  gap: var(--sp-xs);
  padding: var(--sp-xxs);
  margin-block-end: var(--sp-s);
  border-radius: 0.375rem;
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_colorpicker_color_inputs__model-pill {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding: var(--sp-xxs) var(--sp-s);
  border: none;
  border-radius: 0.25rem;
  color: var(--color-foreground-secondary);
  background: transparent;
  cursor: pointer;
}
.main_ui_workspace_colorpicker_color_inputs__model-pill:hover {
  color: var(--color-foreground-primary);
}

.main_ui_workspace_colorpicker_color_inputs__model-pill-active {
  background-color: var(--color-background-primary);
  color: var(--color-accent-primary);
}

.main_ui_workspace_colorpicker_color_inputs__colors-row {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  gap: var(--sp-xs);
}

.main_ui_workspace_colorpicker_color_inputs__hex-alpha-wrapper {
  display: grid;
  grid-template-columns: 1fr 1fr 1fr;
  gap: var(--sp-xs);
}

.main_ui_workspace_colorpicker_color_inputs__hex-input {
  grid-column: span 2;
}
.main_ui_workspace_colorpicker_color_tokens__color-token-list {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_colorpicker_color_tokens__color-token-item {
  --color-token-background: var(--color-background-primary);
  background-color: var(--color-token-background);
  color: var(--color-foreground-primary);
  text-align: left;
  display: grid;
  grid-template-columns: auto 1fr auto;
  align-items: center;
  gap: var(--sp-xs);
  inline-size: 100%;
  border-radius: 0.5rem;
  padding: var(--sp-xs);
  block-size: 1.75rem;
  border: none;
  cursor: pointer;
}
.main_ui_workspace_colorpicker_color_tokens__color-token-item:hover {
  --color-token-background: var(--color-background-tertiary);
}

.main_ui_workspace_colorpicker_color_tokens__color-token-empty-state {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding: var(--sp-s) var(--sp-xxl);
  text-align: center;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_colorpicker_color_tokens__color-token-selected {
  background-color: var(--color-background-tertiary);
}

.main_ui_workspace_colorpicker_color_tokens__color-token-selected-grid {
  border: 0.0625rem solid var(--color-accent-primary);
  border-radius: 0.25rem;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
}

.main_ui_workspace_colorpicker_color_tokens__token-selected-icon {
  color: var(--color-accent-primary);
}

.main_ui_workspace_colorpicker_color_tokens__token-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}

.main_ui_workspace_colorpicker_color_tokens__color-tokens-section {
  max-block-size: 26.875rem;
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}

.main_ui_workspace_colorpicker_color_tokens__grid-view {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(var(--sp-xxl), 1fr));
  justify-items: start;
  gap: var(--sp-s);
}

.main_ui_workspace_colorpicker_color_tokens__list-view {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_workspace_colorpicker_color_tokens__search-input {
  padding: 0.0625rem;
}

.main_ui_workspace_colorpicker_color_tokens__color-tokens-inputs {
  overflow: auto;
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}

.main_ui_workspace_colorpicker_color_tokens__set-title-bar {
  --title-color: var(--color-foreground-secondary);
  --arrow-color: var(--color-foreground-secondary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  text-transform: none;
  display: flex;
  overflow: hidden;
  min-block-size: var(--sp-xxxl);
  padding-block-start: var(--sp-xs);
}

.main_ui_workspace_colorpicker_color_tokens__set-title-btn {
  border: none;
  background: none;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: var(--sp-xs);
  flex-grow: 1;
  padding: 0;
  overflow: hidden;
}
.main_ui_workspace_colorpicker_color_tokens__set-title-btn:hover {
  --arrow-color: var(--color-foreground-primary);
  --title-color: var(--color-foreground-primary);
}

.main_ui_workspace_colorpicker_color_tokens__set-title-icon {
  color: var(--arrow-color);
  block-size: 1.75rem;
  padding-block-start: var(--sp-xxs);
}

.main_ui_workspace_colorpicker_color_tokens__set-title {
  color: var(--title-color);
  text-align: left;
  padding-block-end: var(--sp-xs);
}

.main_ui_workspace_colorpicker_color_tokens__set-title-actions {
  display: flex;
}

.main_ui_workspace_colorpicker_color_tokens__set-title-action-hidden {
  display: none;
}

.main_ui_workspace_colorpicker_color_tokens__token-name {
  color: var(--color-foreground-primary);
}
@keyframes main_ui_workspace_colorpicker_gradients__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker_gradients__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker_gradients__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker_gradients__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_gradients__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_gradients__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker_gradients__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker_gradients__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker_gradients__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker_gradients__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker_gradients__offset-input-wrapper span svg,
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper label svg, .main_ui_workspace_colorpicker_gradients__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker_gradients__offset-input-wrapper span svg,
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper label svg, .main_ui_workspace_colorpicker_gradients__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker_gradients__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker_gradients__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker_gradients__offset-input-wrapper input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_workspace_colorpicker_gradients__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper span,
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper label, .main_ui_workspace_colorpicker_gradients__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker_gradients__offset-input-wrapper {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper span svg,
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus, .main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus span, .main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus input, .main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus:hover, .main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus:hover span, .main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus:hover input, .main_ui_workspace_colorpicker_gradients__offset-input-wrapper:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_workspace_colorpicker_gradients__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_colorpicker_gradients__gradient-panel {
  margin-top: 0.75rem;
  display: grid;
  gap: 0.25rem;
  grid-template-rows: 3.5rem 2rem 1fr;
}

.main_ui_workspace_colorpicker_gradients__gradient-preview {
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  position: relative;
  padding: 0 var(--sp-m);
}

.main_ui_workspace_colorpicker_gradients__gradient-background {
  width: 100%;
  height: 1.25rem;
  border-radius: 4px;
  position: relative;
  cursor: pointer;
}

.main_ui_workspace_colorpicker_gradients__gradient-preview-stop-wrapper {
  position: absolute;
  width: calc(100% - 1.5rem - 0.25rem);
  height: 100%;
  left: 0.125rem;
  top: -0.25rem;
  pointer-events: none;
}

.main_ui_workspace_colorpicker_gradients__gradient-preview-stop {
  background-color: var(--color-foreground-primary);
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAADFJREFUOE9jZGBgEAFifOANPknGUQMYhkkYEEgG+NMJKAwIAbwJbdQABnBCIgRoG4gAIF8IsXB/Rs4AAAAASUVORK5CYII=");
  background-position: left center;
  background-size: 0.5rem;
  border-radius: 6px;
  border: 0.125rem solid var(--color-foreground-primary);
  box-shadow: 0 0 0.25rem 0 var(--menu-shadow-color);
  height: calc(1.5rem - 0.125rem);
  left: var(--position);
  overflow: hidden;
  pointer-events: initial;
  position: absolute;
  width: calc(1.5rem - 0.125rem);
}
.main_ui_workspace_colorpicker_gradients__gradient-preview-stop.main_ui_workspace_colorpicker_gradients__is-selected, .main_ui_workspace_colorpicker_gradients__gradient-preview-stop:hover {
  outline: 0.125rem solid var(--color-accent-primary);
}

.main_ui_workspace_colorpicker_gradients__gradient-preview-stop-decoration {
  background: var(--color-foreground-primary);
  border-radius: 100%;
  bottom: 2rem;
  box-shadow: 0 0 0.25rem 0 var(--menu-shadow-color);
  height: 0.25rem;
  left: calc(var(--position) + 0.5rem);
  position: absolute;
  width: 0.25rem;
}

.main_ui_workspace_colorpicker_gradients__gradient-preview-stop-color {
  position: absolute;
  left: 0;
  width: 50%;
  height: 100%;
  background: var(--color-solid);
}

.main_ui_workspace_colorpicker_gradients__gradient-preview-stop-alpha {
  position: absolute;
  left: 50%;
  width: 50%;
  height: 100%;
  background: var(--color-alpha);
}

.main_ui_workspace_colorpicker_gradients__gradient-options {
  display: flex;
  justify-content: space-between;
  padding: 0 var(--sp-m);
}

.main_ui_workspace_colorpicker_gradients__gradient-options-buttons {
  display: flex;
}

.main_ui_workspace_colorpicker_gradients__gradient-options-select {
  width: 8.75rem;
}

.main_ui_workspace_colorpicker_gradients__rotate-icon {
  transform: scaleX(-1);
}

.main_ui_workspace_colorpicker_gradients__gradient-stops-list {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  max-height: 11.25rem;
  overflow: hidden auto;
  padding: 0 0 var(--sp-s) var(--sp-m);
}

.main_ui_workspace_colorpicker_gradients__gradient-stops-entry {
  display: flex;
  gap: 0.25rem;
  padding: 0.125rem;
  border-radius: 12px;
  border: 1px solid transparent;
  position: relative;
}
.main_ui_workspace_colorpicker_gradients__gradient-stops-entry.main_ui_workspace_colorpicker_gradients__is-selected {
  border-color: var(--color-accent-primary-muted);
}
.main_ui_workspace_colorpicker_gradients__gradient-stops-entry:hover {
  --reorder-icon-visibility: visible;
}
.main_ui_workspace_colorpicker_gradients__gradient-stops-entry.main_ui_workspace_colorpicker_gradients__dnd-over-top {
  --reorder-top-display: block;
}
.main_ui_workspace_colorpicker_gradients__gradient-stops-entry.main_ui_workspace_colorpicker_gradients__dnd-over-bot {
  --reorder-bottom-display: block;
}

.main_ui_workspace_colorpicker_gradients__offset-input-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  width: 5.75rem;
}

.main_ui_workspace_colorpicker_gradients__gradient-separator {
  border-color: var(--color-background-quaternary);
  border-width: calc(1px + 0.125rem);
  margin-left: calc(var(--sp-m) / 2);
  position: relative;
  width: calc(100% - var(--sp-m));
}

.main_ui_workspace_colorpicker_gradients__gradient-preview-stop-preview {
  background: var(--color-foreground-primary);
  border-radius: 50%;
  height: 0.25rem;
  left: calc(var(--preview-position, 0%) - 0.125rem);
  pointer-events: none;
  position: absolute;
  top: calc(50% - 0.125rem);
  width: 0.25rem;
}
@keyframes main_ui_workspace_colorpicker_harmony__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker_harmony__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker_harmony__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker_harmony__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_harmony__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_harmony__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker_harmony__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker_harmony__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker_harmony__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker_harmony__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker_harmony__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker_harmony__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker_harmony__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker_harmony__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker_harmony__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker_harmony__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker_harmony__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_colorpicker_harmony__handler {
  position: absolute;
  left: 50%;
  top: 50%;
  width: 1.5rem;
  height: 1.5rem;
  border: 0.125rem solid var(--colorpicker-details-color);
  border-radius: 50%;
  transform: translate(calc(-1 * 0.75rem), calc(-1 * 0.75rem));
  z-index: 1;
}
.main_ui_workspace_colorpicker_harmony__handler:hover, .main_ui_workspace_colorpicker_harmony__handler:active {
  border-color: var(--colorpicker-details-color-selected);
}

.main_ui_workspace_colorpicker_harmony__harmony-selector {
  display: flex;
  align-items: center;
  gap: 0.5rem;
  margin-top: 0.75rem;
  margin-bottom: 0.5rem;
}

.main_ui_workspace_colorpicker_harmony__hue-wheel-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
}

.main_ui_workspace_colorpicker_harmony__hue-wheel {
  width: 12.25rem;
  height: 12.25rem;
}

.main_ui_workspace_colorpicker_harmony__handler {
  height: 1rem;
  width: 1rem;
  border: 0.125rem solid var(--colorpicker-handlers-color);
}

.main_ui_workspace_colorpicker_harmony__handler.main_ui_workspace_colorpicker_harmony__complement {
  background-color: var(--colorpicker-handlers-color);
  border: 0.125rem solid var(--colorpicker-handlers-color);
}

.main_ui_workspace_colorpicker_harmony__handlers-wrapper {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  height: 12.5rem;
  width: 3.25rem;
  flex-grow: 1;
}
@keyframes main_ui_workspace_colorpicker_hsva__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker_hsva__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker_hsva__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker_hsva__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_hsva__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_hsva__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker_hsva__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker_hsva__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker_hsva__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker_hsva__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker_hsva__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker_hsva__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker_hsva__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker_hsva__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker_hsva__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker_hsva__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker_hsva__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_colorpicker_hsva__hsva-selector {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  padding: 0.25rem;
  row-gap: 0.5rem;
  margin-bottom: 0.5rem;
}

.main_ui_workspace_colorpicker_hsva__hsva-row {
  display: flex;
  align-items: center;
}

.main_ui_workspace_colorpicker_hsva__hsva-selector-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  display: flex;
  align-items: center;
  justify-content: flex-start;
  width: 2rem;
}

.main_ui_workspace_colorpicker_hsva__hsva-bar {
  width: 14.25rem;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

.main_ui_workspace_colorpicker_libraries__libraries {
  margin-block-start: var(--sp-s);
  inline-size: 100%;
}

.main_ui_workspace_colorpicker_libraries__selected-colors {
  display: grid;
  grid-template-columns: repeat(8, 1fr);
  justify-content: space-between;
  gap: var(--sp-xs);
  overflow: auto;
  margin-block-start: var(--sp-s);
  max-block-size: 10.5rem;
  padding-inline-start: var(--sp-xxs);
}

.main_ui_workspace_colorpicker_libraries__selected-colors-list {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  overflow: auto;
  margin-block-start: var(--sp-s);
  max-block-size: 10.5rem;
}

.main_ui_workspace_colorpicker_libraries__color-row-colorpicker-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  inline-size: calc(var(--colorpicker-width) - 4.1875rem);
  color: var(--color-foreground-primary);
  text-align: left;
}

.main_ui_workspace_colorpicker_libraries__color-row-colorpicker-gradient-type,
.main_ui_workspace_colorpicker_libraries__color-row-colorpicker-opacity {
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_colorpicker_libraries__color-row-colorpicker {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: var(--sp-xs);
  min-block-size: 2rem;
  inline-size: calc(var(--colorpicker-width) - 2.1875rem);
  align-items: center;
  justify-content: start;
  border-radius: 0.5rem;
  padding-block: 0;
  padding-inline: var(--sp-xs);
}
.main_ui_workspace_colorpicker_libraries__color-row-colorpicker:hover {
  background: var(--color-background-quaternary);
}

.main_ui_workspace_colorpicker_libraries__color-group-header {
  display: flex;
  align-items: center;
  min-block-size: 2rem;
  gap: var(--sp-xs);
  padding-block: var(--sp-xs);
  padding-inline: var(--sp-xs);
  cursor: pointer;
  border-radius: 0.5rem;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_workspace_colorpicker_libraries__color-group-arrow {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 0;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_colorpicker_libraries__color-group-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  cursor: pointer;
  color: var(--color-foreground-secondary);
}

.main_ui_workspace_colorpicker_libraries__selected-colors::after {
  content: "";
  flex: auto;
}

.main_ui_workspace_colorpicker_libraries__select-wrapper {
  --dropdown-start: auto;
  --dropdown-end: 2.25rem;
  --dropdown-width: var(--seven-columns-width);
  display: flex;
  align-items: center;
  overflow: initial;
  gap: var(--sp-xs);
}

.main_ui_workspace_colorpicker_libraries__empty-state {
  margin-block: 2.5rem 3rem;
}
@keyframes main_ui_workspace_colorpicker_ramp__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker_ramp__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker_ramp__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker_ramp__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_ramp__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_ramp__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker_ramp__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker_ramp__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker_ramp__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker_ramp__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker_ramp__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker_ramp__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker_ramp__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker_ramp__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker_ramp__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker_ramp__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker_ramp__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_colorpicker_ramp__handler {
  position: absolute;
  left: 50%;
  top: 50%;
  width: 1.5rem;
  height: 1.5rem;
  border: 0.125rem solid var(--colorpicker-details-color);
  border-radius: 50%;
  transform: translate(calc(-1 * 0.75rem), calc(-1 * 0.75rem));
  z-index: 1;
}
.main_ui_workspace_colorpicker_ramp__handler:hover, .main_ui_workspace_colorpicker_ramp__handler:active {
  border-color: var(--colorpicker-details-color-selected);
}

.main_ui_workspace_colorpicker_ramp__value-saturation-selector {
  background-color: rgb(var(--hue-rgb));
  position: relative;
  height: 8.75rem;
  width: 100%;
  margin-top: 0.75rem;
  margin-bottom: 0.75rem;
  cursor: pointer;
}
.main_ui_workspace_colorpicker_ramp__value-saturation-selector::before {
  content: "";
  position: absolute;
  width: 100%;
  height: 100%;
  background: linear-gradient(to right, #fff, rgba(255, 255, 255, 0));
}
.main_ui_workspace_colorpicker_ramp__value-saturation-selector::after {
  content: "";
  position: absolute;
  width: 100%;
  height: 100%;
  background: linear-gradient(to top, #000, rgba(0, 0, 0, 0));
}

.main_ui_workspace_colorpicker_ramp__handler {
  height: 1rem;
  width: 1rem;
  border: 0.125rem solid var(--colorpicker-handlers-color);
}

.main_ui_workspace_colorpicker_ramp__shade-selector {
  display: flex;
  gap: 0.25rem;
  height: 3.25rem;
  cursor: pointer;
}

.main_ui_workspace_colorpicker_ramp__sliders-wrapper {
  display: flex;
  flex-direction: column;
  flex: 1;
}
@keyframes main_ui_workspace_colorpicker_slider_selector__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_workspace_colorpicker_slider_selector__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_workspace_colorpicker_slider_selector__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_workspace_colorpicker_slider_selector__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_slider_selector__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_workspace_colorpicker_slider_selector__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_workspace_colorpicker_slider_selector__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_workspace_colorpicker_slider_selector__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_workspace_colorpicker_slider_selector__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_workspace_colorpicker_slider_selector__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_workspace_colorpicker_slider_selector__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_workspace_colorpicker_slider_selector__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_workspace_colorpicker_slider_selector__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_workspace_colorpicker_slider_selector__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_workspace_colorpicker_slider_selector__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_workspace_colorpicker_slider_selector__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_workspace_colorpicker_slider_selector__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_workspace_colorpicker_slider_selector__slider-selector {
  --gradient-direction: 90deg;
  --background-repeat: left;
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__vertical {
  --gradient-direction: 0deg;
  --background-repeat: top;
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector {
  position: relative;
  align-self: center;
  height: 1.5rem;
  inline-size: 100%;
  border: 0.125rem solid var(--colorpicker-details-color);
  border-radius: 6px;
  background: linear-gradient(var(--gradient-direction), rgb(var(--color), 0) 0%, rgb(var(--color), 1) 100%);
  cursor: pointer;
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__vertical {
  width: 1.5rem;
  height: 12.5rem;
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__hue {
  background: linear-gradient(var(--gradient-direction), #f00 0%, #ff0 17%, #0f0 33%, #0ff 50%, #00f 67%, #f0f 83%, #f00 100%);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__saturation {
  background: linear-gradient(var(--gradient-direction), var(--saturation-grad-from) 0%, var(--saturation-grad-to) 100%);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__opacity {
  background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAAAXNSR0IArs4c6QAAAExJREFUSIljvHnz5n8GLEBNTQ2bMMOtW7ewiuNSz4RVlIpg1IKBt4Dx////WFMRqakFl/qhH0SjFhAELNRKLaNl0Qi2YLQsGrWAcgAA0gAgQPhT2rAAAAAASUVORK5CYII=") var(--background-repeat) center;
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__opacity::after {
  content: "";
  position: absolute;
  border-radius: 6px;
  width: 100%;
  height: 100%;
  background: linear-gradient(var(--gradient-direction), rgb(var(--color), 0) 0%, rgb(var(--color), 1) 100%);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__value {
  background: linear-gradient(var(--gradient-direction), #000 0%, #fff 100%);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__hsl-saturation {
  background: linear-gradient(var(--gradient-direction), var(--hsl-saturation-grad-from) 0%, var(--hsl-saturation-grad-to) 100%);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__lightness {
  background: linear-gradient(var(--gradient-direction), #000 0%, var(--lightness-grad-mid) 50%, #fff 100%);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector .main_ui_workspace_colorpicker_slider_selector__handler {
  position: absolute;
  left: 50%;
  width: calc(0.5rem + 0.125rem);
  height: calc(1.5rem + 1px);
  border-radius: 4px;
  z-index: 1;
  transform: translate(-4px, -3px);
  background-color: var(--colorpicker-handlers-color);
}
.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__vertical .main_ui_workspace_colorpicker_slider_selector__handler {
  height: calc(0.5rem + 0.125rem);
  width: calc(1.5rem + 1px);
  transform: translate(-12px, 5px);
}

.main_ui_workspace_colorpicker_slider_selector__opacity-wrapper {
  background-color: var(--colorpicker-background-color);
  border-radius: 8px;
}

.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__hue {
  grid-area: hue;
}

.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__opacity {
  grid-area: opacity;
}

.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__value {
  background: linear-gradient(var(--gradient-direction), var(--hue-from, #000) 0%, var(--hue-to, #fff) 100%);
}

.main_ui_workspace_colorpicker_slider_selector__slider-selector.main_ui_workspace_colorpicker_slider_selector__saturation {
  background: linear-gradient(var(--gradient-direction), var(--saturation-grad-from) 0%, var(--saturation-grad-to) 100%);
}
@keyframes main_ui_viewer_comments__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_comments__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_comments__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_comments__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_comments__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_comments__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_comments__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_comments__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_comments__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_comments__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_comments__icon svg,
.main_ui_viewer_comments__icon-dropdown svg, .main_ui_viewer_comments__dropdown-element .main_ui_viewer_comments__icon svg, .main_ui_viewer_comments__dropdown-element span svg, .main_ui_viewer_comments__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_comments__icon svg,
.main_ui_viewer_comments__icon-dropdown svg, .main_ui_viewer_comments__dropdown-element .main_ui_viewer_comments__icon svg, .main_ui_viewer_comments__dropdown-element span svg, .main_ui_viewer_comments__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_comments__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_comments__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_comments__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_comments__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_comments__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_comments__dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_viewer_comments__dropdown-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_viewer_comments__dropdown-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_viewer_comments__dropdown-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_comments__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_viewer_comments__dropdown-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_viewer_comments__view-options {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  position: relative;
  gap: 0.25rem;
  height: 2rem;
  padding: 0.5rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  cursor: pointer;
}

.main_ui_viewer_comments__dropdown {
  right: 0.125rem;
  top: calc(0.125rem + 3rem);
  width: 17rem;
  padding: 0.375rem;
}

.main_ui_viewer_comments__dropdown-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  flex-grow: 1;
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_comments__label {
  flex-grow: 1;
  color: var(--input-foreground-color);
}

.main_ui_viewer_comments__icon,
.main_ui_viewer_comments__icon-dropdown {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 1rem;
}
.main_ui_viewer_comments__icon svg,
.main_ui_viewer_comments__icon-dropdown svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer_comments__icon-dropdown svg {
  transform: rotate(90deg);
}

.main_ui_viewer_comments__dropdown-element .main_ui_viewer_comments__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 1rem;
}
.main_ui_viewer_comments__dropdown-element .main_ui_viewer_comments__icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_comments__dropdown-element:hover .main_ui_viewer_comments__label {
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_comments__dropdown-element.main_ui_viewer_comments__selected .main_ui_viewer_comments__label {
  color: var(--input-foreground-color-active);
}
.main_ui_viewer_comments__dropdown-element.main_ui_viewer_comments__selected .main_ui_viewer_comments__icon svg {
  stroke: var(--input-foreground-color);
}

.main_ui_viewer_comments__separator {
  height: 0.5rem;
}

.main_ui_viewer_comments__viewer-comments-container {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1;
}

.main_ui_viewer_comments__threads {
  position: absolute;
  top: 0;
  left: 0;
}

.main_ui_viewer_comments__comments-sidebar {
  position: absolute;
  right: 0;
  top: 2.75rem;
  width: var(--right-sidebar-width);
  height: calc(100vh - 3rem);
  z-index: 10;
  background-color: var(--panel-background-color);
}

.main_ui_viewer_comments__settings-bar-inside {
  overflow-y: auto;
}

.main_ui_viewer_comments__comments-section {
  background-color: var(--panel-background-color);
}
@keyframes main_ui_viewer_header__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_header__share-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_viewer_header__share-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_viewer_header__share-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_viewer_header__share-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_viewer_header__share-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_viewer_header__share-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_viewer_header__share-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_viewer_header__share-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_viewer_header__share-btn.disabled, [disabled].main_ui_viewer_header__share-btn, .main_ui_viewer_header__share-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_viewer_header__mode-zone-btn, .main_ui_viewer_header__fullscreen-btn, .main_ui_viewer_header__edit-btn, .main_ui_viewer_header__go-log-btn, .main_ui_viewer_header__zoom-btn, .main_ui_viewer_header__reset-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_viewer_header__mode-zone-btn svg, .main_ui_viewer_header__fullscreen-btn svg, .main_ui_viewer_header__edit-btn svg, .main_ui_viewer_header__go-log-btn svg, .main_ui_viewer_header__zoom-btn svg, .main_ui_viewer_header__reset-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_viewer_header__mode-zone-btn:focus-visible, .main_ui_viewer_header__fullscreen-btn:focus-visible, .main_ui_viewer_header__edit-btn:focus-visible, .main_ui_viewer_header__go-log-btn:focus-visible, .main_ui_viewer_header__zoom-btn:focus-visible, .main_ui_viewer_header__reset-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_header__mode-zone-btn:focus-visible svg, .main_ui_viewer_header__fullscreen-btn:focus-visible svg, .main_ui_viewer_header__edit-btn:focus-visible svg, .main_ui_viewer_header__go-log-btn:focus-visible svg, .main_ui_viewer_header__zoom-btn:focus-visible svg, .main_ui_viewer_header__reset-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_header__mode-zone-btn:hover, .main_ui_viewer_header__fullscreen-btn:hover, .main_ui_viewer_header__edit-btn:hover, .main_ui_viewer_header__go-log-btn:hover, .main_ui_viewer_header__zoom-btn:hover, .main_ui_viewer_header__reset-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_viewer_header__mode-zone-btn:hover svg, .main_ui_viewer_header__fullscreen-btn:hover svg, .main_ui_viewer_header__edit-btn:hover svg, .main_ui_viewer_header__go-log-btn:hover svg, .main_ui_viewer_header__zoom-btn:hover svg, .main_ui_viewer_header__reset-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_viewer_header__mode-zone-btn:active, .main_ui_viewer_header__fullscreen-btn:active, .main_ui_viewer_header__edit-btn:active, .main_ui_viewer_header__go-log-btn:active, .main_ui_viewer_header__zoom-btn:active, .main_ui_viewer_header__reset-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_header__mode-zone-btn:active svg, .main_ui_viewer_header__fullscreen-btn:active svg, .main_ui_viewer_header__edit-btn:active svg, .main_ui_viewer_header__go-log-btn:active svg, .main_ui_viewer_header__zoom-btn:active svg, .main_ui_viewer_header__reset-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_header__mode-zone-btn.disabled, .main_ui_viewer_header__fullscreen-btn.disabled, .main_ui_viewer_header__edit-btn.disabled, .main_ui_viewer_header__go-log-btn.disabled, .main_ui_viewer_header__zoom-btn.disabled, .main_ui_viewer_header__reset-btn.disabled, [disabled].main_ui_viewer_header__mode-zone-btn, [disabled].main_ui_viewer_header__fullscreen-btn, [disabled].main_ui_viewer_header__edit-btn, [disabled].main_ui_viewer_header__go-log-btn, [disabled].main_ui_viewer_header__zoom-btn, [disabled].main_ui_viewer_header__reset-btn, .main_ui_viewer_header__mode-zone-btn:disabled, .main_ui_viewer_header__fullscreen-btn:disabled, .main_ui_viewer_header__edit-btn:disabled, .main_ui_viewer_header__go-log-btn:disabled, .main_ui_viewer_header__zoom-btn:disabled, .main_ui_viewer_header__reset-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_viewer_header__mode-zone-btn.disabled svg, .main_ui_viewer_header__fullscreen-btn.disabled svg, .main_ui_viewer_header__edit-btn.disabled svg, .main_ui_viewer_header__go-log-btn.disabled svg, .main_ui_viewer_header__zoom-btn.disabled svg, .main_ui_viewer_header__reset-btn.disabled svg, [disabled].main_ui_viewer_header__mode-zone-btn svg, [disabled].main_ui_viewer_header__fullscreen-btn svg, [disabled].main_ui_viewer_header__edit-btn svg, [disabled].main_ui_viewer_header__go-log-btn svg, [disabled].main_ui_viewer_header__zoom-btn svg, [disabled].main_ui_viewer_header__reset-btn svg, .main_ui_viewer_header__mode-zone-btn:disabled svg, .main_ui_viewer_header__fullscreen-btn:disabled svg, .main_ui_viewer_header__edit-btn:disabled svg, .main_ui_viewer_header__go-log-btn:disabled svg, .main_ui_viewer_header__zoom-btn:disabled svg, .main_ui_viewer_header__reset-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_viewer_header__selected {
  outline: none;
  border-color: var(--button-icon-border-color-selected);
  background-color: var(--button-icon-background-color-selected);
  color: var(--button-icon-foreground-color-selected);
}
.main_ui_viewer_header__selected svg {
  stroke: var(--button-icon-foreground-color-selected);
}

.main_ui_viewer_header__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_header__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_header__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_header__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_header__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_header__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_header__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_header__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_header__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_header__mode-zone-btn svg, .main_ui_viewer_header__fullscreen-btn svg, .main_ui_viewer_header__edit-btn svg, .main_ui_viewer_header__zoom-btn .main_ui_viewer_header__zoom-icon svg, .main_ui_viewer_header__icon svg, .main_ui_viewer_header__dropdown-element .main_ui_viewer_header__icon-check svg, .main_ui_viewer_header__dropdown-element span svg, .main_ui_viewer_header__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_header__icon svg, .main_ui_viewer_header__dropdown-element .main_ui_viewer_header__icon-check svg, .main_ui_viewer_header__dropdown-element span svg, .main_ui_viewer_header__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_header__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_header__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_header__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_header__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_header__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_header__zoom-option .main_ui_viewer_header__shortcuts {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 0.125rem;
  color: var(--menu-shortcut-foreground-color);
}

.main_ui_viewer_header__zoom-option .main_ui_viewer_header__shortcuts .main_ui_viewer_header__shortcut-key {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.25rem;
  padding: 0.125rem 0.375rem;
  border-radius: 6px;
  background-color: var(--menu-shortcut-background-color);
}

.main_ui_viewer_header__dropdown-sitemap, .main_ui_viewer_header__dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_viewer_header__zoom-option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_viewer_header__zoom-option:hover {
  background-color: var(--menu-background-color-hover);
}

.main_ui_viewer_header__dropdown-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_viewer_header__dropdown-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_viewer_header__dropdown-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_header__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_viewer_header__dropdown-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_viewer_header__viewer-header {
  position: absolute;
  top: 0;
  grid-column: 1/span 1;
  grid-row: 1/span 1;
  display: grid;
  grid-template-columns: 1fr 5.75rem 1fr;
  justify-content: space-between;
  align-items: center;
  height: 3rem;
  width: 100vw;
  padding: 0.5rem 0.75rem;
  transition: transform 400ms ease 300ms;
  background-color: var(--panel-background-color);
}

.main_ui_viewer_header__nav-zone {
  display: flex;
  justify-content: flex-start;
  flex-basis: min-content;
  width: 100%;
  gap: 0.75rem;
}

.main_ui_viewer_header__home-link {
  padding: 0;
  display: grid;
  place-content: center;
}

.main_ui_viewer_header__logo-icon {
  width: 1.75rem;
  height: 1.75rem;
  fill: var(--icon-foreground-hover);
}

.main_ui_viewer_header__sitemap-zone {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: relative;
  width: 100%;
}

.main_ui_viewer_header__project-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--title-foreground-color);
}

.main_ui_viewer_header__sitemap-text {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}

.main_ui_viewer_header__breadcrumb {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.25rem;
  color: var(--title-foreground-color);
  cursor: pointer;
}

.main_ui_viewer_header__breadcrumb-text {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-width: 12vw;
  max-width: 12cqw;
}

.main_ui_viewer_header__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
}
.main_ui_viewer_header__icon svg {
  transform: rotate(90deg);
  stroke: var(--icon-foreground);
}

.main_ui_viewer_header__dropdown {
  position: absolute;
}

.main_ui_viewer_header__dropdown-sitemap {
  left: 0;
  top: calc(0.125rem + 3rem);
  width: 17rem;
  padding: 0.375rem;
}

.main_ui_viewer_header__dropdown-element .main_ui_viewer_header__icon-check {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 1rem;
}
.main_ui_viewer_header__dropdown-element .main_ui_viewer_header__icon-check svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_header__dropdown-element:hover .main_ui_viewer_header__label {
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_header__current-frame {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.25rem;
  flex-grow: 1;
  color: var(--title-foreground-color-hover);
  cursor: pointer;
}
.main_ui_viewer_header__current-frame .main_ui_viewer_header__icon svg {
  stroke: var(--title-foreground-color-hover);
}

.main_ui_viewer_header__frame-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-width: 17vw;
  max-width: 17cqw;
}

.main_ui_viewer_header__mode-zone {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  height: 100%;
}

.main_ui_viewer_header__mode-zone-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2rem;
  width: 1.75rem;
  padding: 0;
}
.main_ui_viewer_header__options-zone {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  position: relative;
  justify-content: flex-end;
  gap: 0.5rem;
  z-index: 10;
}

.main_ui_viewer_header__view-options {
  position: relative;
  display: flex;
  align-items: center;
  cursor: pointer;
}

.main_ui_viewer_header__fullscreen-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_viewer_header__fullscreen-btn svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer_header__share-btn {
  height: 2rem;
  min-width: 4.5rem;
  margin-left: 0.25rem;
}

.main_ui_viewer_header__edit-btn {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_viewer_header__edit-btn svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer_header__go-log-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
}

.main_ui_viewer_header__zoom-widget {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.75rem;
  min-width: 4rem;
  border-radius: 8px;
}
.main_ui_viewer_header__zoom-widget .main_ui_viewer_header__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--button-tertiary-foreground-color-rest);
}
.main_ui_viewer_header__zoom-widget:hover .main_ui_viewer_header__label {
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_header__zoom-widget.main_ui_viewer_header__selected .main_ui_viewer_header__label {
  color: var(--button-tertiary-foreground-color-focus);
}

.main_ui_viewer_header__dropdown {
  right: 0.125rem;
  top: calc(0.125rem + 3rem);
  width: 17rem;
}

.main_ui_viewer_header__basic-zoom-bar {
  display: flex;
  justify-content: space-between;
  padding: 0.375rem;
  cursor: auto;
}

.main_ui_viewer_header__zoom-btns {
  display: flex;
}

.main_ui_viewer_header__zoom-btn {
  height: 1.75rem;
  width: 1.75rem;
  border-radius: 8px;
}
.main_ui_viewer_header__zoom-btn .main_ui_viewer_header__zoom-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.5rem;
  height: 2rem;
}
.main_ui_viewer_header__zoom-btn .main_ui_viewer_header__zoom-icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_header__zoom-btn:hover .main_ui_viewer_header__zoom-icon svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}

.main_ui_viewer_header__zoom-text {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  min-width: 4rem;
  padding: 0;
  margin: 0 0.125rem;
  color: var(--modal-title-foreground-color);
}

.main_ui_viewer_header__reset-btn {
  color: var(--button-tertiary-foreground-color-hover);
  height: 1.75rem;
  border-radius: 8px;
}

.main_ui_viewer_header__zoom-option:hover {
  color: var(--menu-foreground-color-hover);
}
.main_ui_viewer_header__zoom-option:hover .main_ui_viewer_header__shortcuts .main_ui_viewer_header__shortcut-key {
  color: var(--menu-foreground-color-hover);
}

/** FULLSCREEN */
[data-fullscreen=true] .main_ui_viewer_header__viewer-header::after {
  content: " ";
  position: absolute;
  width: 100%;
  height: 3rem;
  left: 0;
  top: 3rem;
}

[data-fullscreen=true] .main_ui_viewer_header__viewer-header {
  transform: translateY(-3rem);
}

[data-force-visible=true] .main_ui_viewer_header__viewer-header,
[data-fullscreen=true] .main_ui_viewer_header__viewer-header:hover {
  transform: translateY(0);
}
@keyframes main_ui_viewer_inspect__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_inspect__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_inspect__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_inspect__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_inspect__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_inspect__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_inspect__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_inspect__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_inspect__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_inspect__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_inspect__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_inspect__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_inspect__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_inspect__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_inspect__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_inspect__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_inspect__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_inspect__inspect-svg-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  flex-direction: column;
  flex: 1;
  width: 100%;
  height: 100%;
  overflow: hidden;
}

.main_ui_viewer_inspect__inspect-svg-container {
  display: grid;
  align-items: center;
  justify-content: safe center;
  width: 100%;
  height: 100%;
  margin: 0 auto;
  overflow: auto;
}

.main_ui_viewer_inspect__sidebar-container {
  position: relative;
  align-self: flex-start;
  width: var(--right-sidebar-width);
  background-color: var(--panel-background-color);
  border-top: 1px solid var(--search-bar-input-border-color);
}

.main_ui_viewer_inspect__not-expand {
  max-width: var(--right-sidebar-width);
}

.main_ui_viewer_inspect__expanded {
  width: var(--right-sidebar-width, var(--right-sidebar-width));
}

.main_ui_viewer_inspect__resize-area {
  position: absolute;
  left: 0;
  width: 0.5rem;
  height: 100%;
  z-index: 10;
  cursor: ew-resize;
}
@keyframes main_ui_viewer_interactions__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_interactions__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_interactions__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_interactions__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_interactions__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_interactions__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_interactions__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_interactions__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_interactions__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_interactions__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_interactions__dropdown-element .main_ui_viewer_interactions__icon svg, .main_ui_viewer_interactions__icon svg,
.main_ui_viewer_interactions__icon-dropdown svg, .main_ui_viewer_interactions__dropdown-element span svg, .main_ui_viewer_interactions__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_interactions__dropdown-element .main_ui_viewer_interactions__icon svg, .main_ui_viewer_interactions__icon svg,
.main_ui_viewer_interactions__icon-dropdown svg, .main_ui_viewer_interactions__dropdown-element span svg, .main_ui_viewer_interactions__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_interactions__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_interactions__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_interactions__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_interactions__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_interactions__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_interactions__dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_viewer_interactions__dropdown-element {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.5rem;
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 6px;
  cursor: pointer;
  color: var(--menu-foreground-color-rest);
}
.main_ui_viewer_interactions__dropdown-element span {
  display: flex;
  justify-content: center;
  align-items: center;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_viewer_interactions__dropdown-element span svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_interactions__dropdown-element:hover {
  background-color: var(--menu-background-color-hover);
  color: var(--menu-foreground-color);
}
.main_ui_viewer_interactions__dropdown-element:hover svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_viewer_interactions__view-options {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  position: relative;
  gap: 0.25rem;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  padding: 0.5rem;
  cursor: pointer;
}

.main_ui_viewer_interactions__dropdown-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  flex-grow: 1;
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_interactions__label {
  flex-grow: 1;
  color: var(--input-foreground-color);
}

.main_ui_viewer_interactions__dropdown {
  right: 0.125rem;
  top: calc(0.125rem + 3rem);
  width: 17rem;
  padding: 0.375rem;
  max-height: calc(100vh - 3 * (0.125rem + 3rem));
  overflow: auto;
}

.main_ui_viewer_interactions__dropdown-element {
  min-height: 2rem;
}
.main_ui_viewer_interactions__dropdown-element .main_ui_viewer_interactions__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 1rem;
}
.main_ui_viewer_interactions__dropdown-element .main_ui_viewer_interactions__icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_interactions__dropdown-element:hover .main_ui_viewer_interactions__label {
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_interactions__dropdown-element.main_ui_viewer_interactions__selected .main_ui_viewer_interactions__label {
  color: var(--input-foreground-color-active);
}
.main_ui_viewer_interactions__dropdown-element.main_ui_viewer_interactions__selected .main_ui_viewer_interactions__icon svg {
  stroke: var(--input-foreground-color);
}

.main_ui_viewer_interactions__icon,
.main_ui_viewer_interactions__icon-dropdown {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: 1rem;
}
.main_ui_viewer_interactions__icon svg,
.main_ui_viewer_interactions__icon-dropdown svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer_interactions__icon-dropdown svg {
  transform: rotate(90deg);
}

.main_ui_viewer_interactions__fixed {
  position: fixed;
  pointer-events: none;
}
.main_ui_viewer_interactions__fixed .frame-children g {
  pointer-events: auto;
}
@keyframes main_ui_viewer_login__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_login__link-entry a {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_viewer_login__link-entry a svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_viewer_login__link-entry a:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_viewer_login__link-entry a:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_viewer_login__link-entry a:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_viewer_login__link-entry a:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_viewer_login__link-entry a:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_viewer_login__link-entry a:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_viewer_login__link-entry a.disabled, .main_ui_viewer_login__link-entry a[disabled], .main_ui_viewer_login__link-entry a:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_viewer_login__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_viewer_login__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_viewer_login__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_login__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_login__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_viewer_login__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_viewer_login__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_login__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_login__modal-close-btn.disabled, [disabled].main_ui_viewer_login__modal-close-btn, .main_ui_viewer_login__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_viewer_login__modal-close-btn.disabled svg, [disabled].main_ui_viewer_login__modal-close-btn svg, .main_ui_viewer_login__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_viewer_login__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_login__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_login__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_login__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_login__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_login__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_login__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_login__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_login__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_login__modal-close-btn svg, .main_ui_viewer_login__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_login__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_login__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_login__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_login__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_login__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_login__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_viewer_login__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_viewer_login__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_viewer_login__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_login__modal-container {
  width: 23rem;
}

.main_ui_viewer_login__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_viewer_login__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_viewer_login__modal-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  gap: 1.5rem;
  max-height: 25rem;
  overflow: hidden auto;
}
.main_ui_viewer_login__modal-content form {
  display: flex;
  flex-direction: column;
  margin-bottom: 1.5rem;
  gap: 0.75rem;
}

.main_ui_viewer_login__form-container {
  display: flex;
  justify-content: center;
  flex-direction: column;
}

.main_ui_viewer_login__links {
  position: relative;
}

.main_ui_viewer_login__link-entry {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
}
.main_ui_viewer_login__link-entry span {
  text-align: center;
  font-size: 0.875rem;
  color: var(--modal-text-foreground-color);
  margin-top: 0.75rem;
}
.main_ui_viewer_login__link-entry a {
  height: 2.5rem;
  text-transform: uppercase;
  font-size: 0.688rem;
}
@keyframes main_ui_viewer_share_link__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_share_link__button-danger, .main_ui_viewer_share_link__button-active {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_viewer_share_link__button-danger svg, .main_ui_viewer_share_link__button-active svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_viewer_share_link__button-danger:focus-visible, .main_ui_viewer_share_link__button-active:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_viewer_share_link__button-danger:focus-visible svg, .main_ui_viewer_share_link__button-active:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_viewer_share_link__button-danger:hover, .main_ui_viewer_share_link__button-active:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_viewer_share_link__button-danger:hover svg, .main_ui_viewer_share_link__button-active:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_viewer_share_link__button-danger:active, .main_ui_viewer_share_link__button-active:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_viewer_share_link__button-danger:active svg, .main_ui_viewer_share_link__button-active:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_viewer_share_link__button-danger.disabled, .main_ui_viewer_share_link__button-active.disabled, [disabled].main_ui_viewer_share_link__button-danger, [disabled].main_ui_viewer_share_link__button-active, .main_ui_viewer_share_link__button-danger:disabled, .main_ui_viewer_share_link__button-active:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_viewer_share_link__copy-button, .main_ui_viewer_share_link__button-cancel {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_viewer_share_link__copy-button svg, .main_ui_viewer_share_link__button-cancel svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_viewer_share_link__copy-button:focus-visible, .main_ui_viewer_share_link__button-cancel:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_viewer_share_link__copy-button:focus-visible svg, .main_ui_viewer_share_link__button-cancel:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_viewer_share_link__copy-button:hover, .main_ui_viewer_share_link__button-cancel:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_viewer_share_link__copy-button:hover svg, .main_ui_viewer_share_link__button-cancel:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_viewer_share_link__copy-button:active, .main_ui_viewer_share_link__button-cancel:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_viewer_share_link__copy-button:active svg, .main_ui_viewer_share_link__button-cancel:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_viewer_share_link__copy-button.disabled, .main_ui_viewer_share_link__button-cancel.disabled, [disabled].main_ui_viewer_share_link__copy-button, [disabled].main_ui_viewer_share_link__button-cancel, .main_ui_viewer_share_link__copy-button:disabled, .main_ui_viewer_share_link__button-cancel:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_viewer_share_link__modal-close-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_viewer_share_link__modal-close-button svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_viewer_share_link__modal-close-button:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_share_link__modal-close-button:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_share_link__modal-close-button:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_viewer_share_link__modal-close-button:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_viewer_share_link__modal-close-button:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_share_link__modal-close-button:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_share_link__modal-close-button.disabled, [disabled].main_ui_viewer_share_link__modal-close-button, .main_ui_viewer_share_link__modal-close-button:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_viewer_share_link__modal-close-button.disabled svg, [disabled].main_ui_viewer_share_link__modal-close-button svg, .main_ui_viewer_share_link__modal-close-button:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_viewer_share_link__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_share_link__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_share_link__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_share_link__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_share_link__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_share_link__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_share_link__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_share_link__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_share_link__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_share_link__copy-button svg, .main_ui_viewer_share_link__icon svg, .main_ui_viewer_share_link__modal-close-button svg, .main_ui_viewer_share_link__checkbox-wrapper span.main_ui_viewer_share_link__checked svg, .main_ui_viewer_share_link__checkbox-wrapper label span.intermediate svg, .main_ui_viewer_share_link__checkbox-wrapper label span.checked svg, .main_ui_viewer_share_link__input-text span svg,
.main_ui_viewer_share_link__input-text label svg, .main_ui_viewer_share_link__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_share_link__checkbox-wrapper span.main_ui_viewer_share_link__checked svg, .main_ui_viewer_share_link__checkbox-wrapper label span.intermediate svg, .main_ui_viewer_share_link__checkbox-wrapper label span.checked svg, .main_ui_viewer_share_link__input-text span svg,
.main_ui_viewer_share_link__input-text label svg, .main_ui_viewer_share_link__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_share_link__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_share_link__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_share_link__input-text input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_viewer_share_link__input-text input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_viewer_share_link__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_share_link__input-text span,
.main_ui_viewer_share_link__input-text label, .main_ui_viewer_share_link__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_share_link__input-text {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_viewer_share_link__input-text span svg,
.main_ui_viewer_share_link__input-text label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_viewer_share_link__input-text ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_viewer_share_link__input-text ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_viewer_share_link__input-text:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_viewer_share_link__input-text:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_viewer_share_link__input-text:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_viewer_share_link__input-text:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_viewer_share_link__input-text:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_viewer_share_link__input-text:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_viewer_share_link__input-text:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_viewer_share_link__input-text:focus, .main_ui_viewer_share_link__input-text:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_viewer_share_link__input-text:focus span, .main_ui_viewer_share_link__input-text:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_viewer_share_link__input-text:focus input, .main_ui_viewer_share_link__input-text:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_viewer_share_link__input-text:focus:hover, .main_ui_viewer_share_link__input-text:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_viewer_share_link__input-text:focus:hover span, .main_ui_viewer_share_link__input-text:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_viewer_share_link__input-text:focus:hover input, .main_ui_viewer_share_link__input-text:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_viewer_share_link__checkbox-wrapper label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_viewer_share_link__checkbox-wrapper label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_viewer_share_link__checkbox-wrapper label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_viewer_share_link__checkbox-wrapper label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_viewer_share_link__checkbox-wrapper label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_viewer_share_link__checkbox-wrapper label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_viewer_share_link__checkbox-wrapper label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_viewer_share_link__checkbox-wrapper label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_viewer_share_link__checkbox-wrapper label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_viewer_share_link__checkbox-wrapper label span.unchecked svg {
  display: none;
}

.main_ui_viewer_share_link__checkbox-wrapper {
  display: flex;
  align-items: center;
}
.main_ui_viewer_share_link__checkbox-wrapper label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_viewer_share_link__checkbox-wrapper label input {
  margin: 0;
}
.main_ui_viewer_share_link__checkbox-wrapper label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_viewer_share_link__checkbox-wrapper label:focus span, .main_ui_viewer_share_link__checkbox-wrapper label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_viewer_share_link__share-link-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_viewer_share_link__modal-close-button {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_viewer_share_link__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_share_link__button-cancel {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_viewer_share_link__button-active {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_viewer_share_link__button-danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_viewer_share_link__share-modal {
  display: block;
  position: absolute;
  top: 3.25rem;
  right: 0.75rem;
  left: calc(100vw - 32rem);
  z-index: 300;
}

.main_ui_viewer_share_link__share-link-dialog {
  min-height: unset;
}

.main_ui_viewer_share_link__share-link-header {
  margin-bottom: 1.5rem;
}

.main_ui_viewer_share_link__share-link-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_viewer_share_link__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  gap: 1.5rem;
}

.main_ui_viewer_share_link__share-link-section {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  gap: 0.5rem;
}

.main_ui_viewer_share_link__hint-wrapper {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}

.main_ui_viewer_share_link__hint {
  flex-grow: 1;
  color: var(--modal-text-foreground-color);
}

.main_ui_viewer_share_link__custon-input-wrapper {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  border-radius: 8px;
  height: 2rem;
  width: 100%;
  background-color: var(--input-background-color);
}

.main_ui_viewer_share_link__input-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-foreground-color-active);
  padding-left: 0.5rem;
  margin: 0;
  flex-grow: 1;
}
.main_ui_viewer_share_link__input-text:focus {
  outline: none;
  border: 1px solid var(--input-border-color-active);
}

.main_ui_viewer_share_link__copy-button {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  gap: 0.5rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_viewer_share_link__copy-button svg {
  stroke: var(--icon-foreground-hover);
}

.main_ui_viewer_share_link__description {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-text-foreground-color);
  margin-bottom: 1.5rem;
}

.main_ui_viewer_share_link__actions {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  justify-content: flex-end;
}

.main_ui_viewer_share_link__permissions-section {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  gap: 0.5rem;
}

.main_ui_viewer_share_link__manage-permissions {
  border: none;
  background: none;
  cursor: pointer;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--menu-foreground-color-rest);
  height: 2rem;
  display: flex;
  align-items: center;
  padding: 0;
}

.main_ui_viewer_share_link__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  margin-right: 0.375rem;
}
.main_ui_viewer_share_link__icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_viewer_share_link__icon.main_ui_viewer_share_link__rotated {
  transform: rotate(90deg);
}

.main_ui_viewer_share_link__view-mode,
.main_ui_viewer_share_link__access-mode,
.main_ui_viewer_share_link__inspect-mode {
  display: flex;
  width: 100%;
}

.main_ui_viewer_share_link__view-mode {
  max-height: 13.5rem;
  overflow: hidden auto;
  scrollbar-gutter: stable;
}

.main_ui_viewer_share_link__subtitle {
  color: var(--modal-text-foreground-color);
  display: flex;
  align-items: center;
  justify-content: flex-start;
  width: 8.5rem;
  height: 2rem;
}

.main_ui_viewer_share_link__items {
  flex-grow: 1;
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_share_link__select-all-row {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  justify-content: space-between;
  height: 2rem;
  border-bottom: 1px solid var(--input-border-color-disabled);
}

.main_ui_viewer_share_link__select-all-label {
  color: var(--input-foreground-color-active);
}

.main_ui_viewer_share_link__pages-selection {
  margin: 0;
}
.main_ui_viewer_share_link__pages-selection li {
  border-bottom: 1px solid var(--input-border-color-disabled);
}
.main_ui_viewer_share_link__pages-selection li:last-child {
  border-bottom: none;
}

.main_ui_viewer_share_link__count-pages,
.main_ui_viewer_share_link__current-tag {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-foreground-color);
}

.main_ui_viewer_share_link__checkbox-wrapper {
  height: 2rem;
  padding: 0;
}
.main_ui_viewer_share_link__checkbox-wrapper span.main_ui_viewer_share_link__checked {
  background-color: var(--input-checkbox-background-color-active);
  border: 1px solid var(--input-checkbox-background-color-active);
}
.main_ui_viewer_share_link__checkbox-wrapper span.main_ui_viewer_share_link__checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
@keyframes main_ui_viewer_thumbnails__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_viewer_thumbnails__expand-btn,
.main_ui_viewer_thumbnails__close-btn, .main_ui_viewer_thumbnails__right-scroll-handler,
.main_ui_viewer_thumbnails__left-scroll-handler {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_viewer_thumbnails__expand-btn svg,
.main_ui_viewer_thumbnails__close-btn svg, .main_ui_viewer_thumbnails__right-scroll-handler svg,
.main_ui_viewer_thumbnails__left-scroll-handler svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_viewer_thumbnails__expand-btn:focus-visible,
.main_ui_viewer_thumbnails__close-btn:focus-visible, .main_ui_viewer_thumbnails__right-scroll-handler:focus-visible,
.main_ui_viewer_thumbnails__left-scroll-handler:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_thumbnails__expand-btn:focus-visible svg,
.main_ui_viewer_thumbnails__close-btn:focus-visible svg, .main_ui_viewer_thumbnails__right-scroll-handler:focus-visible svg,
.main_ui_viewer_thumbnails__left-scroll-handler:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_viewer_thumbnails__expand-btn:hover,
.main_ui_viewer_thumbnails__close-btn:hover, .main_ui_viewer_thumbnails__right-scroll-handler:hover,
.main_ui_viewer_thumbnails__left-scroll-handler:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_viewer_thumbnails__expand-btn:hover svg,
.main_ui_viewer_thumbnails__close-btn:hover svg, .main_ui_viewer_thumbnails__right-scroll-handler:hover svg,
.main_ui_viewer_thumbnails__left-scroll-handler:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_viewer_thumbnails__expand-btn:active,
.main_ui_viewer_thumbnails__close-btn:active, .main_ui_viewer_thumbnails__right-scroll-handler:active,
.main_ui_viewer_thumbnails__left-scroll-handler:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_thumbnails__expand-btn:active svg,
.main_ui_viewer_thumbnails__close-btn:active svg, .main_ui_viewer_thumbnails__right-scroll-handler:active svg,
.main_ui_viewer_thumbnails__left-scroll-handler:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_viewer_thumbnails__expand-btn.disabled,
.main_ui_viewer_thumbnails__close-btn.disabled, .main_ui_viewer_thumbnails__right-scroll-handler.disabled,
.main_ui_viewer_thumbnails__left-scroll-handler.disabled, [disabled].main_ui_viewer_thumbnails__expand-btn,
[disabled].main_ui_viewer_thumbnails__close-btn, [disabled].main_ui_viewer_thumbnails__right-scroll-handler,
[disabled].main_ui_viewer_thumbnails__left-scroll-handler, .main_ui_viewer_thumbnails__expand-btn:disabled,
.main_ui_viewer_thumbnails__close-btn:disabled, .main_ui_viewer_thumbnails__right-scroll-handler:disabled,
.main_ui_viewer_thumbnails__left-scroll-handler:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_viewer_thumbnails__expand-btn.disabled svg,
.main_ui_viewer_thumbnails__close-btn.disabled svg, .main_ui_viewer_thumbnails__right-scroll-handler.disabled svg,
.main_ui_viewer_thumbnails__left-scroll-handler.disabled svg, [disabled].main_ui_viewer_thumbnails__expand-btn svg,
[disabled].main_ui_viewer_thumbnails__close-btn svg, [disabled].main_ui_viewer_thumbnails__right-scroll-handler svg,
[disabled].main_ui_viewer_thumbnails__left-scroll-handler svg, .main_ui_viewer_thumbnails__expand-btn:disabled svg,
.main_ui_viewer_thumbnails__close-btn:disabled svg, .main_ui_viewer_thumbnails__right-scroll-handler:disabled svg,
.main_ui_viewer_thumbnails__left-scroll-handler:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_viewer_thumbnails__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_viewer_thumbnails__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_viewer_thumbnails__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_thumbnails__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_viewer_thumbnails__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_viewer_thumbnails__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_viewer_thumbnails__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_viewer_thumbnails__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_viewer_thumbnails__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_viewer_thumbnails__expand-btn svg,
.main_ui_viewer_thumbnails__close-btn svg, .main_ui_viewer_thumbnails__right-scroll-handler svg,
.main_ui_viewer_thumbnails__left-scroll-handler svg, .main_ui_viewer_thumbnails__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_viewer_thumbnails__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_viewer_thumbnails__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_viewer_thumbnails__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_viewer_thumbnails__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_viewer_thumbnails__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_viewer_thumbnails__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_viewer_thumbnails__viewer-thumbnails {
  background-color: var(--viewer-background-color);
  grid-row: 1/span 1;
  grid-column: 1/span 1;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  z-index: 10;
}

.main_ui_viewer_thumbnails__expanded {
  grid-row: 1/span 2;
}
.main_ui_viewer_thumbnails__expanded .main_ui_viewer_thumbnails__expand-btn svg {
  transform: rotate(-90deg);
}

.main_ui_viewer_thumbnails__thumbnails-summary {
  display: flex;
  justify-content: space-between;
  align-items: center;
  height: 2rem;
  margin: 1.5rem 1.5rem 0 1.5rem;
}

.main_ui_viewer_thumbnails__counter {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--viewer-thumbnails-control-foreground-color);
}

.main_ui_viewer_thumbnails__actions {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  width: 3.75rem;
}

.main_ui_viewer_thumbnails__expand-btn,
.main_ui_viewer_thumbnails__close-btn {
  height: 2rem;
  width: 1.75rem;
}
.main_ui_viewer_thumbnails__expand-btn svg {
  transform: rotate(90deg);
}

.main_ui_viewer_thumbnails__thumbnails-content {
  display: grid;
  grid-template-columns: 2.5rem auto 2.5rem;
  grid-template-rows: auto;
}

.main_ui_viewer_thumbnails__thumbnails-list-expanded {
  grid-column: 1/span 3;
  grid-row: 1/span 1;
  display: flex;
  flex-wrap: wrap;
  overflow: hidden;
}

.main_ui_viewer_thumbnails__right-scroll-handler,
.main_ui_viewer_thumbnails__left-scroll-handler {
  display: flex;
  justify-content: center;
  align-items: center;
  grid-column: 3/span 1;
  grid-row: 1/span 1;
  width: 2rem;
  height: 3.75rem;
  margin: auto 0;
  z-index: 10;
  opacity: 0;
}
.main_ui_viewer_thumbnails__right-scroll-handler:hover,
.main_ui_viewer_thumbnails__left-scroll-handler:hover {
  opacity: 1;
}
.main_ui_viewer_thumbnails__right-scroll-handler svg,
.main_ui_viewer_thumbnails__left-scroll-handler svg {
  stroke: var(--icon-foreground);
}

.main_ui_viewer_thumbnails__left-scroll-handler {
  grid-column: 1/span 1;
  grid-row: 1/span 1;
}
.main_ui_viewer_thumbnails__left-scroll-handler svg {
  transform: rotate(180deg);
}

.main_ui_viewer_thumbnails__thumbnails-list {
  grid-column: 1/span 3;
  grid-row: 1/span 1;
  display: flex;
  flex-wrap: nowrap;
  overflow: hidden;
}

.main_ui_viewer_thumbnails__thumbnails-list-inside {
  display: flex;
  position: relative;
}

.main_ui_viewer_thumbnails__thumbnail-item {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  flex-direction: column;
  padding: 1rem;
}

.main_ui_viewer_thumbnails__thumbnail-preview {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 8.25rem;
  min-height: 8.25rem;
  height: 8.25rem;
  padding: 0.25rem;
}
.main_ui_viewer_thumbnails__thumbnail-preview svg {
  width: 100%;
  height: 100%;
}
.main_ui_viewer_thumbnails__thumbnail-preview.main_ui_viewer_thumbnails__selected {
  background-color: var(--viewer-thumbnail-background-color-selected);
  border-radius: 8px;
}
.main_ui_viewer_thumbnails__thumbnail-preview:hover {
  border: 1px solid var(--viewer-thumbnail-border-color);
  border-radius: 8px;
}

.main_ui_viewer_thumbnails__thumbnail-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  text-align: center;
  color: var(--viewer-thumbnails-control-foreground-color);
  padding: 0.5rem 0;
  width: 100%;
  max-width: 8.25rem;
}
@keyframes main_ui_settings_change_email__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_change_email__action-buttons button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_change_email__action-buttons button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_change_email__action-buttons button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_change_email__action-buttons button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_change_email__action-buttons button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_change_email__action-buttons button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_change_email__action-buttons button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_change_email__action-buttons button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_change_email__action-buttons button.disabled, .main_ui_settings_change_email__action-buttons button[disabled], .main_ui_settings_change_email__action-buttons button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_change_email__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_change_email__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_change_email__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_change_email__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_change_email__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_change_email__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_change_email__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_change_email__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_change_email__cancel-button.disabled, [disabled].main_ui_settings_change_email__cancel-button, .main_ui_settings_change_email__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_change_email__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_settings_change_email__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_settings_change_email__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_settings_change_email__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_settings_change_email__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_settings_change_email__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_settings_change_email__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_settings_change_email__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_settings_change_email__modal-close-btn.disabled, [disabled].main_ui_settings_change_email__modal-close-btn, .main_ui_settings_change_email__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_settings_change_email__modal-close-btn.disabled svg, [disabled].main_ui_settings_change_email__modal-close-btn svg, .main_ui_settings_change_email__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_settings_change_email__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_change_email__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_change_email__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_change_email__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_change_email__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_change_email__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_change_email__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_change_email__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_change_email__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_change_email__modal-close-btn svg, .main_ui_settings_change_email__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_change_email__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_change_email__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_change_email__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_change_email__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_change_email__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_change_email__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_settings_change_email__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_settings_change_email__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_settings_change_email__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_change_email__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_settings_change_email__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_settings_change_email__action-buttons button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_settings_change_email__modal-container {
  min-width: 25.5rem;
}

.main_ui_settings_change_email__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_settings_change_email__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_settings_change_email__modal-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  gap: 1.5rem;
  margin-bottom: 1.5rem;
}

.main_ui_settings_change_email__fields-row {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
}

.main_ui_settings_change_email__select-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
}
@keyframes main_ui_settings_delete_account__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_delete_account__accept-button.main_ui_settings_delete_account__danger, .main_ui_settings_delete_account__accept-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_delete_account__accept-button.main_ui_settings_delete_account__danger svg, .main_ui_settings_delete_account__accept-button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_delete_account__accept-button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_delete_account__accept-button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_delete_account__accept-button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_delete_account__accept-button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_delete_account__accept-button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_delete_account__accept-button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_delete_account__accept-button.disabled, [disabled].main_ui_settings_delete_account__accept-button, .main_ui_settings_delete_account__accept-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_delete_account__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_delete_account__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_delete_account__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_delete_account__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_delete_account__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_delete_account__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_delete_account__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_delete_account__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_delete_account__cancel-button.disabled, [disabled].main_ui_settings_delete_account__cancel-button, .main_ui_settings_delete_account__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_delete_account__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_settings_delete_account__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_settings_delete_account__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_settings_delete_account__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_settings_delete_account__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_settings_delete_account__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_settings_delete_account__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_settings_delete_account__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_settings_delete_account__modal-close-btn.disabled, [disabled].main_ui_settings_delete_account__modal-close-btn, .main_ui_settings_delete_account__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_settings_delete_account__modal-close-btn.disabled svg, [disabled].main_ui_settings_delete_account__modal-close-btn svg, .main_ui_settings_delete_account__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_settings_delete_account__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_delete_account__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_delete_account__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_delete_account__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_delete_account__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_delete_account__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_delete_account__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_delete_account__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_delete_account__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_delete_account__modal-close-btn svg, .main_ui_settings_delete_account__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_delete_account__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_delete_account__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_delete_account__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_delete_account__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_delete_account__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_delete_account__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_settings_delete_account__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_settings_delete_account__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_settings_delete_account__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_delete_account__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_settings_delete_account__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_settings_delete_account__accept-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_settings_delete_account__accept-button.main_ui_settings_delete_account__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_settings_delete_account__modal-container {
  display: flex;
  flex-direction: column;
  min-width: 25.5rem;
}

.main_ui_settings_delete_account__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_settings_delete_account__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_settings_delete_account__modal-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  flex: 1 1 auto;
  min-height: 0;
  gap: 1.5rem;
  margin-bottom: 1.5rem;
}

.main_ui_settings_delete_account__warning-notice {
  flex-shrink: 0;
}

.main_ui_settings_delete_account__fields-row {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
}

.main_ui_settings_delete_account__select-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
}

.main_ui_settings_delete_account__orgs-section {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: flex;
  flex-direction: column;
  flex: 1 1 auto;
  min-height: 0;
  gap: var(--sp-l);
}

.main_ui_settings_delete_account__orgs-section-toggle {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: var(--sp-xs);
  padding: 0;
  border: none;
  background: transparent;
  cursor: pointer;
}

.main_ui_settings_delete_account__orgs-section-title {
  color: var(--color-accent-tertiary);
}

.main_ui_settings_delete_account__orgs-section-arrow {
  color: var(--color-accent-tertiary);
  transition: transform 0.15s ease;
}

.main_ui_settings_delete_account__orgs-section-arrow.main_ui_settings_delete_account__expanded {
  transform: rotate(90deg);
}

.main_ui_settings_delete_account__org-list {
  display: flex;
  flex-direction: column;
  flex: 1 1 auto;
  min-height: 0;
  gap: var(--sp-l);
  margin: 0;
  padding: 0;
  list-style: none;
  overflow-y: auto;
}

.main_ui_settings_delete_account__org-item {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_settings_delete_account__org-info {
  display: flex;
  flex-direction: column;
}

.main_ui_settings_delete_account__org-name {
  color: var(--modal-title-foreground-color);
}

.main_ui_settings_delete_account__org-counts {
  display: flex;
  flex-direction: row;
  gap: var(--sp-s);
  color: var(--df-secondary);
}
@keyframes main_ui_settings_feedback__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link, .main_ui_settings_feedback__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link svg, .main_ui_settings_feedback__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:focus-visible, .main_ui_settings_feedback__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:focus-visible svg, .main_ui_settings_feedback__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:hover, .main_ui_settings_feedback__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:hover svg, .main_ui_settings_feedback__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:active, .main_ui_settings_feedback__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:active svg, .main_ui_settings_feedback__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link.disabled, .main_ui_settings_feedback__btn-primary.disabled, .main_ui_settings_feedback__feedback-form [disabled].main_ui_settings_feedback__feedback-button-link, [disabled].main_ui_settings_feedback__btn-primary, .main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link:disabled, .main_ui_settings_feedback__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_feedback__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_feedback__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_feedback__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_feedback__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_feedback__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_feedback__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_feedback__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_feedback__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_feedback__btn-secondary.disabled, [disabled].main_ui_settings_feedback__btn-secondary, .main_ui_settings_feedback__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_feedback__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_feedback__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_feedback__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_feedback__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_feedback__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_feedback__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_feedback__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_feedback__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_feedback__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_feedback__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_feedback__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_feedback__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_feedback__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_feedback__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_feedback__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_feedback__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_feedback__dashboard-settings {
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.main_ui_settings_feedback__dashboard-settings a:not(.main_ui_settings_feedback__button-primary, .main_ui_settings_feedback__link) {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_feedback__form-container {
  display: flex;
  flex-direction: column;
  max-width: 31.25rem;
  width: 36.25rem;
  margin: 5rem auto 7.5rem auto;
  justify-content: center;
}
.main_ui_settings_feedback__form-container form {
  display: flex;
  flex-direction: column;
}
.main_ui_settings_feedback__form-container form .main_ui_settings_feedback__btn-secondary {
  width: 100%;
  font-size: 0.688rem;
  text-transform: uppercase;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_settings_feedback__form-container form .main_ui_settings_feedback__btn-secondary:hover {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_settings_feedback__form-container form hr {
  display: none;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__fields-row {
  --input-height: 2.5rem;
  margin-bottom: 1.25rem;
  flex-direction: column;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__fields-row .main_ui_settings_feedback__options {
  display: flex;
  justify-content: flex-end;
  font-size: 0.875rem;
  margin-top: 0.75rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__field {
  margin-bottom: 1.25rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__field-title {
  color: var(--color-foreground-primary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__field-title:not(:first-child) {
  margin-top: 4rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__field-text {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select {
  flex-direction: column-reverse;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input label,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select label {
  position: relative;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  font-size: 0.688rem;
  margin-bottom: 0.75rem;
  margin-left: -0.25rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input input,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input select,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select input,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select select {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  color: var(--color-foreground-primary);
  padding: 0 1rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input input:focus,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input select:focus,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select input:focus,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select select:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input input ::-moz-placeholder, .main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input select ::-moz-placeholder, .main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select input ::-moz-placeholder, .main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select select ::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input input ::placeholder,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input select ::placeholder,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select input ::placeholder,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select select ::placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input .main_ui_settings_feedback__help-icon,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select .main_ui_settings_feedback__help-icon {
  bottom: 0.75rem;
  top: auto;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input .main_ui_settings_feedback__help-icon svg,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select .main_ui_settings_feedback__help-icon svg {
  fill: var(--color-foreground-secondary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input.main_ui_settings_feedback__disabled input,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select.main_ui_settings_feedback__disabled input {
  background-color: var(--input-background-color-disabled);
  border-color: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input .main_ui_settings_feedback__input-container,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select .main_ui_settings_feedback__input-container {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  margin-top: 1.5rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input .main_ui_settings_feedback__input-container .main_ui_settings_feedback__main-content label,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select .main_ui_settings_feedback__input-container .main_ui_settings_feedback__main-content label {
  position: absolute;
  top: calc(-1 * 1.5rem);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input .main_ui_settings_feedback__input-container .main_ui_settings_feedback__main-content span,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select .main_ui_settings_feedback__input-container .main_ui_settings_feedback__main-content span {
  color: var(--color-foreground-primary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input .main_ui_settings_feedback__input-container:focus,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select .main_ui_settings_feedback__input-container:focus {
  border: 1px solid var(--color-accent-primary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input textarea,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select textarea {
  border-radius: 8px;
  padding: 0.75rem 1rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-input textarea:focus,
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__custom-select textarea:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_feedback__form-container.main_ui_settings_feedback__two-columns {
  max-width: 32.5rem;
  justify-content: space-between;
  flex-direction: row;
}
.main_ui_settings_feedback__form-container h1 {
  font-size: 2.25rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__subtitle {
  font-size: 1.5rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__notification-icon {
  justify-content: center;
  display: flex;
  margin-bottom: 3rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__notification-icon svg {
  fill: var(--color-background-primary);
  height: 40%;
  width: 40%;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__notification-text {
  font-size: 1rem;
  color: var(--color-background-primary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__notification-text-email {
  background: var(--color-foreground-primary);
  border-radius: 4px;
  color: var(--color-background-primary);
  font-size: 1rem;
  font-weight: 500;
  margin: 1.5rem 0 2.5rem 0;
  padding: 1rem;
  text-align: center;
}
.main_ui_settings_feedback__form-container h2 {
  font-size: 1.5rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 1rem 0;
}
.main_ui_settings_feedback__form-container h3 {
  font-size: 0.75rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 0.5rem 0;
  text-transform: uppercase;
}
.main_ui_settings_feedback__form-container a:not(.main_ui_settings_feedback__button-primary):hover {
  text-decoration: underline;
}
.main_ui_settings_feedback__form-container p {
  color: var(--color-background-primary);
}
.main_ui_settings_feedback__form-container hr {
  border-color: var(--color-foreground-secondary);
}
.main_ui_settings_feedback__form-container .main_ui_settings_feedback__links {
  margin-top: 0.75rem;
}

form.main_ui_settings_feedback__avatar-form {
  display: flex;
  flex-direction: column;
  width: 9.25rem;
  height: 9.25rem;
  margin: 1rem 0;
}
form.main_ui_settings_feedback__avatar-form img {
  border-radius: 50%;
  flex-shrink: 0;
  height: 100%;
  margin-right: 1rem;
  width: 100%;
}

.main_ui_settings_feedback__image-change-field {
  position: relative;
  width: 100%;
  height: 100%;
}
.main_ui_settings_feedback__image-change-field .main_ui_settings_feedback__update-overlay {
  opacity: 0;
  cursor: pointer;
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: 50%;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  line-height: 6;
  text-align: center;
  background: var(--color-accent-tertiary);
  z-index: 300;
}
.main_ui_settings_feedback__image-change-field .main_ui_settings_feedback__delete-overlay {
  position: absolute;
  top: 0.25rem;
  inset-inline-end: 0.25rem;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem;
  padding: 0;
  border: none;
  border-radius: 50%;
  background: var(--color-background-primary);
  color: var(--color-foreground-primary);
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.15s ease-in-out;
  z-index: calc(300 + 1);
}
.main_ui_settings_feedback__image-change-field .main_ui_settings_feedback__delete-overlay:hover {
  background: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_settings_feedback__image-change-field input[type=file] {
  width: 100%;
  height: 100%;
  position: absolute;
  opacity: 0;
  cursor: pointer;
  top: 0;
  z-index: 300;
}
.main_ui_settings_feedback__image-change-field:hover .main_ui_settings_feedback__update-overlay {
  opacity: 0.8;
}
.main_ui_settings_feedback__image-change-field:hover .main_ui_settings_feedback__delete-overlay {
  opacity: 1;
}

.main_ui_settings_feedback__profile-form {
  display: flex;
  flex-direction: column;
  max-width: 23rem;
  width: 100%;
}

.main_ui_settings_feedback__newsletter-subs {
  border-bottom: 1px solid var(--color-foreground-secondary);
  border-top: 1px solid var(--color-foreground-secondary);
  padding: 2rem 0;
  margin-bottom: 2rem;
}
.main_ui_settings_feedback__newsletter-subs .main_ui_settings_feedback__newsletter-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.875rem;
}
.main_ui_settings_feedback__newsletter-subs label {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-background-primary);
  font-size: 0.75rem;
  margin-right: calc(-1 * 1rem);
  margin-bottom: 0.75rem;
}
.main_ui_settings_feedback__newsletter-subs .main_ui_settings_feedback__info {
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  margin-bottom: 0.5rem;
}
.main_ui_settings_feedback__newsletter-subs .main_ui_settings_feedback__input-checkbox label {
  align-items: flex-start;
}

.main_ui_settings_feedback__btn-secondary {
  height: 2rem;
}

.main_ui_settings_feedback__btn-primary {
  height: 2rem;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__fields-row {
  margin-block-end: 2rem;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-description {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  border-radius: 0.5rem;
  padding: var(--sp-m);
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-description ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-description ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-description:focus {
  outline: 0.0625rem solid var(--color-accent-primary);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__field-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  block-size: 2rem;
  color: var(--color-foreground-primary);
  margin-block-end: var(--sp-l);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-button-link {
  margin-block-end: 4.5rem;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__feedback-title {
  margin-block-end: var(--sp-xxxl);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__field-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__bottom-margin {
  margin-block-end: var(--sp-xxxl);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--color-accent-tertiary);
  margin-block-end: var(--sp-s);
}
.main_ui_settings_feedback__feedback-form .main_ui_settings_feedback__download-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
  text-transform: lowercase;
  border: 0.0625rem solid var(--color-background-quaternary);
  margin-block-start: var(--sp-s);
  padding: var(--sp-s);
  border-radius: 0.5rem;
  block-size: 2rem;
  display: inline-block;
  min-inline-size: 10rem;
  text-align: center;
}
@keyframes main_ui_settings_integrations__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_integrations__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_integrations__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_integrations__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_integrations__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_integrations__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_integrations__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_integrations__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_integrations__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_integrations__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_integrations__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_integrations__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_integrations__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_integrations__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_integrations__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_integrations__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_integrations__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_settings_integrations__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_settings_integrations__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_settings_integrations__color-primary {
  color: var(--color-foreground-primary);
}

.main_ui_settings_integrations__color-secondary {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_integrations__text-center {
  text-align: center;
}

.main_ui_settings_integrations__fit-content {
  inline-size: -moz-fit-content;
  inline-size: fit-content;
}

.main_ui_settings_integrations__beta {
  color: var(--color-accent-primary);
  border: 0.0625rem solid var(--color-accent-primary);
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  padding: var(--sp-xxs) var(--sp-s);
  border-radius: 0.25rem;
}

.main_ui_settings_integrations__title {
  display: flex;
  flex-direction: row;
  align-items: baseline;
  gap: var(--sp-s);
}

.main_ui_settings_integrations__modal-container {
  inline-size: 25rem;
  max-block-size: -moz-fit-content;
  max-block-size: fit-content;
  position: relative;
}

.main_ui_settings_integrations__modal-content {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_settings_integrations__modal-form {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxxl);
}

.main_ui_settings_integrations__modal-close-button {
  position: absolute;
  top: var(--sp-s);
  right: var(--sp-s);
}

.main_ui_settings_integrations__modal-footer {
  display: flex;
  justify-content: right;
  gap: var(--sp-s);
}

.main_ui_settings_integrations__input-copy {
  position: relative;
}

.main_ui_settings_integrations__input-copy-button-wrapper {
  position: absolute;
  top: 0;
  right: 0;
  border-start-start-radius: 0;
  border-end-start-radius: 0;
}

.main_ui_settings_integrations__input-copy-button {
  border-radius: 0 0.5rem 0.5rem 0;
}

.main_ui_settings_integrations__integrations {
  display: grid;
  grid-template-rows: auto 1fr;
  margin: 5.5rem auto 7.5rem auto;
  gap: 2rem;
  inline-size: 31.25rem;
}

.main_ui_settings_integrations__access-tokens-section {
  display: grid;
  grid-template-rows: auto auto 1fr;
  gap: var(--sp-m);
}

.main_ui_settings_integrations__mcp-server-section {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_settings_integrations__mcp-server-key {
  display: flex;
  flex-direction: column;
}

.main_ui_settings_integrations__mcp-server-notification {
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
  padding-right: var(--sp-xxl);
}

.main_ui_settings_integrations__mcp-server-notification-link {
  cursor: pointer;
  color: var(--color-accent-primary);
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: var(--sp-xs);
}

.main_ui_settings_integrations__mcp-server-title {
  margin: var(--sp-s) 0;
}

.main_ui_settings_integrations__mcp-server-block {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_settings_integrations__mcp-server-regenerate {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_settings_integrations__mcp-server-switch {
  position: relative;
}

.main_ui_settings_integrations__mcp-server-switch-cover {
  position: absolute;
  inset-block: 0;
  inset-inline: 0;
}

.main_ui_settings_integrations__separator {
  border: 0.0625rem solid var(--color-background-quaternary);
  margin: var(--sp-s) 0;
}

.main_ui_settings_integrations__frame {
  border: 0.0625rem solid var(--color-background-quaternary);
  padding: var(--sp-m);
  border-radius: 0.5rem;
}

.main_ui_settings_integrations__list {
  display: grid;
  grid-auto-rows: 4rem;
  gap: var(--sp-m);
}

.main_ui_settings_integrations__item {
  display: grid;
  grid-template-columns: 45% 1fr auto;
  align-items: center;
  background-color: var(--color-background-tertiary);
  border-radius: 0.5rem;
}

.main_ui_settings_integrations__item-title {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  align-content: center;
  block-size: 4rem;
  padding: 0 var(--sp-l);
  color: var(--color-foreground-primary);
}

.main_ui_settings_integrations__item-subtitle {
  align-content: center;
  block-size: 4rem;
  color: var(--color-foreground-secondary);
}
.main_ui_settings_integrations__item-subtitle.main_ui_settings_integrations__warning {
  padding: var(--sp-s) var(--sp-m);
  block-size: -moz-fit-content;
  block-size: fit-content;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  color: var(--color-foreground-primary);
  background-color: var(--color-background-warning);
  border: 0.0625rem solid var(--color-accent-warning);
  border-radius: 0.5rem;
}

.main_ui_settings_integrations__item-actions {
  position: relative;
}

.main_ui_settings_integrations__item-button {
  block-size: 4rem;
  inline-size: 3rem;
  border-radius: 0 var(--sp-s) var(--sp-s) 0;
}

.main_ui_settings_integrations__textarea {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-secondary);
  padding: var(--sp-xs) var(--sp-s);
  border: 0;
  resize: none;
}
.main_ui_settings_integrations__textarea:hover {
  background-color: var(--color-background-quaternary);
}
.main_ui_settings_integrations__textarea:focus-visible {
  outline: 0.0625rem solid var(--color-accent-primary);
}
@keyframes main_ui_settings_notifications__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_notifications__update-btn, .main_ui_settings_notifications__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_notifications__update-btn svg, .main_ui_settings_notifications__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_notifications__update-btn:focus-visible, .main_ui_settings_notifications__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_notifications__update-btn:focus-visible svg, .main_ui_settings_notifications__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_notifications__update-btn:hover, .main_ui_settings_notifications__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_notifications__update-btn:hover svg, .main_ui_settings_notifications__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_notifications__update-btn:active, .main_ui_settings_notifications__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_notifications__update-btn:active svg, .main_ui_settings_notifications__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_notifications__update-btn.disabled, .main_ui_settings_notifications__btn-primary.disabled, [disabled].main_ui_settings_notifications__update-btn, [disabled].main_ui_settings_notifications__btn-primary, .main_ui_settings_notifications__update-btn:disabled, .main_ui_settings_notifications__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_notifications__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_notifications__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_notifications__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_notifications__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_notifications__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_notifications__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_notifications__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_notifications__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_notifications__btn-secondary.disabled, [disabled].main_ui_settings_notifications__btn-secondary, .main_ui_settings_notifications__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_notifications__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_notifications__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_notifications__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_notifications__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_notifications__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_notifications__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_notifications__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_notifications__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_notifications__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_notifications__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_notifications__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_notifications__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_notifications__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_notifications__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_notifications__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_notifications__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_notifications__dashboard-settings {
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.main_ui_settings_notifications__dashboard-settings a:not(.main_ui_settings_notifications__button-primary, .main_ui_settings_notifications__link) {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_notifications__form-container {
  display: flex;
  flex-direction: column;
  max-width: 31.25rem;
  width: 36.25rem;
  margin: 5rem auto 7.5rem auto;
  justify-content: center;
}
.main_ui_settings_notifications__form-container form {
  display: flex;
  flex-direction: column;
}
.main_ui_settings_notifications__form-container form .main_ui_settings_notifications__btn-secondary {
  width: 100%;
  font-size: 0.688rem;
  text-transform: uppercase;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_settings_notifications__form-container form .main_ui_settings_notifications__btn-secondary:hover {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_settings_notifications__form-container form hr {
  display: none;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__fields-row {
  --input-height: 2.5rem;
  margin-bottom: 1.25rem;
  flex-direction: column;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__fields-row .main_ui_settings_notifications__options {
  display: flex;
  justify-content: flex-end;
  font-size: 0.875rem;
  margin-top: 0.75rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__field {
  margin-bottom: 1.25rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__field-title {
  color: var(--color-foreground-primary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__field-title:not(:first-child) {
  margin-top: 4rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__field-text {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select {
  flex-direction: column-reverse;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input label,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select label {
  position: relative;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  font-size: 0.688rem;
  margin-bottom: 0.75rem;
  margin-left: -0.25rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input input,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input select,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select input,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select select {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  color: var(--color-foreground-primary);
  padding: 0 1rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input input:focus,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input select:focus,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select input:focus,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select select:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input input ::-moz-placeholder, .main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input select ::-moz-placeholder, .main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select input ::-moz-placeholder, .main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select select ::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input input ::placeholder,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input select ::placeholder,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select input ::placeholder,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select select ::placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input .main_ui_settings_notifications__help-icon,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select .main_ui_settings_notifications__help-icon {
  bottom: 0.75rem;
  top: auto;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input .main_ui_settings_notifications__help-icon svg,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select .main_ui_settings_notifications__help-icon svg {
  fill: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input.main_ui_settings_notifications__disabled input,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select.main_ui_settings_notifications__disabled input {
  background-color: var(--input-background-color-disabled);
  border-color: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input .main_ui_settings_notifications__input-container,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select .main_ui_settings_notifications__input-container {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  margin-top: 1.5rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input .main_ui_settings_notifications__input-container .main_ui_settings_notifications__main-content label,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select .main_ui_settings_notifications__input-container .main_ui_settings_notifications__main-content label {
  position: absolute;
  top: calc(-1 * 1.5rem);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input .main_ui_settings_notifications__input-container .main_ui_settings_notifications__main-content span,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select .main_ui_settings_notifications__input-container .main_ui_settings_notifications__main-content span {
  color: var(--color-foreground-primary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input .main_ui_settings_notifications__input-container:focus,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select .main_ui_settings_notifications__input-container:focus {
  border: 1px solid var(--color-accent-primary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input textarea,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select textarea {
  border-radius: 8px;
  padding: 0.75rem 1rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-input textarea:focus,
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__custom-select textarea:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_notifications__form-container.main_ui_settings_notifications__two-columns {
  max-width: 32.5rem;
  justify-content: space-between;
  flex-direction: row;
}
.main_ui_settings_notifications__form-container h1 {
  font-size: 2.25rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__subtitle {
  font-size: 1.5rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__notification-icon {
  justify-content: center;
  display: flex;
  margin-bottom: 3rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__notification-icon svg {
  fill: var(--color-background-primary);
  height: 40%;
  width: 40%;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__notification-text {
  font-size: 1rem;
  color: var(--color-background-primary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__notification-text-email {
  background: var(--color-foreground-primary);
  border-radius: 4px;
  color: var(--color-background-primary);
  font-size: 1rem;
  font-weight: 500;
  margin: 1.5rem 0 2.5rem 0;
  padding: 1rem;
  text-align: center;
}
.main_ui_settings_notifications__form-container h2 {
  font-size: 1.5rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 1rem 0;
}
.main_ui_settings_notifications__form-container h3 {
  font-size: 0.75rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 0.5rem 0;
  text-transform: uppercase;
}
.main_ui_settings_notifications__form-container a:not(.main_ui_settings_notifications__button-primary):hover {
  text-decoration: underline;
}
.main_ui_settings_notifications__form-container p {
  color: var(--color-background-primary);
}
.main_ui_settings_notifications__form-container hr {
  border-color: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container .main_ui_settings_notifications__links {
  margin-top: 0.75rem;
}

form.main_ui_settings_notifications__avatar-form {
  display: flex;
  flex-direction: column;
  width: 9.25rem;
  height: 9.25rem;
  margin: 1rem 0;
}
form.main_ui_settings_notifications__avatar-form img {
  border-radius: 50%;
  flex-shrink: 0;
  height: 100%;
  margin-right: 1rem;
  width: 100%;
}

.main_ui_settings_notifications__image-change-field {
  position: relative;
  width: 100%;
  height: 100%;
}
.main_ui_settings_notifications__image-change-field .main_ui_settings_notifications__update-overlay {
  opacity: 0;
  cursor: pointer;
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: 50%;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  line-height: 6;
  text-align: center;
  background: var(--color-accent-tertiary);
  z-index: 300;
}
.main_ui_settings_notifications__image-change-field .main_ui_settings_notifications__delete-overlay {
  position: absolute;
  top: 0.25rem;
  inset-inline-end: 0.25rem;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem;
  padding: 0;
  border: none;
  border-radius: 50%;
  background: var(--color-background-primary);
  color: var(--color-foreground-primary);
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.15s ease-in-out;
  z-index: calc(300 + 1);
}
.main_ui_settings_notifications__image-change-field .main_ui_settings_notifications__delete-overlay:hover {
  background: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_settings_notifications__image-change-field input[type=file] {
  width: 100%;
  height: 100%;
  position: absolute;
  opacity: 0;
  cursor: pointer;
  top: 0;
  z-index: 300;
}
.main_ui_settings_notifications__image-change-field:hover .main_ui_settings_notifications__update-overlay {
  opacity: 0.8;
}
.main_ui_settings_notifications__image-change-field:hover .main_ui_settings_notifications__delete-overlay {
  opacity: 1;
}

.main_ui_settings_notifications__profile-form {
  display: flex;
  flex-direction: column;
  max-width: 23rem;
  width: 100%;
}

.main_ui_settings_notifications__newsletter-subs {
  border-bottom: 1px solid var(--color-foreground-secondary);
  border-top: 1px solid var(--color-foreground-secondary);
  padding: 2rem 0;
  margin-bottom: 2rem;
}
.main_ui_settings_notifications__newsletter-subs .main_ui_settings_notifications__newsletter-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.875rem;
}
.main_ui_settings_notifications__newsletter-subs label {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-background-primary);
  font-size: 0.75rem;
  margin-right: calc(-1 * 1rem);
  margin-bottom: 0.75rem;
}
.main_ui_settings_notifications__newsletter-subs .main_ui_settings_notifications__info {
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  margin-bottom: 0.5rem;
}
.main_ui_settings_notifications__newsletter-subs .main_ui_settings_notifications__input-checkbox label {
  align-items: flex-start;
}

.main_ui_settings_notifications__btn-secondary {
  height: 2rem;
}

.main_ui_settings_notifications__btn-primary {
  height: 2rem;
}

.main_ui_settings_notifications__update-btn {
  margin-top: 1rem;
  height: 2.25rem;
}

.main_ui_settings_notifications__notifications-form {
  width: 25rem;
}

.main_ui_settings_notifications__notifications-page {
  display: flex;
  justify-content: center;
}

.main_ui_settings_notifications__radio-btns {
  display: flex;
  flex-direction: column;
  gap: 0;
}

.main_ui_settings_notifications__form-container h3 {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_notifications__form-container h4 {
  font-size: 0.688rem;
  color: var(--color-foreground-primary);
  text-transform: uppercase;
  margin: 0.75rem;
}
@keyframes main_ui_settings_options__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_options__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_options__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_options__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_options__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_options__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_options__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_options__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_options__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_options__btn-primary.disabled, [disabled].main_ui_settings_options__btn-primary, .main_ui_settings_options__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_options__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_options__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_options__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_options__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_options__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_options__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_options__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_options__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_options__btn-secondary.disabled, [disabled].main_ui_settings_options__btn-secondary, .main_ui_settings_options__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_options__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_options__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_options__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_options__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_options__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_options__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_options__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_options__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_options__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_options__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_options__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_options__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_options__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_options__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_options__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_options__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_options__dashboard-settings {
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.main_ui_settings_options__dashboard-settings a:not(.main_ui_settings_options__button-primary, .main_ui_settings_options__link) {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_options__form-container {
  display: flex;
  flex-direction: column;
  max-width: 31.25rem;
  width: 36.25rem;
  margin: 5rem auto 7.5rem auto;
  justify-content: center;
}
.main_ui_settings_options__form-container form {
  display: flex;
  flex-direction: column;
}
.main_ui_settings_options__form-container form .main_ui_settings_options__btn-secondary {
  width: 100%;
  font-size: 0.688rem;
  text-transform: uppercase;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_settings_options__form-container form .main_ui_settings_options__btn-secondary:hover {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_settings_options__form-container form hr {
  display: none;
}
.main_ui_settings_options__form-container .main_ui_settings_options__fields-row {
  --input-height: 2.5rem;
  margin-bottom: 1.25rem;
  flex-direction: column;
}
.main_ui_settings_options__form-container .main_ui_settings_options__fields-row .main_ui_settings_options__options {
  display: flex;
  justify-content: flex-end;
  font-size: 0.875rem;
  margin-top: 0.75rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__field {
  margin-bottom: 1.25rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__field-title {
  color: var(--color-foreground-primary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__field-title:not(:first-child) {
  margin-top: 4rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__field-text {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select {
  flex-direction: column-reverse;
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input label,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select label {
  position: relative;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  font-size: 0.688rem;
  margin-bottom: 0.75rem;
  margin-left: -0.25rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input input,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input select,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select input,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select select {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  color: var(--color-foreground-primary);
  padding: 0 1rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input input:focus,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input select:focus,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select input:focus,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select select:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input input ::-moz-placeholder, .main_ui_settings_options__form-container .main_ui_settings_options__custom-input select ::-moz-placeholder, .main_ui_settings_options__form-container .main_ui_settings_options__custom-select input ::-moz-placeholder, .main_ui_settings_options__form-container .main_ui_settings_options__custom-select select ::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input input ::placeholder,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input select ::placeholder,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select input ::placeholder,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select select ::placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input .main_ui_settings_options__help-icon,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select .main_ui_settings_options__help-icon {
  bottom: 0.75rem;
  top: auto;
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input .main_ui_settings_options__help-icon svg,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select .main_ui_settings_options__help-icon svg {
  fill: var(--color-foreground-secondary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input.main_ui_settings_options__disabled input,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select.main_ui_settings_options__disabled input {
  background-color: var(--input-background-color-disabled);
  border-color: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input .main_ui_settings_options__input-container,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select .main_ui_settings_options__input-container {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  margin-top: 1.5rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input .main_ui_settings_options__input-container .main_ui_settings_options__main-content label,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select .main_ui_settings_options__input-container .main_ui_settings_options__main-content label {
  position: absolute;
  top: calc(-1 * 1.5rem);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input .main_ui_settings_options__input-container .main_ui_settings_options__main-content span,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select .main_ui_settings_options__input-container .main_ui_settings_options__main-content span {
  color: var(--color-foreground-primary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input .main_ui_settings_options__input-container:focus,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select .main_ui_settings_options__input-container:focus {
  border: 1px solid var(--color-accent-primary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input textarea,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select textarea {
  border-radius: 8px;
  padding: 0.75rem 1rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings_options__form-container .main_ui_settings_options__custom-input textarea:focus,
.main_ui_settings_options__form-container .main_ui_settings_options__custom-select textarea:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_options__form-container.main_ui_settings_options__two-columns {
  max-width: 32.5rem;
  justify-content: space-between;
  flex-direction: row;
}
.main_ui_settings_options__form-container h1 {
  font-size: 2.25rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__subtitle {
  font-size: 1.5rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__notification-icon {
  justify-content: center;
  display: flex;
  margin-bottom: 3rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__notification-icon svg {
  fill: var(--color-background-primary);
  height: 40%;
  width: 40%;
}
.main_ui_settings_options__form-container .main_ui_settings_options__notification-text {
  font-size: 1rem;
  color: var(--color-background-primary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_options__form-container .main_ui_settings_options__notification-text-email {
  background: var(--color-foreground-primary);
  border-radius: 4px;
  color: var(--color-background-primary);
  font-size: 1rem;
  font-weight: 500;
  margin: 1.5rem 0 2.5rem 0;
  padding: 1rem;
  text-align: center;
}
.main_ui_settings_options__form-container h2 {
  font-size: 1.5rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 1rem 0;
}
.main_ui_settings_options__form-container h3 {
  font-size: 0.75rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 0.5rem 0;
  text-transform: uppercase;
}
.main_ui_settings_options__form-container a:not(.main_ui_settings_options__button-primary):hover {
  text-decoration: underline;
}
.main_ui_settings_options__form-container p {
  color: var(--color-background-primary);
}
.main_ui_settings_options__form-container hr {
  border-color: var(--color-foreground-secondary);
}
.main_ui_settings_options__form-container .main_ui_settings_options__links {
  margin-top: 0.75rem;
}

form.main_ui_settings_options__avatar-form {
  display: flex;
  flex-direction: column;
  width: 9.25rem;
  height: 9.25rem;
  margin: 1rem 0;
}
form.main_ui_settings_options__avatar-form img {
  border-radius: 50%;
  flex-shrink: 0;
  height: 100%;
  margin-right: 1rem;
  width: 100%;
}

.main_ui_settings_options__image-change-field {
  position: relative;
  width: 100%;
  height: 100%;
}
.main_ui_settings_options__image-change-field .main_ui_settings_options__update-overlay {
  opacity: 0;
  cursor: pointer;
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: 50%;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  line-height: 6;
  text-align: center;
  background: var(--color-accent-tertiary);
  z-index: 300;
}
.main_ui_settings_options__image-change-field .main_ui_settings_options__delete-overlay {
  position: absolute;
  top: 0.25rem;
  inset-inline-end: 0.25rem;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem;
  padding: 0;
  border: none;
  border-radius: 50%;
  background: var(--color-background-primary);
  color: var(--color-foreground-primary);
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.15s ease-in-out;
  z-index: calc(300 + 1);
}
.main_ui_settings_options__image-change-field .main_ui_settings_options__delete-overlay:hover {
  background: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_settings_options__image-change-field input[type=file] {
  width: 100%;
  height: 100%;
  position: absolute;
  opacity: 0;
  cursor: pointer;
  top: 0;
  z-index: 300;
}
.main_ui_settings_options__image-change-field:hover .main_ui_settings_options__update-overlay {
  opacity: 0.8;
}
.main_ui_settings_options__image-change-field:hover .main_ui_settings_options__delete-overlay {
  opacity: 1;
}

.main_ui_settings_options__profile-form {
  display: flex;
  flex-direction: column;
  max-width: 23rem;
  width: 100%;
}

.main_ui_settings_options__newsletter-subs {
  border-bottom: 1px solid var(--color-foreground-secondary);
  border-top: 1px solid var(--color-foreground-secondary);
  padding: 2rem 0;
  margin-bottom: 2rem;
}
.main_ui_settings_options__newsletter-subs .main_ui_settings_options__newsletter-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.875rem;
}
.main_ui_settings_options__newsletter-subs label {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-background-primary);
  font-size: 0.75rem;
  margin-right: calc(-1 * 1rem);
  margin-bottom: 0.75rem;
}
.main_ui_settings_options__newsletter-subs .main_ui_settings_options__info {
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  margin-bottom: 0.5rem;
}
.main_ui_settings_options__newsletter-subs .main_ui_settings_options__input-checkbox label {
  align-items: flex-start;
}

.main_ui_settings_options__btn-secondary {
  height: 2rem;
}

.main_ui_settings_options__btn-primary {
  height: 2rem;
}

.main_ui_settings_options__dashboard-settings {
  display: grid;
}

.main_ui_settings_options__form-container {
  --menu-max-height-up: 11.25rem;
}
.main_ui_settings_options__form-container:first-child {
  margin-block-end: var(--sp-xxxl);
}

/* Copied from profile.scss .form-container, but without included nested
   rules, since we want custom styles for it */
.main_ui_settings_options__webgl-container {
  display: grid;
  grid-auto-rows: auto;
  gap: var(--sp-s);
  width: 31.25rem;
  padding-block-start: var(--sp-xxxl);
  margin: var(--sp-xxxl) 7.5rem; /* FIXME: this should be a proper token */
  border-block-start: 0.0625rem solid var(--color-background-quaternary);
  color: var(--color-foreground-primary);
}

.main_ui_settings_options__webgl-header {
  display: flex;
  flex-direction: row;
  align-items: baseline;
  gap: var(--sp-m);
}

.main_ui_settings_options__description {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_options__beta {
  color: var(--color-accent-primary);
  padding: var(--sp-xxs) var(--sp-s);
  border: 0.0625rem solid var(--color-accent-primary);
  border-radius: 0.25rem;
}

.main_ui_settings_options__title {
  color: var(--color-foreground-primary);
}

.main_ui_settings_options__link {
  color: var(--color-accent-primary);
  text-decoration: none;
  display: flex;
  align-items: center;
  gap: var(--sp-xs);
}
@keyframes main_ui_settings_password__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_password__update-btn, .main_ui_settings_password__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_password__update-btn svg, .main_ui_settings_password__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_password__update-btn:focus-visible, .main_ui_settings_password__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_password__update-btn:focus-visible svg, .main_ui_settings_password__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_password__update-btn:hover, .main_ui_settings_password__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_password__update-btn:hover svg, .main_ui_settings_password__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_password__update-btn:active, .main_ui_settings_password__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_password__update-btn:active svg, .main_ui_settings_password__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_password__update-btn.disabled, .main_ui_settings_password__btn-primary.disabled, [disabled].main_ui_settings_password__update-btn, [disabled].main_ui_settings_password__btn-primary, .main_ui_settings_password__update-btn:disabled, .main_ui_settings_password__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_password__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_password__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_password__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_password__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_password__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_password__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_password__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_password__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_password__btn-secondary.disabled, [disabled].main_ui_settings_password__btn-secondary, .main_ui_settings_password__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_password__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_password__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_password__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_password__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_password__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_password__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_password__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_password__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_password__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_password__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_password__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_password__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_password__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_password__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_password__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_password__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_password__dashboard-settings {
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.main_ui_settings_password__dashboard-settings a:not(.main_ui_settings_password__button-primary, .main_ui_settings_password__link) {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_password__form-container {
  display: flex;
  flex-direction: column;
  max-width: 31.25rem;
  width: 36.25rem;
  margin: 5rem auto 7.5rem auto;
  justify-content: center;
}
.main_ui_settings_password__form-container form {
  display: flex;
  flex-direction: column;
}
.main_ui_settings_password__form-container form .main_ui_settings_password__btn-secondary {
  width: 100%;
  font-size: 0.688rem;
  text-transform: uppercase;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_settings_password__form-container form .main_ui_settings_password__btn-secondary:hover {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_settings_password__form-container form hr {
  display: none;
}
.main_ui_settings_password__form-container .main_ui_settings_password__fields-row {
  --input-height: 2.5rem;
  margin-bottom: 1.25rem;
  flex-direction: column;
}
.main_ui_settings_password__form-container .main_ui_settings_password__fields-row .main_ui_settings_password__options {
  display: flex;
  justify-content: flex-end;
  font-size: 0.875rem;
  margin-top: 0.75rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__field {
  margin-bottom: 1.25rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__field-title {
  color: var(--color-foreground-primary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__field-title:not(:first-child) {
  margin-top: 4rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__field-text {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select {
  flex-direction: column-reverse;
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input label,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select label {
  position: relative;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  font-size: 0.688rem;
  margin-bottom: 0.75rem;
  margin-left: -0.25rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input input,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input select,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select input,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select select {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  color: var(--color-foreground-primary);
  padding: 0 1rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input input:focus,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input select:focus,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select input:focus,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select select:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input input ::-moz-placeholder, .main_ui_settings_password__form-container .main_ui_settings_password__custom-input select ::-moz-placeholder, .main_ui_settings_password__form-container .main_ui_settings_password__custom-select input ::-moz-placeholder, .main_ui_settings_password__form-container .main_ui_settings_password__custom-select select ::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input input ::placeholder,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input select ::placeholder,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select input ::placeholder,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select select ::placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input .main_ui_settings_password__help-icon,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select .main_ui_settings_password__help-icon {
  bottom: 0.75rem;
  top: auto;
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input .main_ui_settings_password__help-icon svg,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select .main_ui_settings_password__help-icon svg {
  fill: var(--color-foreground-secondary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input.main_ui_settings_password__disabled input,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select.main_ui_settings_password__disabled input {
  background-color: var(--input-background-color-disabled);
  border-color: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input .main_ui_settings_password__input-container,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select .main_ui_settings_password__input-container {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  margin-top: 1.5rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input .main_ui_settings_password__input-container .main_ui_settings_password__main-content label,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select .main_ui_settings_password__input-container .main_ui_settings_password__main-content label {
  position: absolute;
  top: calc(-1 * 1.5rem);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input .main_ui_settings_password__input-container .main_ui_settings_password__main-content span,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select .main_ui_settings_password__input-container .main_ui_settings_password__main-content span {
  color: var(--color-foreground-primary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input .main_ui_settings_password__input-container:focus,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select .main_ui_settings_password__input-container:focus {
  border: 1px solid var(--color-accent-primary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input textarea,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select textarea {
  border-radius: 8px;
  padding: 0.75rem 1rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings_password__form-container .main_ui_settings_password__custom-input textarea:focus,
.main_ui_settings_password__form-container .main_ui_settings_password__custom-select textarea:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_password__form-container.main_ui_settings_password__two-columns {
  max-width: 32.5rem;
  justify-content: space-between;
  flex-direction: row;
}
.main_ui_settings_password__form-container h1 {
  font-size: 2.25rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__subtitle {
  font-size: 1.5rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__notification-icon {
  justify-content: center;
  display: flex;
  margin-bottom: 3rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__notification-icon svg {
  fill: var(--color-background-primary);
  height: 40%;
  width: 40%;
}
.main_ui_settings_password__form-container .main_ui_settings_password__notification-text {
  font-size: 1rem;
  color: var(--color-background-primary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_password__form-container .main_ui_settings_password__notification-text-email {
  background: var(--color-foreground-primary);
  border-radius: 4px;
  color: var(--color-background-primary);
  font-size: 1rem;
  font-weight: 500;
  margin: 1.5rem 0 2.5rem 0;
  padding: 1rem;
  text-align: center;
}
.main_ui_settings_password__form-container h2 {
  font-size: 1.5rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 1rem 0;
}
.main_ui_settings_password__form-container h3 {
  font-size: 0.75rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 0.5rem 0;
  text-transform: uppercase;
}
.main_ui_settings_password__form-container a:not(.main_ui_settings_password__button-primary):hover {
  text-decoration: underline;
}
.main_ui_settings_password__form-container p {
  color: var(--color-background-primary);
}
.main_ui_settings_password__form-container hr {
  border-color: var(--color-foreground-secondary);
}
.main_ui_settings_password__form-container .main_ui_settings_password__links {
  margin-top: 0.75rem;
}

form.main_ui_settings_password__avatar-form {
  display: flex;
  flex-direction: column;
  width: 9.25rem;
  height: 9.25rem;
  margin: 1rem 0;
}
form.main_ui_settings_password__avatar-form img {
  border-radius: 50%;
  flex-shrink: 0;
  height: 100%;
  margin-right: 1rem;
  width: 100%;
}

.main_ui_settings_password__image-change-field {
  position: relative;
  width: 100%;
  height: 100%;
}
.main_ui_settings_password__image-change-field .main_ui_settings_password__update-overlay {
  opacity: 0;
  cursor: pointer;
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: 50%;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  line-height: 6;
  text-align: center;
  background: var(--color-accent-tertiary);
  z-index: 300;
}
.main_ui_settings_password__image-change-field .main_ui_settings_password__delete-overlay {
  position: absolute;
  top: 0.25rem;
  inset-inline-end: 0.25rem;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem;
  padding: 0;
  border: none;
  border-radius: 50%;
  background: var(--color-background-primary);
  color: var(--color-foreground-primary);
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.15s ease-in-out;
  z-index: calc(300 + 1);
}
.main_ui_settings_password__image-change-field .main_ui_settings_password__delete-overlay:hover {
  background: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_settings_password__image-change-field input[type=file] {
  width: 100%;
  height: 100%;
  position: absolute;
  opacity: 0;
  cursor: pointer;
  top: 0;
  z-index: 300;
}
.main_ui_settings_password__image-change-field:hover .main_ui_settings_password__update-overlay {
  opacity: 0.8;
}
.main_ui_settings_password__image-change-field:hover .main_ui_settings_password__delete-overlay {
  opacity: 1;
}

.main_ui_settings_password__profile-form {
  display: flex;
  flex-direction: column;
  max-width: 23rem;
  width: 100%;
}

.main_ui_settings_password__newsletter-subs {
  border-bottom: 1px solid var(--color-foreground-secondary);
  border-top: 1px solid var(--color-foreground-secondary);
  padding: 2rem 0;
  margin-bottom: 2rem;
}
.main_ui_settings_password__newsletter-subs .main_ui_settings_password__newsletter-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.875rem;
}
.main_ui_settings_password__newsletter-subs label {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-background-primary);
  font-size: 0.75rem;
  margin-right: calc(-1 * 1rem);
  margin-bottom: 0.75rem;
}
.main_ui_settings_password__newsletter-subs .main_ui_settings_password__info {
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  margin-bottom: 0.5rem;
}
.main_ui_settings_password__newsletter-subs .main_ui_settings_password__input-checkbox label {
  align-items: flex-start;
}

.main_ui_settings_password__btn-secondary {
  height: 2rem;
}

.main_ui_settings_password__btn-primary {
  height: 2rem;
}

.main_ui_settings_password__update-btn {
  margin-top: 1rem;
  height: 2.25rem;
}
@keyframes main_ui_settings_profile__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_profile__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_profile__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_profile__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_profile__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_profile__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_profile__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_profile__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_profile__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_profile__btn-primary.disabled, [disabled].main_ui_settings_profile__btn-primary, .main_ui_settings_profile__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_profile__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_profile__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_profile__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_profile__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_profile__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_profile__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_profile__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_profile__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_profile__btn-secondary.disabled, [disabled].main_ui_settings_profile__btn-secondary, .main_ui_settings_profile__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_profile__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_profile__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_profile__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_profile__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_profile__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_profile__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_profile__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_profile__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_profile__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_profile__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_profile__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_profile__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_profile__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_profile__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_profile__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_profile__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_profile__dashboard-settings {
  display: flex;
  width: 100%;
  justify-content: center;
  align-items: center;
}
.main_ui_settings_profile__dashboard-settings a:not(.main_ui_settings_profile__button-primary, .main_ui_settings_profile__link) {
  color: var(--color-foreground-secondary);
}

.main_ui_settings_profile__form-container {
  display: flex;
  flex-direction: column;
  max-width: 31.25rem;
  width: 36.25rem;
  margin: 5rem auto 7.5rem auto;
  justify-content: center;
}
.main_ui_settings_profile__form-container form {
  display: flex;
  flex-direction: column;
}
.main_ui_settings_profile__form-container form .main_ui_settings_profile__btn-secondary {
  width: 100%;
  font-size: 0.688rem;
  text-transform: uppercase;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}
.main_ui_settings_profile__form-container form .main_ui_settings_profile__btn-secondary:hover {
  color: var(--color-accent-primary);
  background-color: var(--color-background-quaternary);
}
.main_ui_settings_profile__form-container form hr {
  display: none;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__fields-row {
  --input-height: 2.5rem;
  margin-bottom: 1.25rem;
  flex-direction: column;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__fields-row .main_ui_settings_profile__options {
  display: flex;
  justify-content: flex-end;
  font-size: 0.875rem;
  margin-top: 0.75rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__field {
  margin-bottom: 1.25rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__field-title {
  color: var(--color-foreground-primary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__field-title:not(:first-child) {
  margin-top: 4rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__field-text {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select {
  flex-direction: column-reverse;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input label,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select label {
  position: relative;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
  font-size: 0.688rem;
  margin-bottom: 0.75rem;
  margin-left: -0.25rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input input,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input select,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select input,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select select {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  color: var(--color-foreground-primary);
  padding: 0 1rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input input:focus,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input select:focus,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select input:focus,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select select:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input input ::-moz-placeholder, .main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input select ::-moz-placeholder, .main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select input ::-moz-placeholder, .main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select select ::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input input ::placeholder,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input select ::placeholder,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select input ::placeholder,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select select ::placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input .main_ui_settings_profile__help-icon,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select .main_ui_settings_profile__help-icon {
  bottom: 0.75rem;
  top: auto;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input .main_ui_settings_profile__help-icon svg,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select .main_ui_settings_profile__help-icon svg {
  fill: var(--color-foreground-secondary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input.main_ui_settings_profile__disabled input,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select.main_ui_settings_profile__disabled input {
  background-color: var(--input-background-color-disabled);
  border-color: var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input .main_ui_settings_profile__input-container,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select .main_ui_settings_profile__input-container {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border-color: transparent;
  margin-top: 1.5rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input .main_ui_settings_profile__input-container .main_ui_settings_profile__main-content label,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select .main_ui_settings_profile__input-container .main_ui_settings_profile__main-content label {
  position: absolute;
  top: calc(-1 * 1.5rem);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input .main_ui_settings_profile__input-container .main_ui_settings_profile__main-content span,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select .main_ui_settings_profile__input-container .main_ui_settings_profile__main-content span {
  color: var(--color-foreground-primary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input .main_ui_settings_profile__input-container:focus,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select .main_ui_settings_profile__input-container:focus {
  border: 1px solid var(--color-accent-primary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input textarea,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select textarea {
  border-radius: 8px;
  padding: 0.75rem 1rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
  border: none;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-input textarea:focus,
.main_ui_settings_profile__form-container .main_ui_settings_profile__custom-select textarea:focus {
  outline: 1px solid var(--color-accent-primary);
}
.main_ui_settings_profile__form-container.main_ui_settings_profile__two-columns {
  max-width: 32.5rem;
  justify-content: space-between;
  flex-direction: row;
}
.main_ui_settings_profile__form-container h1 {
  font-size: 2.25rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__subtitle {
  font-size: 1.5rem;
  color: var(--color-background-tertiary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__notification-icon {
  justify-content: center;
  display: flex;
  margin-bottom: 3rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__notification-icon svg {
  fill: var(--color-background-primary);
  height: 40%;
  width: 40%;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__notification-text {
  font-size: 1rem;
  color: var(--color-background-primary);
  margin-bottom: 1.25rem;
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__notification-text-email {
  background: var(--color-foreground-primary);
  border-radius: 4px;
  color: var(--color-background-primary);
  font-size: 1rem;
  font-weight: 500;
  margin: 1.5rem 0 2.5rem 0;
  padding: 1rem;
  text-align: center;
}
.main_ui_settings_profile__form-container h2 {
  font-size: 1.5rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 1rem 0;
}
.main_ui_settings_profile__form-container h3 {
  font-size: 0.75rem;
  font-weight: 400;
  color: var(--color-foreground-primary);
  display: flex;
  align-items: center;
  margin: 0.5rem 0;
  text-transform: uppercase;
}
.main_ui_settings_profile__form-container a:not(.main_ui_settings_profile__button-primary):hover {
  text-decoration: underline;
}
.main_ui_settings_profile__form-container p {
  color: var(--color-background-primary);
}
.main_ui_settings_profile__form-container hr {
  border-color: var(--color-foreground-secondary);
}
.main_ui_settings_profile__form-container .main_ui_settings_profile__links {
  margin-top: 0.75rem;
}

form.main_ui_settings_profile__avatar-form {
  display: flex;
  flex-direction: column;
  width: 9.25rem;
  height: 9.25rem;
  margin: 1rem 0;
}
form.main_ui_settings_profile__avatar-form img {
  border-radius: 50%;
  flex-shrink: 0;
  height: 100%;
  margin-right: 1rem;
  width: 100%;
}

.main_ui_settings_profile__image-change-field {
  position: relative;
  width: 100%;
  height: 100%;
}
.main_ui_settings_profile__image-change-field .main_ui_settings_profile__update-overlay {
  opacity: 0;
  cursor: pointer;
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: 50%;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  line-height: 6;
  text-align: center;
  background: var(--color-accent-tertiary);
  z-index: 300;
}
.main_ui_settings_profile__image-change-field .main_ui_settings_profile__delete-overlay {
  position: absolute;
  top: 0.25rem;
  inset-inline-end: 0.25rem;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem;
  padding: 0;
  border: none;
  border-radius: 50%;
  background: var(--color-background-primary);
  color: var(--color-foreground-primary);
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.15s ease-in-out;
  z-index: calc(300 + 1);
}
.main_ui_settings_profile__image-change-field .main_ui_settings_profile__delete-overlay:hover {
  background: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_settings_profile__image-change-field input[type=file] {
  width: 100%;
  height: 100%;
  position: absolute;
  opacity: 0;
  cursor: pointer;
  top: 0;
  z-index: 300;
}
.main_ui_settings_profile__image-change-field:hover .main_ui_settings_profile__update-overlay {
  opacity: 0.8;
}
.main_ui_settings_profile__image-change-field:hover .main_ui_settings_profile__delete-overlay {
  opacity: 1;
}

.main_ui_settings_profile__profile-form {
  display: flex;
  flex-direction: column;
  max-width: 23rem;
  width: 100%;
}

.main_ui_settings_profile__newsletter-subs {
  border-bottom: 1px solid var(--color-foreground-secondary);
  border-top: 1px solid var(--color-foreground-secondary);
  padding: 2rem 0;
  margin-bottom: 2rem;
}
.main_ui_settings_profile__newsletter-subs .main_ui_settings_profile__newsletter-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-foreground-secondary);
  font-size: 0.875rem;
}
.main_ui_settings_profile__newsletter-subs label {
  font-family: "worksans", "vazirmatn", sans-serif;
  color: var(--color-background-primary);
  font-size: 0.75rem;
  margin-right: calc(-1 * 1rem);
  margin-bottom: 0.75rem;
}
.main_ui_settings_profile__newsletter-subs .main_ui_settings_profile__info {
  color: var(--color-foreground-secondary);
  font-size: 0.75rem;
  margin-bottom: 0.5rem;
}
.main_ui_settings_profile__newsletter-subs .main_ui_settings_profile__input-checkbox label {
  align-items: flex-start;
}

.main_ui_settings_profile__btn-secondary {
  height: 2rem;
}

.main_ui_settings_profile__btn-primary {
  height: 2rem;
}
@keyframes main_ui_settings_sidebar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_sidebar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_sidebar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_sidebar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_sidebar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_sidebar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_sidebar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_sidebar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_sidebar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_sidebar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_sidebar__arrow-icon, .main_ui_settings_sidebar__feedback-icon, .main_ui_settings_sidebar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_sidebar__feedback-icon, .main_ui_settings_sidebar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_sidebar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_sidebar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_sidebar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_sidebar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_sidebar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_sidebar__dashboard-sidebar {
  scrollbar-width: thin;
  scrollbar-color: rgba(170, 181, 186, 0.3019607843) transparent;
}
.main_ui_settings_sidebar__dashboard-sidebar:hover {
  scrollbar-color: rgba(170, 181, 186, 0.7019607843) transparent;
}
.main_ui_settings_sidebar__dashboard-sidebar::-webkit-scrollbar {
  background: transparent;
  cursor: pointer;
  width: 0.75rem;
  height: 0.75rem;
}
.main_ui_settings_sidebar__dashboard-sidebar::-webkit-scrollbar-track, .main_ui_settings_sidebar__dashboard-sidebar::-webkit-scrollbar-corner {
  background: transparent;
}
.main_ui_settings_sidebar__dashboard-sidebar::-webkit-scrollbar-thumb {
  background-color: rgba(170, 181, 186, 0.3019607843);
  background-clip: content-box;
  border: 0.125rem solid transparent;
  border-radius: 0.5rem;
}
.main_ui_settings_sidebar__dashboard-sidebar::-webkit-scrollbar-thumb:hover {
  background-color: rgba(170, 181, 186, 0.7019607843);
}
.main_ui_settings_sidebar__dashboard-sidebar::-moz-selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_settings_sidebar__dashboard-sidebar::selection {
  background: var(--color-accent-background-select);
  color: var(--color-static-white);
}
.main_ui_settings_sidebar__dashboard-sidebar::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_settings_sidebar__dashboard-sidebar::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_settings_sidebar__dashboard-sidebar {
  grid-column: 1/span 2;
  grid-row: 1/span 2;
  display: grid;
  grid-template-rows: 1fr auto;
  height: 100%;
  padding-block-start: 1rem;
  border-right: 1px solid var(--panel-border-color);
  z-index: 1;
  background-color: var(--panel-background-color);
}

.main_ui_settings_sidebar__sidebar-content {
  display: grid;
  grid-template-rows: auto auto 1fr;
  height: 100%;
  padding: 0;
  overflow-y: auto;
}

.main_ui_settings_sidebar__sidebar-separator {
  border-color: transparent;
  margin: 0.75rem 1rem;
}

.main_ui_settings_sidebar__sidebar-nav-settings {
  display: grid;
  grid-auto-rows: auto;
  margin: 0;
  overflow: unset;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_settings_sidebar__settings-item {
  --settings-foreground-color: var(--menu-foreground-color-rest);
  --settings-background-color: transparent;
  display: flex;
  align-items: center;
  padding: 0.5rem 0.5rem 0.5rem 1.5rem;
  color: var(--settings-foreground-color);
  background-color: var(--settings-background-color);
  cursor: pointer;
}
.main_ui_settings_sidebar__settings-item:hover {
  --settings-foreground-color: var(--sidebar-element-foreground-color-hover);
  --settings-background-color: var(--sidebar-element-background-color-hover);
}
.main_ui_settings_sidebar__settings-item.main_ui_settings_sidebar__current {
  --settings-foreground-color: var(--sidebar-element-foreground-color-selected);
  --settings-background-color: var(--sidebar-element-background-color-selected);
}

.main_ui_settings_sidebar__feedback-icon {
  stroke: var(--settings-foreground-color);
  margin-right: 0.5rem;
}

.main_ui_settings_sidebar__element-title {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
}

.main_ui_settings_sidebar__back-to-dashboard {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  padding: 0.75rem 1rem;
  font-size: 0.875rem;
}

.main_ui_settings_sidebar__back-text {
  color: var(--color-foreground-primary);
}

.main_ui_settings_sidebar__arrow-icon {
  stroke: var(--icon-foreground);
  transform: rotate(180deg);
  margin-right: 0.75rem;
}
@keyframes main_ui_settings_subscription__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_settings_subscription__primary-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_settings_subscription__primary-button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_settings_subscription__primary-button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_subscription__primary-button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_settings_subscription__primary-button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_subscription__primary-button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_settings_subscription__primary-button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_settings_subscription__primary-button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_settings_subscription__primary-button.disabled, [disabled].main_ui_settings_subscription__primary-button, .main_ui_settings_subscription__primary-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_subscription__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_subscription__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_settings_subscription__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_subscription__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_settings_subscription__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_settings_subscription__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_settings_subscription__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_subscription__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_settings_subscription__cancel-button.disabled, [disabled].main_ui_settings_subscription__cancel-button, .main_ui_settings_subscription__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_settings_subscription__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_settings_subscription__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_settings_subscription__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_settings_subscription__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_settings_subscription__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_settings_subscription__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_settings_subscription__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_settings_subscription__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_settings_subscription__close-btn.disabled, [disabled].main_ui_settings_subscription__close-btn, .main_ui_settings_subscription__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_settings_subscription__close-btn.disabled svg, [disabled].main_ui_settings_subscription__close-btn svg, .main_ui_settings_subscription__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_settings_subscription__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_settings_subscription__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_settings_subscription__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_subscription__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_settings_subscription__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_settings_subscription__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_settings_subscription__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_settings_subscription__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_settings_subscription__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_settings_subscription__subscription-member,
.main_ui_settings_subscription__penpot-member, .main_ui_settings_subscription__plan-title-icon, .main_ui_settings_subscription__cta-button svg, .main_ui_settings_subscription__close-btn svg, .main_ui_settings_subscription__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_settings_subscription__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_settings_subscription__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_settings_subscription__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_settings_subscription__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_settings_subscription__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_settings_subscription__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_settings_subscription__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_settings_subscription__close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_settings_subscription__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_settings_subscription__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_settings_subscription__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_settings_subscription__primary-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_settings_subscription__dashboard-section {
  display: flex;
  inline-size: 100%;
  justify-content: center;
  align-items: center;
}

.main_ui_settings_subscription__dashboard-content {
  display: flex;
  flex-direction: column;
  max-inline-size: 31.25rem;
  margin-block-end: var(--sp-xxxl);
  inline-size: 36.25rem;
  margin: 5.75rem auto 7.5rem;
  justify-content: center;
}

.main_ui_settings_subscription__membership-container {
  margin-block-start: var(--sp-l);
}

.main_ui_settings_subscription__membership {
  align-items: center;
  display: flex;
  margin-block-start: var(--sp-s);
}

.main_ui_settings_subscription__membership-date {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  margin-inline-start: var(--sp-s);
}

.main_ui_settings_subscription__penpot-member {
  stroke: var(--icon-foreground);
}

.main_ui_settings_subscription__subscription-member {
  stroke: var(--color-badge-premium);
}

.main_ui_settings_subscription__title-section {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
  margin-block-end: var(--sp-xxl);
}

.main_ui_settings_subscription__plan-section-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
}

.main_ui_settings_subscription__plan-card {
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: var(--sp-s);
  margin-block-start: var(--sp-l);
  padding: var(--sp-l);
}

.main_ui_settings_subscription__plan-card-highlight {
  background-color: var(--color-background-tertiary);
  border: 0.0625rem solid var(--color-accent-select);
}

.main_ui_settings_subscription__plan-card-header {
  display: flex;
  justify-content: space-between;
  margin-block-end: var(--sp-m);
}

.main_ui_settings_subscription__plan-card-title-container {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_settings_subscription__plan-title-icon {
  block-size: var(--sp-xl);
  inline-size: var(--sp-xl);
  border-radius: 6px;
  border: 1.75px solid var(--color-foreground-primary);
}

.main_ui_settings_subscription__plan-title-icon svg {
  stroke: var(--color-foreground-primary);
  stroke-width: 2.25px;
}

.main_ui_settings_subscription__plan-card-title,
.main_ui_settings_subscription__plan-price-value,
.main_ui_settings_subscription__price-value {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.25rem;
  color: var(--color-foreground-primary);
}

.main_ui_settings_subscription__plan-editors {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  align-self: end;
  color: var(--color-foreground-primary);
  margin-block-end: 2px;
}

.main_ui_settings_subscription__plan-price-period {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
}

.main_ui_settings_subscription__plan-cancel {
  align-items: center;
  background-color: var(--color-background-secondary);
  border-radius: var(--sp-xs);
  display: flex;
  padding-inline: var(--sp-s);
}

.main_ui_settings_subscription__plan-cancel-date {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
}

.main_ui_settings_subscription__benefits-list {
  margin-block: 0;
}

.main_ui_settings_subscription__benefits-title,
.main_ui_settings_subscription__benefit {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
}

.main_ui_settings_subscription__other-subscriptions {
  margin-block-start: 3.25rem;
}

.main_ui_settings_subscription__cta-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  border: none;
  background: none;
  cursor: pointer;
  align-items: center;
  color: var(--color-accent-primary);
  display: flex;
  margin-block-start: var(--sp-m);
  text-align: left;
}

.main_ui_settings_subscription__cta-button svg {
  block-size: var(--sp-l);
  inline-size: var(--sp-l);
  stroke: var(--color-accent-primary);
  margin-inline-start: var(--sp-xs);
}

.main_ui_settings_subscription__icon-dropdown svg {
  transform: rotate(90deg);
}

.main_ui_settings_subscription__bottom-link {
  margin-block-start: var(--sp-xs);
}

.main_ui_settings_subscription__bottom-button {
  margin-block-start: var(--sp-xl);
}

.main_ui_settings_subscription__inline-error {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-error);
  margin-block: var(--sp-s) 0;
}

.main_ui_settings_subscription__modal-dialog {
  max-block-size: initial;
  min-inline-size: 34.25rem;
}

.main_ui_settings_subscription__modal-dialog.main_ui_settings_subscription__subscription-success {
  min-inline-size: 40.5rem;
}

.main_ui_settings_subscription__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  margin-block-end: var(--sp-xxxl);
  color: var(--modal-title-foreground-color);
  display: flex;
  gap: var(--sp-m);
}

.main_ui_settings_subscription__subscription-title {
  margin-block-end: var(--sp-l);
}

.main_ui_settings_subscription__modal-text-medium {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}

.main_ui_settings_subscription__modal-text-cap {
  margin-inline-end: var(--sp-s);
}

.main_ui_settings_subscription__text-strikethrough {
  text-decoration: line-through;
}

.main_ui_settings_subscription__modal-text-medium strong,
.main_ui_settings_subscription__text-strikethrough strong,
.main_ui_settings_subscription__modal-text-cap strong {
  font-weight: 700;
}

.main_ui_settings_subscription__modal-content,
.main_ui_settings_subscription__modal-end {
  color: var(--color-foreground-secondary);
  display: flex;
  flex-direction: column;
}

.main_ui_settings_subscription__modal-success-content {
  display: flex;
  gap: 2.5rem;
}

.main_ui_settings_subscription__modal-footer {
  margin-block-start: 2.5rem;
}

.main_ui_settings_subscription__success-action-buttons {
  margin-block-start: var(--sp-l);
}

.main_ui_settings_subscription__primary-button {
  min-block-size: 2rem;
  block-size: auto;
}

.main_ui_settings_subscription__cancel-button {
  min-block-size: 2rem;
  white-space: break-spaces;
  block-size: auto;
}

.main_ui_settings_subscription__modal-start {
  display: flex;
  justify-content: center;
  max-inline-size: 14rem;
}
@media (width <= 992px) {
  .main_ui_settings_subscription__modal-start {
    display: none;
  }
}

.main_ui_settings_subscription__modal-start svg {
  inline-size: 100%;
  block-size: auto;
}

.main_ui_settings_subscription__editors-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  margin: 0;
}

.main_ui_settings_subscription__editors-list-warning {
  margin-inline-start: var(--sp-xl);
  margin-block: var(--sp-s);
}

.main_ui_settings_subscription__editors-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  list-style-position: inside;
  list-style-type: none;
  margin-inline-start: var(--sp-xl);
  max-block-size: 13.5rem;
  overflow-y: auto;
}

.main_ui_settings_subscription__input-field {
  --input-icon-padding: var(--sp-s);
  inline-size: 5rem;
}

.main_ui_settings_subscription__error-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-error);
  margin-block-start: var(--sp-s);
}

.main_ui_settings_subscription__editors-wrapper {
  align-items: center;
  display: flex;
  gap: var(--sp-xl);
  margin-block-start: var(--sp-l);
}

.main_ui_settings_subscription__editors-cost {
  display: flex;
  flex-direction: column;
}

.main_ui_settings_subscription__unlimited-capped-warning {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  background-color: var(--color-background-tertiary);
  border-radius: var(--sp-s);
  margin-block-start: 2.5rem;
  padding-block: var(--sp-s);
  padding-inline: var(--sp-m);
}

.main_ui_settings_subscription__show-editors-button {
  padding-inline: 0;
}

.main_ui_settings_subscription__radio-btns {
  display: flex;
  flex-direction: column;
  padding-block-end: var(--sp-xl);
  gap: var(--sp-s);
}

.main_ui_settings_subscription__radio-btns label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  padding: 0;
  display: flex;
  align-items: center;
  color: var(--color-foreground-secondary);
}

.main_ui_settings_subscription__modal-contact-content {
  gap: var(--sp-xl);
}

.main_ui_settings_subscription__downgrade-warning {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  background-color: var(--color-background-tertiary);
  border-radius: var(--sp-s);
  padding-block: var(--sp-s);
  padding-inline: var(--sp-m);
  margin-block: var(--sp-m) var(--sp-xxxl);
}

.main_ui_settings_subscription__downgrade-list {
  list-style-position: outside;
  list-style-type: disc;
  margin-block: var(--sp-l) 0;
  padding-inline-start: var(--sp-l);
}

.main_ui_settings_subscription__downgrade-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  margin-block-end: var(--sp-l);
}

.main_ui_settings_subscription__cta-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  align-items: center;
  color: var(--color-accent-primary);
  display: flex;
  margin-block-end: var(--sp-xxxl);
  text-align: left;
  text-decoration: underline;
}

.main_ui_settings_subscription__button-full-width {
  justify-content: center;
  inline-size: 100%;
}

.main_ui_settings_subscription__price-text,
.main_ui_settings_subscription__nitrate-subscription {
  margin-block-end: 1.875rem;
}

.main_ui_settings_subscription__price-text {
  align-items: center;
  display: flex;
  gap: var(--sp-s);
  margin-block-end: 2.125rem;
}

.main_ui_settings_subscription__price-value {
  font-weight: 500;
}
@keyframes main_ui_releases_common__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_common__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_common__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_common__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_common__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_common__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_common__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_common__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_common__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_common__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_common__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_common__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_common__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_common__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_common__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_common__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_common__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_common__step-dots {
  display: grid;
  grid-template-columns: none;
  grid-auto-flow: column;
  gap: 0.5rem;
  height: -moz-fit-content;
  height: fit-content;
  width: -moz-fit-content;
  width: fit-content;
  margin: 0;
  padding: 0;
  place-self: center flex-start;
}

.main_ui_releases_common__dot {
  height: 0.75rem;
  width: 0.75rem;
  border-radius: 50%;
  background-color: var(--modal-navigator-foreground-color-rest);
  cursor: pointer;
}

.main_ui_releases_common__current {
  background-color: var(--modal-navigator-foreground-color-active);
}
@keyframes main_ui_releases_v2_0__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_0__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_0__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_0__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_0__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_0__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_0__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_0__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_0__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_0__next-btn.disabled, [disabled].main_ui_releases_v2_0__next-btn, .main_ui_releases_v2_0__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_0__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_0__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_0__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_0__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_0__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_0__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_0__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_0__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_0__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_0__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_0__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_0__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_0__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_0__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_0__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_0__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_0__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_0__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_0__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_0__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}

.main_ui_releases_v2_0__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_0__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_0__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_0__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_0__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_0__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_0__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_0__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_0__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_0__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_1__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_1__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_1__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_1__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_1__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_1__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_1__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_1__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_1__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_1__next-btn.disabled, [disabled].main_ui_releases_v2_1__next-btn, .main_ui_releases_v2_1__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_1__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_1__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_1__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_1__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_1__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_1__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_1__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_1__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_1__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_1__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_1__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_1__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_1__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_1__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_1__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_1__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_1__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_1__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_1__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_1__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}

.main_ui_releases_v2_1__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_1__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_1__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_1__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_1__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_1__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_1__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_10__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_10__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_10__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_10__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_10__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_10__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_10__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_10__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_10__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_10__next-btn.disabled, [disabled].main_ui_releases_v2_10__next-btn, .main_ui_releases_v2_10__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_10__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_10__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_10__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_10__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_10__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_10__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_10__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_10__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_10__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_10__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_10__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_10__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_10__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_10__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_10__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_10__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_10__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_10__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_10__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_10__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_10__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_10__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_10__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_10__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_10__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_10__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_10__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_10__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_10__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_10__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_10__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_11__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_11__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_11__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_11__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_11__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_11__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_11__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_11__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_11__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_11__next-btn.disabled, [disabled].main_ui_releases_v2_11__next-btn, .main_ui_releases_v2_11__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_11__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_11__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_11__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_11__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_11__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_11__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_11__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_11__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_11__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_11__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_11__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_11__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_11__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_11__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_11__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_11__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_11__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_11__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_11__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_11__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_11__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_11__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_11__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_11__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_11__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_11__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_11__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_11__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_11__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_11__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_11__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_12__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_12__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_12__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_12__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_12__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_12__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_12__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_12__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_12__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_12__next-btn.disabled, [disabled].main_ui_releases_v2_12__next-btn, .main_ui_releases_v2_12__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_12__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_12__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_12__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_12__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_12__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_12__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_12__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_12__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_12__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_12__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_12__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_12__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_12__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_12__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_12__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_12__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_12__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_12__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_12__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_12__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_12__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_12__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_12__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_12__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_12__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_12__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_12__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_12__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_12__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_12__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_12__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_13__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_13__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_13__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_13__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_13__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_13__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_13__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_13__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_13__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_13__next-btn.disabled, [disabled].main_ui_releases_v2_13__next-btn, .main_ui_releases_v2_13__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_13__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_13__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_13__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_13__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_13__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_13__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_13__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_13__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_13__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_13__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_13__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_13__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_13__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_13__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_13__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_13__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_13__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_13__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_13__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_13__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_13__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_13__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_13__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_13__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_13__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_13__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_13__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_13__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_13__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_13__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_13__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_14__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_14__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_14__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_14__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_14__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_14__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_14__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_14__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_14__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_14__next-btn.disabled, [disabled].main_ui_releases_v2_14__next-btn, .main_ui_releases_v2_14__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_14__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_14__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_14__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_14__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_14__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_14__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_14__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_14__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_14__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_14__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_14__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_14__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_14__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_14__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_14__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_14__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_14__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_14__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_14__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_14__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_14__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_14__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_14__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_14__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_14__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_14__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_14__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_14__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_14__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_14__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_14__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_15__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_15__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_15__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_15__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_15__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_15__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_15__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_15__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_15__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_15__next-btn.disabled, [disabled].main_ui_releases_v2_15__next-btn, .main_ui_releases_v2_15__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_15__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_15__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_15__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_15__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_15__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_15__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_15__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_15__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_15__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_15__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_15__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_15__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_15__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_15__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_15__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_15__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_15__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_15__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_15__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_15__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_15__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_15__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_15__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_15__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_15__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_15__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_15__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_15__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_15__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_15__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_15__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_16__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_16__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_16__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_16__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_16__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_16__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_16__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_16__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_16__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_16__next-btn.disabled, [disabled].main_ui_releases_v2_16__next-btn, .main_ui_releases_v2_16__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_16__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_16__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_16__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_16__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_16__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_16__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_16__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_16__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_16__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_16__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_16__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_16__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_16__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_16__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_16__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_16__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_16__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_16__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_16__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_16__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_16__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_16__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_16__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_16__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_16__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_16__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_16__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_16__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_16__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_16__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_16__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_17__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_17__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_17__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_17__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_17__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_17__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_17__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_17__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_17__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_17__next-btn.disabled, [disabled].main_ui_releases_v2_17__next-btn, .main_ui_releases_v2_17__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_17__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_17__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_17__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_17__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_17__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_17__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_17__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_17__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_17__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_17__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_17__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_17__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_17__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_17__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_17__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_17__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_17__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_17__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_17__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_17__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_17__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_17__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_17__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_17__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_17__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_17__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_17__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_17__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_17__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_17__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_17__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_2__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_2__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_2__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_2__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_2__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_2__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_2__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_2__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_2__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_2__next-btn.disabled, [disabled].main_ui_releases_v2_2__next-btn, .main_ui_releases_v2_2__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_2__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_2__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_2__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_2__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_2__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_2__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_2__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_2__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_2__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_2__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_2__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_2__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_2__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_2__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_2__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_2__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_2__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_2__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 30rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_2__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_2__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}

.main_ui_releases_v2_2__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_2__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_2__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_2__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_2__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_2__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_2__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_3__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_3__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_3__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_3__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_3__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_3__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_3__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_3__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_3__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_3__next-btn.disabled, [disabled].main_ui_releases_v2_3__next-btn, .main_ui_releases_v2_3__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_3__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_3__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_3__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_3__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_3__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_3__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_3__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_3__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_3__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_3__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_3__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_3__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_3__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_3__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_3__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_3__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_3__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_3__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_3__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_3__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_3__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_3__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_3__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_3__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_3__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_3__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_3__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_3__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_3__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_3__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_3__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_4__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_4__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_4__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_4__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_4__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_4__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_4__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_4__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_4__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_4__next-btn.disabled, [disabled].main_ui_releases_v2_4__next-btn, .main_ui_releases_v2_4__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_4__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_4__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_4__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_4__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_4__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_4__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_4__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_4__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_4__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_4__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_4__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_4__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_4__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_4__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_4__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_4__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_4__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_4__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_4__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_4__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_4__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_4__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_4__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_4__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_4__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_4__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_4__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_4__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_4__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_4__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_4__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_5__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_5__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_5__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_5__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_5__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_5__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_5__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_5__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_5__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_5__next-btn.disabled, [disabled].main_ui_releases_v2_5__next-btn, .main_ui_releases_v2_5__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_5__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_5__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_5__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_5__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_5__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_5__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_5__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_5__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_5__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_5__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_5__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_5__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_5__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_5__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_5__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_5__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_5__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_5__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_5__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_5__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_5__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_5__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_5__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_5__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_5__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_5__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_5__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_5__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_5__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_5__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_5__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_6__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_6__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_6__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_6__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_6__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_6__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_6__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_6__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_6__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_6__next-btn.disabled, [disabled].main_ui_releases_v2_6__next-btn, .main_ui_releases_v2_6__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_6__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_6__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_6__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_6__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_6__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_6__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_6__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_6__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_6__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_6__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_6__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_6__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_6__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_6__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_6__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_6__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_6__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_6__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_6__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_6__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_6__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_6__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_6__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_6__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_6__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_6__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_6__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_6__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_6__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_6__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_6__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_7__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_7__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_7__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_7__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_7__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_7__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_7__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_7__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_7__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_7__next-btn.disabled, [disabled].main_ui_releases_v2_7__next-btn, .main_ui_releases_v2_7__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_7__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_7__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_7__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_7__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_7__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_7__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_7__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_7__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_7__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_7__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_7__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_7__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_7__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_7__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_7__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_7__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_7__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_7__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_7__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_7__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_7__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_7__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_7__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_7__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_7__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_7__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_7__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_7__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_7__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_7__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_7__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_8__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_8__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_8__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_8__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_8__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_8__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_8__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_8__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_8__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_8__next-btn.disabled, [disabled].main_ui_releases_v2_8__next-btn, .main_ui_releases_v2_8__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_8__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_8__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_8__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_8__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_8__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_8__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_8__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_8__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_8__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_8__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_8__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_8__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_8__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_8__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_8__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_8__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_8__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_8__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_8__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_8__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_8__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_8__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_8__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_8__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_8__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_8__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_8__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_8__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_8__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_8__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_8__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_releases_v2_9__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_releases_v2_9__next-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_releases_v2_9__next-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_releases_v2_9__next-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_9__next-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_releases_v2_9__next-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_releases_v2_9__next-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_releases_v2_9__next-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_releases_v2_9__next-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_releases_v2_9__next-btn.disabled, [disabled].main_ui_releases_v2_9__next-btn, .main_ui_releases_v2_9__next-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_releases_v2_9__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_releases_v2_9__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_releases_v2_9__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_9__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_releases_v2_9__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_releases_v2_9__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_releases_v2_9__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_releases_v2_9__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_releases_v2_9__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_releases_v2_9__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_releases_v2_9__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_releases_v2_9__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_releases_v2_9__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_releases_v2_9__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_releases_v2_9__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_releases_v2_9__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_releases_v2_9__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_releases_v2_9__modal-container {
  display: grid;
  grid-template-columns: 20.25rem 1fr;
  height: 31.25rem;
  width: 55.5rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
}

.main_ui_releases_v2_9__start-image {
  width: 20.25rem;
  border-radius: 8px 0 0 8px;
}

.main_ui_releases_v2_9__modal-content {
  padding: 2.5rem;
  display: grid;
  grid-template-rows: auto 1fr 2rem;
  gap: 1.5rem;
}
.main_ui_releases_v2_9__modal-content a {
  color: var(--button-primary-background-color-rest);
}

.main_ui_releases_v2_9__modal-header {
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_9__version-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  height: 2rem;
  width: 6rem;
  background-color: var(--communication-tag-background-color);
  color: var(--communication-tag-foreground-color);
  border-radius: 8px;
}

.main_ui_releases_v2_9__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_9__features-block {
  display: flex;
  flex-direction: column;
  gap: 1rem;
  width: 27.5rem;
}

.main_ui_releases_v2_9__feature {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.main_ui_releases_v2_9__feature-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_releases_v2_9__feature-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  margin: 0;
  color: var(--modal-text-foreground-color);
}

.main_ui_releases_v2_9__feature-list {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
  list-style: disc;
  display: grid;
  gap: 0.5rem;
}

.main_ui_releases_v2_9__navigation {
  width: 100%;
  display: grid;
  grid-template-areas: "bullets button";
}

.main_ui_releases_v2_9__next-btn {
  width: 6.25rem;
  justify-self: flex-end;
  grid-area: button;
}
@keyframes main_ui_onboarding_questions__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_onboarding_questions__next-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_onboarding_questions__next-button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_onboarding_questions__next-button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_onboarding_questions__next-button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_onboarding_questions__next-button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_onboarding_questions__next-button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_onboarding_questions__next-button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_onboarding_questions__next-button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_onboarding_questions__next-button.disabled, [disabled].main_ui_onboarding_questions__next-button, .main_ui_onboarding_questions__next-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_onboarding_questions__prev-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_onboarding_questions__prev-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_onboarding_questions__prev-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_onboarding_questions__prev-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_onboarding_questions__prev-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_onboarding_questions__prev-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_onboarding_questions__prev-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_onboarding_questions__prev-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_onboarding_questions__prev-button.disabled, [disabled].main_ui_onboarding_questions__prev-button, .main_ui_onboarding_questions__prev-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_onboarding_questions__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_onboarding_questions__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_onboarding_questions__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_onboarding_questions__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_onboarding_questions__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_onboarding_questions__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_onboarding_questions__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_onboarding_questions__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_onboarding_questions__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_onboarding_questions__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_onboarding_questions__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_onboarding_questions__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_onboarding_questions__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_onboarding_questions__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_onboarding_questions__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_onboarding_questions__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_onboarding_questions__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_onboarding_questions__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_onboarding_questions__prev-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_onboarding_questions__next-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_onboarding_questions__modal-container {
  max-width: 60.25rem;
  max-height: -moz-fit-content;
  max-height: fit-content;
  inline-size: -moz-fit-content;
  inline-size: fit-content;
  padding-inline: 6rem;
  padding-block: 2.5rem 4rem;
  border-radius: 0.5rem;
  border: 0.125rem solid var(--modal-border-color);
  background-color: var(--modal-background-color);
}

.main_ui_onboarding_questions__form-wrapper {
  display: grid;
  grid-template-columns: 1fr;
  gap: var(--sp-xxl);
}

.main_ui_onboarding_questions__paginator {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  text-align: right;
  color: var(--modal-text-foreground-color);
}

.main_ui_onboarding_questions__radio label,
.main_ui_onboarding_questions__select span {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}

.main_ui_onboarding_questions__header-image {
  block-size: 7.5rem;
  inline-size: auto;
  margin-inline-start: auto;
}

.main_ui_onboarding_questions__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--modal-title-foreground-color);
  min-block-size: 2rem;
  margin-block: auto;
}

.main_ui_onboarding_questions__modal-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-title-foreground-color);
  margin: 0;
  padding: 0;
}

.main_ui_onboarding_questions__modal-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
  margin: 0;
}

.main_ui_onboarding_questions__step {
  max-inline-size: 32.5rem;
  inline-size: 32.5rem;
}

.main_ui_onboarding_questions__modal-question {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: 1rem 2rem;
  gap: var(--sp-l);
  block-size: -moz-fit-content;
  block-size: fit-content;
}

.main_ui_onboarding_questions__radio-wrapper {
  display: grid;
  grid-template-columns: 1fr;
  gap: var(--sp-l);
}

.main_ui_onboarding_questions__radio-image {
  display: grid;
  grid-template-rows: 1fr 1fr;
  grid-template-columns: 6rem 6rem 6rem;
  gap: var(--sp-l) var(--sp-xxl);
  justify-content: center;
}
@keyframes main_ui_onboarding_team_choice__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_onboarding_team_choice__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_onboarding_team_choice__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_onboarding_team_choice__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_onboarding_team_choice__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_onboarding_team_choice__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_onboarding_team_choice__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_onboarding_team_choice__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_onboarding_team_choice__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_onboarding_team_choice__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_onboarding_team_choice__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_onboarding_team_choice__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_onboarding_team_choice__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_onboarding_team_choice__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_onboarding_team_choice__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_onboarding_team_choice__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_onboarding_team_choice__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_onboarding_team_choice__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_onboarding_team_choice__color-light {
  color: var(--color-foreground-primary);
}

.main_ui_onboarding_team_choice__color-dimmed {
  color: var(--color-foreground-secondary);
}

.main_ui_onboarding_team_choice__text-align-right {
  text-align: right;
}

.main_ui_onboarding_team_choice__align-center {
  justify-content: center;
}

.main_ui_onboarding_team_choice__link-wrapper {
  display: flex;
  justify-content: center;
}

.main_ui_onboarding_team_choice__link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  cursor: pointer;
  text-decoration: underline;
  text-align: center;
  text-transform: uppercase;
  color: var(--color-foreground-secondary);
}
.main_ui_onboarding_team_choice__link:hover {
  color: var(--color-foreground-primary);
}

.main_ui_onboarding_team_choice__modal-container {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
  position: relative;
  inline-size: 56.75rem;
  padding: 4.5rem 6.25rem;
  border-radius: 0.5rem;
  background-color: var(--color-background-primary);
  border: 0.125rem solid var(--color-background-quaternary);
}

.main_ui_onboarding_team_choice__modal-sections {
  display: grid;
  grid-template-columns: 21rem 0.75rem 1fr;
  gap: var(--sp-xxl);
  block-size: 100%;
}

.main_ui_onboarding_team_choice__modal-info {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
  padding: var(--sp-m);
}

.main_ui_onboarding_team_choice__modal-info-desc {
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
}

.main_ui_onboarding_team_choice__modal-info-features {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}

.main_ui_onboarding_team_choice__modal-info-item {
  display: flex;
  align-items: center;
  gap: var(--sp-l);
}

.main_ui_onboarding_team_choice__modal-info-icon {
  display: flex;
  align-items: center;
  justify-content: center;
  inline-size: 2rem;
  block-size: 2rem;
  border-radius: 50%;
  border: 0.0625rem solid var(--color-accent-primary);
  color: var(--color-accent-primary);
}

.main_ui_onboarding_team_choice__modal-separator {
  display: flex;
  justify-content: center;
}

.main_ui_onboarding_team_choice__modal-separator-line {
  inline-size: 0.0625rem;
  block-size: 100%;
  background-color: var(--color-background-quaternary);
}

.main_ui_onboarding_team_choice__modal-team {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xl);
}

.main_ui_onboarding_team_choice__modal-team-form {
  display: grid;
  grid-template-columns: 1fr;
  gap: var(--sp-xxl);
}

.main_ui_onboarding_team_choice__modal-team-block {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
}

.main_ui_onboarding_team_choice__modal-team-sub-block {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}
@keyframes main_ui_notifications_badge__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_notifications_badge__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_notifications_badge__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_notifications_badge__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_notifications_badge__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_notifications_badge__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_notifications_badge__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_notifications_badge__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_notifications_badge__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_notifications_badge__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_notifications_badge__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_notifications_badge__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_notifications_badge__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_notifications_badge__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_notifications_badge__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_notifications_badge__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_notifications_badge__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_notifications_badge__badge-notification {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  --badge-notification-bg-color: var(--alert-background-color-default);
  --badge-notification-fg-color: var(--alert-text-foreground-color-default);
  --badge-notification-border-color: var(--alert-border-color-default);
  box-sizing: border-box;
  display: grid;
  place-items: center;
  grid-template-columns: 1fr;
  min-height: 2rem;
  height: -moz-fit-content;
  height: fit-content;
  min-width: 5rem;
  width: -moz-fit-content;
  width: fit-content;
  padding-block: 0;
  padding-inline: var(--sp-xs);
  margin: 0;
  border: 1px solid var(--badge-notification-border-color);
  border-radius: 8px;
  background-color: var(--badge-notification-bg-color);
  color: var(--badge-notification-fg-color);
}

.main_ui_notifications_badge__small {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  min-height: 1.25rem;
  border-radius: 6px;
}

.main_ui_notifications_badge__warning {
  --badge-notification-bg-color: var(--alert-background-color-warning);
  --badge-notification-fg-color: var(--alert-text-foreground-color-warning);
  --badge-notification-border-color: var(--alert-border-color-warning);
}

.main_ui_notifications_badge__success {
  --badge-notification-bg-color: var(--alert-background-color-success);
  --badge-notification-fg-color: var(--alert-text-foreground-color-success);
  --badge-notification-border-color: var(--alert-border-color-success);
}

.main_ui_notifications_badge__info {
  --badge-notification-bg-color: var(--alert-background-color-info);
  --badge-notification-fg-color: var(--alert-text-foreground-color-info);
  --badge-notification-border-color: var(--alert-border-color-info);
}

.main_ui_notifications_badge__error {
  --badge-notification-bg-color: var(--alert-background-color-error);
  --badge-notification-fg-color: var(--alert-text-foreground-color-error);
  --badge-notification-border-color: var(--alert-border-color-error);
}

.main_ui_notifications_badge__focus {
  --badge-notification-bg-color: transparent;
  --badge-notification-fg-color: var(--alert-text-foreground-color-focus);
  --badge-notification-border-color: var(--alert-border-color-focus);
}
@keyframes main_ui_notifications_context_notification__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_notifications_context_notification__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_notifications_context_notification__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_notifications_context_notification__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_notifications_context_notification__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_notifications_context_notification__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_notifications_context_notification__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_notifications_context_notification__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_notifications_context_notification__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_notifications_context_notification__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_notifications_context_notification__icon, .main_ui_notifications_context_notification__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_notifications_context_notification__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_notifications_context_notification__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_notifications_context_notification__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_notifications_context_notification__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_notifications_context_notification__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_notifications_context_notification__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_notifications_context_notification__context-notification {
  --context-notification-bg-color: var(--alert-background-color-default);
  --context-notification-fg-color: var(--alert-text-foreground-color-default);
  --context-notification-icon-color: var(--alert-icon-foreground-color-default);
  --context-notification-border-color: var(--alert-border-color-default);
  box-sizing: border-box;
  display: grid;
  grid-template-columns: 1rem 1fr;
  gap: 0.5rem;
  min-height: 2rem;
  height: -moz-fit-content;
  height: fit-content;
  width: 100%;
  padding: 0.5rem;
  border: 1px solid var(--context-notification-border-color);
  border-radius: 8px;
  background-color: var(--context-notification-bg-color);
}

.main_ui_notifications_context_notification__warning {
  --context-notification-bg-color: var(--alert-background-color-warning);
  --context-notification-fg-color: var(--alert-text-foreground-color-warning);
  --context-notification-icon-color: var(--alert-icon-foreground-color-warning);
  --context-notification-border-color: var(--alert-border-color-warning);
}

.main_ui_notifications_context_notification__success {
  --context-notification-bg-color: var(--alert-background-color-success);
  --context-notification-fg-color: var(--alert-text-foreground-color-success);
  --context-notification-icon-color: var(--alert-icon-foreground-color-success);
  --context-notification-border-color: var(--alert-border-color-success);
}

.main_ui_notifications_context_notification__info {
  --context-notification-bg-color: var(--alert-background-color-info);
  --context-notification-fg-color: var(--alert-text-foreground-color-info);
  --context-notification-icon-color: var(--alert-icon-foreground-color-info);
  --context-notification-border-color: var(--alert-border-color-info);
}

.main_ui_notifications_context_notification__default {
  --context-notification-bg-color: var(--alert-background-color-default);
  --context-notification-fg-color: var(--alert-text-foreground-color-default);
  --context-notification-icon-color: var(--alert-icon-foreground-color-default);
  --context-notification-border-color: var(--alert-border-color-default);
}

.main_ui_notifications_context_notification__error {
  --context-notification-bg-color: var(--alert-background-color-error);
  --context-notification-fg-color: var(--alert-text-foreground-color-error);
  --context-notification-icon-color: var(--alert-icon-foreground-color-error);
  --context-notification-border-color: var(--alert-border-color-error);
}

.main_ui_notifications_context_notification__icon {
  align-self: self-start;
  stroke: var(--context-notification-icon-color);
}

.main_ui_notifications_context_notification__context-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  align-self: center;
  color: var(--context-notification-fg-color);
  margin: auto 0;
}

.main_ui_notifications_context_notification__link,
.main_ui_notifications_context_notification__contain-html .main_ui_notifications_context_notification__context-text a {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  align-self: center;
  display: inline;
  text-align: left;
  height: 1rem;
  margin: 0;
  color: var(--modal-link-foreground-color);
}
@keyframes main_ui_notifications_inline_notification__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_notifications_inline_notification__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_notifications_inline_notification__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_notifications_inline_notification__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_notifications_inline_notification__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_notifications_inline_notification__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_notifications_inline_notification__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_notifications_inline_notification__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_notifications_inline_notification__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_notifications_inline_notification__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_notifications_inline_notification__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_notifications_inline_notification__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_notifications_inline_notification__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_notifications_inline_notification__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_notifications_inline_notification__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_notifications_inline_notification__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_notifications_inline_notification__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_notifications_inline_notification__link {
  background: unset;
  border: none;
  color: var(--link-foreground-color);
  cursor: pointer;
  text-decoration: none;
}

.main_ui_notifications_inline_notification__new-inline {
  position: absolute;
  top: 4.5rem;
  margin: auto;
  left: 0;
  right: 0;
  min-height: 3rem;
  min-width: 40rem;
  width: -moz-fit-content;
  width: fit-content;
  max-width: 60rem;
  z-index: 300;
}

.main_ui_notifications_inline_notification__link {
  margin: 0;
}
@keyframes main_ui_nitrate_nitrate_activation_success_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn.disabled, [disabled].main_ui_nitrate_nitrate_activation_success_modal__close-btn, .main_ui_nitrate_nitrate_activation_success_modal__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_nitrate_nitrate_activation_success_modal__close-btn.disabled svg, [disabled].main_ui_nitrate_nitrate_activation_success_modal__close-btn svg, .main_ui_nitrate_nitrate_activation_success_modal__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_nitrate_nitrate_activation_success_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_nitrate_nitrate_activation_success_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_nitrate_nitrate_activation_success_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_nitrate_nitrate_activation_success_modal__close-btn svg, .main_ui_nitrate_nitrate_activation_success_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_nitrate_nitrate_activation_success_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_nitrate_nitrate_activation_success_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_nitrate_nitrate_activation_success_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_nitrate_nitrate_activation_success_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_nitrate_nitrate_activation_success_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_nitrate_nitrate_activation_success_modal__close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_nitrate_nitrate_activation_success_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-overlay {
  z-index: var(--z-index-notifications);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-dialog {
  max-block-size: initial;
  min-inline-size: 38rem;
  max-inline-size: 38rem;
  padding: var(--sp-xxxl);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-content {
  display: flex;
  gap: 2.5rem;
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-start {
  display: flex;
  justify-content: center;
  min-inline-size: 14rem;
}
@media (width <= 640px) {
  .main_ui_nitrate_nitrate_activation_success_modal__modal-start {
    display: none;
  }
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-start svg {
  inline-size: 100%;
  block-size: auto;
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-end {
  color: var(--color-foreground-secondary);
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--modal-title-foreground-color);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-text-primary {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--color-foreground-primary);
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}

.main_ui_nitrate_nitrate_activation_success_modal__modal-button {
  margin-block-start: var(--sp-s);
  align-self: flex-start;
}
@keyframes main_ui_nitrate_nitrate_code_activation_modal__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_nitrate_nitrate_code_activation_modal__accept-btn.disabled, [disabled].main_ui_nitrate_nitrate_code_activation_modal__accept-btn, .main_ui_nitrate_nitrate_code_activation_modal__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_nitrate_nitrate_code_activation_modal__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn.disabled, [disabled].main_ui_nitrate_nitrate_code_activation_modal__close-btn, .main_ui_nitrate_nitrate_code_activation_modal__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_nitrate_nitrate_code_activation_modal__close-btn.disabled svg, [disabled].main_ui_nitrate_nitrate_code_activation_modal__close-btn svg, .main_ui_nitrate_nitrate_code_activation_modal__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_nitrate_nitrate_code_activation_modal__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_nitrate_nitrate_code_activation_modal__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_nitrate_nitrate_code_activation_modal__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_nitrate_nitrate_code_activation_modal__close-btn svg, .main_ui_nitrate_nitrate_code_activation_modal__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_nitrate_nitrate_code_activation_modal__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_nitrate_nitrate_code_activation_modal__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_nitrate_nitrate_code_activation_modal__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_nitrate_nitrate_code_activation_modal__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_nitrate_nitrate_code_activation_modal__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_nitrate_nitrate_code_activation_modal__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_nitrate_nitrate_code_activation_modal__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_nitrate_nitrate_code_activation_modal__close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_nitrate_nitrate_code_activation_modal__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_nitrate_nitrate_code_activation_modal__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_nitrate_nitrate_code_activation_modal__modal-overlay {
  z-index: var(--z-index-notifications);
}

.main_ui_nitrate_nitrate_code_activation_modal__modal-dialog {
  inline-size: 30rem;
  max-inline-size: 30rem;
  max-block-size: none;
  max-height: none;
  padding: var(--sp-xxxl);
}

.main_ui_nitrate_nitrate_code_activation_modal__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
  margin-block-end: var(--sp-xxxl);
}

.main_ui_nitrate_nitrate_code_activation_modal__modal-content {
  display: flex;
  flex-direction: column;
  color: var(--color-foreground-secondary);
}

.main_ui_nitrate_nitrate_code_activation_modal__content-stack {
  display: flex;
  flex-direction: column;
  gap: var(--sp-m);
}

.main_ui_nitrate_nitrate_code_activation_modal__accept-btn {
  inline-size: 100%;
}

.main_ui_nitrate_nitrate_code_activation_modal__code-field {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_nitrate_nitrate_code_activation_modal__code-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
}

.main_ui_nitrate_nitrate_code_activation_modal__code-textarea {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  block-size: 12.5rem;
  resize: vertical;
  font-family: monospace;
  word-break: break-all;
  padding: var(--sp-s);
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--input-border-color);
  background-color: var(--input-background-color);
  color: var(--color-foreground-primary);
  outline: none;
}

.main_ui_nitrate_nitrate_code_activation_modal__code-textarea:focus {
  border-color: var(--color-accent-primary);
}

.main_ui_nitrate_nitrate_code_activation_modal__invalid .main_ui_nitrate_nitrate_code_activation_modal__code-textarea {
  border-color: var(--input-border-color-error);
}

.main_ui_nitrate_nitrate_code_activation_modal__invalid .main_ui_nitrate_nitrate_code_activation_modal__code-textarea:focus {
  border-color: var(--input-border-color-error);
}

.main_ui_nitrate_nitrate_code_activation_modal__error-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--element-foreground-error);
}

.main_ui_nitrate_nitrate_code_activation_modal__footer-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
  margin-block-start: var(--sp-xxxl);
}

.main_ui_nitrate_nitrate_code_activation_modal__link {
  color: var(--color-accent-primary);
}
@keyframes main_ui_nitrate_nitrate_form__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_nitrate_nitrate_form__close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_nitrate_nitrate_form__close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_nitrate_nitrate_form__close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_form__close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_nitrate_nitrate_form__close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_nitrate_nitrate_form__close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_nitrate_nitrate_form__close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_nitrate_nitrate_form__close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_nitrate_nitrate_form__close-btn.disabled, [disabled].main_ui_nitrate_nitrate_form__close-btn, .main_ui_nitrate_nitrate_form__close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_nitrate_nitrate_form__close-btn.disabled svg, [disabled].main_ui_nitrate_nitrate_form__close-btn svg, .main_ui_nitrate_nitrate_form__close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_nitrate_nitrate_form__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_nitrate_nitrate_form__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_nitrate_nitrate_form__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_nitrate_nitrate_form__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_nitrate_nitrate_form__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_nitrate_nitrate_form__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_nitrate_nitrate_form__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_nitrate_nitrate_form__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_nitrate_nitrate_form__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_nitrate_nitrate_form__close-btn svg, .main_ui_nitrate_nitrate_form__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_nitrate_nitrate_form__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_nitrate_nitrate_form__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_nitrate_nitrate_form__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_nitrate_nitrate_form__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_nitrate_nitrate_form__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_nitrate_nitrate_form__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_nitrate_nitrate_form__modal-dialog {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_nitrate_nitrate_form__close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_nitrate_nitrate_form__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_nitrate_nitrate_form__modal-overlay {
  z-index: var(--z-index-notifications);
}

.main_ui_nitrate_nitrate_form__modal-dialog {
  max-block-size: initial;
  min-inline-size: 63.8125rem;
  padding: 5rem;
}
@media (width <= 1024px) {
  .main_ui_nitrate_nitrate_form__modal-dialog {
    min-inline-size: 44.5rem;
    padding: var(--sp-xxxl);
  }
}

.main_ui_nitrate_nitrate_form__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  margin-block-end: var(--sp-xxxl);
  color: var(--modal-title-foreground-color);
  display: flex;
  gap: var(--sp-m);
}

.main_ui_nitrate_nitrate_form__modal-text-large {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}

.main_ui_nitrate_nitrate_form__modal-text-medium {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}

.main_ui_nitrate_nitrate_form__modal-text-small {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_nitrate_nitrate_form__price-value {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.25rem;
  color: var(--color-foreground-primary);
  font-weight: 500;
}

.main_ui_nitrate_nitrate_form__price-text {
  align-items: center;
  display: flex;
  gap: var(--sp-s);
  margin-block-end: var(--sp-xxxl);
}

.main_ui_nitrate_nitrate_form__modal-info {
  margin-block: var(--sp-s) var(--sp-l);
  width: 40%;
}

.main_ui_nitrate_nitrate_form__modal-content,
.main_ui_nitrate_nitrate_form__modal-end {
  color: var(--color-foreground-secondary);
  display: flex;
  flex-direction: column;
}

.main_ui_nitrate_nitrate_form__modal-success-content {
  display: flex;
  gap: 2.5rem;
}

.main_ui_nitrate_nitrate_form__modal-start {
  display: flex;
  justify-content: center;
  min-inline-size: 17.75rem;
}
@media (width <= 992px) {
  .main_ui_nitrate_nitrate_form__modal-start {
    display: none;
  }
}

.main_ui_nitrate_nitrate_form__modal-start svg {
  inline-size: 100%;
  block-size: auto;
}

.main_ui_nitrate_nitrate_form__radio-btns {
  display: flex;
  flex-direction: column;
  padding: var(--sp-l) 0 0 0;
  gap: 0;
}

.main_ui_nitrate_nitrate_form__radio-btns label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  padding: 0;
  display: flex;
  align-items: center;
}

.main_ui_nitrate_nitrate_form__contact {
  margin-block-start: 3rem;
  color: var(--color-foreground-primary);
}

.main_ui_nitrate_nitrate_form__activation-code {
  margin-block-start: var(--sp-xxxl);
}

.main_ui_nitrate_nitrate_form__link {
  color: var(--color-accent-primary);
}
@keyframes main_ui_inspect_annotation__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_annotation__title-spacing-annotation button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_inspect_annotation__title-spacing-annotation button svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_inspect_annotation__title-spacing-annotation button:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_inspect_annotation__title-spacing-annotation button:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_inspect_annotation__title-spacing-annotation button:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_inspect_annotation__title-spacing-annotation button:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_inspect_annotation__title-spacing-annotation button:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_inspect_annotation__title-spacing-annotation button:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_inspect_annotation__title-spacing-annotation button.disabled, .main_ui_inspect_annotation__title-spacing-annotation button[disabled], .main_ui_inspect_annotation__title-spacing-annotation button:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_inspect_annotation__title-spacing-annotation button.disabled svg, .main_ui_inspect_annotation__title-spacing-annotation button[disabled] svg, .main_ui_inspect_annotation__title-spacing-annotation button:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_inspect_annotation__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_annotation__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_annotation__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_annotation__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_annotation__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_annotation__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_annotation__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_annotation__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_annotation__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_annotation__title-spacing-annotation button svg, .main_ui_inspect_annotation__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_annotation__title-spacing-annotation button svg, .main_ui_inspect_annotation__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_annotation__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_annotation__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_annotation__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_annotation__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_annotation__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_annotation__title-spacing-annotation div {
  margin-left: 0;
  color: var(--entry-foreground-color-hover);
}
.main_ui_inspect_annotation__title-spacing-annotation button {
  display: none;
}
.main_ui_inspect_annotation__title-spacing-annotation button svg {
  stroke: var(--icon-foreground);
}
.main_ui_inspect_annotation__title-spacing-annotation:hover button {
  display: flex;
}

.main_ui_inspect_annotation__attributes-block {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
}

.main_ui_inspect_annotation__annotation-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--entry-foreground-color);
}

.main_ui_inspect_annotation__copy-btn-title {
  max-width: 1.75rem;
}
.main_ui_inspect_attributes__element-options {
  display: flex;
  flex-direction: column;
  gap: var(--sp-l);
  width: 100%;
  max-height: calc(100vh - 8rem);
  padding-top: var(--sp-s);
  padding-inline: var(--sp-m);
  overflow: hidden auto;
  scrollbar-gutter: stable;
  background-color: var(--low-emphasis-background);
}

.main_ui_inspect_attributes__workspace-element-options {
  max-height: calc(100vh - 11.25rem);
  padding-inline: var(--sp-m);
  background-color: var(--low-emphasis-background);
}
@keyframes main_ui_inspect_code__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_code__download-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_inspect_code__download-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_inspect_code__download-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_inspect_code__download-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_inspect_code__download-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_inspect_code__download-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_inspect_code__download-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_inspect_code__download-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_inspect_code__download-button.disabled, [disabled].main_ui_inspect_code__download-button, .main_ui_inspect_code__download-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_inspect_code__expand-button,
.main_ui_inspect_code__css-copy-btn,
.main_ui_inspect_code__html-copy-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_inspect_code__expand-button svg,
.main_ui_inspect_code__css-copy-btn svg,
.main_ui_inspect_code__html-copy-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_inspect_code__expand-button:focus-visible,
.main_ui_inspect_code__css-copy-btn:focus-visible,
.main_ui_inspect_code__html-copy-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_inspect_code__expand-button:focus-visible svg,
.main_ui_inspect_code__css-copy-btn:focus-visible svg,
.main_ui_inspect_code__html-copy-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_inspect_code__expand-button:hover,
.main_ui_inspect_code__css-copy-btn:hover,
.main_ui_inspect_code__html-copy-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_inspect_code__expand-button:hover svg,
.main_ui_inspect_code__css-copy-btn:hover svg,
.main_ui_inspect_code__html-copy-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_inspect_code__expand-button:active,
.main_ui_inspect_code__css-copy-btn:active,
.main_ui_inspect_code__html-copy-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_inspect_code__expand-button:active svg,
.main_ui_inspect_code__css-copy-btn:active svg,
.main_ui_inspect_code__html-copy-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_inspect_code__expand-button.disabled,
.main_ui_inspect_code__css-copy-btn.disabled,
.main_ui_inspect_code__html-copy-btn.disabled, [disabled].main_ui_inspect_code__expand-button,
[disabled].main_ui_inspect_code__css-copy-btn,
[disabled].main_ui_inspect_code__html-copy-btn, .main_ui_inspect_code__expand-button:disabled,
.main_ui_inspect_code__css-copy-btn:disabled,
.main_ui_inspect_code__html-copy-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_inspect_code__expand-button.disabled svg,
.main_ui_inspect_code__css-copy-btn.disabled svg,
.main_ui_inspect_code__html-copy-btn.disabled svg, [disabled].main_ui_inspect_code__expand-button svg,
[disabled].main_ui_inspect_code__css-copy-btn svg,
[disabled].main_ui_inspect_code__html-copy-btn svg, .main_ui_inspect_code__expand-button:disabled svg,
.main_ui_inspect_code__css-copy-btn:disabled svg,
.main_ui_inspect_code__html-copy-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_inspect_code__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_code__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_code__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_code__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_code__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_code__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_code__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_code__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_code__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_code__expand-button svg,
.main_ui_inspect_code__css-copy-btn svg,
.main_ui_inspect_code__html-copy-btn svg, .main_ui_inspect_code__toggle-btn .main_ui_inspect_code__collapsabled-icon svg, .main_ui_inspect_code__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_code__toggle-btn .main_ui_inspect_code__collapsabled-icon svg, .main_ui_inspect_code__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_code__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_code__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_code__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_code__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_code__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_code__element-options {
  display: flex;
  flex-direction: column;
  height: calc(100vh - 10rem);
  overflow: hidden;
  padding-bottom: 1rem;
  overflow-y: auto;
  padding-inline: var(--sp-m);
}

.main_ui_inspect_code__viewer-code-block {
  height: calc(100vh - 6.75rem);
}

.main_ui_inspect_code__download-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2rem;
  width: 100%;
  margin: 0.5rem 0;
}

.main_ui_inspect_code__code-block {
  font-family: "robotomono", monospace;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.2;
  display: flex;
  flex-direction: column;
  height: 100%;
  min-height: 0;
  padding: 0 0.25rem 0.5rem 0;
}
.main_ui_inspect_code__code-block pre {
  border-radius: 8px;
  padding: 1rem;
  overflow: auto;
  height: 100%;
}
.main_ui_inspect_code__code-block .hljs {
  background: var(--color-background-tertiary);
}
.main_ui_inspect_code__code-block.main_ui_inspect_code__collapsed {
  height: initial;
}

.main_ui_inspect_code__code-row-lang {
  display: grid;
  grid-template-columns: 0.75rem 1fr 3.75rem;
  gap: 0.25rem;
  width: 100%;
}

.main_ui_inspect_code__code-lang {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  display: flex;
  align-items: center;
}

.main_ui_inspect_code__action-btns {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 0.25rem;
}

.main_ui_inspect_code__expand-button,
.main_ui_inspect_code__css-copy-btn,
.main_ui_inspect_code__html-copy-btn {
  height: 2rem;
  width: 1.75rem;
}
.main_ui_inspect_code__expand-button svg,
.main_ui_inspect_code__css-copy-btn svg,
.main_ui_inspect_code__html-copy-btn svg {
  stroke: var(--icon-foreground);
}

.main_ui_inspect_code__code-lang-options {
  max-width: 6.75rem;
}

.main_ui_inspect_code__code-lang-select {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  width: 4.5rem;
  border: 1px solid transparent;
  background-color: transparent;
  color: var(--menu-foreground-color-disabled);
}

.main_ui_inspect_code__code-lang-option {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  width: 4.5rem;
  height: 2rem;
  padding: 0.5rem;
  color: var(--menu-foreground-color-disabled);
}

.main_ui_inspect_code__code-row-display {
  flex: 1;
  min-height: 0;
  overflow: hidden;
  padding-bottom: 0.5rem;
}

.main_ui_inspect_code__toggle-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  padding: 0;
  color: var(--title-foreground-color);
  stroke: var(--title-foreground-color);
}
.main_ui_inspect_code__toggle-btn .main_ui_inspect_code__collapsabled-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  border-radius: 8px;
}
.main_ui_inspect_code__toggle-btn .main_ui_inspect_code__collapsabled-icon svg {
  transform: rotate(90deg);
  stroke: var(--icon-foreground);
}
.main_ui_inspect_code__toggle-btn .main_ui_inspect_code__collapsabled-icon.main_ui_inspect_code__rotated svg {
  transform: rotate(0deg);
}
.main_ui_inspect_code__toggle-btn:hover {
  color: var(--title-foreground-color-hover);
  stroke: var(--title-foreground-color-hover);
}
.main_ui_inspect_code__toggle-btn:hover .main_ui_inspect_code__title {
  color: var(--title-foreground-color-hover);
  stroke: var(--title-foreground-color-hover);
}
.main_ui_inspect_code__toggle-btn:hover .main_ui_inspect_code__collapsabled-icon svg {
  stroke: var(--title-foreground-color-hover);
}
@keyframes main_ui_inspect_exports__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_exports__export-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_inspect_exports__export-btn svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_inspect_exports__export-btn:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_inspect_exports__export-btn:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_inspect_exports__export-btn:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_inspect_exports__export-btn:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_inspect_exports__export-btn:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_inspect_exports__export-btn:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_inspect_exports__export-btn.disabled, [disabled].main_ui_inspect_exports__export-btn, .main_ui_inspect_exports__export-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_inspect_exports__add-export, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_inspect_exports__add-export svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_inspect_exports__add-export:focus-visible, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_inspect_exports__add-export:focus-visible svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_inspect_exports__add-export:hover, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_inspect_exports__add-export:hover svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_inspect_exports__add-export:active, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_inspect_exports__add-export:active svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_inspect_exports__add-export.disabled, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn.disabled, [disabled].main_ui_inspect_exports__add-export, .main_ui_inspect_exports__element-group [disabled].main_ui_inspect_exports__action-btn, .main_ui_inspect_exports__add-export:disabled, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_inspect_exports__add-export.disabled svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn.disabled svg, [disabled].main_ui_inspect_exports__add-export svg, .main_ui_inspect_exports__element-group [disabled].main_ui_inspect_exports__action-btn svg, .main_ui_inspect_exports__add-export:disabled svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_inspect_exports__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_exports__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_exports__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_exports__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_exports__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_exports__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_exports__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_exports__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_exports__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_exports__add-export svg, .main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn svg, .main_ui_inspect_exports__suffix-input span svg,
.main_ui_inspect_exports__suffix-input label svg, .main_ui_inspect_exports__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_exports__suffix-input span svg,
.main_ui_inspect_exports__suffix-input label svg, .main_ui_inspect_exports__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_exports__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_exports__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_exports__suffix-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_inspect_exports__suffix-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_inspect_exports__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_exports__suffix-input span,
.main_ui_inspect_exports__suffix-input label, .main_ui_inspect_exports__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_exports__suffix-input {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_inspect_exports__suffix-input span svg,
.main_ui_inspect_exports__suffix-input label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_inspect_exports__suffix-input ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_inspect_exports__suffix-input ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_inspect_exports__suffix-input:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_inspect_exports__suffix-input:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_inspect_exports__suffix-input:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_inspect_exports__suffix-input:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_inspect_exports__suffix-input:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_inspect_exports__suffix-input:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_inspect_exports__suffix-input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_inspect_exports__suffix-input:focus, .main_ui_inspect_exports__suffix-input:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_inspect_exports__suffix-input:focus span, .main_ui_inspect_exports__suffix-input:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_inspect_exports__suffix-input:focus input, .main_ui_inspect_exports__suffix-input:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_inspect_exports__suffix-input:focus:hover, .main_ui_inspect_exports__suffix-input:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_inspect_exports__suffix-input:focus:hover span, .main_ui_inspect_exports__suffix-input:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_inspect_exports__suffix-input:focus:hover input, .main_ui_inspect_exports__suffix-input:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_inspect_exports__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_exports__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  flex-grow: 1;
  border-radius: 8px;
  height: 2rem;
  padding: 0.5rem;
  background-color: var(--input-background-color);
  color: var(--input-foreground-color-active);
}

.main_ui_inspect_exports__element-set {
  padding-bottom: 1rem;
  margin: 0;
}

.main_ui_inspect_exports__element-title {
  margin: 0;
}

.main_ui_inspect_exports__title-spacing-export-viewer {
  margin: 0;
  color: var(--entry-foreground-color-hover);
  margin-inline-start: calc(-1 * 0.5rem);
  width: calc(100% + 0.5rem);
}

.main_ui_inspect_exports__add-export {
  height: 2rem;
  width: 1.75rem;
}
.main_ui_inspect_exports__add-export svg {
  stroke: var(--icon-foreground);
}

.main_ui_inspect_exports__element-set-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  margin-bottom: 0.25rem;
}

.main_ui_inspect_exports__multiple-exports {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  grid-column: 1/span 9;
}

.main_ui_inspect_exports__actions {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}

.main_ui_inspect_exports__element-group {
  display: grid;
  grid-template-columns: repeat(9, 1fr);
  -moz-column-gap: 0.25rem;
       column-gap: 0.25rem;
}
.main_ui_inspect_exports__element-group .main_ui_inspect_exports__action-btn {
  height: 2rem;
  width: 1.75rem;
}
.main_ui_inspect_exports__input-wrapper {
  grid-column: span 8;
  display: grid;
  grid-template-columns: subgrid;
}

.main_ui_inspect_exports__format-select {
  grid-column: span 3;
  padding: 0;
}
.main_ui_inspect_exports__format-select .main_ui_inspect_exports__dropdown-upwards {
  bottom: 2.25rem;
  width: 5rem;
  top: unset;
}

.main_ui_inspect_exports__size-select {
  grid-column: span 2;
  padding: 0;
}
.main_ui_inspect_exports__size-select .main_ui_inspect_exports__dropdown-upwards {
  bottom: 2.25rem;
  top: unset;
  width: 5rem;
}

.main_ui_inspect_exports__suffix-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  grid-column: span 3;
}

.main_ui_inspect_exports__export-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2rem;
  width: 100%;
}
@keyframes main_ui_inspect_left_sidebar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_left_sidebar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_left_sidebar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_left_sidebar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_left_sidebar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_left_sidebar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_left_sidebar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_left_sidebar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_left_sidebar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_left_sidebar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_left_sidebar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_left_sidebar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_left_sidebar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_left_sidebar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_left_sidebar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_left_sidebar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_left_sidebar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_left_sidebar__settings-bar-left {
  background-color: var(--panel-background-color);
  height: 100%;
  width: 16rem;
}

.main_ui_inspect_left_sidebar__settings-bar-inside {
  display: grid;
  grid-template-columns: 100%;
  grid-template-rows: 100%;
  height: calc(100% - 0.125rem);
  overflow-y: auto;
  padding-top: 0.5rem;
}
@keyframes main_ui_inspect_right_sidebar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_right_sidebar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_right_sidebar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_right_sidebar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_right_sidebar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_right_sidebar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_right_sidebar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_right_sidebar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_right_sidebar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_right_sidebar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_right_sidebar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_right_sidebar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_right_sidebar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_right_sidebar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_right_sidebar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_right_sidebar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_right_sidebar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_right_sidebar__settings-bar-right {
  min-inline-size: 15.75rem;
  inline-size: 100%;
  block-size: 100vh;
  position: relative;
  inset-inline-start: unset;
  inset-inline-end: unset;
  grid-area: right-sidebar;
  overflow: hidden;
}
.main_ui_inspect_right_sidebar__settings-bar-right.main_ui_inspect_right_sidebar__viewer-code {
  block-size: calc(100vh - 3rem);
}

.main_ui_inspect_right_sidebar__tool-windows {
  block-size: 100%;
  display: grid;
  grid-template-rows: auto 1fr;
  gap: var(--sp-s);
}

.main_ui_inspect_right_sidebar__shape-info {
  display: grid;
  grid-template-columns: auto minmax(0, 1fr);
  gap: var(--sp-s);
  align-items: center;
  block-size: 2rem;
  padding-inline-start: var(--sp-m);
}

.main_ui_inspect_right_sidebar__shape-info-subtitle {
  block-size: -moz-fit-content;
  block-size: fit-content;
  align-items: flex-start;
}

.main_ui_inspect_right_sidebar__layers-icon,
.main_ui_inspect_right_sidebar__shape-icon {
  --icon-stroke-color: var(--color-foreground-primary);
  display: flex;
  justify-content: center;
  align-items: center;
  block-size: 2rem;
}

.main_ui_inspect_right_sidebar__layer-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  block-size: 2rem;
  padding: var(--sp-s) 0;
  color: var(--color-foreground-primary);
}

.main_ui_inspect_right_sidebar__layer-title-with-subtitle {
  block-size: -moz-fit-content;
  block-size: fit-content;
  padding-block-end: 0;
}

.main_ui_inspect_right_sidebar__layer-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--assets-item-name-foreground-color-rest);
}

.main_ui_inspect_right_sidebar__empty {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) auto;
  inline-size: 12.5rem;
}

.main_ui_inspect_right_sidebar__empty-button {
  display: flex;
  justify-content: center;
}

.main_ui_inspect_right_sidebar__inspect-tab-switcher {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: var(--sp-s) var(--sp-m) var(--sp-s) var(--sp-m);
  gap: var(--sp-m);
}

.main_ui_inspect_right_sidebar__inspect-tab-switcher-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
  flex: 0 1 40%;
}

.main_ui_inspect_right_sidebar__inspect-tab-switcher-controls {
  display: flex;
  align-items: center;
  flex: 1;
  gap: var(--sp-s);
  justify-content: flex-end;
}

.main_ui_inspect_right_sidebar__inspect-tab-switcher-controls-color-space {
  flex: 0 0 65px;
}

.main_ui_inspect_right_sidebar__inspect-tab-switcher-controls-color-space-select {
  justify-self: end;
}

.main_ui_inspect_right_sidebar__inspect-tab-switcher-controls-tab {
  flex: 0 0 110px;
}

.main_ui_inspect_right_sidebar__inspect-content {
  overflow: hidden;
}

.main_ui_inspect_right_sidebar__viewer-tab-switcher {
  --tabs-nav-padding-inline-start: 0;
  --tabs-nav-padding-inline-end: var(--sp-m);
  overflow: auto;
}
.main_ui_inspect_styles__styles-tab {
  block-size: calc(100vh - 8.75rem);
}

.main_ui_inspect_styles__styles-tab-workspace {
  block-size: calc(100vh - 11.25rem);
}

.main_ui_inspect_styles__exports-wrapper {
  padding-block: var(--sp-s);
  padding-inline: var(--sp-m);
}
.main_ui_inspect_styles_property_detail_copiable__property-detail-copiable {
  --detail-color: var(--color-foreground-primary);
  --button-min-inline-size: 9.625rem;
  --button-min-block-size: 2.25rem;
  --button-border-radius: 0.25rem;
  --button-background: none;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background: var(--button-background);
  cursor: pointer;
  display: grid;
  grid-template-columns: 1fr auto;
  gap: var(--sp-s);
  align-items: center;
  width: 100%;
  color: var(--detail-color);
  min-block-size: var(--button-min-block-size);
  min-inline-size: var(--button-min-inline-size);
  padding: var(--sp-s);
  border-radius: var(--button-border-radius);
  border: 0.0625rem solid transparent;
  text-align: left;
}
.main_ui_inspect_styles_property_detail_copiable__property-detail-copiable:hover {
  --button-background: var(--color-background-tertiary);
}
.main_ui_inspect_styles_property_detail_copiable__property-detail-copiable:hover .main_ui_inspect_styles_property_detail_copiable__property-detail-icon {
  display: block;
}

.main_ui_inspect_styles_property_detail_copiable__property-detail-copiable-color {
  grid-template-columns: auto 1fr auto;
}

.main_ui_inspect_styles_property_detail_copiable__property-detail-copied {
  --button-border-active: var(--color-accent-tertiary);
  border: 0.0625rem solid var(--button-border-active);
}

.main_ui_inspect_styles_property_detail_copiable__property-detail-icon {
  display: none;
}

:where(.main_ui_inspect_styles_property_detail_copiable__property-detail-text, .main_ui_inspect_styles_property_detail_copiable__property-detail-text-token) {
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
}

.main_ui_inspect_styles_property_detail_copiable__property-detail-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--detail-color);
}

.main_ui_inspect_styles_property_detail_copiable__property-detail-text-token {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  --detail-color: var(--color-token-foreground);
  line-height: 1.4;
}
.light {
  --low-emphasis-background: #fafafa;
}

.default {
  --low-emphasis-background: #121214;
}

.main_ui_inspect_styles_style_box__style-box {
  --title-gap: var(--sp-xs);
  --title-padding: var(--sp-s);
  --title-color: var(--color-foreground-primary);
  --arrow-color: var(--color-foreground-secondary);
  --box-border-color: var(--color-background-primary);
  padding-block: var(--sp-s);
  padding-inline: var(--sp-m);
  background-color: var(--low-emphasis-background);
  border-block-end: 2px solid var(--box-border-color);
}

.main_ui_inspect_styles_style_box__disclosure-header {
  display: flex;
  align-items: center;
  gap: var(--title-gap);
}

.main_ui_inspect_styles_style_box__disclosure-button {
  display: grid;
  place-items: center;
  color: var(--arrow-color);
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background: none;
  padding: 0;
  margin: 0;
  border: none;
}

.main_ui_inspect_styles_style_box__panel-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  flex: 1;
  color: var(--title-color);
  padding-block: var(--title-padding);
}
.main_ui_inspect_styles_rows_color_properties_row__property-row {
  --term-color: var(--color-foreground-secondary);
  --detail-color: var(--color-foreground-primary);
  --button-min-inline-size: 9.625rem;
  --button-min-block-size: 2.25rem;
  display: grid;
  grid-template-columns: 30% 1fr;
  align-items: center;
  min-inline-size: var(--button-min-inline-size);
  min-block-size: var(--button-min-block-size);
}

.main_ui_inspect_styles_rows_color_properties_row__property-term,
.main_ui_inspect_styles_rows_color_properties_row__property-detail {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_inspect_styles_rows_color_properties_row__property-term {
  color: var(--term-color);
}

.main_ui_inspect_styles_rows_color_properties_row__property-detail {
  color: var(--detail-color);
}

.main_ui_inspect_styles_rows_color_properties_row__color-image-preview {
  --image-margin: var(--sp-m);
  display: grid;
  justify-content: center;
  align-items: center;
  margin: var(--image-margin);
  gap: var(--sp-m);
}

.main_ui_inspect_styles_rows_color_properties_row__color-image-preview-wrapper {
  --image-background: var(--color-background-secondary);
  background: var(--image-background);
}

.main_ui_inspect_styles_rows_color_properties_row__color-image {
  max-block-size: 10rem;
  block-size: 100%;
  inline-size: 100%;
  -o-object-fit: contain;
     object-fit: contain;
}

.main_ui_inspect_styles_rows_color_properties_row__tooltip-token {
  --title-color: var(--color-foreground-secondary);
  --title-value: var(--color-foreground-primary);
}

.main_ui_inspect_styles_rows_color_properties_row__tooltip-token-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--title-color);
}

.main_ui_inspect_styles_rows_color_properties_row__tooltip-token-value {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--title-value);
}

.main_ui_inspect_styles_rows_color_properties_row__tooltip-token-wrapper {
  inline-size: 100%;
}
.main_ui_inspect_styles_rows_properties_row__property-row {
  --term-color: var(--color-foreground-secondary);
  --detail-color: var(--color-foreground-primary);
  --button-min-inline-size: 9.625rem;
  --button-min-block-size: 2.25rem;
  display: grid;
  grid-template-columns: 30% 1fr;
  align-items: center;
  min-inline-size: var(--button-min-inline-size);
  min-block-size: var(--button-min-block-size);
}

.main_ui_inspect_styles_rows_properties_row__property-term,
.main_ui_inspect_styles_rows_properties_row__property-detail {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_inspect_styles_rows_properties_row__property-term {
  color: var(--term-color);
}

.main_ui_inspect_styles_rows_properties_row__property-detail {
  color: var(--detail-color);
}

.main_ui_inspect_styles_rows_properties_row__tooltip-token {
  --title-color: var(--color-foreground-secondary);
  --title-value: var(--color-foreground-primary);
}

.main_ui_inspect_styles_rows_properties_row__tooltip-token-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--title-color);
}

.main_ui_inspect_styles_rows_properties_row__tooltip-token-value {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--title-value);
}

.main_ui_inspect_styles_rows_properties_row__tooltip-token-resolved-values {
  padding: var(--sp-xs) 0 var(--sp-xs) var(--sp-m);
  margin: 0;
  list-style-type: disc;
}

.main_ui_inspect_styles_rows_properties_row__tooltip-token-wrapper {
  inline-size: 100%;
}
.main_ui_inspect_styles_panels_text__text-content-wrapper {
  --border-color: var(--color-background-quaternary);
  --border-radius: 0.5rem;
  border: 0.0625rem solid var(--border-color);
  border-radius: var(--border-radius);
}

.main_ui_inspect_styles_panels_text__text-content {
  --detail-color: var(--color-foreground-secondary);
  color: var(--detail-color);
}
.main_ui_inspect_styles_panels_tokens_panel__token-theme,
.main_ui_inspect_styles_panels_tokens_panel__token-sets {
  align-items: flex-start;
  padding-block: var(--sp-s);
}
@keyframes main_ui_inspect_attributes_blur__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_blur__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_blur__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_blur__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_blur__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_blur__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_blur__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_blur__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_blur__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_blur__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_blur__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_blur__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_blur__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_blur__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_blur__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_blur__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_blur__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_blur__blur-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_blur__blur-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_blur__blur-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_blur__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_blur__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_blur__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_blur__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_blur__blur-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_blur__blur-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_blur__copy-btn-title {
  max-inline-size: 1.75rem;
}
@keyframes main_ui_inspect_attributes_common__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_common__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_common__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_common__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_common__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_common__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_common__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_common__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_common__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_common__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_common__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_common__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_common__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_common__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_common__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_common__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_common__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_common__attributes-color-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_common__attributes-color-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_common__attributes-color-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_common__attributes-image-as-color-row {
  max-inline-size: 15rem;
}

.main_ui_inspect_attributes_common__attributes-color-row {
  display: grid;
  grid-template-columns: auto auto 1fr;
  gap: var(--sp-xs);
  align-items: center;
}

.main_ui_inspect_attributes_common__bullet-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  block-size: 2rem;
}

.main_ui_inspect_attributes_common__format-wrapper {
  inline-size: 4.5rem;
  block-size: 2rem;
}

.main_ui_inspect_attributes_common__image-format {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  block-size: 2rem;
  padding: var(--sp-s) 0;
  color: var(--color-foreground-secondary);
}

.main_ui_inspect_attributes_common__select-format-wrapper {
  inline-size: 100%;
  padding: var(--sp-s) var(--sp-xxs);
  background-color: transparent;
  border-color: transparent;
  color: var(--color-foreground-secondary);
}

.main_ui_inspect_attributes_common__format-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding-left: var(--sp-xxs);
  color: var(--color-foreground-secondary);
}

.main_ui_inspect_attributes_common__color-info {
  display: flex;
  align-items: flex-start;
  gap: var(--sp-xs);
  flex-grow: 1;
  max-inline-size: 9rem;
}
.main_ui_inspect_attributes_common__color-info button {
  visibility: hidden;
  min-inline-size: 1.75rem;
}
.main_ui_inspect_attributes_common__color-info:hover button {
  visibility: visible;
}

.main_ui_inspect_attributes_common__one-line {
  max-block-size: 2rem;
}

.main_ui_inspect_attributes_common__two-line {
  display: grid;
  grid-template-rows: auto 1fr;
  gap: var(--sp-xs);
}

.main_ui_inspect_attributes_common__color-name-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  padding: var(--sp-s);
  padding-inline-end: var(--sp-xs);
  block-size: 2rem;
  max-inline-size: 5rem;
}

.main_ui_inspect_attributes_common__first-row {
  display: grid;
  grid-template-columns: 1fr 1.75rem;
}

.main_ui_inspect_attributes_common__name-opacity {
  line-height: 1rem;
  display: grid;
  grid-template-columns: 1fr auto;
}

.main_ui_inspect_attributes_common__color-value-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--menu-foreground-color);
  text-transform: uppercase;
}

.main_ui_inspect_attributes_common__gradient-name {
  text-transform: none;
}

.main_ui_inspect_attributes_common__opacity-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--menu-foreground-color);
  text-transform: uppercase;
  inline-size: 100%;
}

.main_ui_inspect_attributes_common__second-row {
  min-block-size: 1rem;
  inline-size: 100%;
  text-align: left;
  margin: 0;
  padding: 0;
}

.main_ui_inspect_attributes_common__color-name-library {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  overflow-wrap: break-word;
}

.main_ui_inspect_attributes_common__image-download {
  grid-column: 1/4;
}

.main_ui_inspect_attributes_common__download-button {
  justify-content: center;
  inline-size: 100%;
  margin-block-start: var(--sp-xs);
}

.main_ui_inspect_attributes_common__image-wrapper {
  background-color: var(--menu-background-color);
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  inline-size: 15.5rem;
  block-size: 10rem;
  max-block-size: 10rem;
  max-inline-size: 15.5rem;
  margin: var(--sp-s) 0;
  border-radius: 0.5rem;
}

.main_ui_inspect_attributes_common__resolved-image {
  block-size: 100%;
  inline-size: 100%;
  -o-object-fit: contain;
     object-fit: contain;
}
@keyframes main_ui_inspect_attributes_fill__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_fill__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_fill__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_fill__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_fill__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_fill__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_fill__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_fill__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_fill__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_fill__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_fill__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_fill__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_fill__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_fill__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_fill__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_fill__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_fill__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_fill__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_fill__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_fill__fill-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_fill__attributes-content {
  display: grid;
  gap: 0.25rem;
}

.main_ui_inspect_attributes_fill__attributes-fill-block {
  block-size: 2.25rem;
}
@keyframes main_ui_inspect_attributes_geometry__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_geometry__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_geometry__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_geometry__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_geometry__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_geometry__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_geometry__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_geometry__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_geometry__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_geometry__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_geometry__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_geometry__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_geometry__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_geometry__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_geometry__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_geometry__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_geometry__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_geometry__geometry-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_geometry__geometry-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_geometry__geometry-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_geometry__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_geometry__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_geometry__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_geometry__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_geometry__geometry-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_geometry__geometry-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_geometry__copy-btn-title {
  max-inline-size: 1.75rem;
}
@keyframes main_ui_inspect_attributes_layout__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_layout__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_layout__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_layout__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_layout__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_layout__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_layout__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_layout__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_layout__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_layout__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_layout__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_layout__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_layout__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_layout__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_layout__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_layout__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_layout__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_layout__layout-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_layout__layout-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_layout__layout-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_layout__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_layout__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_layout__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_layout__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_layout__layout-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_layout__layout-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_layout__copy-btn-title {
  max-inline-size: 1.75rem;
}
@keyframes main_ui_inspect_attributes_layout_element__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_layout_element__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_layout_element__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_layout_element__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_layout_element__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_layout_element__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_layout_element__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_layout_element__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_layout_element__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_layout_element__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_layout_element__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_layout_element__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_layout_element__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_layout_element__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_layout_element__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_layout_element__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_layout_element__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_layout_element__layout-element-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_layout_element__layout-element-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_layout_element__layout-element-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_layout_element__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_layout_element__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_layout_element__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_layout_element__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_layout_element__layout-element-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_layout_element__layout-element-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_layout_element__copy-btn-title {
  max-inline-size: 1.75rem;
}
@keyframes main_ui_inspect_attributes_shadow__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_shadow__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_shadow__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_shadow__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_shadow__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_shadow__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_shadow__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_shadow__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_shadow__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_shadow__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_shadow__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_shadow__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_shadow__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_shadow__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_shadow__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_shadow__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_shadow__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_shadow__shadow-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_shadow__shadow-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_shadow__shadow-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_shadow__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_shadow__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_shadow__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_shadow__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_shadow__shadow-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_shadow__shadow-row {
  block-size: 2.25rem;
}
@keyframes main_ui_inspect_attributes_stroke__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_stroke__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_stroke__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_stroke__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_stroke__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_stroke__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_stroke__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_stroke__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_stroke__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_stroke__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_stroke__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_stroke__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_stroke__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_stroke__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_stroke__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_stroke__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_stroke__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_stroke__stroke-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_stroke__stroke-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_stroke__stroke-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_stroke__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_stroke__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_stroke__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_stroke__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_stroke__stroke-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_stroke__attributes-stroke-block {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_inspect_attributes_stroke__stroke-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_stroke__attributes-content {
  display: grid;
  gap: var(--sp-xs);
}
@keyframes main_ui_inspect_attributes_svg__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_svg__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_svg__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_svg__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_svg__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_svg__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_svg__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_svg__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_svg__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_svg__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_svg__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_svg__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_svg__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_svg__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_svg__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_svg__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_svg__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_svg__svg-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_svg__svg-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_svg__svg-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_svg__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_svg__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_svg__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_svg__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_svg__svg-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_svg__svg-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_svg__attributes-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  display: flex;
  justify-content: space-between;
  block-size: 2rem;
}
.main_ui_inspect_attributes_svg__attributes-subtitle span {
  block-size: 2rem;
  display: flex;
  align-items: center;
}
.main_ui_inspect_attributes_svg__attributes-subtitle button {
  display: none;
}
.main_ui_inspect_attributes_svg__attributes-subtitle:hover button {
  display: block;
}
@keyframes main_ui_inspect_attributes_text__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_text__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_text__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_text__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_text__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_text__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_text__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_text__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_text__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_text__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_text__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_text__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_text__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_text__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_text__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_text__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_text__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_text__text-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_text__text-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_text__text-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_text__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_text__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_text__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_text__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_text__text-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_text__attributes-content {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_inspect_attributes_text__text-row {
  block-size: unset;
  min-block-size: 2.25rem;
}
.main_ui_inspect_attributes_text__text-row .attr-value {
  align-items: center;
}

.main_ui_inspect_attributes_text__attributes-content-row {
  max-inline-size: 15rem;
  min-block-size: 2.125rem;
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--menu-border-color-disabled);
  margin-block-start: var(--sp-xs);
}
.main_ui_inspect_attributes_text__attributes-content-row .main_ui_inspect_attributes_text__content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  width: 100%;
  padding: var(--sp-xs) 0;
  color: var(--color-foreground-secondary);
}
.main_ui_inspect_attributes_text__attributes-content-row:hover {
  border: 0.0625rem solid var(--color-background-tertiary);
  background-color: var(--menu-background-color);
}
.main_ui_inspect_attributes_text__attributes-content-row:hover .main_ui_inspect_attributes_text__content {
  color: var(--menu-foreground-color-hover);
}
@keyframes main_ui_inspect_attributes_variant__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_variant__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_variant__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_variant__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_variant__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_variant__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_variant__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_variant__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_variant__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_variant__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_variant__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_variant__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_variant__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_variant__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_variant__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_variant__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_variant__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_variant__variant-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_variant__variant-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_variant__variant-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_variant__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_variant__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_variant__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_variant__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_variant__variant-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_variant__variant-row {
  block-size: -moz-fit-content;
  block-size: fit-content;
  min-block-size: 2.25rem;
}

.main_ui_inspect_attributes_variant__button-children {
  overflow-wrap: break-word;
}
@keyframes main_ui_inspect_attributes_visibility__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_inspect_attributes_visibility__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_inspect_attributes_visibility__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_inspect_attributes_visibility__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_visibility__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_inspect_attributes_visibility__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_inspect_attributes_visibility__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_inspect_attributes_visibility__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_inspect_attributes_visibility__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_inspect_attributes_visibility__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_inspect_attributes_visibility__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_inspect_attributes_visibility__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_inspect_attributes_visibility__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_inspect_attributes_visibility__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_inspect_attributes_visibility__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_inspect_attributes_visibility__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_inspect_attributes_visibility__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_inspect_attributes_visibility__visibility-row {
  display: grid;
  grid-template-areas: "name content";
  grid-template-columns: 1fr 3fr;
  gap: 0.25rem;
  height: 2rem;
}
.main_ui_inspect_attributes_visibility__visibility-row .attr-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  width: 5.75rem;
  margin: auto 0;
  color: var(--entry-foreground-color);
  grid-area: name;
}
.main_ui_inspect_attributes_visibility__visibility-row .attr-value {
  grid-area: content;
  display: flex;
  color: var(--entry-foreground-color-hover);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_inspect_attributes_visibility__button-children {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--color-foreground-primary);
  text-align: left;
  margin: 0;
  padding: 0;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_inspect_attributes_visibility__button-children:hover div {
  color: var(--entry-foreground-color-hover);
}

.main_ui_inspect_attributes_visibility__attributes-block {
  --box-border-color: var(--color-background-primary);
  display: flex;
  flex-direction: column;
  border-block-end: 0.125rem solid var(--box-border-color);
}

.main_ui_inspect_attributes_visibility__title-wrapper {
  margin-inline-start: 0;
}

.main_ui_inspect_attributes_visibility__visibility-attr-title {
  color: var(--entry-foreground-color-hover);
  padding-block: var(--sp-s);
}

.main_ui_inspect_attributes_visibility__visibility-row {
  block-size: 2.25rem;
}

.main_ui_inspect_attributes_visibility__copy-btn-title {
  max-inline-size: 1.75rem;
}
@keyframes main_ui_exports_assets__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_exports_assets__accept-btn.main_ui_exports_assets__danger, .main_ui_exports_assets__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_exports_assets__accept-btn.main_ui_exports_assets__danger svg, .main_ui_exports_assets__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_exports_assets__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_exports_assets__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_exports_assets__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_exports_assets__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_exports_assets__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_exports_assets__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_exports_assets__accept-btn.disabled, [disabled].main_ui_exports_assets__accept-btn, .main_ui_exports_assets__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_exports_assets__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_exports_assets__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_exports_assets__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_exports_assets__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_exports_assets__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_exports_assets__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_exports_assets__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_exports_assets__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_exports_assets__cancel-button.disabled, [disabled].main_ui_exports_assets__cancel-button, .main_ui_exports_assets__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_exports_assets__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_exports_assets__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_exports_assets__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_exports_assets__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_exports_assets__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_exports_assets__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_exports_assets__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_exports_assets__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_exports_assets__modal-close-btn.disabled, [disabled].main_ui_exports_assets__modal-close-btn, .main_ui_exports_assets__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_exports_assets__modal-close-btn.disabled svg, [disabled].main_ui_exports_assets__modal-close-btn svg, .main_ui_exports_assets__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_exports_assets__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_exports_assets__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_exports_assets__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_exports_assets__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_exports_assets__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_exports_assets__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_exports_assets__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_exports_assets__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_exports_assets__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_exports_assets__icon, .main_ui_exports_assets__close-icon, .main_ui_exports_assets__modal-close-btn svg, .main_ui_exports_assets__file-entry .main_ui_exports_assets__file-name .main_ui_exports_assets__file-icon svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate svg, .main_ui_exports_assets__export-option label span.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked svg, .main_ui_exports_assets__export-option label span.checked svg, .main_ui_exports_assets__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_exports_assets__file-entry .main_ui_exports_assets__file-name .main_ui_exports_assets__file-icon svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate svg, .main_ui_exports_assets__export-option label span.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked svg, .main_ui_exports_assets__export-option label span.checked svg, .main_ui_exports_assets__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_exports_assets__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_exports_assets__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_exports_assets__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_exports_assets__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span, .main_ui_exports_assets__export-option label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span svg, .main_ui_exports_assets__export-option label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span:hover,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span:hover, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick:hover,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick:hover, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span:hover,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span:hover, .main_ui_exports_assets__export-option label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span:focus,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span:focus, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick:focus,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick:focus, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span:focus,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span:focus, .main_ui_exports_assets__export-option label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked, .main_ui_exports_assets__export-option label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.checked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.checked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.checked svg, .main_ui_exports_assets__export-option label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate, .main_ui_exports_assets__export-option label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.intermediate svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.intermediate svg, .main_ui_exports_assets__export-option label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.unchecked,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.unchecked, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.unchecked,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.unchecked, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.unchecked,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.unchecked, .main_ui_exports_assets__export-option label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.unchecked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn span.unchecked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.unchecked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper .main_ui_exports_assets__checkobox-tick.unchecked svg, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.unchecked svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label span.unchecked svg, .main_ui_exports_assets__export-option label span.unchecked svg {
  display: none;
}

.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper, .main_ui_exports_assets__export-option {
  display: flex;
  align-items: center;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label, .main_ui_exports_assets__export-option label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label input,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label input, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label input,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label input, .main_ui_exports_assets__export-option label input {
  margin: 0;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label:hover span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label:hover span, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label:hover span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label:hover span, .main_ui_exports_assets__export-option label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label:focus span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label:focus span, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label:focus span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label:focus span, .main_ui_exports_assets__export-option label:focus span, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label:focus-within span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn label:focus-within span, .main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label:focus-within span,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper label:focus-within span, .main_ui_exports_assets__export-option label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_exports_assets__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_exports_assets__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_exports_assets__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_exports_assets__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_exports_assets__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_exports_assets__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_exports_assets__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_exports_assets__accept-btn.main_ui_exports_assets__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_exports_assets__export-progress-widget {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.75rem;
  height: 1.75rem;
}

.main_ui_exports_assets__export-progress-modal {
  --export-modal-bg-color: var(--alert-background-color-default);
  --export-modal-fg-color: var(--alert-text-foreground-color-default);
  --export-modal-icon-color: var(--alert-icon-foreground-color-default);
  --export-modal-border-color: var(--alert-border-color-default);
  position: absolute;
  right: 1rem;
  top: 3rem;
  display: grid;
  grid-template-columns: 1.5rem 1fr 1.5rem;
  grid-template-areas: "icon text close" "bar bar bar";
  gap: 0.25rem 0.5rem;
  padding-block-start: 0.5rem;
  background-color: var(--export-modal-bg-color);
  border: 1px solid var(--export-modal-border-color);
  border-radius: 8px;
  z-index: 300;
  overflow: hidden;
}

.main_ui_exports_assets__has-error {
  --export-modal-bg-color: var(--alert-background-color-error);
  --export-modal-fg-color: var(--alert-text-foreground-color-error);
  --export-modal-icon-color: var(--alert-icon-foreground-color-error);
  --export-modal-border-color: var(--alert-border-color-error);
  grid-template-areas: "icon text close";
  gap: 0.5rem;
  padding-block: 0.5rem;
}

.main_ui_exports_assets__icon {
  grid-area: icon;
  align-self: center;
  margin-inline-start: 0.5rem;
  stroke: var(--export-modal-icon-color);
}

.main_ui_exports_assets__export-progress-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 0.5rem;
  grid-area: text;
  align-self: center;
  padding: 0;
  margin: 0;
  color: var(--export-modal-fg-color);
}

.main_ui_exports_assets__progress {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  padding-left: 0.5rem;
  margin: 0;
  align-self: center;
  color: var(--modal-text-foreground-color);
}

.main_ui_exports_assets__retry-btn {
  border: none;
  background: none;
  cursor: pointer;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: inline;
  text-align: left;
  color: var(--modal-link-foreground-color);
  margin: 0;
  padding: 0;
}

.main_ui_exports_assets__progress-close-button {
  border: none;
  background: none;
  cursor: pointer;
  padding: 0;
  margin-inline-end: 0.5rem;
}

.main_ui_exports_assets__close-icon {
  stroke: var(--export-modal-icon-color);
}

.main_ui_exports_assets__progress-bar {
  margin-top: 0;
  grid-area: bar;
}

.main_ui_exports_assets__modal-overlay.main_ui_exports_assets__transparent {
  background-color: transparent;
}

.main_ui_exports_assets__modal-container {
  max-height: calc(10 * 5rem);
}

.main_ui_exports_assets__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_exports_assets__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.4;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_exports_assets__modal-content,
.main_ui_exports_assets__no-selection {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-bottom: 1.5rem;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__modal-link,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__modal-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  text-decoration: none;
  cursor: pointer;
  color: var(--modal-link-foreground-color);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  height: 2rem;
  margin-bottom: 0.25rem;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
  padding: 0;
  margin-left: 1rem;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-title,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-header .main_ui_exports_assets__selection-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-wrapper,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-wrapper {
  position: relative;
  width: 100%;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-shadow,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-shadow {
  width: 100%;
  height: 100%;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-shadow::after,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-shadow::after {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 50px;
  background: linear-gradient(to top, rgb(24, 24, 26) 0%, rgba(24, 24, 26, 0) 100%);
  content: "";
  pointer-events: none;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  max-height: 25rem;
  overflow-y: auto;
  padding-bottom: 0.75rem;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  background-color: var(--entry-background-color);
  min-height: 2.5rem;
  border-radius: 8px;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  grid-template-columns: min-content auto 1fr auto auto;
  align-items: center;
  width: 100%;
  height: 10%;
  gap: 0.5rem;
  padding: 0 1rem;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__checkbox-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
  padding: 0;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__selection-name,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__selection-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  color: var(--modal-text-foreground-color);
  text-align: start;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__selection-scale,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__selection-scale {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  min-width: 6.75rem;
  padding: 0.75rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__selection-extension,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__selection-btn .main_ui_exports_assets__selection-extension {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  min-width: 4.5rem;
  padding: 0.75rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__image-wrapper,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__image-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  min-height: 2rem;
  min-width: 2rem;
  background-color: var(--app-white);
  border-radius: 6px;
  margin: auto 0;
}
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__image-wrapper img,
.main_ui_exports_assets__modal-content .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__image-wrapper svg,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__image-wrapper img,
.main_ui_exports_assets__no-selection .main_ui_exports_assets__selection-list .main_ui_exports_assets__selection-row .main_ui_exports_assets__image-wrapper svg {
  -o-object-fit: contain;
     object-fit: contain;
  max-height: 2.5rem;
}

.main_ui_exports_assets__modal-scd-msg,
.main_ui_exports_assets__modal-subtitle,
.main_ui_exports_assets__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
}

.main_ui_exports_assets__export-option {
  width: 100%;
  align-items: flex-start;
}
.main_ui_exports_assets__export-option label {
  align-items: flex-start;
}
.main_ui_exports_assets__export-option label .main_ui_exports_assets__modal-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}
.main_ui_exports_assets__export-option span {
  margin-top: 0.5rem;
}

.main_ui_exports_assets__option-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
}

.main_ui_exports_assets__file-entry .main_ui_exports_assets__file-name {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}
.main_ui_exports_assets__file-entry .main_ui_exports_assets__file-name .main_ui_exports_assets__file-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
}
.main_ui_exports_assets__file-entry .main_ui_exports_assets__file-name .main_ui_exports_assets__file-icon svg {
  stroke: var(--input-foreground);
}
.main_ui_exports_assets__file-entry .main_ui_exports_assets__file-name .main_ui_exports_assets__file-name-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_exports_assets__file-entry.main_ui_exports_assets__loading .main_ui_exports_assets__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__file-entry.main_ui_exports_assets__error .main_ui_exports_assets__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__file-entry.main_ui_exports_assets__error .main_ui_exports_assets__file-name .main_ui_exports_assets__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__file-entry.main_ui_exports_assets__success .main_ui_exports_assets__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_assets__file-entry.main_ui_exports_assets__success .main_ui_exports_assets__file-name .main_ui_exports_assets__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
@keyframes main_ui_exports_files__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_exports_files__accept-btn.main_ui_exports_files__danger, .main_ui_exports_files__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_exports_files__accept-btn.main_ui_exports_files__danger svg, .main_ui_exports_files__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_exports_files__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_exports_files__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_exports_files__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_exports_files__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_exports_files__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_exports_files__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_exports_files__accept-btn.disabled, [disabled].main_ui_exports_files__accept-btn, .main_ui_exports_files__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_exports_files__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_exports_files__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_exports_files__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_exports_files__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_exports_files__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_exports_files__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_exports_files__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_exports_files__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_exports_files__cancel-button.disabled, [disabled].main_ui_exports_files__cancel-button, .main_ui_exports_files__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_exports_files__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_exports_files__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_exports_files__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_exports_files__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_exports_files__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_exports_files__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_exports_files__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_exports_files__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_exports_files__modal-close-btn.disabled, [disabled].main_ui_exports_files__modal-close-btn, .main_ui_exports_files__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_exports_files__modal-close-btn.disabled svg, [disabled].main_ui_exports_files__modal-close-btn svg, .main_ui_exports_files__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_exports_files__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_exports_files__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_exports_files__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_exports_files__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_exports_files__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_exports_files__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_exports_files__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_exports_files__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_exports_files__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_exports_files__modal-close-btn svg, .main_ui_exports_files__file-entry .main_ui_exports_files__file-name .main_ui_exports_files__file-icon svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.intermediate svg, .main_ui_exports_files__export-option label span.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.checked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.checked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.checked svg, .main_ui_exports_files__export-option label span.checked svg, .main_ui_exports_files__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_exports_files__file-entry .main_ui_exports_files__file-name .main_ui_exports_files__file-icon svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.intermediate svg, .main_ui_exports_files__export-option label span.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.checked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.checked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.checked svg, .main_ui_exports_files__export-option label span.checked svg, .main_ui_exports_files__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_exports_files__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_exports_files__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_exports_files__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_exports_files__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span, .main_ui_exports_files__export-option label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span svg, .main_ui_exports_files__export-option label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span:hover, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick:hover, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span:hover, .main_ui_exports_files__export-option label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span:focus, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick:focus, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span:focus, .main_ui_exports_files__export-option label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.checked, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.checked, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.checked, .main_ui_exports_files__export-option label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.checked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.checked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.checked svg, .main_ui_exports_files__export-option label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.intermediate, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.intermediate, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.intermediate, .main_ui_exports_files__export-option label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.intermediate svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.intermediate svg, .main_ui_exports_files__export-option label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.unchecked, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.unchecked, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.unchecked, .main_ui_exports_files__export-option label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn span.unchecked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper .main_ui_exports_files__checkobox-tick.unchecked svg, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label span.unchecked svg, .main_ui_exports_files__export-option label span.unchecked svg {
  display: none;
}

.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper, .main_ui_exports_files__export-option {
  display: flex;
  align-items: center;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn label, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label, .main_ui_exports_files__export-option label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn label input, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label input, .main_ui_exports_files__export-option label input {
  margin: 0;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn label:hover span, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label:hover span, .main_ui_exports_files__export-option label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn label:focus span, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label:focus span, .main_ui_exports_files__export-option label:focus span, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn label:focus-within span, .main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper label:focus-within span, .main_ui_exports_files__export-option label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_exports_files__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_exports_files__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_exports_files__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_exports_files__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_exports_files__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_exports_files__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_exports_files__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_exports_files__accept-btn.main_ui_exports_files__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_exports_files__modal-overlay.main_ui_exports_files__transparent {
  background-color: transparent;
}

.main_ui_exports_files__modal-container {
  max-height: calc(10 * 5rem);
}

.main_ui_exports_files__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_exports_files__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.4;
  text-transform: uppercase;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
}

.main_ui_exports_files__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-bottom: 1.5rem;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__modal-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  text-decoration: none;
  cursor: pointer;
  color: var(--modal-link-foreground-color);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  height: 2rem;
  margin-bottom: 0.25rem;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
  padding: 0;
  margin-left: 1rem;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-header .main_ui_exports_files__selection-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-wrapper {
  position: relative;
  width: 100%;
  height: -moz-fit-content;
  height: fit-content;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-shadow {
  width: 100%;
  height: 100%;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-shadow::after {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 50px;
  background: linear-gradient(to top, rgb(24, 24, 26) 0%, rgba(24, 24, 26, 0) 100%);
  content: "";
  pointer-events: none;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  max-height: 25rem;
  overflow-y: auto;
  padding-bottom: 0.75rem;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row {
  display: flex;
  align-items: center;
  gap: 0.25rem;
  background-color: var(--entry-background-color);
  min-height: 2.5rem;
  border-radius: 8px;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  grid-template-columns: min-content auto 1fr auto auto;
  align-items: center;
  width: 100%;
  height: 10%;
  gap: 0.5rem;
  padding: 0 1rem;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__checkbox-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
  padding: 0;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__selection-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex-grow: 1;
  color: var(--modal-text-foreground-color);
  text-align: start;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__selection-scale {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  min-width: 6.75rem;
  padding: 0.75rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__selection-btn .main_ui_exports_files__selection-extension {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  min-width: 4.5rem;
  padding: 0.75rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__image-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  min-height: 2rem;
  min-width: 2rem;
  background-color: var(--app-white);
  border-radius: 6px;
  margin: auto 0;
}
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__image-wrapper img,
.main_ui_exports_files__modal-content .main_ui_exports_files__selection-list .main_ui_exports_files__selection-row .main_ui_exports_files__image-wrapper svg {
  -o-object-fit: contain;
     object-fit: contain;
  max-height: 2.5rem;
}

.main_ui_exports_files__status-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  font-style: italic;
}

.main_ui_exports_files__modal-scd-msg,
.main_ui_exports_files__modal-subtitle,
.main_ui_exports_files__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-text-foreground-color);
}

.main_ui_exports_files__export-option {
  width: 100%;
  align-items: flex-start;
}
.main_ui_exports_files__export-option label {
  align-items: flex-start;
}
.main_ui_exports_files__export-option label .main_ui_exports_files__modal-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  color: var(--modal-title-foreground-color);
  padding: 0.25rem 0;
}
.main_ui_exports_files__export-option span {
  margin-top: 0.5rem;
}

.main_ui_exports_files__option-content {
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
}

.main_ui_exports_files__file-entry .main_ui_exports_files__file-name {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}
.main_ui_exports_files__file-entry .main_ui_exports_files__file-name .main_ui_exports_files__file-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
}
.main_ui_exports_files__file-entry .main_ui_exports_files__file-name .main_ui_exports_files__file-icon svg {
  stroke: var(--input-foreground);
}
.main_ui_exports_files__file-entry .main_ui_exports_files__file-name .main_ui_exports_files__file-name-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  font-weight: 400;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_exports_files__file-entry.main_ui_exports_files__loading .main_ui_exports_files__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_files__file-entry.main_ui_exports_files__error .main_ui_exports_files__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_files__file-entry.main_ui_exports_files__error .main_ui_exports_files__file-name .main_ui_exports_files__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
.main_ui_exports_files__file-entry.main_ui_exports_files__success .main_ui_exports_files__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_exports_files__file-entry.main_ui_exports_files__success .main_ui_exports_files__file-name .main_ui_exports_files__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
@keyframes main_ui_debug_icons_preview__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_debug_icons_preview__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_debug_icons_preview__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_debug_icons_preview__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_debug_icons_preview__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_debug_icons_preview__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_debug_icons_preview__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_debug_icons_preview__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_debug_icons_preview__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_debug_icons_preview__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_debug_icons_preview__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_debug_icons_preview__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_debug_icons_preview__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_debug_icons_preview__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_debug_icons_preview__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_debug_icons_preview__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_debug_icons_preview__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_debug_icons_preview__container {
  display: grid;
  row-gap: 1rem;
  height: 100vh;
  overflow-y: auto;
  padding: 1rem;
}

.main_ui_debug_icons_preview__title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--color-foreground-primary);
}

.main_ui_debug_icons_preview__gallery {
  display: grid;
  grid-template-columns: repeat(auto-fill, 120px);
  grid-template-rows: repeat(auto-fill, 120px);
  gap: 1rem;
  --cell-size: 64px;
}

.main_ui_debug_icons_preview__gallery-item {
  display: grid;
  place-items: center;
  row-gap: 0.5rem;
  grid-template-rows: var(--cell-size) 1fr;
  padding: 0.5rem;
  color: var(--color-foreground-primary);
  overflow-wrap: break-word;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}
.main_ui_debug_icons_preview__gallery-item svg {
  width: var(--cell-size);
  height: var(--cell-size);
  fill: none;
  color: transparent;
  stroke: var(--color-accent-primary);
}

.main_ui_debug_icons_preview__cursor {
  width: var(--cell-size);
  height: var(--cell-size);
  background-size: contain;
  background-repeat: no-repeat;
  background-position: center;
}
@keyframes main_ui_dashboard_change_owner__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_change_owner__accept-btn.main_ui_dashboard_change_owner__danger, .main_ui_dashboard_change_owner__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_change_owner__accept-btn.main_ui_dashboard_change_owner__danger svg, .main_ui_dashboard_change_owner__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_change_owner__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_change_owner__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_change_owner__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_change_owner__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_change_owner__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_change_owner__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_change_owner__accept-btn.disabled, [disabled].main_ui_dashboard_change_owner__accept-btn, .main_ui_dashboard_change_owner__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_change_owner__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_change_owner__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_change_owner__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_change_owner__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_change_owner__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_change_owner__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_change_owner__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_change_owner__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_change_owner__cancel-button.disabled, [disabled].main_ui_dashboard_change_owner__cancel-button, .main_ui_dashboard_change_owner__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_change_owner__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_dashboard_change_owner__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_change_owner__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_change_owner__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_change_owner__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_dashboard_change_owner__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_dashboard_change_owner__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_change_owner__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_change_owner__modal-close-btn.disabled, [disabled].main_ui_dashboard_change_owner__modal-close-btn, .main_ui_dashboard_change_owner__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_dashboard_change_owner__modal-close-btn.disabled svg, [disabled].main_ui_dashboard_change_owner__modal-close-btn svg, .main_ui_dashboard_change_owner__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_dashboard_change_owner__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_change_owner__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_change_owner__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_change_owner__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_change_owner__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_change_owner__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_change_owner__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_change_owner__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_change_owner__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_change_owner__modal-close-btn svg, .main_ui_dashboard_change_owner__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_change_owner__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_change_owner__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_change_owner__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_change_owner__input-wrapper input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_change_owner__input-wrapper input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_dashboard_change_owner__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_change_owner__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_change_owner__input-wrapper.disabled {
  background-color: var(--input-background-color-disabled);
  border: 1px solid var(--input-border-color-disabled);
  color: var(--input-foreground-color-disabled);
}
.main_ui_dashboard_change_owner__input-wrapper.disabled input {
  pointer-events: none;
  cursor: default;
  color: var(--input-foreground-color-disabled);
}
.main_ui_dashboard_change_owner__input-wrapper.disabled svg {
  stroke: var(--input-foreground-color-disabled);
}

.main_ui_dashboard_change_owner__input-wrapper {
  display: flex;
  flex-direction: column;
}
.main_ui_dashboard_change_owner__input-wrapper label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  min-height: 1rem;
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_change_owner__input-wrapper input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  border-radius: 8px;
  height: 2rem;
  min-height: 2rem;
  margin-top: 0.5rem;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_change_owner__input-wrapper input:focus-within input, .main_ui_dashboard_change_owner__input-wrapper input:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_change_owner__input-wrapper input:focus-within, .main_ui_dashboard_change_owner__input-wrapper input:active {
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_dashboard_change_owner__input-wrapper.invalid input {
  border: 1px solid var(--input-border-color-error);
}

.main_ui_dashboard_change_owner__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_dashboard_change_owner__modal-container, .main_ui_dashboard_change_owner__modal-org-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_dashboard_change_owner__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_dashboard_change_owner__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_change_owner__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_dashboard_change_owner__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_change_owner__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_change_owner__accept-btn.main_ui_dashboard_change_owner__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_dashboard_change_owner__modal-overlay {
  z-index: var(--z-index-notifications);
}

.main_ui_dashboard_change_owner__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_dashboard_change_owner__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_dashboard_change_owner__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-bottom: 1.5rem;
}

.main_ui_dashboard_change_owner__input-wrapper {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
}

.main_ui_dashboard_change_owner__modal-msg {
  color: var(--modal-text-foreground-color);
}

.main_ui_dashboard_change_owner__teams-container {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
  margin: var(--sp-xxxl) 0;
}

.main_ui_dashboard_change_owner__team-select-container {
  display: grid;
  grid-template-columns: 1fr 2fr;
  align-items: center;
  width: 100%;
}

.main_ui_dashboard_change_owner__modal-org-container {
  overflow-y: auto;
  max-height: 32rem;
}

.main_ui_dashboard_change_owner__modal-org-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_dashboard_change_owner__modal-org-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--modal-text-foreground-color);
}

.main_ui_dashboard_change_owner__team-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--modal-text-foreground-color);
}

.main_ui_dashboard_change_owner__team-member {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
}
@keyframes main_ui_dashboard_comments__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_comments__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_comments__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_comments__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_comments__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_comments__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_comments__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_comments__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_comments__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_comments__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_comments__comments-icon, .main_ui_dashboard_comments__comments-icon-small, .main_ui_dashboard_comments__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_comments__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_comments__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_comments__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_comments__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_comments__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_comments__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_comments__dashboard-comments-section {
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  border-radius: 8px;
}

.main_ui_dashboard_comments__thread-groups {
  height: calc(100% - 2rem);
  max-height: 27.5rem;
  overflow: auto;
}

.main_ui_dashboard_comments__thread-group {
  display: flex;
  flex-direction: column;
  font-size: 0.75rem;
}

.main_ui_dashboard_comments__thread-groups-placeholder {
  align-items: center;
  display: flex;
  flex-direction: column;
  font-size: 0.75rem;
  padding: 1.5rem;
  text-align: center;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_comments__comments-icon {
  stroke: var(--icon-foreground);
  height: 1.5rem;
  width: 1.5rem;
  margin-bottom: 1.5rem;
}

.main_ui_dashboard_comments__comment-button {
  position: relative;
}
.main_ui_dashboard_comments__comment-button .main_ui_dashboard_comments__unread {
  position: absolute;
  width: 0.5rem;
  height: 0.5rem;
  border: 0.125rem solid var(--color-background-tertiary);
  border-radius: 50%;
  background: var(--color-foreground-error);
  top: 0.375rem;
  right: 0.375rem;
}

.main_ui_dashboard_comments__comments-icon-small {
  stroke: var(--comment-icon-small-foreground-color);
}

.main_ui_dashboard_comments__dropdown {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  border: 1px solid transparent;
  bottom: 0.25rem;
  height: 40vh;
  max-height: 30rem;
  min-height: 12.5rem;
  position: absolute;
  overflow: hidden;
  width: 100%;
  z-index: 4;
}
.main_ui_dashboard_comments__dropdown hr {
  margin: 0;
  border-color: var(--color-foreground-secondary);
}

.main_ui_dashboard_comments__header {
  display: flex;
  height: 2.5rem;
  align-items: center;
  padding: 0 0.75rem;
  gap: 0.25rem;
}

.main_ui_dashboard_comments__header-title {
  color: var(--color-foreground-secondary);
  font-size: 0.688rem;
  line-height: 1.28;
  flex-grow: 1;
  text-transform: uppercase;
}

.main_ui_dashboard_comments__notifications-button:hover {
  cursor: pointer;
}
.main_ui_dashboard_comments__notifications-button.main_ui_dashboard_comments__mark-all-as-read-button {
  border-radius: 0.5rem;
  border: 1px solid;
}
@keyframes main_ui_dashboard_deleted__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_deleted__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_deleted__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_deleted__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_deleted__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_deleted__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_deleted__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_deleted__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_deleted__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_deleted__btn-primary.disabled, [disabled].main_ui_dashboard_deleted__btn-primary, .main_ui_dashboard_deleted__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_deleted__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_deleted__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_deleted__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_deleted__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_deleted__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_deleted__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_deleted__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_deleted__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_deleted__btn-secondary.disabled, [disabled].main_ui_dashboard_deleted__btn-secondary, .main_ui_dashboard_deleted__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_deleted__add-file-btn,
.main_ui_dashboard_deleted__options-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_dashboard_deleted__add-file-btn svg,
.main_ui_dashboard_deleted__options-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_deleted__add-file-btn:focus-visible,
.main_ui_dashboard_deleted__options-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_deleted__add-file-btn:focus-visible svg,
.main_ui_dashboard_deleted__options-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_deleted__add-file-btn:hover,
.main_ui_dashboard_deleted__options-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_dashboard_deleted__add-file-btn:hover svg,
.main_ui_dashboard_deleted__options-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_dashboard_deleted__add-file-btn:active,
.main_ui_dashboard_deleted__options-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_deleted__add-file-btn:active svg,
.main_ui_dashboard_deleted__options-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_deleted__add-file-btn.disabled,
.main_ui_dashboard_deleted__options-btn.disabled, [disabled].main_ui_dashboard_deleted__add-file-btn,
[disabled].main_ui_dashboard_deleted__options-btn, .main_ui_dashboard_deleted__add-file-btn:disabled,
.main_ui_dashboard_deleted__options-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_dashboard_deleted__add-file-btn.disabled svg,
.main_ui_dashboard_deleted__options-btn.disabled svg, [disabled].main_ui_dashboard_deleted__add-file-btn svg,
[disabled].main_ui_dashboard_deleted__options-btn svg, .main_ui_dashboard_deleted__add-file-btn:disabled svg,
.main_ui_dashboard_deleted__options-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_dashboard_deleted__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_deleted__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_deleted__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_deleted__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_deleted__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_deleted__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_deleted__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_deleted__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_deleted__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_deleted__add-icon,
.main_ui_dashboard_deleted__menu-icon, .main_ui_dashboard_deleted__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_deleted__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_deleted__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_deleted__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_deleted__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_deleted__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_deleted__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_deleted__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_deleted__dashboard-header.main_ui_dashboard_deleted__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_deleted__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_deleted__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_deleted__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_deleted__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-title .main_ui_dashboard_deleted__context-menu.main_ui_dashboard_deleted__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_deleted__dashboard-header .main_ui_dashboard_deleted__dashboard-header-options li.main_ui_dashboard_deleted__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_deleted__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_deleted__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_dashboard_deleted__dashboard-container {
  flex: 1 0 0;
  width: 100%;
  margin-inline-end: var(--sp-l);
  border-top: 0.0625rem solid var(--panel-border-color);
  overflow-y: auto;
  padding-block-end: var(--sp-xxxl);
}

.main_ui_dashboard_deleted__deleted-info-content {
  display: flex;
  justify-content: space-between;
  padding: var(--sp-s) var(--sp-xxl) var(--sp-s) var(--sp-xxl);
}

.main_ui_dashboard_deleted__deleted-info {
  display: block;
  color: var(--color-foreground-secondary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  line-height: 0.8;
  height: var(--sp-xl);
}

.main_ui_dashboard_deleted__info-text-highlight {
  color: var(--color-accent-primary);
}

.main_ui_dashboard_deleted__deleted-options {
  display: flex;
  gap: 5px;
  flex-shrink: 0;
}

.main_ui_dashboard_deleted__nav {
  background: var(--color-background-default);
  padding: var(--sp-xxl) var(--sp-xxl) var(--sp-s) var(--sp-xxl);
  position: sticky;
  top: 0;
  z-index: var(--z-index-panels);
}

.main_ui_dashboard_deleted__nav-inside {
  border-bottom: 0.0625rem solid var(--panel-border-color);
  display: flex;
  gap: var(--sp-l);
  justify-content: space-between;
}

.main_ui_dashboard_deleted__nav-option {
  color: var(--color-foreground-secondary);
  padding: 0.5rem;
  display: flex;
  align-items: center;
  justify-content: center;
  border: 0.0625rem solid transparent;
  cursor: pointer;
}

.main_ui_dashboard_deleted__selected {
  color: var(--color-foreground-primary);
  border-bottom: 0.0625rem solid var(--color-foreground-primary);
}

.main_ui_dashboard_deleted__project {
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
  gap: var(--sp-s);
  width: 99%;
  max-height: 2.5rem;
  padding: var(--sp-s) var(--sp-s) var(--sp-s) var(--sp-l);
  margin-block-start: var(--sp-l);
  border-radius: 0.25rem;
}

.main_ui_dashboard_deleted__project-name-wrapper {
  display: flex;
  align-items: center;
  justify-content: flex-start;
  width: 100%;
  min-height: var(--sp-xxxl);
  margin-inline-start: var(--sp-s);
}

.main_ui_dashboard_deleted__project-name {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  width: -moz-fit-content;
  width: fit-content;
  margin-inline-end: var(--sp-m);
  line-height: 0.8;
  color: var(--title-foreground-color-hover);
  height: var(--sp-l);
}

.main_ui_dashboard_deleted__project-actions {
  display: flex;
  opacity: var(--actions-opacity);
  margin-inline-start: var(--sp-xxxl);
}

.main_ui_dashboard_deleted__add-file-btn,
.main_ui_dashboard_deleted__options-btn {
  height: var(--sp-xxxl);
  width: var(--sp-xxxl);
  margin: 0 var(--sp-s);
  padding: var(--sp-s);
}

.main_ui_dashboard_deleted__info-wrapper {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_dashboard_deleted__add-icon,
.main_ui_dashboard_deleted__menu-icon {
  stroke: var(--icon-foreground);
}
@keyframes main_ui_dashboard_files__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_files__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_files__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_files__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_files__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_files__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_files__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_files__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_files__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_files__btn-primary.disabled, [disabled].main_ui_dashboard_files__btn-primary, .main_ui_dashboard_files__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_files__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_files__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_files__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_files__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_files__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_files__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_files__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_files__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_files__btn-secondary.disabled, [disabled].main_ui_dashboard_files__btn-secondary, .main_ui_dashboard_files__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_files__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_files__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_files__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_files__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_files__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_files__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_files__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_files__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_files__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_files__menu-icon, .main_ui_dashboard_files__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_files__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_files__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_files__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_files__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_files__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_files__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_files__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_files__dashboard-header.main_ui_dashboard_files__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_files__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_files__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_files__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_files__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-title .main_ui_dashboard_files__context-menu.main_ui_dashboard_files__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_files__dashboard-header .main_ui_dashboard_files__dashboard-header-options li.main_ui_dashboard_files__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_files__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_files__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

.main_ui_dashboard_files__dashboard-container {
  flex: 1 0 0;
  margin-right: 1rem;
  overflow-y: auto;
  width: 100%;
  border-top: 1px solid var(--color-background-quaternary);
  padding-block-end: var(--sp-xxxl);
}
.main_ui_dashboard_files__dashboard-container.main_ui_dashboard_files__dashboard-projects {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_files__dashboard-container.main_ui_dashboard_files__dashboard-shared {
  width: calc(100vw - 20rem);
  margin-right: 3.25rem;
}
.main_ui_dashboard_files__dashboard-container.main_ui_dashboard_files__search {
  margin-top: 0.75rem;
}

.main_ui_dashboard_files__new-file {
  margin-inline-end: 0.5rem;
}

.main_ui_dashboard_files__menu-icon {
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_files__placeholder-placement {
  margin: 1rem 2rem;
}
@keyframes main_ui_dashboard_fonts__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_fonts__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_fonts__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_fonts__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_fonts__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_fonts__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_fonts__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_fonts__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_fonts__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_fonts__btn-primary.disabled, [disabled].main_ui_dashboard_fonts__btn-primary, .main_ui_dashboard_fonts__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_fonts__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_fonts__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_fonts__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_fonts__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_fonts__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_fonts__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_fonts__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_fonts__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_fonts__btn-secondary.disabled, [disabled].main_ui_dashboard_fonts__btn-secondary, .main_ui_dashboard_fonts__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_fonts__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_fonts__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_fonts__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_fonts__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_fonts__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_fonts__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_fonts__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_fonts__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_fonts__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_fonts__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_fonts__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_fonts__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_fonts__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_fonts__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_fonts__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_fonts__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_fonts__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_fonts__dashboard-header.main_ui_dashboard_fonts__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_fonts__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_fonts__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_fonts__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_fonts__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-title .main_ui_dashboard_fonts__context-menu.main_ui_dashboard_fonts__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_fonts__dashboard-header .main_ui_dashboard_fonts__dashboard-header-options li.main_ui_dashboard_fonts__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_fonts__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_fonts__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_dashboard_fonts__dashboard-fonts {
  border-top: 0.0625rem solid var(--color-background-quaternary);
  display: flex;
  flex-direction: column;
  padding-left: 7.5rem;
  padding-bottom: 7.5rem;
  overflow-y: auto;
}
.main_ui_dashboard_fonts__dashboard-fonts .main_ui_dashboard_fonts__btn-primary {
  font-size: 0.6875rem;
  height: 2rem;
  min-width: 6.25rem;
}

.main_ui_dashboard_fonts__dashboard-installed-fonts {
  max-width: 62.5rem;
  width: 100%;
  display: flex;
  margin-top: var(--sp-xxl);
  flex-direction: column;
}
.main_ui_dashboard_fonts__dashboard-installed-fonts h3 {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
  margin: var(--sp-xs);
}
.main_ui_dashboard_fonts__dashboard-installed-fonts .main_ui_dashboard_fonts__font-item {
  color: var(--color-background-secondary);
}

.main_ui_dashboard_fonts__installed-fonts-header {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  align-items: center;
  color: var(--color-foreground-secondary);
  display: flex;
  height: 2.5rem;
  padding-left: var(--sp-xxl);
}
.main_ui_dashboard_fonts__installed-fonts-header > .main_ui_dashboard_fonts__family {
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  min-width: 12.5rem;
  width: 12.5rem;
}
.main_ui_dashboard_fonts__installed-fonts-header > .main_ui_dashboard_fonts__variants {
  padding-left: var(--sp-m);
}

.main_ui_dashboard_fonts__search-input {
  display: flex;
  flex-grow: 1;
  justify-content: flex-end;
}
.main_ui_dashboard_fonts__search-input input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  background-color: var(--color-background-tertiary);
  border-radius: 0.5rem;
  border: 0.0625rem solid transparent;
  color: var(--color-foreground-primary);
  height: 2rem;
  margin: 0;
  padding: 0 var(--sp-s);
  width: 9.5rem;
}
.main_ui_dashboard_fonts__search-input input:focus {
  outline: 0.0625rem solid var(--color-accent-primary);
}
.main_ui_dashboard_fonts__search-input input::-moz-placeholder {
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_fonts__search-input input::placeholder {
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_fonts__font-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  align-items: center;
  background-color: var(--color-background-tertiary);
  border-radius: 0.25rem;
  color: var(--color-foreground-secondary);
  display: flex;
  justify-content: space-between;
  margin-top: var(--sp-xs);
  max-width: 62.5rem;
  padding: var(--sp-m) var(--sp-xxl);
  width: 100%;
}
.main_ui_dashboard_fonts__font-item input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  border: 0.0625rem solid transparent;
  margin: 0;
  padding: var(--sp-s);
  background-color: var(--color-background-tertiary);
  border-radius: 0.5rem;
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_fonts__font-item input:focus {
  outline: 0.0625rem solid var(--color-accent-primary);
  overflow: visible;
  text-overflow: unset;
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__family {
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  min-width: 12.5rem;
  width: 12.5rem;
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__family.main_ui_dashboard_fonts__is-edition {
  overflow: visible;
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__filenames {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  min-width: 12.5rem;
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__variants {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: flex;
  flex-wrap: wrap;
  flex-grow: 1;
  padding-left: var(--sp-l);
  gap: 0.375rem;
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__variants .main_ui_dashboard_fonts__variant {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: var(--sp-s) var(--sp-m);
  cursor: pointer;
  gap: var(--sp-xs);
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__variants .main_ui_dashboard_fonts__variant .main_ui_dashboard_fonts__icon {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__variants .main_ui_dashboard_fonts__variant .main_ui_dashboard_fonts__icon svg {
  fill: none;
  width: 0.75rem;
  height: 0.75rem;
  transform: rotate(45deg);
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__variants .main_ui_dashboard_fonts__variant:hover .main_ui_dashboard_fonts__icon svg {
  stroke: var(--color-foreground-secondary);
}
.main_ui_dashboard_fonts__font-item > .main_ui_dashboard_fonts__variants .main_ui_dashboard_fonts__inhert-variant {
  cursor: default;
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__table-field {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__table-field .main_ui_dashboard_fonts__variant {
  background-color: var(--color-background-quaternary);
  border-radius: 0.5rem;
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__filenames {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  min-width: 25rem;
  padding-left: var(--sp-xxxl);
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options {
  display: flex;
  justify-content: flex-end;
  min-width: 11.25rem;
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options .main_ui_dashboard_fonts__icon {
  width: 1.5rem;
  cursor: pointer;
  display: flex;
  margin-left: var(--sp-m);
  justify-content: center;
  align-items: center;
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options .main_ui_dashboard_fonts__icon svg {
  width: 1rem;
  height: 1rem;
  stroke: var(--color-foreground-secondary);
  fill: none;
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options .main_ui_dashboard_fonts__icon.main_ui_dashboard_fonts__failure {
  margin-right: var(--sp-m);
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options .main_ui_dashboard_fonts__icon.main_ui_dashboard_fonts__failure svg {
  stroke: var(--element-foreground-warning);
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options .main_ui_dashboard_fonts__icon.main_ui_dashboard_fonts__close {
  background: none;
  border: none;
}
.main_ui_dashboard_fonts__font-item .main_ui_dashboard_fonts__options .main_ui_dashboard_fonts__icon.main_ui_dashboard_fonts__close svg {
  stroke: var(--color-foreground-secondary);
}

.main_ui_dashboard_fonts__dashboard-fonts-upload {
  max-width: 62.5rem;
  width: 100%;
  display: flex;
  flex-direction: column;
}
.main_ui_dashboard_fonts__dashboard-fonts-upload .main_ui_dashboard_fonts__upload-button {
  width: 6.25rem;
}
.main_ui_dashboard_fonts__dashboard-fonts-upload .main_ui_dashboard_fonts__btn-secondary {
  margin-left: var(--sp-m);
}

.main_ui_dashboard_fonts__dashboard-fonts-hero {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  padding: var(--sp-xxxl) 0;
  margin-top: 5rem;
  display: flex;
  justify-content: space-between;
}
.main_ui_dashboard_fonts__dashboard-fonts-hero .main_ui_dashboard_fonts__btn-primary {
  height: 2.5rem;
  width: 100%;
}
.main_ui_dashboard_fonts__dashboard-fonts-hero .main_ui_dashboard_fonts__desc {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
  color: var(--color-background-secondary);
  width: 31.25rem;
}
.main_ui_dashboard_fonts__dashboard-fonts-hero .main_ui_dashboard_fonts__desc h2 {
  color: var(--color-foreground-primary);
  font-weight: 400;
}
.main_ui_dashboard_fonts__dashboard-fonts-hero .main_ui_dashboard_fonts__desc p {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_fonts__dashboard-fonts-hero .main_ui_dashboard_fonts__btn-primary {
  flex-shrink: 0;
}

.main_ui_dashboard_fonts__fonts-placeholder {
  align-items: center;
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--color-background-quaternary);
  display: flex;
  flex-direction: column;
  height: 10rem;
  justify-content: center;
  margin-top: var(--sp-l);
  max-width: 62.5rem;
  width: 100%;
}
.main_ui_dashboard_fonts__fonts-placeholder .main_ui_dashboard_fonts__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 2rem;
  height: 2rem;
}
.main_ui_dashboard_fonts__fonts-placeholder .main_ui_dashboard_fonts__label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
}
@keyframes main_ui_dashboard_grid__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_grid__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_grid__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_grid__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_grid__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_grid__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_grid__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_grid__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_grid__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_grid__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_grid__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_grid__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_grid__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_grid__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_grid__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_grid__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_grid__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_grid__dashboard-grid {
  font-size: 0.875rem;
  height: 100%;
  overflow: hidden auto;
  padding: 0 var(--sp-l) 1rem;
}

.main_ui_dashboard_grid__grid-row {
  display: grid;
  grid-auto-flow: column;
  grid-auto-columns: calc(0.75rem + var(--th-width, 15.75rem));
  width: 100%;
  gap: 1.5rem;
}

.main_ui_dashboard_grid__grid-item {
  align-items: center;
  cursor: pointer;
  display: flex;
  flex-direction: column;
  margin: 0.75rem 0;
  position: relative;
  text-align: center;
}
.main_ui_dashboard_grid__grid-item a,
.main_ui_dashboard_grid__grid-item button {
  width: 100%;
  font-weight: 400;
}
.main_ui_dashboard_grid__grid-item button {
  background-color: transparent;
  border: none;
  padding: 0 0.375rem;
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__grid-item-th {
  border-radius: 8px;
  text-align: initial;
  width: var(--th-width, 15.75rem);
  height: var(--th-height, 10.5rem);
  background-size: cover;
  overflow: hidden;
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__grid-item-th img {
  -o-object-fit: contain;
     object-fit: contain;
}
.main_ui_dashboard_grid__grid-item.main_ui_dashboard_grid__dragged {
  border-radius: 4px;
  outline: 4px solid var(--color-accent-primary);
  text-align: initial;
  width: calc(var(--th-width) + 0.75rem);
  height: var(--th-height, 10.5rem);
}
.main_ui_dashboard_grid__grid-item.main_ui_dashboard_grid__overlay {
  border-radius: 4px;
  border: 0.125rem solid var(--color-accent-tertiary);
  height: 100%;
  opacity: 0;
  pointer-events: none;
  position: absolute;
  width: 100%;
  z-index: 1;
}
.main_ui_dashboard_grid__grid-item:hover .main_ui_dashboard_grid__overlay {
  display: block;
  opacity: 1;
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__info-wrapper {
  display: grid;
  grid-template-columns: 1fr auto;
  cursor: pointer;
  max-width: var(--th-width, 15.75rem);
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-info {
  display: grid;
  padding: 0.5rem;
  text-align: left;
  width: 100%;
  font-size: 0.75rem;
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-info h3 {
  border: 1px solid transparent;
  color: var(--color-foreground-primary);
  font-size: 1rem;
  font-weight: 400;
  height: 1.75rem;
  line-height: 1.92;
  max-width: 16.25rem;
  overflow: hidden;
  padding: 0;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 100%;
}
@media (max-width: 1366px) {
  .main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-info h3 {
    max-width: 14.5rem;
  }
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-info .main_ui_dashboard_grid__date {
  color: var(--color-foreground-secondary);
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
  white-space: nowrap;
  max-width: 16.25rem;
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-info .main_ui_dashboard_grid__date::first-letter {
  text-transform: capitalize;
}
@media (max-width: 1366px) {
  .main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-info .main_ui_dashboard_grid__date {
    max-width: 14.5rem;
  }
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-badge {
  background-color: var(--color-accent-primary);
  border: none;
  border-radius: 6px;
  position: absolute;
  top: 0.75rem;
  right: 0.75rem;
  height: 2rem;
  width: 2rem;
  display: flex;
  align-items: center;
  justify-content: center;
}
.main_ui_dashboard_grid__grid-item .main_ui_dashboard_grid__item-badge svg {
  stroke: var(--color-background-secondary);
  fill: none;
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_grid__grid-item.main_ui_dashboard_grid__add-file {
  border: 1px dashed var(--color-foreground-secondary);
  justify-content: center;
  box-shadow: none;
}
.main_ui_dashboard_grid__grid-item.main_ui_dashboard_grid__add-file span {
  color: var(--color-background-primary);
  font-size: 0.875rem;
}
.main_ui_dashboard_grid__grid-item.main_ui_dashboard_grid__add-file:hover {
  background-color: var(--color-foreground-primary);
  border: 0.125rem solid var(--color-accent-tertiary);
}

.main_ui_dashboard_grid__drag-counter {
  position: absolute;
  top: 0.25rem;
  left: 0.25rem;
  width: 2rem;
  height: 2rem;
  background-color: var(--color-accent-tertiary);
  border-radius: 50%;
  color: var(--color-background-secondary);
  font-size: 1rem;
  display: flex;
  justify-content: center;
  align-items: center;
}

.main_ui_dashboard_grid__project-th {
  background-color: transparent;
  border-radius: 8px;
  padding-top: 0.375rem;
}
.main_ui_dashboard_grid__project-th:hover, .main_ui_dashboard_grid__project-th:focus, .main_ui_dashboard_grid__project-th:focus-within {
  background-color: var(--color-background-tertiary);
}
.main_ui_dashboard_grid__project-th:hover .main_ui_dashboard_grid__project-th-actions, .main_ui_dashboard_grid__project-th:focus .main_ui_dashboard_grid__project-th-actions, .main_ui_dashboard_grid__project-th:focus-within .main_ui_dashboard_grid__project-th-actions {
  opacity: 1;
}
.main_ui_dashboard_grid__project-th:hover a, .main_ui_dashboard_grid__project-th:focus a, .main_ui_dashboard_grid__project-th:focus-within a {
  text-decoration: none;
}
.main_ui_dashboard_grid__project-th .main_ui_dashboard_grid__selected .main_ui_dashboard_grid__grid-item-th {
  outline: 0.25rem solid var(--color-accent-tertiary);
}

.main_ui_dashboard_grid__project-th-actions {
  align-items: center;
  display: flex;
  height: 100%;
  justify-content: center;
  opacity: 0;
  right: 0.375rem;
  width: 2rem;
}
.main_ui_dashboard_grid__project-th-actions span {
  color: var(--color-background-secondary);
}

.main_ui_dashboard_grid__project-th-icon {
  align-items: center;
  display: flex;
  margin-right: 0.5rem;
  margin-top: 0;
}

.main_ui_dashboard_grid__menu {
  align-items: flex-end;
  display: flex;
  flex-direction: column;
  height: 2rem;
  justify-content: center;
  margin-right: 0;
  margin-top: 1.25rem;
  width: 100%;
  --menu-icon-color: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_grid__menu:hover, .main_ui_dashboard_grid__menu:focus {
  --menu-icon-color: var(--button-tertiary-foreground-color-hover);
}

.main_ui_dashboard_grid__menu-icon {
  stroke: var(--menu-icon-color);
  fill: none;
  margin-right: 0;
  height: 1rem;
  width: 1rem;
}

.main_ui_dashboard_grid__project-th-actions.main_ui_dashboard_grid__force-display {
  opacity: 1;
}

.main_ui_dashboard_grid__grid-item-th {
  border-radius: 4px;
  cursor: pointer;
  height: 100%;
  overflow: hidden;
  position: relative;
  width: 100%;
  display: flex;
  justify-content: center;
  flex-direction: row;
}
.main_ui_dashboard_grid__grid-item-th .main_ui_dashboard_grid__img-th {
  height: auto;
  width: 100%;
}

.main_ui_dashboard_grid__library {
  height: 36.25rem;
}

.main_ui_dashboard_grid__grid-item.main_ui_dashboard_grid__project-th.main_ui_dashboard_grid__library {
  height: 38.25rem;
}

.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library {
  background-color: var(--color-background-tertiary);
  flex-direction: column;
  height: 90%;
  justify-content: flex-start;
  max-height: 36.25rem;
  padding: 2rem;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-section {
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-section:not(:first-child) {
  margin-top: 1rem;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-title {
  display: flex;
  font-size: 0.75rem;
  text-transform: uppercase;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-title .main_ui_dashboard_grid__num-assets {
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item {
  align-items: center;
  border-radius: 4px;
  border: 1px solid transparent;
  color: var(--color-foreground-primary);
  display: flex;
  font-size: 0.75rem;
  margin-top: 0.25rem;
  padding: 0.125rem;
  position: relative;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item .main_ui_dashboard_grid__name-block {
  color: var(--color-foreground-secondary);
  width: calc(100% - 1.5rem - 0.5rem);
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item .main_ui_dashboard_grid__item-name {
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item svg {
  background-color: var(--color-canvas);
  border-radius: 4px;
  border: 0.125rem solid transparent;
  height: 1.5rem;
  margin-right: 0.5rem;
  width: 1.5rem;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item .main_ui_dashboard_grid__color-name {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item .main_ui_dashboard_grid__color-value {
  color: var(--color-foreground-secondary);
  margin-left: 0.25rem;
  text-transform: uppercase;
}
.main_ui_dashboard_grid__grid-item-th.main_ui_dashboard_grid__library .main_ui_dashboard_grid__asset-list-item .main_ui_dashboard_grid__typography-sample {
  height: 1.25rem;
  margin-right: 0.25rem;
  width: 1.25rem;
}

.main_ui_dashboard_grid__color-item {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 0.5rem;
}

.main_ui_dashboard_grid__grid-loader {
  --icon-width: calc(var(--th-width, 15.75rem) * 0.25);
}

.main_ui_dashboard_grid__deleted-item {
  opacity: 0.5;
}
@keyframes main_ui_dashboard_import__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_import__accept-btn.main_ui_dashboard_import__danger, .main_ui_dashboard_import__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_import__accept-btn.main_ui_dashboard_import__danger svg, .main_ui_dashboard_import__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_import__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_import__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_import__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_import__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_import__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_import__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_import__accept-btn.disabled, [disabled].main_ui_dashboard_import__accept-btn, .main_ui_dashboard_import__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_import__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_import__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_import__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_import__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_import__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_import__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_import__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_import__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_import__cancel-button.disabled, [disabled].main_ui_dashboard_import__cancel-button, .main_ui_dashboard_import__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button, .main_ui_dashboard_import__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button svg, .main_ui_dashboard_import__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:focus-visible, .main_ui_dashboard_import__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:focus-visible svg, .main_ui_dashboard_import__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:hover, .main_ui_dashboard_import__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:hover svg, .main_ui_dashboard_import__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:active, .main_ui_dashboard_import__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:active svg, .main_ui_dashboard_import__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button.disabled, .main_ui_dashboard_import__modal-close-btn.disabled, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button[disabled], [disabled].main_ui_dashboard_import__modal-close-btn, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:disabled, .main_ui_dashboard_import__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button.disabled svg, .main_ui_dashboard_import__modal-close-btn.disabled svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button[disabled] svg, [disabled].main_ui_dashboard_import__modal-close-btn svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button:disabled svg, .main_ui_dashboard_import__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_dashboard_import__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_import__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_import__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_import__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_import__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_import__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_import__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_import__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_import__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__linked-library .main_ui_dashboard_import__linked-library-tag svg, .main_ui_dashboard_import__modal-close-btn svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-label .main_ui_dashboard_import__icon svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit span svg,
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit label svg, .main_ui_dashboard_import__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-label .main_ui_dashboard_import__icon svg, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit span svg,
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit label svg, .main_ui_dashboard_import__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_import__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_import__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_dashboard_import__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit span,
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit label, .main_ui_dashboard_import__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit {
  display: flex;
  align-items: center;
  height: 2rem;
  border-radius: 8px;
  background-color: var(--input-background-color);
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit span svg,
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit label svg {
  stroke: var(--input-foreground-color);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit ::-moz-placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit ::placeholder {
  color: var(--input-placeholder-color);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:hover {
  border: 1px solid var(--input-border-color-hover);
  background-color: var(--input-background-color-hover);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:hover span {
  color: var(--input-foreground-color-hover);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:hover input {
  color: var(--input-foreground-color-hover);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:active {
  border: 1px solid var(--input-border-color-active);
  background-color: var(--input-background-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:active span {
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:active input {
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus span, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within span {
  color: var(--input-foreground-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus input, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within input {
  color: var(--input-foreground-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus:hover, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within:hover {
  border: 1px solid var(--input-border-color-focus);
  background-color: var(--input-background-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus:hover span, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within:hover span {
  color: var(--input-foreground-color-focus);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus:hover input, .main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit:focus-within:hover input {
  color: var(--input-foreground-color-focus);
}

.main_ui_dashboard_import__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_dashboard_import__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_dashboard_import__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_dashboard_import__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_import__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_dashboard_import__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_import__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_import__accept-btn.main_ui_dashboard_import__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_dashboard_import__modal-container {
  display: flex;
  flex-direction: column;
}

.main_ui_dashboard_import__modal-header {
  margin-bottom: 1.5rem;
}

.main_ui_dashboard_import__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_dashboard_import__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  flex: 1;
  overflow: hidden auto;
  display: grid;
  grid-template-columns: 1fr;
  gap: 1rem;
  margin-bottom: 1.5rem;
  min-height: 40px;
}

.main_ui_dashboard_import__status-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  font-style: italic;
}

.main_ui_dashboard_import__modal-scd-msg,
.main_ui_dashboard_import__modal-subtitle,
.main_ui_dashboard_import__modal-msg {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-text-foreground-color);
  line-height: 1.5;
}

.main_ui_dashboard_import__file-entry {
  display: flex;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon.main_ui_dashboard_import__icon-fill svg {
  fill: var(--icon-foreground);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-edit {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  flex-grow: 1;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.75rem;
  flex-grow: 1;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-label .main_ui_dashboard_import__icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-name-label .main_ui_dashboard_import__icon svg {
  stroke: var(--icon-foreground);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons {
  display: flex;
  align-items: center;
  gap: 0.25rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button {
  width: 1.75rem;
  height: 2rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__file-name .main_ui_dashboard_import__edit-entry-buttons button svg {
  stroke: var(--icon-foreground);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__error-message,
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__progress-message {
  display: flex;
  align-items: center;
  min-height: 2rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__error-message {
  align-items: flex-start;
  white-space: pre-wrap;
  overflow-wrap: anywhere;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__linked-library {
  display: flex;
  align-items: center;
  gap: 0.75rem;
  color: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__linked-library .main_ui_dashboard_import__linked-library-tag {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1.5rem;
  width: 1.5rem;
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__linked-library .main_ui_dashboard_import__linked-library-tag svg {
  stroke: var(--icon-foreground);
}
.main_ui_dashboard_import__file-entry .main_ui_dashboard_import__linked-library .main_ui_dashboard_import__linked-library-tag.main_ui_dashboard_import__error svg {
  stroke: var(--element-foreground-error);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__loading .main_ui_dashboard_import__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__warning .main_ui_dashboard_import__file-name {
  color: var(--element-foreground-warning);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__warning .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon svg {
  stroke: var(--element-foreground-warning);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__warning .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon.main_ui_dashboard_import__icon-fill svg {
  fill: var(--element-foreground-warning);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__success .main_ui_dashboard_import__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__success .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__success .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon.main_ui_dashboard_import__icon-fill svg {
  fill: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__error .main_ui_dashboard_import__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__error .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__error .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon.main_ui_dashboard_import__icon-fill svg {
  fill: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__editable .main_ui_dashboard_import__file-name {
  color: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__editable .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon svg {
  stroke: var(--modal-text-foreground-color);
}
.main_ui_dashboard_import__file-entry.main_ui_dashboard_import__editable .main_ui_dashboard_import__file-name .main_ui_dashboard_import__file-icon.main_ui_dashboard_import__icon-fill svg {
  fill: var(--modal-text-foreground-color);
}

.main_ui_dashboard_import__context-notification-error {
  --context-notification-bg-color: var(--modal-background-color);
}

.main_ui_dashboard_import__import-error-disclaimer {
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_import__import-error-list {
  padding: 0 var(--sp-l);
  list-style: disc;
}

.main_ui_dashboard_import__import-error-list-enry {
  padding: var(--sp-xs) 0;
}

.main_ui_dashboard_import__import-error-detail {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  margin-top: var(--sp-xs);
  color: var(--modal-text-foreground-color);
  white-space: pre-wrap;
  overflow-wrap: anywhere;
}
@keyframes main_ui_dashboard_inline_edition__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_inline_edition__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_inline_edition__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_inline_edition__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_inline_edition__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_inline_edition__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_inline_edition__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_inline_edition__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_inline_edition__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_inline_edition__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_inline_edition__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_inline_edition__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_inline_edition__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_inline_edition__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_inline_edition__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_inline_edition__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_inline_edition__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_inline_edition__edit-wrapper {
  border-radius: 4px;
  display: flex;
  padding-right: 1.5rem;
  position: relative;
  margin-right: 1.5rem;
}

input.main_ui_dashboard_inline_edition__element-title {
  background-color: var(--input-background-color-active);
  border-radius: 8px;
  color: var(--color-foreground-primary);
  font-size: 1rem;
  height: 2rem;
  margin: 0;
  border: none;
  padding: 0.375rem;
  width: 100%;
}
input.main_ui_dashboard_inline_edition__element-title:focus-visible {
  border: 1px solid var(--color-accent-primary);
  outline: none;
}

.main_ui_dashboard_inline_edition__close {
  cursor: pointer;
  position: absolute;
  top: 1px;
  right: calc(-1 * 0.5rem);
}
.main_ui_dashboard_inline_edition__close svg {
  fill: var(--color-foreground-secondary);
  height: 1rem;
  transform: rotate(45deg) translateY(7px);
  width: 1rem;
  margin: 0;
}
.main_ui_dashboard_inline_edition__close:hover svg {
  fill: var(--element-foreground-warning);
}
@keyframes main_ui_dashboard_libraries__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_libraries__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_libraries__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_libraries__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_libraries__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_libraries__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_libraries__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_libraries__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_libraries__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_libraries__btn-primary.disabled, [disabled].main_ui_dashboard_libraries__btn-primary, .main_ui_dashboard_libraries__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_libraries__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_libraries__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_libraries__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_libraries__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_libraries__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_libraries__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_libraries__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_libraries__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_libraries__btn-secondary.disabled, [disabled].main_ui_dashboard_libraries__btn-secondary, .main_ui_dashboard_libraries__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_libraries__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_libraries__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_libraries__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_libraries__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_libraries__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_libraries__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_libraries__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_libraries__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_libraries__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_libraries__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_libraries__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_libraries__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_libraries__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_libraries__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_libraries__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_libraries__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_libraries__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_libraries__dashboard-header.main_ui_dashboard_libraries__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_libraries__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_libraries__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_libraries__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_libraries__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-title .main_ui_dashboard_libraries__context-menu.main_ui_dashboard_libraries__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_libraries__dashboard-header .main_ui_dashboard_libraries__dashboard-header-options li.main_ui_dashboard_libraries__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_libraries__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_libraries__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

.main_ui_dashboard_libraries__dashboard-container {
  flex: 1 0 0;
  margin-right: 1rem;
  overflow-y: auto;
  width: 100%;
  border-top: 1px solid var(--color-background-quaternary);
}
.main_ui_dashboard_libraries__dashboard-container.main_ui_dashboard_libraries__dashboard-projects {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_libraries__dashboard-container.main_ui_dashboard_libraries__search {
  margin-top: 0.75rem;
}
@keyframes main_ui_dashboard_pin_button__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_pin_button__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_pin_button__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_pin_button__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_pin_button__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_pin_button__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_pin_button__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_pin_button__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_pin_button__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_pin_button__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_pin_button__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_pin_button__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_pin_button__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_pin_button__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_pin_button__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_pin_button__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_pin_button__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_pin_button__button {
  --pin-button-icon-color: var(--button-icon-foreground-color);
  --pin-button-bg-color: none;
  --pin-button-border-color: none;
  width: 2rem;
  height: 2rem;
  background: var(--pin-button-bg-color);
  border: 0.125rem solid var(--pin-button-border-color);
  border-radius: 8px;
  display: grid;
  place-content: center;
  cursor: pointer;
}

.main_ui_dashboard_pin_button__button-active {
  --pin-button-icon-color: var(--button-icon-foreground-color-selected);
  --pin-button-bg-color: var(--button-icon-background-color-selected);
  --pin-button-border-color: var(--button-icon-border-color-selected);
}

.main_ui_dashboard_pin_button__icon {
  width: 1rem;
  height: 1rem;
  fill: none;
  stroke: var(--pin-button-icon-color);
}
@keyframes main_ui_dashboard_placeholder__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_placeholder__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_placeholder__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_placeholder__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_placeholder__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_placeholder__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_placeholder__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_placeholder__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_placeholder__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_placeholder__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_placeholder__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_placeholder__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_placeholder__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_placeholder__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_placeholder__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_placeholder__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_placeholder__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_placeholder__dashboard-grid {
  font-size: 0.875rem;
  height: 100%;
  overflow: hidden auto;
  padding: 0 var(--sp-l) 1rem;
}

.main_ui_dashboard_placeholder__grid-row {
  display: grid;
  grid-auto-flow: column;
  grid-auto-columns: calc(0.75rem + var(--th-width, 15.75rem));
  width: 100%;
  gap: 1.5rem;
}

.main_ui_dashboard_placeholder__grid-item {
  align-items: center;
  cursor: pointer;
  display: flex;
  flex-direction: column;
  margin: 0.75rem 0;
  position: relative;
  text-align: center;
}
.main_ui_dashboard_placeholder__grid-item a,
.main_ui_dashboard_placeholder__grid-item button {
  width: 100%;
  font-weight: 400;
}
.main_ui_dashboard_placeholder__grid-item button {
  background-color: transparent;
  border: none;
  padding: 0 0.375rem;
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__grid-item-th {
  border-radius: 8px;
  text-align: initial;
  width: var(--th-width, 15.75rem);
  height: var(--th-height, 10.5rem);
  background-size: cover;
  overflow: hidden;
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__grid-item-th img {
  -o-object-fit: contain;
     object-fit: contain;
}
.main_ui_dashboard_placeholder__grid-item.main_ui_dashboard_placeholder__dragged {
  border-radius: 4px;
  outline: 4px solid var(--color-accent-primary);
  text-align: initial;
  width: calc(var(--th-width) + 0.75rem);
  height: var(--th-height, 10.5rem);
}
.main_ui_dashboard_placeholder__grid-item.main_ui_dashboard_placeholder__overlay {
  border-radius: 4px;
  border: 0.125rem solid var(--color-accent-tertiary);
  height: 100%;
  opacity: 0;
  pointer-events: none;
  position: absolute;
  width: 100%;
  z-index: 1;
}
.main_ui_dashboard_placeholder__grid-item:hover .main_ui_dashboard_placeholder__overlay {
  display: block;
  opacity: 1;
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__info-wrapper {
  display: grid;
  grid-template-columns: 1fr auto;
  cursor: pointer;
  max-width: var(--th-width, 15.75rem);
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-info {
  display: grid;
  padding: 0.5rem;
  text-align: left;
  width: 100%;
  font-size: 0.75rem;
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-info h3 {
  border: 1px solid transparent;
  color: var(--color-foreground-primary);
  font-size: 1rem;
  font-weight: 400;
  height: 1.75rem;
  line-height: 1.92;
  max-width: 16.25rem;
  overflow: hidden;
  padding: 0;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 100%;
}
@media (max-width: 1366px) {
  .main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-info h3 {
    max-width: 14.5rem;
  }
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-info .main_ui_dashboard_placeholder__date {
  color: var(--color-foreground-secondary);
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
  white-space: nowrap;
  max-width: 16.25rem;
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-info .main_ui_dashboard_placeholder__date::first-letter {
  text-transform: capitalize;
}
@media (max-width: 1366px) {
  .main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-info .main_ui_dashboard_placeholder__date {
    max-width: 14.5rem;
  }
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-badge {
  background-color: var(--color-accent-primary);
  border: none;
  border-radius: 6px;
  position: absolute;
  top: 0.75rem;
  right: 0.75rem;
  height: 2rem;
  width: 2rem;
  display: flex;
  align-items: center;
  justify-content: center;
}
.main_ui_dashboard_placeholder__grid-item .main_ui_dashboard_placeholder__item-badge svg {
  stroke: var(--color-background-secondary);
  fill: none;
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_placeholder__grid-item.main_ui_dashboard_placeholder__add-file {
  border: 1px dashed var(--color-foreground-secondary);
  justify-content: center;
  box-shadow: none;
}
.main_ui_dashboard_placeholder__grid-item.main_ui_dashboard_placeholder__add-file span {
  color: var(--color-background-primary);
  font-size: 0.875rem;
}
.main_ui_dashboard_placeholder__grid-item.main_ui_dashboard_placeholder__add-file:hover {
  background-color: var(--color-foreground-primary);
  border: 0.125rem solid var(--color-accent-tertiary);
}

.main_ui_dashboard_placeholder__drag-counter {
  position: absolute;
  top: 0.25rem;
  left: 0.25rem;
  width: 2rem;
  height: 2rem;
  background-color: var(--color-accent-tertiary);
  border-radius: 50%;
  color: var(--color-background-secondary);
  font-size: 1rem;
  display: flex;
  justify-content: center;
  align-items: center;
}

.main_ui_dashboard_placeholder__project-th {
  background-color: transparent;
  border-radius: 8px;
  padding-top: 0.375rem;
}
.main_ui_dashboard_placeholder__project-th:hover, .main_ui_dashboard_placeholder__project-th:focus, .main_ui_dashboard_placeholder__project-th:focus-within {
  background-color: var(--color-background-tertiary);
}
.main_ui_dashboard_placeholder__project-th:hover .main_ui_dashboard_placeholder__project-th-actions, .main_ui_dashboard_placeholder__project-th:focus .main_ui_dashboard_placeholder__project-th-actions, .main_ui_dashboard_placeholder__project-th:focus-within .main_ui_dashboard_placeholder__project-th-actions {
  opacity: 1;
}
.main_ui_dashboard_placeholder__project-th:hover a, .main_ui_dashboard_placeholder__project-th:focus a, .main_ui_dashboard_placeholder__project-th:focus-within a {
  text-decoration: none;
}
.main_ui_dashboard_placeholder__project-th .main_ui_dashboard_placeholder__selected .main_ui_dashboard_placeholder__grid-item-th {
  outline: 0.25rem solid var(--color-accent-tertiary);
}

.main_ui_dashboard_placeholder__project-th-actions {
  align-items: center;
  display: flex;
  height: 100%;
  justify-content: center;
  opacity: 0;
  right: 0.375rem;
  width: 2rem;
}
.main_ui_dashboard_placeholder__project-th-actions span {
  color: var(--color-background-secondary);
}

.main_ui_dashboard_placeholder__project-th-icon {
  align-items: center;
  display: flex;
  margin-right: 0.5rem;
  margin-top: 0;
}

.main_ui_dashboard_placeholder__menu {
  align-items: flex-end;
  display: flex;
  flex-direction: column;
  height: 2rem;
  justify-content: center;
  margin-right: 0;
  margin-top: 1.25rem;
  width: 100%;
  --menu-icon-color: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_placeholder__menu:hover, .main_ui_dashboard_placeholder__menu:focus {
  --menu-icon-color: var(--button-tertiary-foreground-color-hover);
}

.main_ui_dashboard_placeholder__menu-icon {
  stroke: var(--menu-icon-color);
  fill: none;
  margin-right: 0;
  height: 1rem;
  width: 1rem;
}

.main_ui_dashboard_placeholder__project-th-actions.main_ui_dashboard_placeholder__force-display {
  opacity: 1;
}

.main_ui_dashboard_placeholder__grid-item-th {
  border-radius: 4px;
  cursor: pointer;
  height: 100%;
  overflow: hidden;
  position: relative;
  width: 100%;
  display: flex;
  justify-content: center;
  flex-direction: row;
}
.main_ui_dashboard_placeholder__grid-item-th .main_ui_dashboard_placeholder__img-th {
  height: auto;
  width: 100%;
}

.main_ui_dashboard_placeholder__library {
  height: 36.25rem;
}

.main_ui_dashboard_placeholder__grid-item.main_ui_dashboard_placeholder__project-th.main_ui_dashboard_placeholder__library {
  height: 38.25rem;
}

.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library {
  background-color: var(--color-background-tertiary);
  flex-direction: column;
  height: 90%;
  justify-content: flex-start;
  max-height: 36.25rem;
  padding: 2rem;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-section {
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-section:not(:first-child) {
  margin-top: 1rem;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-title {
  display: flex;
  font-size: 0.75rem;
  text-transform: uppercase;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-title .main_ui_dashboard_placeholder__num-assets {
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item {
  align-items: center;
  border-radius: 4px;
  border: 1px solid transparent;
  color: var(--color-foreground-primary);
  display: flex;
  font-size: 0.75rem;
  margin-top: 0.25rem;
  padding: 0.125rem;
  position: relative;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item .main_ui_dashboard_placeholder__name-block {
  color: var(--color-foreground-secondary);
  width: calc(100% - 1.5rem - 0.5rem);
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item .main_ui_dashboard_placeholder__item-name {
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item svg {
  background-color: var(--color-canvas);
  border-radius: 4px;
  border: 0.125rem solid transparent;
  height: 1.5rem;
  margin-right: 0.5rem;
  width: 1.5rem;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item .main_ui_dashboard_placeholder__color-name {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item .main_ui_dashboard_placeholder__color-value {
  color: var(--color-foreground-secondary);
  margin-left: 0.25rem;
  text-transform: uppercase;
}
.main_ui_dashboard_placeholder__grid-item-th.main_ui_dashboard_placeholder__library .main_ui_dashboard_placeholder__asset-list-item .main_ui_dashboard_placeholder__typography-sample {
  height: 1.25rem;
  margin-right: 0.25rem;
  width: 1.25rem;
}

.main_ui_dashboard_placeholder__color-item {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 0.5rem;
}

.main_ui_dashboard_placeholder__grid-loader {
  --icon-width: calc(var(--th-width, 15.75rem) * 0.25);
}

.main_ui_dashboard_placeholder__deleted-item {
  opacity: 0.5;
}

.main_ui_dashboard_placeholder__grid-empty-placeholder {
  border-radius: 12px;
  display: grid;
  padding: 0.75rem 0;
}
.main_ui_dashboard_placeholder__grid-empty-placeholder.main_ui_dashboard_placeholder__libs {
  background-image: url("/images/ph-left.svg"), url("/images/ph-right.svg");
  background-position: 15% bottom, 85% top;
  background-repeat: no-repeat;
  align-items: center;
  border: 1px solid var(--color-background-quaternary);
  border-radius: 4px;
  display: flex;
  flex-direction: column;
  height: 12.5rem;
  margin: 1rem;
  padding: 3rem;
  justify-content: center;
}
.main_ui_dashboard_placeholder__grid-empty-placeholder.main_ui_dashboard_placeholder__libs .main_ui_dashboard_placeholder__text a {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_placeholder__grid-empty-placeholder.main_ui_dashboard_placeholder__libs .main_ui_dashboard_placeholder__text p {
  max-width: 22.5rem;
  text-align: center;
  font-size: 1rem;
}
.main_ui_dashboard_placeholder__grid-empty-placeholder .main_ui_dashboard_placeholder__create-new {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  color: var(--color-foreground-primary);
  cursor: pointer;
  margin: 0.5rem;
  border: 0.125rem solid transparent;
  width: var(--th-width, 15.75rem);
  height: var(--th-height, 10.5rem);
}
.main_ui_dashboard_placeholder__grid-empty-placeholder .main_ui_dashboard_placeholder__create-new svg {
  width: 2rem;
  height: 2rem;
  stroke: var(--color-foreground-secondary);
}
.main_ui_dashboard_placeholder__grid-empty-placeholder .main_ui_dashboard_placeholder__create-new:hover {
  border: 0.125rem solid var(--color-accent-tertiary);
  background-color: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_dashboard_placeholder__grid-empty-placeholder .main_ui_dashboard_placeholder__create-new:hover svg {
  stroke: var(--color-accent-tertiary);
}
.main_ui_dashboard_placeholder__grid-empty-placeholder .main_ui_dashboard_placeholder__text {
  margin-top: 0.75rem;
  color: var(--color-foreground-secondary);
  font-size: 1rem;
}

.main_ui_dashboard_placeholder__placeholder-loader {
  display: flex;
  flex-direction: column;
  justify-content: center;
  row-gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) 0 var(--sp-m) 0;
}

.main_ui_dashboard_placeholder__placeholder-text {
  color: var(--color-foreground-secondary);
  font-size: 1rem;
  text-align: center;
}

.main_ui_dashboard_placeholder__placeholder-markdown {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}
.main_ui_dashboard_placeholder__placeholder-markdown a {
  color: var(--color-accent-primary);
}

.main_ui_dashboard_placeholder__empty-placeholder-libraries {
  margin: 1rem;
}

.main_ui_dashboard_placeholder__empty-project-container {
  width: 100%;
  display: grid;
  gap: 1rem;
  grid-template-columns: 1fr 1fr 1fr;
  margin-top: 0.75rem;
}

.main_ui_dashboard_placeholder__empty-project-card {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  --color-card-background: var(--color-background-tertiary);
  --color-card-title: var(--color-foreground-primary);
  --color-card-subtitle: var(--color-foreground-secondary);
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  background-color: var(--color-card-background);
  border: 0.125rem solid var(--color-background-quaternary);
  border-radius: 8px;
  padding: var(--sp-m) 0;
}
.main_ui_dashboard_placeholder__empty-project-card:hover {
  --color-card-background: var(--color-accent-primary);
  --color-card-title: var(--color-background-secondary);
  --color-card-subtitle: var(--color-background-secondary);
  cursor: pointer;
}
.main_ui_dashboard_placeholder__empty-project-card:hover .main_ui_dashboard_placeholder__empty-project-card-title {
  font-weight: 500;
}
.main_ui_dashboard_placeholder__empty-project-card {
  flex-grow: 1;
}

.main_ui_dashboard_placeholder__empty-project-card-title {
  color: var(--color-card-title);
}

.main_ui_dashboard_placeholder__empty-project-card-subtitle {
  color: var(--color-card-subtitle);
}
@keyframes main_ui_dashboard_projects__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_projects__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_projects__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_projects__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_projects__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_projects__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_projects__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_projects__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_projects__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_projects__btn-primary.disabled, [disabled].main_ui_dashboard_projects__btn-primary, .main_ui_dashboard_projects__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_projects__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_projects__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_projects__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_projects__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_projects__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_projects__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_projects__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_projects__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_projects__btn-secondary.disabled, [disabled].main_ui_dashboard_projects__btn-secondary, .main_ui_dashboard_projects__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_projects__add-file-btn,
.main_ui_dashboard_projects__options-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_dashboard_projects__add-file-btn svg,
.main_ui_dashboard_projects__options-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_projects__add-file-btn:focus-visible,
.main_ui_dashboard_projects__options-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_projects__add-file-btn:focus-visible svg,
.main_ui_dashboard_projects__options-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_projects__add-file-btn:hover,
.main_ui_dashboard_projects__options-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_dashboard_projects__add-file-btn:hover svg,
.main_ui_dashboard_projects__options-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_dashboard_projects__add-file-btn:active,
.main_ui_dashboard_projects__options-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_projects__add-file-btn:active svg,
.main_ui_dashboard_projects__options-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_projects__add-file-btn.disabled,
.main_ui_dashboard_projects__options-btn.disabled, [disabled].main_ui_dashboard_projects__add-file-btn,
[disabled].main_ui_dashboard_projects__options-btn, .main_ui_dashboard_projects__add-file-btn:disabled,
.main_ui_dashboard_projects__options-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_dashboard_projects__add-file-btn.disabled svg,
.main_ui_dashboard_projects__options-btn.disabled svg, [disabled].main_ui_dashboard_projects__add-file-btn svg,
[disabled].main_ui_dashboard_projects__options-btn svg, .main_ui_dashboard_projects__add-file-btn:disabled svg,
.main_ui_dashboard_projects__options-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_dashboard_projects__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_projects__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_projects__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_projects__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_projects__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_projects__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_projects__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_projects__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_projects__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_projects__add-icon,
.main_ui_dashboard_projects__menu-icon, .main_ui_dashboard_projects__close-icon, .main_ui_dashboard_projects__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_projects__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_projects__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_projects__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_projects__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_projects__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_projects__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_projects__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_projects__dashboard-header.main_ui_dashboard_projects__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_projects__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_projects__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_projects__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_projects__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-title .main_ui_dashboard_projects__context-menu.main_ui_dashboard_projects__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_projects__dashboard-header .main_ui_dashboard_projects__dashboard-header-options li.main_ui_dashboard_projects__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_projects__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_projects__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_dashboard_projects__dashboard-container {
  flex: 1 0 0;
  inline-size: 100%;
  margin-inline-end: var(--sp-l);
  border-block-start: 0.0625rem solid var(--panel-border-color);
  overflow-y: auto;
}

.main_ui_dashboard_projects__dashboard-projects {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  block-size: calc(100vh - 5rem);
}

.main_ui_dashboard_projects__with-team-hero {
  block-size: calc(100vh - 22.5rem);
}

.main_ui_dashboard_projects__dashboard-shared {
  inline-size: calc(100vw - 20rem);
  margin-inline-end: 3.25rem;
}

.main_ui_dashboard_projects__search {
  margin-block-start: var(--sp-m);
}

.main_ui_dashboard_projects__dashboard-project-row {
  --actions-opacity: 0;
  margin-block-end: var(--sp-xxl);
  position: relative;
}
.main_ui_dashboard_projects__dashboard-project-row:hover, .main_ui_dashboard_projects__dashboard-project-row:focus, .main_ui_dashboard_projects__dashboard-project-row:focus-within {
  --actions-opacity: 1;
}

.main_ui_dashboard_projects__pinned-project {
  --actions-opacity: 1;
}

.main_ui_dashboard_projects__projects-container {
  display: grid;
  grid-auto-rows: min-content;
}

.main_ui_dashboard_projects__project {
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-between;
  gap: var(--sp-s);
  inline-size: 99%;
  max-block-size: 2.5rem;
  padding: var(--sp-s) var(--sp-s) var(--sp-s) var(--sp-l);
  margin-block-start: var(--sp-l);
  border-radius: 0.25rem;
}

.main_ui_dashboard_projects__project-name-wrapper {
  display: flex;
  align-items: center;
  justify-content: flex-start;
  inline-size: 100%;
  min-block-size: 2rem;
  margin-inline-start: var(--sp-s);
}

.main_ui_dashboard_projects__project-name {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--title-foreground-color-hover);
  cursor: pointer;
  block-size: 1rem;
  line-height: 0.8;
  margin-inline-end: var(--sp-m);
}

.main_ui_dashboard_projects__info-wrapper {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_dashboard_projects__info,
.main_ui_dashboard_projects__recent-files-row-title-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--title-foreground-color);
}
@media (width <= 760px) {
  .main_ui_dashboard_projects__info,
  .main_ui_dashboard_projects__recent-files-row-title-info {
    display: none;
  }
}

.main_ui_dashboard_projects__project-actions {
  display: flex;
  opacity: var(--actions-opacity);
  margin-inline-start: var(--sp-xxxl);
}

.main_ui_dashboard_projects__add-file-btn,
.main_ui_dashboard_projects__options-btn {
  block-size: 2rem;
  inline-size: 2rem;
  margin: 0 var(--sp-s);
  padding: var(--sp-s);
}

.main_ui_dashboard_projects__add-icon,
.main_ui_dashboard_projects__menu-icon {
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_projects__grid-container {
  inline-size: 100%;
  padding: 0 var(--sp-xs);
}

.main_ui_dashboard_projects__placeholder-placement {
  margin: var(--sp-l) var(--sp-xxxl);
}

.main_ui_dashboard_projects__show-more {
  --show-more-color: var(--button-secondary-foreground-color-rest);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  border: none;
  background: none;
  cursor: pointer;
  position: absolute;
  inset-block-start: var(--sp-s);
  inset-inline-end: 3.25rem;
  display: flex;
  align-items: center;
  justify-content: space-between;
  -moz-column-gap: var(--sp-m);
       column-gap: var(--sp-m);
  color: var(--show-more-color);
}
.main_ui_dashboard_projects__show-more:hover {
  --show-more-color: var(--button-secondary-foreground-color-active);
}

.main_ui_dashboard_projects__show-more-icon {
  block-size: 1rem;
  inline-size: 1rem;
  fill: none;
  stroke: var(--show-more-color);
}

.main_ui_dashboard_projects__team-hero {
  background-color: var(--color-background-tertiary);
  border-radius: 0.5rem;
  border: none;
  display: flex;
  margin: var(--sp-l);
  padding: var(--sp-s);
  position: relative;
}
.main_ui_dashboard_projects__team-hero img {
  border-radius: 0.25rem;
  inline-size: auto;
}
@media (width <= 1200px) {
  .main_ui_dashboard_projects__team-hero img {
    display: none;
    inline-size: 0;
  }
}

.main_ui_dashboard_projects__text {
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  flex-grow: 1;
  padding: var(--sp-xl) var(--sp-xl);
}

.main_ui_dashboard_projects__title {
  color: var(--color-foreground-primary);
  font-size: 1.5rem;
}

.main_ui_dashboard_projects__info {
  flex: 1;
  font-size: 1rem;
}
.main_ui_dashboard_projects__info span {
  color: var(--color-foreground-secondary);
  display: block;
}
.main_ui_dashboard_projects__info a {
  color: var(--color-accent-primary);
}
.main_ui_dashboard_projects__info {
  padding: var(--sp-s) 0;
}

.main_ui_dashboard_projects__close {
  --close-icon-foreground-color: var(--icon-foreground);
  position: absolute;
  top: var(--sp-xl);
  inset-inline-end: var(--sp-xxl);
  inline-size: var(--sp-xxl);
  background-color: transparent;
  border: none;
  cursor: pointer;
}
.main_ui_dashboard_projects__close:hover {
  --close-icon-foreground-color: var(--button-icon-foreground-color-selected);
}

.main_ui_dashboard_projects__close-icon {
  stroke: var(--close-icon-foreground-color);
}

.main_ui_dashboard_projects__invite {
  block-size: 2rem;
  inline-size: 11.25rem;
}

.main_ui_dashboard_projects__img-wrapper {
  display: flex;
  align-items: center;
  justify-content: center;
  inline-size: var(--sp-xl) 0;
  block-size: var(--sp-xl) 0;
  overflow: hidden;
  border-radius: 0.25rem;
}
@media (width <= 1200px) {
  .main_ui_dashboard_projects__img-wrapper {
    display: none;
    inline-size: 0;
  }
}
@keyframes main_ui_dashboard_search__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_search__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_search__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_search__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_search__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_search__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_search__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_search__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_search__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_search__btn-primary.disabled, [disabled].main_ui_dashboard_search__btn-primary, .main_ui_dashboard_search__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_search__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_search__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_search__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_search__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_search__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_search__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_search__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_search__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_search__btn-secondary.disabled, [disabled].main_ui_dashboard_search__btn-secondary, .main_ui_dashboard_search__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_search__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_search__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_search__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_search__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_search__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_search__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_search__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_search__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_search__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_search__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_search__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_search__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_search__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_search__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_search__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_search__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_search__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_search__dashboard-header.main_ui_dashboard_search__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_search__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_search__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_search__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_search__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-title .main_ui_dashboard_search__context-menu.main_ui_dashboard_search__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_search__dashboard-header .main_ui_dashboard_search__dashboard-header-options li.main_ui_dashboard_search__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_search__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_search__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

.main_ui_dashboard_search__dashboard-grid {
  font-size: 0.875rem;
  height: 100%;
  overflow: hidden auto;
  padding: 0 var(--sp-l) 1rem;
}

.main_ui_dashboard_search__grid-row {
  display: grid;
  grid-auto-flow: column;
  grid-auto-columns: calc(0.75rem + var(--th-width, 15.75rem));
  width: 100%;
  gap: 1.5rem;
}

.main_ui_dashboard_search__grid-item {
  align-items: center;
  cursor: pointer;
  display: flex;
  flex-direction: column;
  margin: 0.75rem 0;
  position: relative;
  text-align: center;
}
.main_ui_dashboard_search__grid-item a,
.main_ui_dashboard_search__grid-item button {
  width: 100%;
  font-weight: 400;
}
.main_ui_dashboard_search__grid-item button {
  background-color: transparent;
  border: none;
  padding: 0 0.375rem;
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__grid-item-th {
  border-radius: 8px;
  text-align: initial;
  width: var(--th-width, 15.75rem);
  height: var(--th-height, 10.5rem);
  background-size: cover;
  overflow: hidden;
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__grid-item-th img {
  -o-object-fit: contain;
     object-fit: contain;
}
.main_ui_dashboard_search__grid-item.main_ui_dashboard_search__dragged {
  border-radius: 4px;
  outline: 4px solid var(--color-accent-primary);
  text-align: initial;
  width: calc(var(--th-width) + 0.75rem);
  height: var(--th-height, 10.5rem);
}
.main_ui_dashboard_search__grid-item.main_ui_dashboard_search__overlay {
  border-radius: 4px;
  border: 0.125rem solid var(--color-accent-tertiary);
  height: 100%;
  opacity: 0;
  pointer-events: none;
  position: absolute;
  width: 100%;
  z-index: 1;
}
.main_ui_dashboard_search__grid-item:hover .main_ui_dashboard_search__overlay {
  display: block;
  opacity: 1;
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__info-wrapper {
  display: grid;
  grid-template-columns: 1fr auto;
  cursor: pointer;
  max-width: var(--th-width, 15.75rem);
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-info {
  display: grid;
  padding: 0.5rem;
  text-align: left;
  width: 100%;
  font-size: 0.75rem;
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-info h3 {
  border: 1px solid transparent;
  color: var(--color-foreground-primary);
  font-size: 1rem;
  font-weight: 400;
  height: 1.75rem;
  line-height: 1.92;
  max-width: 16.25rem;
  overflow: hidden;
  padding: 0;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 100%;
}
@media (max-width: 1366px) {
  .main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-info h3 {
    max-width: 14.5rem;
  }
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-info .main_ui_dashboard_search__date {
  color: var(--color-foreground-secondary);
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
  white-space: nowrap;
  max-width: 16.25rem;
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-info .main_ui_dashboard_search__date::first-letter {
  text-transform: capitalize;
}
@media (max-width: 1366px) {
  .main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-info .main_ui_dashboard_search__date {
    max-width: 14.5rem;
  }
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-badge {
  background-color: var(--color-accent-primary);
  border: none;
  border-radius: 6px;
  position: absolute;
  top: 0.75rem;
  right: 0.75rem;
  height: 2rem;
  width: 2rem;
  display: flex;
  align-items: center;
  justify-content: center;
}
.main_ui_dashboard_search__grid-item .main_ui_dashboard_search__item-badge svg {
  stroke: var(--color-background-secondary);
  fill: none;
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_search__grid-item.main_ui_dashboard_search__add-file {
  border: 1px dashed var(--color-foreground-secondary);
  justify-content: center;
  box-shadow: none;
}
.main_ui_dashboard_search__grid-item.main_ui_dashboard_search__add-file span {
  color: var(--color-background-primary);
  font-size: 0.875rem;
}
.main_ui_dashboard_search__grid-item.main_ui_dashboard_search__add-file:hover {
  background-color: var(--color-foreground-primary);
  border: 0.125rem solid var(--color-accent-tertiary);
}

.main_ui_dashboard_search__drag-counter {
  position: absolute;
  top: 0.25rem;
  left: 0.25rem;
  width: 2rem;
  height: 2rem;
  background-color: var(--color-accent-tertiary);
  border-radius: 50%;
  color: var(--color-background-secondary);
  font-size: 1rem;
  display: flex;
  justify-content: center;
  align-items: center;
}

.main_ui_dashboard_search__project-th {
  background-color: transparent;
  border-radius: 8px;
  padding-top: 0.375rem;
}
.main_ui_dashboard_search__project-th:hover, .main_ui_dashboard_search__project-th:focus, .main_ui_dashboard_search__project-th:focus-within {
  background-color: var(--color-background-tertiary);
}
.main_ui_dashboard_search__project-th:hover .main_ui_dashboard_search__project-th-actions, .main_ui_dashboard_search__project-th:focus .main_ui_dashboard_search__project-th-actions, .main_ui_dashboard_search__project-th:focus-within .main_ui_dashboard_search__project-th-actions {
  opacity: 1;
}
.main_ui_dashboard_search__project-th:hover a, .main_ui_dashboard_search__project-th:focus a, .main_ui_dashboard_search__project-th:focus-within a {
  text-decoration: none;
}
.main_ui_dashboard_search__project-th .main_ui_dashboard_search__selected .main_ui_dashboard_search__grid-item-th {
  outline: 0.25rem solid var(--color-accent-tertiary);
}

.main_ui_dashboard_search__project-th-actions {
  align-items: center;
  display: flex;
  height: 100%;
  justify-content: center;
  opacity: 0;
  right: 0.375rem;
  width: 2rem;
}
.main_ui_dashboard_search__project-th-actions span {
  color: var(--color-background-secondary);
}

.main_ui_dashboard_search__project-th-icon {
  align-items: center;
  display: flex;
  margin-right: 0.5rem;
  margin-top: 0;
}

.main_ui_dashboard_search__menu {
  align-items: flex-end;
  display: flex;
  flex-direction: column;
  height: 2rem;
  justify-content: center;
  margin-right: 0;
  margin-top: 1.25rem;
  width: 100%;
  --menu-icon-color: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_search__menu:hover, .main_ui_dashboard_search__menu:focus {
  --menu-icon-color: var(--button-tertiary-foreground-color-hover);
}

.main_ui_dashboard_search__menu-icon {
  stroke: var(--menu-icon-color);
  fill: none;
  margin-right: 0;
  height: 1rem;
  width: 1rem;
}

.main_ui_dashboard_search__project-th-actions.main_ui_dashboard_search__force-display {
  opacity: 1;
}

.main_ui_dashboard_search__grid-item-th {
  border-radius: 4px;
  cursor: pointer;
  height: 100%;
  overflow: hidden;
  position: relative;
  width: 100%;
  display: flex;
  justify-content: center;
  flex-direction: row;
}
.main_ui_dashboard_search__grid-item-th .main_ui_dashboard_search__img-th {
  height: auto;
  width: 100%;
}

.main_ui_dashboard_search__library {
  height: 36.25rem;
}

.main_ui_dashboard_search__grid-item.main_ui_dashboard_search__project-th.main_ui_dashboard_search__library {
  height: 38.25rem;
}

.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library {
  background-color: var(--color-background-tertiary);
  flex-direction: column;
  height: 90%;
  justify-content: flex-start;
  max-height: 36.25rem;
  padding: 2rem;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-section {
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-section:not(:first-child) {
  margin-top: 1rem;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-title {
  display: flex;
  font-size: 0.75rem;
  text-transform: uppercase;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-title .main_ui_dashboard_search__num-assets {
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item {
  align-items: center;
  border-radius: 4px;
  border: 1px solid transparent;
  color: var(--color-foreground-primary);
  display: flex;
  font-size: 0.75rem;
  margin-top: 0.25rem;
  padding: 0.125rem;
  position: relative;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item .main_ui_dashboard_search__name-block {
  color: var(--color-foreground-secondary);
  width: calc(100% - 1.5rem - 0.5rem);
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item .main_ui_dashboard_search__item-name {
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item svg {
  background-color: var(--color-canvas);
  border-radius: 4px;
  border: 0.125rem solid transparent;
  height: 1.5rem;
  margin-right: 0.5rem;
  width: 1.5rem;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item .main_ui_dashboard_search__color-name {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item .main_ui_dashboard_search__color-value {
  color: var(--color-foreground-secondary);
  margin-left: 0.25rem;
  text-transform: uppercase;
}
.main_ui_dashboard_search__grid-item-th.main_ui_dashboard_search__library .main_ui_dashboard_search__asset-list-item .main_ui_dashboard_search__typography-sample {
  height: 1.25rem;
  margin-right: 0.25rem;
  width: 1.25rem;
}

.main_ui_dashboard_search__color-item {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 0.5rem;
}

.main_ui_dashboard_search__grid-loader {
  --icon-width: calc(var(--th-width, 15.75rem) * 0.25);
}

.main_ui_dashboard_search__deleted-item {
  opacity: 0.5;
}

.main_ui_dashboard_search__grid-empty-placeholder {
  border-radius: 12px;
  display: grid;
  padding: 0.75rem 0;
}
.main_ui_dashboard_search__grid-empty-placeholder.main_ui_dashboard_search__libs {
  background-image: url("/images/ph-left.svg"), url("/images/ph-right.svg");
  background-position: 15% bottom, 85% top;
  background-repeat: no-repeat;
  align-items: center;
  border: 1px solid var(--color-background-quaternary);
  border-radius: 4px;
  display: flex;
  flex-direction: column;
  height: 12.5rem;
  margin: 1rem;
  padding: 3rem;
  justify-content: center;
}
.main_ui_dashboard_search__grid-empty-placeholder.main_ui_dashboard_search__libs .main_ui_dashboard_search__text a {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_search__grid-empty-placeholder.main_ui_dashboard_search__libs .main_ui_dashboard_search__text p {
  max-width: 22.5rem;
  text-align: center;
  font-size: 1rem;
}
.main_ui_dashboard_search__grid-empty-placeholder .main_ui_dashboard_search__create-new {
  background-color: var(--color-background-tertiary);
  border-radius: 8px;
  color: var(--color-foreground-primary);
  cursor: pointer;
  margin: 0.5rem;
  border: 0.125rem solid transparent;
  width: var(--th-width, 15.75rem);
  height: var(--th-height, 10.5rem);
}
.main_ui_dashboard_search__grid-empty-placeholder .main_ui_dashboard_search__create-new svg {
  width: 2rem;
  height: 2rem;
  stroke: var(--color-foreground-secondary);
}
.main_ui_dashboard_search__grid-empty-placeholder .main_ui_dashboard_search__create-new:hover {
  border: 0.125rem solid var(--color-accent-tertiary);
  background-color: var(--color-background-quaternary);
  color: var(--color-accent-primary);
}
.main_ui_dashboard_search__grid-empty-placeholder .main_ui_dashboard_search__create-new:hover svg {
  stroke: var(--color-accent-tertiary);
}
.main_ui_dashboard_search__grid-empty-placeholder .main_ui_dashboard_search__text {
  margin-top: 0.75rem;
  color: var(--color-foreground-secondary);
  font-size: 1rem;
}

.main_ui_dashboard_search__placeholder-loader {
  display: flex;
  flex-direction: column;
  justify-content: center;
  row-gap: var(--sp-xxxl);
  margin: var(--sp-xxxl) 0 var(--sp-m) 0;
}

.main_ui_dashboard_search__placeholder-text {
  color: var(--color-foreground-secondary);
  font-size: 1rem;
  text-align: center;
}

.main_ui_dashboard_search__placeholder-markdown {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}
.main_ui_dashboard_search__placeholder-markdown a {
  color: var(--color-accent-primary);
}

.main_ui_dashboard_search__empty-placeholder-libraries {
  margin: 1rem;
}

.main_ui_dashboard_search__empty-project-container {
  width: 100%;
  display: grid;
  gap: 1rem;
  grid-template-columns: 1fr 1fr 1fr;
  margin-top: 0.75rem;
}

.main_ui_dashboard_search__empty-project-card {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  --color-card-background: var(--color-background-tertiary);
  --color-card-title: var(--color-foreground-primary);
  --color-card-subtitle: var(--color-foreground-secondary);
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  background-color: var(--color-card-background);
  border: 0.125rem solid var(--color-background-quaternary);
  border-radius: 8px;
  padding: var(--sp-m) 0;
}
.main_ui_dashboard_search__empty-project-card:hover {
  --color-card-background: var(--color-accent-primary);
  --color-card-title: var(--color-background-secondary);
  --color-card-subtitle: var(--color-background-secondary);
  cursor: pointer;
}
.main_ui_dashboard_search__empty-project-card:hover .main_ui_dashboard_search__empty-project-card-title {
  font-weight: 500;
}
.main_ui_dashboard_search__empty-project-card {
  flex-grow: 1;
}

.main_ui_dashboard_search__empty-project-card-title {
  color: var(--color-card-title);
}

.main_ui_dashboard_search__empty-project-card-subtitle {
  color: var(--color-card-subtitle);
}

.main_ui_dashboard_search__dashboard-container {
  flex: 1 0 0;
  margin-right: 1rem;
  overflow-y: auto;
  width: 100%;
  border-top: 1px solid var(--color-background-quaternary);
}
.main_ui_dashboard_search__dashboard-container.main_ui_dashboard_search__dashboard-projects {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_search__dashboard-container.main_ui_dashboard_search__dashboard-shared {
  width: calc(100vw - 20rem);
  margin-right: 3.25rem;
}
.main_ui_dashboard_search__dashboard-container.main_ui_dashboard_search__search {
  margin-top: 0.75rem;
}

.main_ui_dashboard_search__grid-empty-placeholder.main_ui_dashboard_search__search {
  align-items: center;
  display: flex;
  justify-content: center;
  flex-direction: column;
  height: 12.5rem;
  background: transparent;
  border: 1px solid var(--color-background-quaternary);
  border-radius: 8px;
}
.main_ui_dashboard_search__grid-empty-placeholder.main_ui_dashboard_search__search .main_ui_dashboard_search__text {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_search__grid-empty-placeholder.main_ui_dashboard_search__search .main_ui_dashboard_search__icon svg {
  stroke: var(--color-foreground-secondary);
  width: 2rem;
  height: 2rem;
}
.light {
  --color-accent-primary: #6911d4;
  --color-accent-primary-muted: #e1d2f5;
  --color-accent-secondary: #1345aa;
  --color-accent-tertiary: #8c33eb;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(105, 17, 212, 0.6);
  --color-accent-select: rgba(140, 51, 235, 0.1019607843);
  --color-accent-background-select: rgba(140, 51, 235, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #a7e8d9;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #fedeac;
  --color-accent-error: #c80857;
  --color-background-error: #ffcada;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #bae3fd;
  --color-background-default: #fff;
  --color-accent-default: #eef0f2;
  --color-icon-default: #495e74;
  --color-background-disabled: #e8eaee;
  --color-background-primary: #fff;
  --color-background-secondary: #e8eaee;
  --color-background-tertiary: #f3f4f6;
  --color-background-quaternary: #eef0f2;
  --color-foreground-primary: #000;
  --color-foreground-secondary: #495e74;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(232, 234, 238, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(255, 255, 255, 0.6);
  --color-overlay-onboarding: rgba(255, 255, 255, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #ddf7ff;
  --color-token-border: #77e1f3;
  --color-token-accent: #59acbb;
  --color-token-foreground: #1d4464;
  --color-badge-premium: #fe9c07;
}

.default {
  --color-accent-primary: #7efff5;
  --color-accent-primary-muted: #426158;
  --color-accent-secondary: #bb97d8;
  --color-accent-tertiary: #00d1b8;
  --color-accent-quaternary: #ff6fe0;
  --color-accent-overlay: rgba(126, 255, 245, 0.6);
  --color-accent-select: rgba(0, 209, 184, 0.1019607843);
  --color-accent-background-select: rgba(0, 209, 184, 0.7019607843);
  --color-accent-action: #bb97d8;
  --color-accent-action-hover: #a977d1;
  --color-accent-off: #f3f4f6;
  --color-accent-success: #2d9f8f;
  --color-background-success: #0a2927;
  --color-accent-warning: #fe9c07;
  --color-background-warning: #3d2501;
  --color-accent-error: #c80857;
  --color-background-error: #500124;
  --color-foreground-error: #ff3277;
  --color-accent-info: #0e9be9;
  --color-background-info: #082c49;
  --color-background-default: #18181a;
  --color-accent-default: #2e3434;
  --color-icon-default: #8f9da3;
  --color-background-disabled: #2e3434;
  --color-background-primary: #18181a;
  --color-background-secondary: #000;
  --color-background-tertiary: #212426;
  --color-background-quaternary: #2e3434;
  --color-foreground-primary: #fff;
  --color-foreground-secondary: #8f9da3;
  --color-static-white: #fff;
  --color-static-black: #000;
  --color-shadow-dark: rgba(0, 0, 0, 0.6);
  --color-shadow-light: rgba(0, 0, 0, 0.3);
  --color-overlay-default: rgba(24, 24, 26, 0.6);
  --color-overlay-onboarding: rgba(24, 24, 26, 0.9019607843);
  --color-canvas: #bfbfbf;
  --color-token-background: #272941;
  --color-token-border: #484c74;
  --color-token-accent: #6c6dad;
  --color-token-foreground: #a7a9ff;
  --color-badge-premium: #fedeac;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

@keyframes main_ui_dashboard_sidebar__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_sidebar__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_sidebar__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_sidebar__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_sidebar__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_sidebar__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_sidebar__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_sidebar__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_sidebar__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_sidebar__btn-primary.disabled, [disabled].main_ui_dashboard_sidebar__btn-primary, .main_ui_dashboard_sidebar__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_sidebar__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_sidebar__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_sidebar__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_sidebar__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_sidebar__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_sidebar__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_sidebar__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_sidebar__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_sidebar__btn-secondary.disabled, [disabled].main_ui_dashboard_sidebar__btn-secondary, .main_ui_dashboard_sidebar__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_sidebar__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_sidebar__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_sidebar__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_sidebar__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_sidebar__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_sidebar__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_sidebar__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_sidebar__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_sidebar__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_sidebar__arrow-icon, .main_ui_dashboard_sidebar__menu-icon, .main_ui_dashboard_sidebar__add-icon, .main_ui_dashboard_sidebar__search-icon,
.main_ui_dashboard_sidebar__clear-search-btn, .main_ui_dashboard_sidebar__profile-dropdown-item .main_ui_dashboard_sidebar__open-arrow svg, .main_ui_dashboard_sidebar__exit-icon, .main_ui_dashboard_sidebar__add-org-icon, .main_ui_dashboard_sidebar__arrow-up-right-icon, .main_ui_dashboard_sidebar__org-menu-icon, .main_ui_dashboard_sidebar__org-menu-icon-open, .main_ui_dashboard_sidebar__tick-icon, .main_ui_dashboard_sidebar__pin-icon, .main_ui_dashboard_sidebar__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_sidebar__tick-icon, .main_ui_dashboard_sidebar__pin-icon, .main_ui_dashboard_sidebar__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_sidebar__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_sidebar__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_sidebar__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_sidebar__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_sidebar__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_sidebar__teams-dropdown, .main_ui_dashboard_sidebar__options-dropdown, .main_ui_dashboard_sidebar__profile-dropdown, .main_ui_dashboard_sidebar__sub-menu {
  box-shadow: 0 0 0.75rem 0 var(--menu-shadow-color);
  display: flex;
  flex-direction: column;
  gap: 0.25rem;
  position: absolute;
  padding: 0.25rem;
  border-radius: 8px;
  z-index: 400;
  color: var(--title-foreground-color-hover);
  background-color: var(--menu-background-color);
  border: 0.125rem solid var(--panel-border-color);
  margin: 0;
}

.main_ui_dashboard_sidebar__team-dropdown-item, .main_ui_dashboard_sidebar__org-dropdown-item, .main_ui_dashboard_sidebar__team-options-item, .main_ui_dashboard_sidebar__profile-dropdown-item, .main_ui_dashboard_sidebar__submenu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_dashboard_sidebar__team-dropdown-item:hover, .main_ui_dashboard_sidebar__org-dropdown-item:hover, .main_ui_dashboard_sidebar__team-options-item:hover, .main_ui_dashboard_sidebar__profile-dropdown-item:hover, .main_ui_dashboard_sidebar__submenu-item:hover {
  background-color: var(--menu-background-color-hover);
}

.main_ui_dashboard_sidebar__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_sidebar__dashboard-header.main_ui_dashboard_sidebar__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_sidebar__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_sidebar__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_sidebar__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_sidebar__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-title .main_ui_dashboard_sidebar__context-menu.main_ui_dashboard_sidebar__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_sidebar__dashboard-header .main_ui_dashboard_sidebar__dashboard-header-options li.main_ui_dashboard_sidebar__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_sidebar__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_sidebar__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

.main_ui_dashboard_sidebar__dashboard-sidebar {
  display: grid;
  grid-row: 1/span 2;
  grid-column: 1/span 2;
  grid-template-rows: 1fr auto;
  height: 100%;
  width: 100%;
  padding: var(--sp-l) 0 0 0;
  margin: 0 var(--sp-l) 0 0;
  border-right: 0.0625rem solid var(--panel-border-color);
  background-color: var(--panel-background-color);
}

.main_ui_dashboard_sidebar__sidebar-content-wrapper {
  display: flex;
  flex-direction: column;
  min-height: 0;
  height: 100%;
  overflow: hidden;
}

.main_ui_dashboard_sidebar__sidebar-content {
  display: grid;
  grid-template-rows: auto auto auto auto 1fr;
  gap: var(--sp-xxl);
  flex: 1;
  min-height: 0;
  padding: 0;
  overflow: hidden auto;
}

.main_ui_dashboard_sidebar__sidebar-content-nitrate {
  padding: var(--sp-m) 0 0 0;
  border-block-start: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_dashboard_sidebar__separator {
  height: var(--sp-xxs);
  width: 94%;
  margin-left: 3%;
}

.main_ui_dashboard_sidebar__overflow-separator {
  border-bottom: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_dashboard_sidebar__sidebar-section-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 var(--sp-s) var(--sp-s) var(--sp-xxl);
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_sidebar__sidebar-team-switch {
  position: relative;
  margin: var(--sp-xs) var(--sp-l);
}

.main_ui_dashboard_sidebar__switch-content {
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  height: 3rem;
  width: 100%;
  border-radius: 0.5rem;
  border: 0.0625rem solid var(--menu-background-color);
  background-color: var(--menu-background-color);
}

.main_ui_dashboard_sidebar__current-team {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  align-items: center;
  grid-template-columns: 1fr auto;
  gap: var(--sp-s);
  height: 100%;
  padding: 0 var(--sp-m);
}

.main_ui_dashboard_sidebar__team-name {
  display: grid;
  align-items: center;
  grid-template-columns: auto 1fr;
  gap: var(--sp-m);
  height: 2.5rem;
}

.main_ui_dashboard_sidebar__team-text {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  width: auto;
  text-align: left;
  color: var(--menu-foreground-color-hover);
}

.main_ui_dashboard_sidebar__team-text-with-icon {
  display: flex;
  gap: var(--sp-s);
  max-width: 100%;
  overflow: hidden;
}

.main_ui_dashboard_sidebar__penpot-icon {
  display: flex;
  justify-content: center;
  align-items: center;
}
.main_ui_dashboard_sidebar__penpot-icon svg {
  fill: var(--icon-foreground);
  width: var(--sp-xxl);
  height: var(--sp-xxl);
}

.main_ui_dashboard_sidebar__team-picture {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 50%;
  height: var(--sp-xxl);
  width: var(--sp-xxl);
}

.main_ui_dashboard_sidebar__arrow-icon {
  transform: rotate(90deg);
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_sidebar__switch-options {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  max-width: var(--sp-xxl);
  min-width: 1.75rem;
  height: 100%;
  border-left: 0.0625rem solid var(--panel-background-color);
  background-color: transparent;
}

.main_ui_dashboard_sidebar__menu-icon {
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_sidebar__teams-dropdown {
  left: 0;
  top: 3.25rem;
  height: -moz-fit-content;
  height: fit-content;
  max-height: 30rem;
  min-width: 15.5rem;
  width: 100%;
  overflow: hidden auto;
}

.main_ui_dashboard_sidebar__team-dropdown-item {
  display: grid;
  grid-template-columns: var(--sp-xxl) 1fr auto;
  gap: var(--sp-s);
  height: 2.5rem;
}

.main_ui_dashboard_sidebar__org-dropdown-item {
  display: grid;
  grid-template-columns: var(--sp-xxxl) 1fr auto;
  gap: var(--sp-s);
  height: 2.5rem;
}

.main_ui_dashboard_sidebar__action {
  --sidebar-action-icon-color: var(--icon-foreground);
  --sidebar-icon-backgroun-color: var(--color-background-secondary);
}
.main_ui_dashboard_sidebar__action:hover {
  --sidebar-action-icon-color: var(--color-background-secondary);
  --sidebar-icon-backgroun-color: var(--color-accent-primary);
}

.main_ui_dashboard_sidebar__icon-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  width: var(--sp-xxl);
  height: var(--sp-xxl);
  margin-right: var(--sp-m);
  border-radius: 50%;
  background-color: var(--sidebar-icon-backgroun-color);
}

.main_ui_dashboard_sidebar__add-icon {
  width: var(--sp-xxl);
  height: var(--sp-xxl);
  stroke: var(--sidebar-action-icon-color);
}

.main_ui_dashboard_sidebar__team-separator {
  border-top: 0.0625rem solid var(--color-background-quaternary);
  margin: 0;
}

.main_ui_dashboard_sidebar__org-section-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--color-foreground-secondary);
  list-style: none;
  padding: var(--sp-m) 0.375rem 0.375rem;
  text-transform: uppercase;
}

.main_ui_dashboard_sidebar__tick-icon {
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_sidebar__options-dropdown {
  right: var(--sp-xxs);
  top: 3.25rem;
  max-height: 30rem;
}
.main_ui_dashboard_sidebar__options-dropdown:not(.main_ui_dashboard_sidebar__teams-dropdown) {
  min-width: var(--sp-l) 0;
}

.main_ui_dashboard_sidebar__team-options-item {
  height: 2.5rem;
}

.main_ui_dashboard_sidebar__team-option-separator {
  height: 1px;
  margin: 0;
  border-top: 0.0625rem solid var(--dropdown-separator-color);
}

.main_ui_dashboard_sidebar__sidebar-nav {
  margin: 0;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_dashboard_sidebar__pinned-projects {
  overflow-y: auto;
}

.main_ui_dashboard_sidebar__sidebar-nav-item {
  cursor: pointer;
}
.main_ui_dashboard_sidebar__sidebar-nav-item:hover {
  background-color: var(--sidebar-element-background-color-hover);
}
.main_ui_dashboard_sidebar__sidebar-nav-item:hover span {
  color: var(--sidebar-element-foreground-color-hover);
}
.main_ui_dashboard_sidebar__sidebar-nav-item.main_ui_dashboard_sidebar__current {
  background-color: var(--sidebar-element-background-color-selected);
}
.main_ui_dashboard_sidebar__sidebar-nav-item.main_ui_dashboard_sidebar__current .main_ui_dashboard_sidebar__element-title {
  color: var(--sidebar-element-foreground-color-selected);
}

.main_ui_dashboard_sidebar__recent-projects svg {
  stroke: var(--main-icon-foreground);
}

.main_ui_dashboard_sidebar__sidebar-link {
  display: block;
  padding: var(--sp-s) var(--sp-s) var(--sp-s) var(--sp-xxl);
  font-weight: 400;
  width: 100%;
}
.main_ui_dashboard_sidebar__sidebar-link:hover {
  text-decoration: none;
}

.main_ui_dashboard_sidebar__project-element {
  padding: var(--sp-s) var(--sp-s) var(--sp-s) var(--sp-xxl);
}

.main_ui_dashboard_sidebar__element-title {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 16rem;
  color: var(--color-foreground-primary);
  font-size: 0.875rem;
}

.main_ui_dashboard_sidebar__sidebar-empty-placeholder {
  padding: var(--sp-m);
  color: var(--empty-message-foreground-color);
  display: flex;
  align-items: center;
}

.main_ui_dashboard_sidebar__pin-icon {
  stroke: var(--icon-foreground);
  margin: 0 var(--sp-m);
}

.main_ui_dashboard_sidebar__empty-text {
  font-size: 0.75rem;
}

.main_ui_dashboard_sidebar__sidebar-search {
  position: relative;
  display: grid;
  grid-template-columns: 1fr;
  align-items: center;
  border: 0.0625rem solid transparent;
  margin: 0 var(--sp-l);
  border-radius: 0.5rem;
  background-color: var(--search-bar-input-background-color);
}

.main_ui_dashboard_sidebar__input-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  height: 2.5rem;
  width: 100%;
  padding: 0.375rem var(--sp-m);
  margin: 0;
  border: transparent;
  border-radius: 0.5rem;
  background: transparent;
  color: var(--search-bar-foreground-color);
}
.main_ui_dashboard_sidebar__input-text:focus, .main_ui_dashboard_sidebar__input-text:focus-within, .main_ui_dashboard_sidebar__input-text:focus-visible {
  outline: none;
  border: 0.0625rem solid var(--search-bar-input-border-color-focus);
}
.main_ui_dashboard_sidebar__input-text ::-moz-placeholder {
  color: var(--search-bar-placeholder-foreground-color);
}
.main_ui_dashboard_sidebar__input-text ::placeholder {
  color: var(--search-bar-placeholder-foreground-color);
}

.main_ui_dashboard_sidebar__search-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  right: 0;
  height: var(--sp-xxl);
  width: var(--sp-xxxl);
  padding: 0 var(--sp-s);
}

.main_ui_dashboard_sidebar__search-icon,
.main_ui_dashboard_sidebar__clear-search-btn {
  --sidebar-search-foreground-color: var(--search-bar-icon-foreground-color);
  stroke: var(--sidebar-search-foreground-color);
}

.main_ui_dashboard_sidebar__clear-search-btn:hover {
  --sidebar-search-foreground-color: var(--search-bar-icon-foreground-color-hover);
}

.main_ui_dashboard_sidebar__profile-section {
  position: relative;
  display: grid;
  grid-template-columns: 1fr auto;
  padding: var(--sp-m) var(--sp-l);
  border-top: 0.0625rem solid var(--panel-border-color);
  background-color: var(--profile-section-background-color);
  cursor: pointer;
}

.main_ui_dashboard_sidebar__profile {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: var(--sp-s);
  cursor: pointer;
  text-align: left;
}

.main_ui_dashboard_sidebar__profile-fullname {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  align-self: center;
  max-width: var(--sp-l) 0;
  color: var(--profile-foreground-color);
}

.main_ui_dashboard_sidebar__profile-img {
  height: 2.5rem;
  width: 2.5rem;
  border-radius: 50%;
}

.main_ui_dashboard_sidebar__profile-dropdown {
  inset-inline-start: var(--sp-s);
  inset-block-end: 4.5rem;
  min-width: calc(100% - var(--sp-s));
}

.main_ui_dashboard_sidebar__profile-dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  block-size: 2.5rem;
  margin-block-end: var(--sp-xs);
  padding: var(--sp-s);
  padding-inline-start: var(--sp-l);
}
.main_ui_dashboard_sidebar__profile-dropdown-item:hover {
  color: var(--menu-foreground-color-hover);
}
.main_ui_dashboard_sidebar__profile-dropdown-item:hover .main_ui_dashboard_sidebar__open-arrow {
  --icon-stroke-color: var(--menu-foreground-color-hover);
}

.main_ui_dashboard_sidebar__profile-dropdown-item .main_ui_dashboard_sidebar__open-arrow {
  display: flex;
  justify-content: center;
  align-items: center;
}

.main_ui_dashboard_sidebar__profile-dropdown-item .main_ui_dashboard_sidebar__open-arrow svg {
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_sidebar__sub-menu {
  inset-inline-start: calc(18.25rem + var(--sp-s));
  min-width: 12rem;
}

.main_ui_dashboard_sidebar__sub-menu.main_ui_dashboard_sidebar__help-learning {
  inset-block-end: 7.5rem;
}

.main_ui_dashboard_sidebar__sub-menu.main_ui_dashboard_sidebar__community {
  inset-block-end: 7.5rem;
}

.main_ui_dashboard_sidebar__sub-menu.main_ui_dashboard_sidebar__about {
  inset-block-end: 1.5rem;
}

.main_ui_dashboard_sidebar__submenu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  block-size: 2.5rem;
  margin-block-end: var(--sp-xs);
  padding-block: var(--sp-s);
  padding-inline: var(--sp-l);
}
.main_ui_dashboard_sidebar__submenu-item:hover {
  color: var(--menu-foreground-color-hover);
}

.main_ui_dashboard_sidebar__about-penpot {
  align-items: baseline;
  display: grid;
  grid-template-columns: auto 1fr;
}

.main_ui_dashboard_sidebar__menu-version {
  font-family: "Roboto Mono", monospace;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.75rem;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: var(--color-foreground-secondary);
  margin-inline-start: var(--sp-s);
  text-transform: uppercase;
}

.main_ui_dashboard_sidebar__profile-separator {
  height: 0.375rem;
  border-top: 0.0625rem solid var(--color-background-quaternary);
}

.main_ui_dashboard_sidebar__item-with-icon {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: var(--sp-s);
}

.main_ui_dashboard_sidebar__exit-icon {
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_sidebar__add-org-icon {
  width: var(--sp-l);
  height: var(--sp-l);
  stroke: var(--sidebar-action-icon-color);
}

.main_ui_dashboard_sidebar__arrow-up-right-icon {
  width: var(--sp-m);
  height: var(--sp-m);
  stroke: var(--sidebar-action-icon-color);
}

.main_ui_dashboard_sidebar__upgrade-plan-section {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: space-between;
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: var(--sp-s);
  padding: var(--sp-m);
  margin: var(--sp-m);
  color: var(--color-foreground-secondary);
  cursor: pointer;
}

.main_ui_dashboard_sidebar__penpot-free {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: flex;
  flex-direction: column;
  text-align: left;
}

.main_ui_dashboard_sidebar__no-limits {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
}

.main_ui_dashboard_sidebar__power-up {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-accent-tertiary);
}

.main_ui_dashboard_sidebar__orgs-container {
  align-items: center;
  display: flex;
  height: calc(2 * var(--sp-xxxl));
  max-height: calc(2 * var(--sp-xxxl));
  justify-content: space-between;
  padding: 0 var(--sp-xl);
}

.main_ui_dashboard_sidebar__selected-org {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
  width: 100%;
  padding-inline-start: var(--sp-s);
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_dashboard_sidebar__create-org {
  margin-inline-start: auto;
  text-transform: uppercase;
}

.main_ui_dashboard_sidebar__org-penpot-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 50%;
  height: var(--sp-xxxl);
  width: var(--sp-xxxl);
  background-color: var(--color-foreground-primary);
}
.main_ui_dashboard_sidebar__org-penpot-icon svg {
  fill: var(--icon-stroke-color);
  width: var(--sp-xxl);
  height: var(--sp-xxl);
}

.main_ui_dashboard_sidebar__org-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 50%;
  height: var(--sp-xxl);
  width: var(--sp-xxl);
  background-color: var(--color-foreground-primary);
}
.main_ui_dashboard_sidebar__org-icon svg {
  fill: var(--icon-stroke-color);
  width: var(--sp-xl);
  height: var(--sp-xl);
}

.main_ui_dashboard_sidebar__my-teams-icon {
  height: var(--sp-xxl);
  width: var(--sp-xxl);
}
.main_ui_dashboard_sidebar__my-teams-icon svg {
  fill: var(--icon-stroke-color);
  width: var(--sp-xxl);
  height: var(--sp-xxl);
}

.main_ui_dashboard_sidebar__my-teams-icon-xxxl {
  height: var(--sp-xxxl);
  width: var(--sp-xxxl);
}
.main_ui_dashboard_sidebar__my-teams-icon-xxxl svg {
  fill: var(--icon-stroke-color);
  width: var(--sp-xxxl);
  height: var(--sp-xxxl);
}

.main_ui_dashboard_sidebar__sidebar-org-switch {
  position: relative;
  width: 100%;
}

.main_ui_dashboard_sidebar__current-org {
  border: none;
  background: none;
  cursor: pointer;
  text-transform: none;
  display: grid;
  align-items: center;
  grid-template-columns: 1fr auto auto;
  gap: var(--sp-s);
  height: 100%;
  width: 100%;
}

.main_ui_dashboard_sidebar__current-org-no-options {
  gap: 0;
}

.main_ui_dashboard_sidebar__current-org .main_ui_dashboard_sidebar__arrow-icon {
  margin-inline-end: var(--sp-xs);
}

.main_ui_dashboard_sidebar__org-options {
  display: flex;
  justify-content: center;
  align-items: center;
  max-width: var(--sp-xxl);
  min-width: 1.75rem;
  height: 100%;
}

.main_ui_dashboard_sidebar__org-switch-content {
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  height: 3rem;
  width: 100%;
}

.main_ui_dashboard_sidebar__org-options-btn {
  --icon-stroke: var(--icon-foreground);
  display: flex;
  justify-content: center;
  align-items: center;
  width: 2rem;
  height: 2rem;
}
.main_ui_dashboard_sidebar__org-options-btn:hover {
  --icon-stroke: var(--color-accent-primary);
}

.main_ui_dashboard_sidebar__org-menu-icon {
  stroke: var(--icon-stroke);
}

.main_ui_dashboard_sidebar__org-menu-icon-open {
  stroke: var(--color-accent-primary);
}
@keyframes main_ui_dashboard_subscription__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_subscription__btn-primary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_subscription__btn-primary svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_subscription__btn-primary:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_subscription__btn-primary:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_subscription__btn-primary:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_subscription__btn-primary:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_subscription__btn-primary:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_subscription__btn-primary:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_subscription__btn-primary.disabled, [disabled].main_ui_dashboard_subscription__btn-primary, .main_ui_dashboard_subscription__btn-primary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_subscription__btn-secondary {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_subscription__btn-secondary svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_subscription__btn-secondary:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_subscription__btn-secondary:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_subscription__btn-secondary:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_subscription__btn-secondary:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_subscription__btn-secondary:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_subscription__btn-secondary:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_subscription__btn-secondary.disabled, [disabled].main_ui_dashboard_subscription__btn-secondary, .main_ui_dashboard_subscription__btn-secondary:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_subscription__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_subscription__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_subscription__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_subscription__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_subscription__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_subscription__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_subscription__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_subscription__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_subscription__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_subscription__icon-dropdown svg, .main_ui_dashboard_subscription__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_subscription__icon-dropdown svg, .main_ui_dashboard_subscription__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_subscription__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_subscription__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_subscription__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_subscription__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_subscription__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_subscription__menu-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 8px;
  cursor: pointer;
}
.main_ui_dashboard_subscription__menu-item:hover {
  background-color: var(--menu-background-color-hover);
}

.main_ui_dashboard_subscription__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_subscription__dashboard-header.main_ui_dashboard_subscription__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_subscription__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_subscription__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_subscription__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_subscription__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-title .main_ui_dashboard_subscription__context-menu.main_ui_dashboard_subscription__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_subscription__dashboard-header .main_ui_dashboard_subscription__dashboard-header-options li.main_ui_dashboard_subscription__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_subscription__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_subscription__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

:root {
  --sp-xxs: 0.125rem;
  --sp-xs: 0.25rem;
  --sp-s: 0.5rem;
  --sp-m: 0.75rem;
  --sp-l: 1rem;
  --sp-xl: 1.25rem;
  --sp-xxl: 1.5rem;
  --sp-xxxl: 2rem;
}

.main_ui_dashboard_subscription__cta-power-up {
  display: flex;
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: var(--sp-s);
  flex-direction: column;
  margin: var(--sp-m);
  padding: var(--sp-m);
}

.main_ui_dashboard_subscription__cta-power-up.main_ui_dashboard_subscription__highlighted {
  background: var(--color-background-quaternary);
  border: 0.0625rem solid var(--color-accent-primary-muted);
  padding: var(--sp-l);
}

.main_ui_dashboard_subscription__cta-top-section {
  border: none;
  background: none;
  cursor: pointer;
  display: grid;
  color: var(--color-foreground-secondary);
  grid-template-columns: 1fr auto;
  padding: 0;
}

.main_ui_dashboard_subscription__cta-top-section.main_ui_dashboard_subscription__cta-without-dropdown {
  cursor: default;
}

.main_ui_dashboard_subscription__cta-top-section .main_ui_dashboard_subscription__content {
  display: flex;
  flex-direction: column;
}

.main_ui_dashboard_subscription__icon-dropdown {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  width: var(--sp-l);
}

.main_ui_dashboard_subscription__icon-dropdown svg {
  stroke: var(--icon-foreground);
  transform: rotate(90deg);
}

.main_ui_dashboard_subscription__cta-bottom-section {
  border-block-start: 0.0625rem solid var(--color-background-quaternary);
  color: var(--color-foreground-secondary);
  margin-block-start: var(--sp-m);
  padding-block-start: var(--sp-m);
}

.main_ui_dashboard_subscription__highlighted .main_ui_dashboard_subscription__cta-bottom-section {
  border-block-start: 0.0625rem solid var(--color-accent-primary-muted);
}

.main_ui_dashboard_subscription__cta-bottom-section .main_ui_dashboard_subscription__content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  border: none;
  background: none;
  cursor: pointer;
  color: var(--color-foreground-secondary);
  display: inline-block;
  text-align: left;
}

.main_ui_dashboard_subscription__cta-bottom-button {
  margin-block-start: var(--sp-s);
}

.main_ui_dashboard_subscription__highlighted .main_ui_dashboard_subscription__cta-bottom-button {
  margin-block-start: var(--sp-m);
}

.main_ui_dashboard_subscription__cta-text,
.main_ui_dashboard_subscription__cta-title {
  text-align: left;
}

.main_ui_dashboard_subscription__cta-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  margin-block-end: var(--sp-xs);
}

.main_ui_dashboard_subscription__highlighted .main_ui_dashboard_subscription__cta-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  margin-block-end: 0;
}

.main_ui_dashboard_subscription__cta-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
}

.main_ui_dashboard_subscription__highlighted .main_ui_dashboard_subscription__cta-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_subscription__cta-bottom-section .main_ui_dashboard_subscription__content a {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-accent-tertiary);
  margin-inline-start: var(--sp-xs);
}

.main_ui_dashboard_subscription__cta-link {
  border: none;
  background: none;
  cursor: pointer;
  align-self: end;
  margin-inline-start: var(--sp-xs);
}

.main_ui_dashboard_subscription__team {
  display: grid;
  grid-auto-rows: min-content;
  gap: var(--sp-s);
  max-width: 62.5rem;
  width: 100%;
}

.main_ui_dashboard_subscription__team-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--title-foreground-color);
}

.main_ui_dashboard_subscription__team-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.25rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_subscription__manage-subscription-link {
  border: none;
  background: none;
  cursor: pointer;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-accent-tertiary);
  display: flex;
  margin-block-start: -8px;
  padding: 0;
}

.main_ui_dashboard_subscription__subscription-icon-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  background: var(--color-background-primary);
  border-radius: 0.375rem;
  border: 1.75px solid var(--color-foreground-secondary);
  block-size: var(--sp-xl);
  inline-size: var(--sp-xl);
}

.main_ui_dashboard_subscription__subscription-icon {
  stroke: var(--color-foreground-secondary);
  stroke-width: 2.25px;
}

.main_ui_dashboard_subscription__menu-item {
  cursor: pointer;
}
.main_ui_dashboard_subscription__menu-item:hover {
  color: var(--menu-foreground-color-hover);
}
.main_ui_dashboard_subscription__menu-item:hover .main_ui_dashboard_subscription__open-arrow svg {
  stroke: var(--menu-foreground-color-hover);
}

.main_ui_dashboard_subscription__members-cta {
  height: -moz-fit-content;
  height: fit-content;
  margin-block-start: var(--sp-s);
  margin-inline-start: 3.25rem;
  max-width: 13.75rem;
}
.main_ui_dashboard_subscription__members-cta .main_ui_dashboard_subscription__cta-title {
  line-height: 1.2;
}

.main_ui_dashboard_subscription__dashboard-cta {
  height: -moz-fit-content;
  height: fit-content;
  margin: var(--sp-l);
}
.main_ui_dashboard_subscription__dashboard-cta .main_ui_dashboard_subscription__cta-title {
  line-height: 1.2;
}

.main_ui_dashboard_subscription__cta-message {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
  line-height: 1;
}
.main_ui_dashboard_subscription__cta-message a {
  color: var(--color-accent-primary);
  overflow-wrap: break-word;
}

.main_ui_dashboard_subscription__nitrate-banner {
  display: flex;
  border-radius: var(--sp-s);
  flex-direction: column;
  margin: var(--sp-m) var(--sp-m) 0;
  background: var(--color-background-quaternary);
  border: 0.0625rem solid var(--color-accent-primary-muted);
  padding: var(--sp-l);
}

.main_ui_dashboard_subscription__nitrate-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_subscription__nitrate-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
  margin-block: var(--sp-s) var(--sp-xxl);
}

.main_ui_dashboard_subscription__nitrate-content {
  display: flex;
  flex-direction: column;
}

.main_ui_dashboard_subscription__nitrate-bottom-button {
  width: -moz-fit-content;
  width: fit-content;
  height: -moz-fit-content;
  height: fit-content;
  padding: var(--sp-s) var(--sp-m);
}

.main_ui_dashboard_subscription__nitrate-current-plan {
  border-radius: var(--sp-s);
  margin-block: var(--sp-s) var(--sp-m);
  margin-inline: var(--sp-m);
  background: var(--color-background-tertiary);
  border: 0.0625rem solid var(--color-background-quaternary);
  padding: var(--sp-m) var(--sp-l);
}

.main_ui_dashboard_subscription__nitrate-current-plan-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  padding-block-end: var(--sp-xs);
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_subscription__nitrate-current-plan-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  background: none;
  border: none;
  padding: 0;
  cursor: pointer;
  color: var(--color-foreground-primary);
}
@keyframes main_ui_dashboard_team__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_team__btn-empty-invitations, .main_ui_dashboard_team__hero-btn, .main_ui_dashboard_team__btn-primary, .main_ui_dashboard_team__accept-btn, .main_ui_dashboard_team__action-buttons button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_team__btn-empty-invitations svg, .main_ui_dashboard_team__hero-btn svg, .main_ui_dashboard_team__btn-primary svg, .main_ui_dashboard_team__accept-btn svg, .main_ui_dashboard_team__action-buttons button svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_team__btn-empty-invitations:focus-visible, .main_ui_dashboard_team__hero-btn:focus-visible, .main_ui_dashboard_team__btn-primary:focus-visible, .main_ui_dashboard_team__accept-btn:focus-visible, .main_ui_dashboard_team__action-buttons button:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_team__btn-empty-invitations:focus-visible svg, .main_ui_dashboard_team__hero-btn:focus-visible svg, .main_ui_dashboard_team__btn-primary:focus-visible svg, .main_ui_dashboard_team__accept-btn:focus-visible svg, .main_ui_dashboard_team__action-buttons button:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_team__btn-empty-invitations:hover, .main_ui_dashboard_team__hero-btn:hover, .main_ui_dashboard_team__btn-primary:hover, .main_ui_dashboard_team__accept-btn:hover, .main_ui_dashboard_team__action-buttons button:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_team__btn-empty-invitations:hover svg, .main_ui_dashboard_team__hero-btn:hover svg, .main_ui_dashboard_team__btn-primary:hover svg, .main_ui_dashboard_team__accept-btn:hover svg, .main_ui_dashboard_team__action-buttons button:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_team__btn-empty-invitations:active, .main_ui_dashboard_team__hero-btn:active, .main_ui_dashboard_team__btn-primary:active, .main_ui_dashboard_team__accept-btn:active, .main_ui_dashboard_team__action-buttons button:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_team__btn-empty-invitations:active svg, .main_ui_dashboard_team__hero-btn:active svg, .main_ui_dashboard_team__btn-primary:active svg, .main_ui_dashboard_team__accept-btn:active svg, .main_ui_dashboard_team__action-buttons button:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_team__btn-empty-invitations.disabled, .main_ui_dashboard_team__hero-btn.disabled, .main_ui_dashboard_team__btn-primary.disabled, .main_ui_dashboard_team__accept-btn.disabled, .main_ui_dashboard_team__action-buttons button.disabled, [disabled].main_ui_dashboard_team__btn-empty-invitations, [disabled].main_ui_dashboard_team__hero-btn, [disabled].main_ui_dashboard_team__btn-primary, [disabled].main_ui_dashboard_team__accept-btn, .main_ui_dashboard_team__action-buttons button[disabled], .main_ui_dashboard_team__btn-empty-invitations:disabled, .main_ui_dashboard_team__hero-btn:disabled, .main_ui_dashboard_team__btn-primary:disabled, .main_ui_dashboard_team__accept-btn:disabled, .main_ui_dashboard_team__action-buttons button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_team__btn-secondary, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_team__btn-secondary svg, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_team__btn-secondary:focus-visible, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_team__btn-secondary:focus-visible svg, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_team__btn-secondary:hover, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_team__btn-secondary:hover svg, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_team__btn-secondary:active, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_team__btn-secondary:active svg, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_team__btn-secondary.disabled, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button.disabled, [disabled].main_ui_dashboard_team__btn-secondary, .main_ui_dashboard_team__action-buttons [disabled].main_ui_dashboard_team__cancel-button, .main_ui_dashboard_team__btn-secondary:disabled, .main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_team__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_dashboard_team__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_team__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_team__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_team__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_dashboard_team__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_dashboard_team__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_team__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_team__modal-close-btn.disabled, [disabled].main_ui_dashboard_team__modal-close-btn, .main_ui_dashboard_team__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_dashboard_team__modal-close-btn.disabled svg, [disabled].main_ui_dashboard_team__modal-close-btn svg, .main_ui_dashboard_team__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_dashboard_team__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_team__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_team__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_team__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_team__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_team__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_team__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_team__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_team__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_team__modal-close-btn svg, .main_ui_dashboard_team__input-wrapper span.intermediate svg, .main_ui_dashboard_team__input-checkbox label span.intermediate svg, .main_ui_dashboard_team__input-wrapper span.checked svg, .main_ui_dashboard_team__input-checkbox label span.checked svg, .main_ui_dashboard_team__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_team__input-wrapper span.intermediate svg, .main_ui_dashboard_team__input-checkbox label span.intermediate svg, .main_ui_dashboard_team__input-wrapper span.checked svg, .main_ui_dashboard_team__input-checkbox label span.checked svg, .main_ui_dashboard_team__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_team__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_team__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_team__email-input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
[disabled].main_ui_dashboard_team__email-input {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_dashboard_team__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_team__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_team__input-wrapper span, .main_ui_dashboard_team__input-checkbox label span {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1rem;
  height: 1rem;
  min-width: 1rem;
  min-height: 1rem;
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-border-color-rest);
  border-radius: 4px;
}
.main_ui_dashboard_team__input-wrapper span svg, .main_ui_dashboard_team__input-checkbox label span svg {
  width: 1rem;
  height: 1rem;
  display: none;
  stroke: var(--input-checkbox-inactive-foreground-color);
}
.main_ui_dashboard_team__input-wrapper span:hover, .main_ui_dashboard_team__input-checkbox label span:hover {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_dashboard_team__input-wrapper span:focus, .main_ui_dashboard_team__input-checkbox label span:focus {
  border-color: var(--input-checkbox-border-color-focus);
}
.main_ui_dashboard_team__input-wrapper span.checked, .main_ui_dashboard_team__input-checkbox label span.checked {
  border-color: var(--input-checkbox-border-color-active);
  background-color: var(--input-checkbox-background-color-active);
}
.main_ui_dashboard_team__input-wrapper span.checked svg, .main_ui_dashboard_team__input-checkbox label span.checked svg {
  stroke: var(--input-checkbox-foreground-color-active);
}
.main_ui_dashboard_team__input-wrapper span.intermediate, .main_ui_dashboard_team__input-checkbox label span.intermediate {
  background-color: var(--input-checkbox-background-color-intermediate);
  border-color: var(--input-checkbox-border-color-intermediate);
}
.main_ui_dashboard_team__input-wrapper span.intermediate svg, .main_ui_dashboard_team__input-checkbox label span.intermediate svg {
  stroke: var(--input-checkbox-foreground-color-intermediate);
}
.main_ui_dashboard_team__input-wrapper span.unchecked, .main_ui_dashboard_team__input-checkbox label span.unchecked {
  background-color: var(--input-checkbox-background-color-rest);
  border: 1px solid var(--input-checkbox-background-color-rest);
}
.main_ui_dashboard_team__input-wrapper span.unchecked svg, .main_ui_dashboard_team__input-checkbox label span.unchecked svg {
  display: none;
}

.main_ui_dashboard_team__input-checkbox {
  display: flex;
  align-items: center;
}
.main_ui_dashboard_team__input-checkbox label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--input-checkbox-text-foreground-color);
}
.main_ui_dashboard_team__input-checkbox label input {
  margin: 0;
}
.main_ui_dashboard_team__input-checkbox label:hover span {
  border-color: var(--input-checkbox-border-color-hover);
}
.main_ui_dashboard_team__input-checkbox label:focus span, .main_ui_dashboard_team__input-checkbox label:focus-within span {
  border-color: var(--input-checkbox-border-color-focus);
}

.main_ui_dashboard_team__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_dashboard_team__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_team__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_dashboard_team__action-buttons .main_ui_dashboard_team__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_team__accept-btn, .main_ui_dashboard_team__action-buttons button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_team__dashboard-header {
  align-items: center;
  display: flex;
  height: 4rem;
  max-height: 4rem;
  justify-content: space-between;
  padding: 0.25rem 1rem 0.25rem 0.5rem;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.main_ui_dashboard_team__dashboard-header.main_ui_dashboard_team__team {
  display: grid;
  grid-template-columns: 20% 1fr 20%;
  max-height: 4rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__element-name {
  margin-right: 0.5rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__btn-secondary {
  flex-shrink: 0;
  height: 2rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__btn-secondary svg {
  height: 1rem;
  width: 1rem;
}
.main_ui_dashboard_team__dashboard-header nav {
  display: flex;
  align-items: flex-end;
  justify-content: center;
}
.main_ui_dashboard_team__dashboard-header nav ul {
  display: flex;
  font-size: 0.875rem;
  justify-content: center;
  margin: 0;
}
.main_ui_dashboard_team__dashboard-header nav li a {
  display: flex;
  align-items: center;
  flex-basis: 8.75rem;
  border-bottom: calc(1px + 0.125rem) solid transparent;
  color: var(--color-foreground-secondary);
  height: 2.5rem;
  padding: 0.25rem 1.5rem;
  font-weight: 400;
}
.main_ui_dashboard_team__dashboard-header nav li a:hover {
  color: var(--color-background-secondary);
  text-decoration: none;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-title {
  display: flex;
  align-items: center;
  margin-left: 0.75rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-title h1 {
  color: var(--color-foreground-primary);
  display: block;
  flex-shrink: 0;
  font-size: 1.5rem;
  font-weight: 400;
  max-width: 44.5rem;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
  white-space: nowrap;
  width: 100%;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-title .main_ui_dashboard_team__context-menu.main_ui_dashboard_team__is-open {
  margin-top: 0.5rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__icon {
  display: flex;
  align-items: center;
  cursor: pointer;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__icon svg {
  stroke: var(--color-foreground-secondary);
  fill: none;
  width: 1rem;
  height: 1rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__icon svg:hover {
  stroke: var(--color-accent-tertiary);
  fill: none;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-buttons {
  display: flex;
  justify-content: flex-end;
  align-items: center;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-header-actions {
  display: flex;
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-header-options li a {
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  border-color: transparent;
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-header-options li a:hover {
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_team__dashboard-header .main_ui_dashboard_team__dashboard-header-options li.main_ui_dashboard_team__active a {
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__btn-primary {
  text-transform: uppercase;
  font-size: 0.875rem;
  font-weight: 400;
}

.main_ui_dashboard_team__btn-secondary {
  color: var(--color-foreground-primary);
  font-size: 0.75rem;
  text-transform: uppercase;
  padding: 0 1rem;
}

.main_ui_dashboard_team__dashboard-team-settings {
  display: flex;
  flex-direction: column;
  align-items: center;
  width: 100%;
  border-top: 0.0625rem solid var(--color-background-quaternary);
  overflow-y: auto;
  padding-inline-start: var(--sp-xl);
  padding-block-start: var(--sp-xl);
}

.main_ui_dashboard_team__settings-container {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: var(--sp-xxl);
}

.main_ui_dashboard_team__block {
  display: grid;
  grid-auto-rows: min-content;
  gap: var(--sp-s);
  max-width: 62.5rem;
  width: 100%;
}

.main_ui_dashboard_team__info-block {
  margin-block-start: var(--sp-l);
}

.main_ui_dashboard_team__block-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__block-text {
  color: var(--color-foreground-primary);
  text-wrap: nowrap;
}

.main_ui_dashboard_team__block-content {
  display: grid;
  grid-template-columns: var(--sp-xxxl) 1fr;
  align-items: center;
  gap: var(--sp-m);
}

.main_ui_dashboard_team__owner-icon {
  width: 2rem;
  height: 2rem;
  border-radius: 50%;
}

.main_ui_dashboard_team__user-icon,
.main_ui_dashboard_team__document-icon,
.main_ui_dashboard_team__group-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  margin: 0 auto;
  stroke: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__team-icon {
  --update-button-opacity: 0;
  position: relative;
  height: 7.5rem;
  width: 7.5rem;
  padding: var(--sp-l);
  margin-block-end: var(--sp-xxxl);
}
.main_ui_dashboard_team__team-icon:hover {
  --update-button-opacity: 1;
}

.main_ui_dashboard_team__team-image {
  position: absolute;
  top: 0;
  left: 0;
  border-radius: 50%;
  width: 7.5rem;
  height: 7.5rem;
}

.main_ui_dashboard_team__update-overlay {
  opacity: var(--update-button-opacity);
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  position: absolute;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%;
  z-index: var(--z-index-set);
  border-radius: 50%;
  background-color: var(--color-accent-primary);
}

.main_ui_dashboard_team__image-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  min-width: 1.5rem;
  min-height: 1.5rem;
  stroke: var(--color-foreground-primary);
}

.main_ui_dashboard_team__dashboard-team-members {
  display: flex;
  justify-content: center;
  width: 100%;
  height: 100%;
  padding-inline-start: var(--sp-xl);
  padding-block-start: var(--sp-xl);
  border-top: 0.0625rem solid var(--color-background-quaternary);
  overflow-y: auto;
  scrollbar-gutter: stable;
}

.main_ui_dashboard_team__dashboard-team-members.main_ui_dashboard_team__dashboard-top-cta {
  flex-direction: column;
  justify-content: flex-start;
}

.main_ui_dashboard_team__team-members {
  display: grid;
  grid-template-rows: auto 1fr;
  height: -moz-fit-content;
  height: fit-content;
  max-width: 62.5rem;
  width: 100%;
}

.main_ui_dashboard_team__table-header {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 500;
  line-height: 1.2;
  font-size: 0.75rem;
  text-transform: uppercase;
  display: grid;
  align-items: center;
  grid-template-columns: 43% 1fr 6.75rem var(--sp-m);
  height: 2.5rem;
  width: 100%;
  max-width: 62.5rem;
  padding: 0 var(--sp-l);
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__table-rows {
  display: grid;
  grid-auto-rows: 4rem;
  gap: var(--sp-l);
  width: 100%;
  height: 100%;
  max-width: 62.5rem;
  margin-top: var(--sp-l);
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__table-row {
  display: grid;
  grid-template-columns: 43% 1fr auto;
  align-items: center;
  height: 4rem;
  width: 100%;
  padding: 0 var(--sp-l);
  border-radius: 0.5rem;
  background-color: var(--color-background-tertiary);
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__title-field-name {
  width: 43%;
  min-width: 18.75rem;
}

.main_ui_dashboard_team__title-field-role {
  position: relative;
  cursor: default;
}

.main_ui_dashboard_team__title-field-role,
.main_ui_dashboard_team__title-field-status {
  display: flex;
  align-items: center;
  gap: var(--sp-s);
}

.main_ui_dashboard_team__field-name {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: var(--sp-l);
  width: 43%;
  min-width: 18.75rem;
}

.main_ui_dashboard_team__field-roles {
  position: relative;
  cursor: default;
}

.main_ui_dashboard_team__field-actions {
  position: relative;
}

.main_ui_dashboard_team__member-image {
  height: 2rem;
  width: 2rem;
  border-radius: 50%;
}

.main_ui_dashboard_team__member-info {
  display: grid;
  grid-template-rows: 1fr 1fr;
  width: 100%;
}

.main_ui_dashboard_team__member-name,
.main_ui_dashboard_team__member-email {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}

.main_ui_dashboard_team__member-email {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__you {
  color: var(--color-foreground-secondary);
  margin-left: 0.375rem;
}

.main_ui_dashboard_team__rol-selector {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  position: relative;
  display: grid;
  grid-template-columns: 1fr auto;
  align-items: center;
  height: 2rem;
  min-width: 10rem;
  width: -moz-fit-content;
  width: fit-content;
  padding: var(--sp-xs) var(--sp-s);
  border-radius: 0.5rem;
  border-color: var(--color-background-quaternary);
  background-color: var(--color-background-quaternary);
}

.main_ui_dashboard_team__has-priv {
  cursor: pointer;
}

.main_ui_dashboard_team__rol-label {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

.main_ui_dashboard_team__roles-dropdown {
  box-shadow: var(--el-shadow-dark);
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: absolute;
  padding: var(--sp-xs);
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  color: var(--color-foreground-primary);
  background-color: var(--color-background-tertiary);
  border: 0.125rem solid var(--color-background-quaternary);
  margin: 0;
  bottom: -4.75rem;
  width: -moz-fit-content;
  width: fit-content;
  min-width: 10rem;
}

.main_ui_dashboard_team__rol-dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 0.5rem;
  cursor: pointer;
}
.main_ui_dashboard_team__rol-dropdown-item:hover {
  background-color: var(--color-background-quaternary);
}

.main_ui_dashboard_team__menu-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--color-foreground-primary);
}

.main_ui_dashboard_team__menu-btn {
  border: none;
  background: none;
  cursor: pointer;
}

.main_ui_dashboard_team__input-checkbox {
  cursor: pointer;
}

.main_ui_dashboard_team__actions-dropdown {
  box-shadow: var(--el-shadow-dark);
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: absolute;
  padding: var(--sp-xs);
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  color: var(--color-foreground-primary);
  background-color: var(--color-background-tertiary);
  border: 0.125rem solid var(--color-background-quaternary);
  margin: 0;
  bottom: calc(-1 * var(--sp-xxxl));
  right: 0;
  left: unset;
  width: -moz-fit-content;
  width: fit-content;
  min-width: 10rem;
}

.main_ui_dashboard_team__action-dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 0.5rem;
  cursor: pointer;
}
.main_ui_dashboard_team__action-dropdown-item:hover {
  background-color: var(--color-background-quaternary);
}

.main_ui_dashboard_team__dashboard-team-invitations {
  display: flex;
  justify-content: center;
  width: 100%;
  height: 100%;
  padding-inline-start: var(--sp-xl);
  padding-block-start: var(--sp-xl);
  border-top: 0.0625rem solid var(--color-background-quaternary);
  overflow-y: auto;
  scrollbar-gutter: stable;
}

.main_ui_dashboard_team__invitations {
  display: grid;
  grid-template-rows: auto 1fr;
  height: -moz-fit-content;
  height: fit-content;
  max-width: 62.5rem;
  width: 100%;
}

.main_ui_dashboard_team__invitations-actions {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: flex;
  justify-content: end;
  align-items: center;
  gap: var(--sp-l);
  color: var(--title-foreground-color);
  height: 2.5rem;
  margin-block-end: 2.25rem;
}

.main_ui_dashboard_team__error-notification {
  margin-block-end: var(--sp-xxl);
}

.main_ui_dashboard_team__table-row-invitations {
  grid-template-columns: 43% 1fr 5.5rem var(--sp-xxl);
  align-items: center;
}

.main_ui_dashboard_team__empty-invitations {
  width: 100%;
  margin-top: var(--sp-l);
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: 0.5rem;
  color: var(--color-foreground-secondary);
  padding: var(--sp-xxxl);
  text-align: center;
}

.main_ui_dashboard_team__empty-invitations-buttons {
  width: -moz-fit-content;
  width: fit-content;
  margin: auto;
}

.main_ui_dashboard_team__no-permission-text {
  max-width: 32rem;
  margin: auto;
}

.main_ui_dashboard_team__btn-empty-invitations {
  margin-block-start: var(--sp-l);
  padding-inline: var(--sp-m);
}

.main_ui_dashboard_team__title-field-status {
  position: relative;
  cursor: default;
}

.main_ui_dashboard_team__sort-inactive {
  opacity: 0.5;
}

.main_ui_dashboard_team__sort-active {
  opacity: 1;
}

.main_ui_dashboard_team__field-email {
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  display: flex;
  gap: var(--sp-l);
  align-items: center;
}

.main_ui_dashboard_team__invitations-dropdown {
  bottom: -7rem;
  right: calc(-1 * var(--sp-xl));
}

.main_ui_dashboard_team__dashboard-team-webhooks {
  display: grid;
  grid-template-rows: auto 1fr;
  justify-items: center;
  gap: var(--sp-xxl);
  width: 100%;
  height: 100%;
  padding-inline-start: var(--sp-xl);
  padding-block-start: var(--sp-xl);
  border-top: 0.0625rem solid var(--color-background-quaternary);
  overflow-y: auto;
}

.main_ui_dashboard_team__webhooks-hero-container {
  display: grid;
  grid-template-rows: auto 1fr;
  margin: 5rem auto var(--sp-xl) auto;
  gap: var(--sp-xxl);
}

.main_ui_dashboard_team__webhooks-empty {
  display: grid;
  place-items: center;
  align-content: center;
  height: 9.75rem;
  max-width: 62.5rem;
  width: 100%;
  padding: var(--sp-xxxl);
  border: 0.0625rem solid var(--color-background-quaternary);
  border-radius: 0.5rem;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__webhooks-hero {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  display: grid;
  grid-template-rows: auto 1fr auto;
  gap: var(--sp-xxxl);
  margin: 0;
  padding: var(--sp-xxxl);
  padding: 0;
  width: 29.25rem;
}

.main_ui_dashboard_team__hero-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.5rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__hero-desc {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  color: var(--color-foreground-secondary);
  margin-bottom: 0;
  max-width: 32rem;
}

.main_ui_dashboard_team__hero-btn {
  height: 2rem;
  max-width: 32rem;
}

.main_ui_dashboard_team__webhook-table {
  height: -moz-fit-content;
  height: fit-content;
}

.main_ui_dashboard_team__webhook-row {
  display: grid;
  align-items: center;
  grid-template-columns: auto 1fr auto auto;
  gap: var(--sp-l);
}

.main_ui_dashboard_team__actions {
  position: relative;
}

.main_ui_dashboard_team__menu-disabled {
  color: var(--color-foreground-secondary);
  width: 1.75rem;
  display: flex;
  justify-content: center;
  align-items: center;
}

.main_ui_dashboard_team__webhook-actions-dropdown {
  box-shadow: var(--el-shadow-dark);
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: absolute;
  padding: var(--sp-xs);
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  color: var(--color-foreground-primary);
  background-color: var(--color-background-tertiary);
  border: 0.125rem solid var(--color-background-quaternary);
  margin: 0;
  right: calc(-1 * var(--sp-l));
  bottom: -2.5rem;
  width: -moz-fit-content;
  width: fit-content;
  min-width: 10rem;
}

.main_ui_dashboard_team__webhook-dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 0.5rem;
  cursor: pointer;
}
.main_ui_dashboard_team__webhook-dropdown-item:hover {
  background-color: var(--color-background-quaternary);
}

.main_ui_dashboard_team__success-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--color-accent-success);
}

.main_ui_dashboard_team__warning-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--color-accent-warning);
}

.main_ui_dashboard_team__modal-team-container {
  border-radius: 0.5rem;
  border: 0.125rem solid var(--color-background-quaternary);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
  box-shadow: var(--el-shadow-dark);
  position: fixed;
  top: 4.5rem;
  right: var(--sp-m);
  left: unset;
  width: 25rem;
  padding: var(--sp-xxxl);
  background-color: var(--color-background-primary);
  z-index: var(--z-index-set);
}
.main_ui_dashboard_team__modal-team-container.main_ui_dashboard_team__hero {
  top: 13.5rem;
  right: var(--sp-xxxl);
}

.main_ui_dashboard_team__modal-team-container-workspace {
  top: 2.5rem;
  z-index: var(--z-index-set);
}

.main_ui_dashboard_team__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  text-transform: uppercase;
  height: 2rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__role-select {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  row-gap: var(--sp-s);
}

.main_ui_dashboard_team__arrow-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--color-foreground-secondary);
  transform: rotate(90deg);
}

.main_ui_dashboard_team__invite-team-member-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  margin: 0 0 var(--sp-l) 0;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__role-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  margin: 0;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__invitation-row {
  margin-top: var(--sp-s);
  margin-bottom: var(--sp-xxl);
}

.main_ui_dashboard_team__action-buttons {
  display: flex;
  justify-content: flex-end;
}

.main_ui_dashboard_team__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: var(--z-index-set);
  background-color: var(--overlay-color);
}

.main_ui_dashboard_team__modal-container {
  position: relative;
  padding: var(--sp-xxxl);
  border-radius: 0.5rem;
  background-color: var(--color-background-primary);
  border: 0.125rem solid var(--color-background-quaternary);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_dashboard_team__modal-header {
  margin-bottom: var(--sp-xxl);
}

.main_ui_dashboard_team__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.2;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__modal-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
  margin-bottom: var(--sp-xxl);
}

.main_ui_dashboard_team__fields-row {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_dashboard_team__select-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__custom-input-checkbox {
  align-items: flex-start;
}

.main_ui_dashboard_team__hint {
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__email-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  height: auto;
}

.main_ui_dashboard_team__input-wrapper {
  display: flex;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}
.main_ui_dashboard_team__input-wrapper label {
  display: flex;
  align-items: center;
  gap: 0.375rem;
  cursor: pointer;
  color: var(--color-foreground-primary);
}
.main_ui_dashboard_team__input-wrapper label:focus span, .main_ui_dashboard_team__input-wrapper label:focus-within span {
  border-color: var(--color-accent-primary);
}
.main_ui_dashboard_team__input-wrapper label:hover span {
  border-color: var(--color-accent-primary-muted);
}
.main_ui_dashboard_team__input-wrapper span {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}
.main_ui_dashboard_team__input-wrapper input {
  margin: 0;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__modal-invitation-container {
  overflow: hidden;
  display: flex;
  flex-direction: column;
}

.main_ui_dashboard_team__modal-invitation-header {
  margin-block-end: var(--sp-xxxl);
}

.main_ui_dashboard_team__modal-invitation-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__modal-invitation-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  overflow: auto;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__invitation-list p {
  margin: 0;
}

.main_ui_dashboard_team__modal-invitation-action-buttons {
  margin-block-start: var(--sp-xxxl);
  gap: var(--sp-s);
}

.main_ui_dashboard_team__modal-restricted-container {
  overflow: hidden;
  display: flex;
  flex-direction: column;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__modal-restricted-header {
  margin-block-end: var(--sp-xxxl);
}

.main_ui_dashboard_team__modal-restricted-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__modal-restricted-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  margin-block-end: 0;
}

.main_ui_dashboard_team__restricted-warning {
  margin-block: var(--sp-xxl);
}

.main_ui_dashboard_team__restricted-email-summary {
  color: var(--color-accent-primary);
}

.main_ui_dashboard_team__restricted-emails-section {
  display: flex;
  flex-direction: column;
}

.main_ui_dashboard_team__restricted-emails-toggle {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: var(--sp-xs);
  padding: 0;
  border: none;
  background: transparent;
  cursor: pointer;
}

.main_ui_dashboard_team__restricted-emails-arrow {
  color: var(--color-accent-primary);
  transition: transform 0.15s ease;
}

.main_ui_dashboard_team__restricted-emails-arrow.main_ui_dashboard_team__expanded {
  transform: rotate(90deg);
}

.main_ui_dashboard_team__restricted-email-list {
  list-style: none;
  margin: var(--sp-s) 0 0;
  padding: 0;
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
}

.main_ui_dashboard_team__modal-select-org-container {
  display: flex;
  flex-direction: column;
  width: 32rem;
}

.main_ui_dashboard_team__modal-select-org-header {
  margin-block-end: var(--sp-xxxl);
}

.main_ui_dashboard_team__modal-select-org-body {
  display: flex;
  flex-direction: column;
  gap: var(--sp-s);
}

.main_ui_dashboard_team__modal-select-org-warning {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xxl);
}

.main_ui_dashboard_team__modal-select-org-content {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__modal-select-org-info {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__modal-select-org-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_team__modal-select-org-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-secondary);
}

.main_ui_dashboard_team__external-invitations-warning {
  margin: 0;
}

.main_ui_dashboard_team__org-block-content {
  display: grid;
  grid-template-columns: var(--sp-xxxl) 1fr var(--sp-xxxl);
  align-items: center;
  gap: var(--sp-m);
  width: -moz-max-content;
  width: max-content;
}

.main_ui_dashboard_team__org-options-btn {
  padding: 0;
  justify-content: center;
  --stroke-color: var(--color-foreground-primary);
}
.main_ui_dashboard_team__org-options-btn:hover {
  --stroke-color: var(--color-accent-primary);
}

.main_ui_dashboard_team__org-options-btn-open {
  padding: 0;
  justify-content: center;
  --stroke-color: var(--color-accent-primary);
  background-color: var(--color-background-tertiary);
  position: relative;
}

.main_ui_dashboard_team__org-menu-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--stroke-color);
}

.main_ui_dashboard_team__org-dropdown {
  box-shadow: var(--el-shadow-dark);
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  position: absolute;
  padding: var(--sp-xs);
  border-radius: 0.5rem;
  z-index: var(--z-index-dropdown);
  color: var(--color-foreground-primary);
  background-color: var(--color-background-tertiary);
  border: 0.125rem solid var(--color-background-quaternary);
  margin: 0;
  top: var(--sp-xxxl);
  width: -moz-fit-content;
  width: fit-content;
  min-width: 10rem;
}

.main_ui_dashboard_team__org-dropdown-item {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 1.75rem;
  width: 100%;
  padding: 0.375rem;
  border-radius: 0.5rem;
  cursor: pointer;
  text-transform: none;
  white-space: nowrap;
}
.main_ui_dashboard_team__org-dropdown-item:hover {
  background-color: var(--color-background-quaternary);
}

a {
  color: var(--modal-link-foreground-color);
}
@keyframes main_ui_dashboard_team_form__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_dashboard_team_form__accept-btn.main_ui_dashboard_team_form__danger, .main_ui_dashboard_team_form__accept-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_dashboard_team_form__accept-btn.main_ui_dashboard_team_form__danger svg, .main_ui_dashboard_team_form__accept-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_dashboard_team_form__accept-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_team_form__accept-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_dashboard_team_form__accept-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_team_form__accept-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_dashboard_team_form__accept-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_dashboard_team_form__accept-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_dashboard_team_form__accept-btn.disabled, [disabled].main_ui_dashboard_team_form__accept-btn, .main_ui_dashboard_team_form__accept-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_team_form__cancel-button {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_team_form__cancel-button svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_dashboard_team_form__cancel-button:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_team_form__cancel-button:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_dashboard_team_form__cancel-button:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_dashboard_team_form__cancel-button:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_dashboard_team_form__cancel-button:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_team_form__cancel-button:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_dashboard_team_form__cancel-button.disabled, [disabled].main_ui_dashboard_team_form__cancel-button, .main_ui_dashboard_team_form__cancel-button:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_dashboard_team_form__modal-close-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  --button-tertiary-border-width: 0.125rem;
  border-radius: 8px;
  color: var(--button-tertiary-foreground-color-rest);
  background-color: transparent;
  border: var(--button-tertiary-border-width) solid transparent;
  display: grid;
  place-content: center;
}
.main_ui_dashboard_team_form__modal-close-btn svg {
  stroke: var(--button-tertiary-foreground-color-rest);
}
.main_ui_dashboard_team_form__modal-close-btn:focus-visible {
  outline: none;
  background-color: var(--button-tertiary-background-color-focus);
  border: 1px solid var(--button-tertiary-border-color-focus);
  color: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_team_form__modal-close-btn:focus-visible svg {
  stroke: var(--button-tertiary-foreground-color-focus);
}
.main_ui_dashboard_team_form__modal-close-btn:hover {
  background-color: var(--button-tertiary-background-color-hover);
  color: var(--button-tertiary-foreground-color-hover);
  border-color: var(--button-secondary-border-color-hover);
}
.main_ui_dashboard_team_form__modal-close-btn:hover svg {
  stroke: var(--button-tertiary-foreground-color-hover);
}
.main_ui_dashboard_team_form__modal-close-btn:active {
  outline: none;
  border-color: transparent;
  background-color: var(--button-tertiary-background-color-active);
  color: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_team_form__modal-close-btn:active svg {
  stroke: var(--button-tertiary-foreground-color-active);
}
.main_ui_dashboard_team_form__modal-close-btn.disabled, [disabled].main_ui_dashboard_team_form__modal-close-btn, .main_ui_dashboard_team_form__modal-close-btn:disabled {
  color: var(--button-foreground-color-disabled);
  cursor: unset;
  pointer-events: none;
}
.main_ui_dashboard_team_form__modal-close-btn.disabled svg, [disabled].main_ui_dashboard_team_form__modal-close-btn svg, .main_ui_dashboard_team_form__modal-close-btn:disabled svg {
  stroke: var(--button-foreground-color-disabled);
}

.main_ui_dashboard_team_form__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_dashboard_team_form__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_dashboard_team_form__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_team_form__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_dashboard_team_form__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_dashboard_team_form__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_dashboard_team_form__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_dashboard_team_form__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_dashboard_team_form__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_dashboard_team_form__modal-close-btn svg, .main_ui_dashboard_team_form__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_dashboard_team_form__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_dashboard_team_form__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_dashboard_team_form__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_dashboard_team_form__group-name-input input {
  border: none;
  background: none;
  outline: none;
  display: block;
  max-width: 99%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  height: 1.75rem;
  width: 100%;
  flex-grow: 1;
  margin: 0.125rem 0;
  padding: 0 0 0 0.375rem;
  border-radius: 8px;
  color: var(--input-foreground-color-active);
}
.main_ui_dashboard_team_form__group-name-input input[disabled] {
  opacity: 0.5;
  pointer-events: none;
}

.main_ui_dashboard_team_form__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_dashboard_team_form__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_dashboard_team_form__group-name-input {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  align-items: flex-start;
  padding: 0;
}
.main_ui_dashboard_team_form__group-name-input input {
  padding-left: 0.5rem;
  display: flex;
  align-items: flex-start;
  height: 2rem;
  box-sizing: border-box;
  width: 100%;
  margin: 0;
  border-radius: 8px;
  border: 1px solid var(--input-border-color);
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color);
}
.main_ui_dashboard_team_form__group-name-input ::-moz-placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_dashboard_team_form__group-name-input ::placeholder {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--input-placeholder-color);
}
.main_ui_dashboard_team_form__group-name-input:hover input {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-hover);
}
.main_ui_dashboard_team_form__group-name-input:focus-within input, .main_ui_dashboard_team_form__group-name-input:active input {
  color: var(--input-foreground-color-active);
  background-color: var(--input-background-color-active);
  border: 1px solid var(--input-border-color-active);
}

.main_ui_dashboard_team_form__modal-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 300;
  background-color: var(--overlay-color);
}

.main_ui_dashboard_team_form__modal-container {
  position: relative;
  padding: 2rem;
  border-radius: 8px;
  background-color: var(--modal-background-color);
  border: 0.125rem solid var(--modal-border-color);
  min-width: 22.75rem;
  min-height: 12rem;
  max-width: 32rem;
  max-height: 32rem;
}

.main_ui_dashboard_team_form__modal-close-btn {
  position: absolute;
  top: 0.5rem;
  right: 0.375rem;
  height: 2rem;
  width: 1.75rem;
}
.main_ui_dashboard_team_form__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_dashboard_team_form__action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 1rem;
}

.main_ui_dashboard_team_form__cancel-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_team_form__accept-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
}

.main_ui_dashboard_team_form__accept-btn.main_ui_dashboard_team_form__danger {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  padding: 0.5rem 1.5rem;
  border-radius: 8px;
  height: 2rem;
  margin: 0;
  background-color: var(--modal-button-background-color-error);
  border: 1px solid var(--modal-button-background-color-error);
  color: var(--modal-button-foreground-color-error);
}

.main_ui_dashboard_team_form__modal-header {
  margin-block-end: var(--sp-xxl);
}

.main_ui_dashboard_team_form__modal-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1.125rem;
  text-transform: uppercase;
  color: var(--modal-title-foreground-color);
}

.main_ui_dashboard_team_form__modal-content {
  margin-block-end: var(--sp-xxl);
  color: var(--color-foreground-secondary);
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
}

.main_ui_dashboard_team_form__team-form {
  min-inline-size: 25rem;
}

.main_ui_dashboard_team_form__group-name-input {
  margin-block-end: var(--sp-s);
}

.main_ui_dashboard_team_form__group-name-input label {
  display: flex;
  flex-direction: column;
  gap: var(--sp-xs);
  align-items: flex-start;
  width: 100%;
  border: none;
  background-color: transparent;
  height: 100%;
}
:root {
  --z-index-auto: auto;
  --z-index-panels: 100;
  --z-index-guides: 200;
  --z-index-set: 300;
  --z-index-dropdown: 400;
  --z-index-notifications: 500;
  --z-index-loaders: 600;
}

.main_ui_dashboard_templates__dashboard-templates-section {
  background-color: var(--color-background-tertiary);
  inset-block-end: 0;
  border-end-start-radius: 0.5rem;
  border-end-end-radius: 0.5rem;
  border-start-end-radius: 0.5rem;
  display: flex;
  flex-direction: column;
  height: 15.25rem;
  justify-content: flex-end;
  margin-inline: var(--sp-s);
  margin-block-end: var(--sp-xs);
  position: absolute;
  transition: inset-block-end 300ms;
  width: calc(100% - 0.75rem);
  pointer-events: none;
  z-index: var(--z-index-panels);
}
.main_ui_dashboard_templates__dashboard-templates-section.main_ui_dashboard_templates__collapsed {
  inset-block-end: -14.25rem;
  background-color: transparent;
  transition: inset-block-end 300ms;
}
.main_ui_dashboard_templates__dashboard-templates-section.main_ui_dashboard_templates__collapsed .main_ui_dashboard_templates__title-btn {
  border-end-end-radius: 0.5rem;
  border-end-start-radius: 0.5rem;
}
.main_ui_dashboard_templates__dashboard-templates-section.main_ui_dashboard_templates__collapsed .main_ui_dashboard_templates__content,
.main_ui_dashboard_templates__dashboard-templates-section.main_ui_dashboard_templates__collapsed .main_ui_dashboard_templates__content-description {
  visibility: hidden;
}

.main_ui_dashboard_templates__title {
  pointer-events: all;
  width: 26.25rem;
  inset-block-start: -2.5rem;
  text-align: right;
  height: 3.5rem;
  position: absolute;
}

.main_ui_dashboard_templates__title-btn {
  border: none;
  cursor: pointer;
  height: 3.5rem;
  display: inline-flex;
  align-items: center;
  border-start-start-radius: 0.5rem;
  border-start-end-radius: 0.5rem;
  position: relative;
  z-index: var(--z-index-auto);
  background-color: var(--color-background-tertiary);
  width: 100%;
}

.main_ui_dashboard_templates__title-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  display: inline-block;
  vertical-align: middle;
  margin-inline: var(--sp-m) var(--sp-s);
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_templates__title-icon-container {
  display: inline-block;
  vertical-align: middle;
  margin-inline: auto var(--sp-s);
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_templates__title-icon {
  display: inline-block;
  vertical-align: middle;
  margin-inline: auto var(--sp-s);
  transform: rotate(90deg);
}

.main_ui_dashboard_templates__title-icon-text {
  margin-inline-end: var(--sp-s);
}

.main_ui_dashboard_templates__title-icon-collapsed {
  transform: rotate(-90deg);
}

.main_ui_dashboard_templates__arrow-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--color-foreground-secondary);
}

.main_ui_dashboard_templates__move-button {
  position: absolute;
  inset-block-start: 6rem;
  border: 0.125rem solid var(--color-foreground-secondary);
  border-radius: 50%;
  text-align: center;
  width: 2.25rem;
  height: 2.25rem;
  cursor: pointer;
  background-color: var(--color-background-tertiary);
  display: flex;
  align-items: center;
  justify-content: center;
  pointer-events: all;
}
.main_ui_dashboard_templates__move-button:hover {
  border: 0.125rem solid var(--color-background-tertiary);
  background-color: var(--color-accent-primary);
}
.main_ui_dashboard_templates__move-button:hover .main_ui_dashboard_templates__arrow-icon {
  stroke: var(--color-background-tertiary);
}

.main_ui_dashboard_templates__move-left {
  inset-inline-start: 0;
  margin-inline-start: 2.75rem;
  transform: rotate(180deg);
}

.main_ui_dashboard_templates__move-right {
  inset-inline-end: 0;
  margin-inline-end: 2.75rem;
}

.main_ui_dashboard_templates__content-description {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
  margin-block: var(--sp-l) calc(-1 * var(--sp-s));
  margin-inline-start: var(--sp-l);
  visibility: visible;
}

.main_ui_dashboard_templates__content {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(17.25rem, 17.25rem));
  grid-auto-flow: column;
  pointer-events: all;
  height: 14.25rem;
  overflow: scroll hidden;
  scroll-behavior: smooth;
  scroll-snap-type: x mandatory;
  scroll-snap-stop: always;
  visibility: visible;
}

.main_ui_dashboard_templates__card-container {
  width: 17.25rem;
  margin-block-start: var(--sp-xl);
  text-align: center;
  vertical-align: top;
  background-color: transparent;
  border: none;
  padding: 0;
  scroll-snap-align: start;
}

.main_ui_dashboard_templates__template-card {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  display: inline-block;
  width: 16rem;
  cursor: pointer;
  color: var(--color-foreground-primary);
  padding: 0 var(--sp-xs) var(--sp-s) var(--sp-xs);
  border-radius: 0.5rem;
  border: 0.125rem solid transparent;
}
.main_ui_dashboard_templates__template-card:hover {
  text-decoration: none;
  border-color: var(--color-accent-primary);
}
.main_ui_dashboard_templates__template-card:hover .main_ui_dashboard_templates__download-icon {
  stroke: var(--color-accent-primary);
}
.main_ui_dashboard_templates__template-card:hover .main_ui_dashboard_templates__card-text {
  color: var(--color-accent-primary);
}

.main_ui_dashboard_templates__img-container {
  width: 100%;
  height: 8.5rem;
  margin-block-end: var(--sp-s);
  border-radius: 0.375rem;
  display: flex;
  justify-content: center;
  flex-direction: column;
}
.main_ui_dashboard_templates__img-container img {
  border-radius: 0.25rem;
}

.main_ui_dashboard_templates__card-name {
  padding: 0 var(--sp-s);
  display: flex;
  justify-content: space-between;
  height: 1.5rem;
  align-items: center;
}

.main_ui_dashboard_templates__card-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 1rem;
  white-space: nowrap;
  overflow: hidden;
  width: 90%;
  text-overflow: ellipsis;
  text-align: left;
}

.main_ui_dashboard_templates__download-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 0.0625rem;
  stroke: var(--icon-foreground);
}

.main_ui_dashboard_templates__template-link {
  border: 0.125rem solid transparent;
  margin: var(--sp-xxxl);
  padding: var(--sp-xxxl) 0;
}

.main_ui_dashboard_templates__template-link-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.4;
  font-size: 0.875rem;
  color: var(--color-foreground-primary);
}

.main_ui_dashboard_templates__template-link-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-optical-sizing: auto;
  font-weight: 400;
  line-height: 1.3;
  font-size: 0.75rem;
  margin-block-start: var(--sp-s);
  color: var(--color-foreground-secondary);
}
@keyframes main_ui_auth_common__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_auth_common__login-button,
.main_ui_auth_common__login-ldap-button, .main_ui_auth_common__submit-btn,
.main_ui_auth_common__register-btn,
.main_ui_auth_common__recover-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_auth_common__login-button svg,
.main_ui_auth_common__login-ldap-button svg, .main_ui_auth_common__submit-btn svg,
.main_ui_auth_common__register-btn svg,
.main_ui_auth_common__recover-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_auth_common__login-button:focus-visible,
.main_ui_auth_common__login-ldap-button:focus-visible, .main_ui_auth_common__submit-btn:focus-visible,
.main_ui_auth_common__register-btn:focus-visible,
.main_ui_auth_common__recover-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_common__login-button:focus-visible svg,
.main_ui_auth_common__login-ldap-button:focus-visible svg, .main_ui_auth_common__submit-btn:focus-visible svg,
.main_ui_auth_common__register-btn:focus-visible svg,
.main_ui_auth_common__recover-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_common__login-button:hover,
.main_ui_auth_common__login-ldap-button:hover, .main_ui_auth_common__submit-btn:hover,
.main_ui_auth_common__register-btn:hover,
.main_ui_auth_common__recover-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_common__login-button:hover svg,
.main_ui_auth_common__login-ldap-button:hover svg, .main_ui_auth_common__submit-btn:hover svg,
.main_ui_auth_common__register-btn:hover svg,
.main_ui_auth_common__recover-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_auth_common__login-button:active,
.main_ui_auth_common__login-ldap-button:active, .main_ui_auth_common__submit-btn:active,
.main_ui_auth_common__register-btn:active,
.main_ui_auth_common__recover-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_auth_common__login-button:active svg,
.main_ui_auth_common__login-ldap-button:active svg, .main_ui_auth_common__submit-btn:active svg,
.main_ui_auth_common__register-btn:active svg,
.main_ui_auth_common__recover-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_auth_common__login-button.disabled,
.main_ui_auth_common__login-ldap-button.disabled, .main_ui_auth_common__submit-btn.disabled,
.main_ui_auth_common__register-btn.disabled,
.main_ui_auth_common__recover-btn.disabled, [disabled].main_ui_auth_common__login-button,
[disabled].main_ui_auth_common__login-ldap-button, [disabled].main_ui_auth_common__submit-btn,
[disabled].main_ui_auth_common__register-btn,
[disabled].main_ui_auth_common__recover-btn, .main_ui_auth_common__login-button:disabled,
.main_ui_auth_common__login-ldap-button:disabled, .main_ui_auth_common__submit-btn:disabled,
.main_ui_auth_common__register-btn:disabled,
.main_ui_auth_common__recover-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_common__go-back-link {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_common__go-back-link svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_common__go-back-link:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_common__go-back-link:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_common__go-back-link:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_common__go-back-link:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_auth_common__go-back-link:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_common__go-back-link:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_common__go-back-link.disabled, [disabled].main_ui_auth_common__go-back-link, .main_ui_auth_common__go-back-link:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_common__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_auth_common__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_auth_common__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_common__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_common__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_auth_common__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_auth_common__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_auth_common__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_auth_common__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_auth_common__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_auth_common__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_auth_common__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_auth_common__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_auth_common__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_auth_common__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_auth_common__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_auth_common__auth-form-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.75rem;
}
.main_ui_auth_common__auth-form-wrapper form {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  margin-top: 0.75rem;
}

.main_ui_auth_common__auth-title-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_common__separator {
  border-color: var(--modal-separator-background-color);
  margin: 0;
}

.main_ui_auth_common__auth-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color-hover);
}

.main_ui_auth_common__auth-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color);
}

.main_ui_auth_common__auth-tagline {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  margin: 0;
  color: var(--title-foreground-color);
}

.main_ui_auth_common__form-field {
  --input-width: 100%;
  --input-height: 2.5rem;
  --input-min-width: 100%;
}

.main_ui_auth_common__buttons-stack {
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_common__login-button,
.main_ui_auth_common__login-ldap-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_common__go-back {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  padding: 0;
  border-block-start: none;
}

.main_ui_auth_common__go-back-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
}

.main_ui_auth_common__links {
  display: grid;
  gap: 1.5rem;
}

.main_ui_auth_common__register,
.main_ui_auth_common__account,
.main_ui_auth_common__recovery-request,
.main_ui_auth_common__demo-account {
  display: flex;
  justify-content: center;
  gap: 0.5rem;
  padding: 0;
}

.main_ui_auth_common__register-text,
.main_ui_auth_common__account-text,
.main_ui_auth_common__recovery-text,
.main_ui_auth_common__demo-account-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: right;
  color: var(--title-foreground-color);
}

.main_ui_auth_common__register-link,
.main_ui_auth_common__account-link,
.main_ui_auth_common__recovery-link,
.main_ui_auth_common__forgot-pass-link,
.main_ui_auth_common__demo-account-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: left;
  background-color: transparent;
  border: none;
  display: inline;
  color: var(--link-foreground-color);
}
.main_ui_auth_common__register-link:hover,
.main_ui_auth_common__account-link:hover,
.main_ui_auth_common__recovery-link:hover,
.main_ui_auth_common__forgot-pass-link:hover,
.main_ui_auth_common__demo-account-link:hover {
  text-decoration: underline;
}

.main_ui_auth_common__forgot-password {
  display: flex;
  justify-content: flex-end;
}

.main_ui_auth_common__submit-btn,
.main_ui_auth_common__register-btn,
.main_ui_auth_common__recover-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_common__login-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  width: 100%;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  color: var(--button-foreground-color-focus);
}
.main_ui_auth_common__login-btn span {
  padding-block-start: 0.125rem;
}
.main_ui_auth_common__login-btn:hover {
  color: var(--button-foreground-color-focus);
  background-color: var(--button-secondary-background-color-hover);
}

.main_ui_auth_common__auth-buttons {
  display: flex;
  gap: 0.5rem;
}
@keyframes main_ui_auth_login__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_auth_login__login-button,
.main_ui_auth_login__login-ldap-button, .main_ui_auth_login__submit-btn,
.main_ui_auth_login__register-btn,
.main_ui_auth_login__recover-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_auth_login__login-button svg,
.main_ui_auth_login__login-ldap-button svg, .main_ui_auth_login__submit-btn svg,
.main_ui_auth_login__register-btn svg,
.main_ui_auth_login__recover-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_auth_login__login-button:focus-visible,
.main_ui_auth_login__login-ldap-button:focus-visible, .main_ui_auth_login__submit-btn:focus-visible,
.main_ui_auth_login__register-btn:focus-visible,
.main_ui_auth_login__recover-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_login__login-button:focus-visible svg,
.main_ui_auth_login__login-ldap-button:focus-visible svg, .main_ui_auth_login__submit-btn:focus-visible svg,
.main_ui_auth_login__register-btn:focus-visible svg,
.main_ui_auth_login__recover-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_login__login-button:hover,
.main_ui_auth_login__login-ldap-button:hover, .main_ui_auth_login__submit-btn:hover,
.main_ui_auth_login__register-btn:hover,
.main_ui_auth_login__recover-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_login__login-button:hover svg,
.main_ui_auth_login__login-ldap-button:hover svg, .main_ui_auth_login__submit-btn:hover svg,
.main_ui_auth_login__register-btn:hover svg,
.main_ui_auth_login__recover-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_auth_login__login-button:active,
.main_ui_auth_login__login-ldap-button:active, .main_ui_auth_login__submit-btn:active,
.main_ui_auth_login__register-btn:active,
.main_ui_auth_login__recover-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_auth_login__login-button:active svg,
.main_ui_auth_login__login-ldap-button:active svg, .main_ui_auth_login__submit-btn:active svg,
.main_ui_auth_login__register-btn:active svg,
.main_ui_auth_login__recover-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_auth_login__login-button.disabled,
.main_ui_auth_login__login-ldap-button.disabled, .main_ui_auth_login__submit-btn.disabled,
.main_ui_auth_login__register-btn.disabled,
.main_ui_auth_login__recover-btn.disabled, [disabled].main_ui_auth_login__login-button,
[disabled].main_ui_auth_login__login-ldap-button, [disabled].main_ui_auth_login__submit-btn,
[disabled].main_ui_auth_login__register-btn,
[disabled].main_ui_auth_login__recover-btn, .main_ui_auth_login__login-button:disabled,
.main_ui_auth_login__login-ldap-button:disabled, .main_ui_auth_login__submit-btn:disabled,
.main_ui_auth_login__register-btn:disabled,
.main_ui_auth_login__recover-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_login__go-back-link {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_login__go-back-link svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_login__go-back-link:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_login__go-back-link:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_login__go-back-link:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_login__go-back-link:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_auth_login__go-back-link:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_login__go-back-link:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_login__go-back-link.disabled, [disabled].main_ui_auth_login__go-back-link, .main_ui_auth_login__go-back-link:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_login__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_auth_login__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_auth_login__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_login__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_login__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_auth_login__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_auth_login__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_auth_login__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_auth_login__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_auth_login__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_auth_login__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_auth_login__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_auth_login__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_auth_login__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_auth_login__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_auth_login__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_auth_login__auth-form-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.75rem;
}
.main_ui_auth_login__auth-form-wrapper form {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  margin-top: 0.75rem;
}

.main_ui_auth_login__auth-title-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_login__separator {
  border-color: var(--modal-separator-background-color);
  margin: 0;
}

.main_ui_auth_login__auth-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color-hover);
}

.main_ui_auth_login__auth-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color);
}

.main_ui_auth_login__auth-tagline {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  margin: 0;
  color: var(--title-foreground-color);
}

.main_ui_auth_login__form-field {
  --input-width: 100%;
  --input-height: 2.5rem;
  --input-min-width: 100%;
}

.main_ui_auth_login__buttons-stack {
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_login__login-button,
.main_ui_auth_login__login-ldap-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_login__go-back {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  padding: 0;
  border-block-start: none;
}

.main_ui_auth_login__go-back-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
}

.main_ui_auth_login__links {
  display: grid;
  gap: 1.5rem;
}

.main_ui_auth_login__register,
.main_ui_auth_login__account,
.main_ui_auth_login__recovery-request,
.main_ui_auth_login__demo-account {
  display: flex;
  justify-content: center;
  gap: 0.5rem;
  padding: 0;
}

.main_ui_auth_login__register-text,
.main_ui_auth_login__account-text,
.main_ui_auth_login__recovery-text,
.main_ui_auth_login__demo-account-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: right;
  color: var(--title-foreground-color);
}

.main_ui_auth_login__register-link,
.main_ui_auth_login__account-link,
.main_ui_auth_login__recovery-link,
.main_ui_auth_login__forgot-pass-link,
.main_ui_auth_login__demo-account-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: left;
  background-color: transparent;
  border: none;
  display: inline;
  color: var(--link-foreground-color);
}
.main_ui_auth_login__register-link:hover,
.main_ui_auth_login__account-link:hover,
.main_ui_auth_login__recovery-link:hover,
.main_ui_auth_login__forgot-pass-link:hover,
.main_ui_auth_login__demo-account-link:hover {
  text-decoration: underline;
}

.main_ui_auth_login__forgot-password {
  display: flex;
  justify-content: flex-end;
}

.main_ui_auth_login__submit-btn,
.main_ui_auth_login__register-btn,
.main_ui_auth_login__recover-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_login__login-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  width: 100%;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  color: var(--button-foreground-color-focus);
}
.main_ui_auth_login__login-btn span {
  padding-block-start: 0.125rem;
}
.main_ui_auth_login__login-btn:hover {
  color: var(--button-foreground-color-focus);
  background-color: var(--button-secondary-background-color-hover);
}

.main_ui_auth_login__auth-buttons {
  display: flex;
  gap: 0.5rem;
}
@keyframes main_ui_auth_recovery__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_auth_recovery__login-button,
.main_ui_auth_recovery__login-ldap-button, .main_ui_auth_recovery__submit-btn,
.main_ui_auth_recovery__register-btn,
.main_ui_auth_recovery__recover-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_auth_recovery__login-button svg,
.main_ui_auth_recovery__login-ldap-button svg, .main_ui_auth_recovery__submit-btn svg,
.main_ui_auth_recovery__register-btn svg,
.main_ui_auth_recovery__recover-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_auth_recovery__login-button:focus-visible,
.main_ui_auth_recovery__login-ldap-button:focus-visible, .main_ui_auth_recovery__submit-btn:focus-visible,
.main_ui_auth_recovery__register-btn:focus-visible,
.main_ui_auth_recovery__recover-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_recovery__login-button:focus-visible svg,
.main_ui_auth_recovery__login-ldap-button:focus-visible svg, .main_ui_auth_recovery__submit-btn:focus-visible svg,
.main_ui_auth_recovery__register-btn:focus-visible svg,
.main_ui_auth_recovery__recover-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_recovery__login-button:hover,
.main_ui_auth_recovery__login-ldap-button:hover, .main_ui_auth_recovery__submit-btn:hover,
.main_ui_auth_recovery__register-btn:hover,
.main_ui_auth_recovery__recover-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_recovery__login-button:hover svg,
.main_ui_auth_recovery__login-ldap-button:hover svg, .main_ui_auth_recovery__submit-btn:hover svg,
.main_ui_auth_recovery__register-btn:hover svg,
.main_ui_auth_recovery__recover-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_auth_recovery__login-button:active,
.main_ui_auth_recovery__login-ldap-button:active, .main_ui_auth_recovery__submit-btn:active,
.main_ui_auth_recovery__register-btn:active,
.main_ui_auth_recovery__recover-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_auth_recovery__login-button:active svg,
.main_ui_auth_recovery__login-ldap-button:active svg, .main_ui_auth_recovery__submit-btn:active svg,
.main_ui_auth_recovery__register-btn:active svg,
.main_ui_auth_recovery__recover-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_auth_recovery__login-button.disabled,
.main_ui_auth_recovery__login-ldap-button.disabled, .main_ui_auth_recovery__submit-btn.disabled,
.main_ui_auth_recovery__register-btn.disabled,
.main_ui_auth_recovery__recover-btn.disabled, [disabled].main_ui_auth_recovery__login-button,
[disabled].main_ui_auth_recovery__login-ldap-button, [disabled].main_ui_auth_recovery__submit-btn,
[disabled].main_ui_auth_recovery__register-btn,
[disabled].main_ui_auth_recovery__recover-btn, .main_ui_auth_recovery__login-button:disabled,
.main_ui_auth_recovery__login-ldap-button:disabled, .main_ui_auth_recovery__submit-btn:disabled,
.main_ui_auth_recovery__register-btn:disabled,
.main_ui_auth_recovery__recover-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_recovery__go-back-link {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_recovery__go-back-link svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_recovery__go-back-link:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_recovery__go-back-link:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_recovery__go-back-link:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_recovery__go-back-link:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_auth_recovery__go-back-link:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_recovery__go-back-link:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_recovery__go-back-link.disabled, [disabled].main_ui_auth_recovery__go-back-link, .main_ui_auth_recovery__go-back-link:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_recovery__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_auth_recovery__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_auth_recovery__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_recovery__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_recovery__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_auth_recovery__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_auth_recovery__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_auth_recovery__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_auth_recovery__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_auth_recovery__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_auth_recovery__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_auth_recovery__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_auth_recovery__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_auth_recovery__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_auth_recovery__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_auth_recovery__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_auth_recovery__auth-form-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.75rem;
}
.main_ui_auth_recovery__auth-form-wrapper form {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  margin-top: 0.75rem;
}

.main_ui_auth_recovery__auth-title-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_recovery__separator {
  border-color: var(--modal-separator-background-color);
  margin: 0;
}

.main_ui_auth_recovery__auth-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color-hover);
}

.main_ui_auth_recovery__auth-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color);
}

.main_ui_auth_recovery__auth-tagline {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  margin: 0;
  color: var(--title-foreground-color);
}

.main_ui_auth_recovery__form-field {
  --input-width: 100%;
  --input-height: 2.5rem;
  --input-min-width: 100%;
}

.main_ui_auth_recovery__buttons-stack {
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_recovery__login-button,
.main_ui_auth_recovery__login-ldap-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_recovery__go-back {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  padding: 0;
  border-block-start: none;
}

.main_ui_auth_recovery__go-back-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
}

.main_ui_auth_recovery__links {
  display: grid;
  gap: 1.5rem;
}

.main_ui_auth_recovery__register,
.main_ui_auth_recovery__account,
.main_ui_auth_recovery__recovery-request,
.main_ui_auth_recovery__demo-account {
  display: flex;
  justify-content: center;
  gap: 0.5rem;
  padding: 0;
}

.main_ui_auth_recovery__register-text,
.main_ui_auth_recovery__account-text,
.main_ui_auth_recovery__recovery-text,
.main_ui_auth_recovery__demo-account-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: right;
  color: var(--title-foreground-color);
}

.main_ui_auth_recovery__register-link,
.main_ui_auth_recovery__account-link,
.main_ui_auth_recovery__recovery-link,
.main_ui_auth_recovery__forgot-pass-link,
.main_ui_auth_recovery__demo-account-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: left;
  background-color: transparent;
  border: none;
  display: inline;
  color: var(--link-foreground-color);
}
.main_ui_auth_recovery__register-link:hover,
.main_ui_auth_recovery__account-link:hover,
.main_ui_auth_recovery__recovery-link:hover,
.main_ui_auth_recovery__forgot-pass-link:hover,
.main_ui_auth_recovery__demo-account-link:hover {
  text-decoration: underline;
}

.main_ui_auth_recovery__forgot-password {
  display: flex;
  justify-content: flex-end;
}

.main_ui_auth_recovery__submit-btn,
.main_ui_auth_recovery__register-btn,
.main_ui_auth_recovery__recover-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_recovery__login-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  width: 100%;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  color: var(--button-foreground-color-focus);
}
.main_ui_auth_recovery__login-btn span {
  padding-block-start: 0.125rem;
}
.main_ui_auth_recovery__login-btn:hover {
  color: var(--button-foreground-color-focus);
  background-color: var(--button-secondary-background-color-hover);
}

.main_ui_auth_recovery__auth-buttons {
  display: flex;
  gap: 0.5rem;
}

.main_ui_auth_recovery__submit-btn {
  margin-top: 1rem;
}
@keyframes main_ui_auth_recovery_request__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_auth_recovery_request__login-button,
.main_ui_auth_recovery_request__login-ldap-button, .main_ui_auth_recovery_request__submit-btn,
.main_ui_auth_recovery_request__register-btn,
.main_ui_auth_recovery_request__recover-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_auth_recovery_request__login-button svg,
.main_ui_auth_recovery_request__login-ldap-button svg, .main_ui_auth_recovery_request__submit-btn svg,
.main_ui_auth_recovery_request__register-btn svg,
.main_ui_auth_recovery_request__recover-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_auth_recovery_request__login-button:focus-visible,
.main_ui_auth_recovery_request__login-ldap-button:focus-visible, .main_ui_auth_recovery_request__submit-btn:focus-visible,
.main_ui_auth_recovery_request__register-btn:focus-visible,
.main_ui_auth_recovery_request__recover-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_recovery_request__login-button:focus-visible svg,
.main_ui_auth_recovery_request__login-ldap-button:focus-visible svg, .main_ui_auth_recovery_request__submit-btn:focus-visible svg,
.main_ui_auth_recovery_request__register-btn:focus-visible svg,
.main_ui_auth_recovery_request__recover-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_recovery_request__login-button:hover,
.main_ui_auth_recovery_request__login-ldap-button:hover, .main_ui_auth_recovery_request__submit-btn:hover,
.main_ui_auth_recovery_request__register-btn:hover,
.main_ui_auth_recovery_request__recover-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_recovery_request__login-button:hover svg,
.main_ui_auth_recovery_request__login-ldap-button:hover svg, .main_ui_auth_recovery_request__submit-btn:hover svg,
.main_ui_auth_recovery_request__register-btn:hover svg,
.main_ui_auth_recovery_request__recover-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_auth_recovery_request__login-button:active,
.main_ui_auth_recovery_request__login-ldap-button:active, .main_ui_auth_recovery_request__submit-btn:active,
.main_ui_auth_recovery_request__register-btn:active,
.main_ui_auth_recovery_request__recover-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_auth_recovery_request__login-button:active svg,
.main_ui_auth_recovery_request__login-ldap-button:active svg, .main_ui_auth_recovery_request__submit-btn:active svg,
.main_ui_auth_recovery_request__register-btn:active svg,
.main_ui_auth_recovery_request__recover-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_auth_recovery_request__login-button.disabled,
.main_ui_auth_recovery_request__login-ldap-button.disabled, .main_ui_auth_recovery_request__submit-btn.disabled,
.main_ui_auth_recovery_request__register-btn.disabled,
.main_ui_auth_recovery_request__recover-btn.disabled, [disabled].main_ui_auth_recovery_request__login-button,
[disabled].main_ui_auth_recovery_request__login-ldap-button, [disabled].main_ui_auth_recovery_request__submit-btn,
[disabled].main_ui_auth_recovery_request__register-btn,
[disabled].main_ui_auth_recovery_request__recover-btn, .main_ui_auth_recovery_request__login-button:disabled,
.main_ui_auth_recovery_request__login-ldap-button:disabled, .main_ui_auth_recovery_request__submit-btn:disabled,
.main_ui_auth_recovery_request__register-btn:disabled,
.main_ui_auth_recovery_request__recover-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_recovery_request__go-back-link {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_recovery_request__go-back-link svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_recovery_request__go-back-link:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_recovery_request__go-back-link:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_recovery_request__go-back-link:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_recovery_request__go-back-link:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_auth_recovery_request__go-back-link:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_recovery_request__go-back-link:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_recovery_request__go-back-link.disabled, [disabled].main_ui_auth_recovery_request__go-back-link, .main_ui_auth_recovery_request__go-back-link:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_recovery_request__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_auth_recovery_request__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_auth_recovery_request__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_recovery_request__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_recovery_request__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_auth_recovery_request__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_auth_recovery_request__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_auth_recovery_request__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_auth_recovery_request__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_auth_recovery_request__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_auth_recovery_request__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_auth_recovery_request__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_auth_recovery_request__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_auth_recovery_request__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_auth_recovery_request__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_auth_recovery_request__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_auth_recovery_request__auth-form-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.75rem;
}
.main_ui_auth_recovery_request__auth-form-wrapper form {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  margin-top: 0.75rem;
}

.main_ui_auth_recovery_request__auth-title-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_recovery_request__separator {
  border-color: var(--modal-separator-background-color);
  margin: 0;
}

.main_ui_auth_recovery_request__auth-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color-hover);
}

.main_ui_auth_recovery_request__auth-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color);
}

.main_ui_auth_recovery_request__auth-tagline {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  margin: 0;
  color: var(--title-foreground-color);
}

.main_ui_auth_recovery_request__form-field {
  --input-width: 100%;
  --input-height: 2.5rem;
  --input-min-width: 100%;
}

.main_ui_auth_recovery_request__buttons-stack {
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_recovery_request__login-button,
.main_ui_auth_recovery_request__login-ldap-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_recovery_request__go-back {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  padding: 0;
  border-block-start: none;
}

.main_ui_auth_recovery_request__go-back-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
}

.main_ui_auth_recovery_request__links {
  display: grid;
  gap: 1.5rem;
}

.main_ui_auth_recovery_request__register,
.main_ui_auth_recovery_request__account,
.main_ui_auth_recovery_request__recovery-request,
.main_ui_auth_recovery_request__demo-account {
  display: flex;
  justify-content: center;
  gap: 0.5rem;
  padding: 0;
}

.main_ui_auth_recovery_request__register-text,
.main_ui_auth_recovery_request__account-text,
.main_ui_auth_recovery_request__recovery-text,
.main_ui_auth_recovery_request__demo-account-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: right;
  color: var(--title-foreground-color);
}

.main_ui_auth_recovery_request__register-link,
.main_ui_auth_recovery_request__account-link,
.main_ui_auth_recovery_request__recovery-link,
.main_ui_auth_recovery_request__forgot-pass-link,
.main_ui_auth_recovery_request__demo-account-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: left;
  background-color: transparent;
  border: none;
  display: inline;
  color: var(--link-foreground-color);
}
.main_ui_auth_recovery_request__register-link:hover,
.main_ui_auth_recovery_request__account-link:hover,
.main_ui_auth_recovery_request__recovery-link:hover,
.main_ui_auth_recovery_request__forgot-pass-link:hover,
.main_ui_auth_recovery_request__demo-account-link:hover {
  text-decoration: underline;
}

.main_ui_auth_recovery_request__forgot-password {
  display: flex;
  justify-content: flex-end;
}

.main_ui_auth_recovery_request__submit-btn,
.main_ui_auth_recovery_request__register-btn,
.main_ui_auth_recovery_request__recover-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_recovery_request__login-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  width: 100%;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  color: var(--button-foreground-color-focus);
}
.main_ui_auth_recovery_request__login-btn span {
  padding-block-start: 0.125rem;
}
.main_ui_auth_recovery_request__login-btn:hover {
  color: var(--button-foreground-color-focus);
  background-color: var(--button-secondary-background-color-hover);
}

.main_ui_auth_recovery_request__auth-buttons {
  display: flex;
  gap: 0.5rem;
}

.main_ui_auth_recovery_request__fields-row {
  margin-bottom: 0.5rem;
}

.main_ui_auth_recovery_request__notification-text-email {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.2;
  font-size: 1.25rem;
  color: var(--register-confirmation-color);
  margin-inline: 2.25rem;
}
@keyframes main_ui_auth_register__spin-animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.main_ui_auth_register__login-button,
.main_ui_auth_register__login-ldap-button, .main_ui_auth_register__submit-btn,
.main_ui_auth_register__register-btn,
.main_ui_auth_register__recover-btn {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  background-color: var(--button-primary-background-color-rest);
  border: 1px solid var(--button-primary-border-color-rest);
  color: var(--button-primary-foreground-color-rest);
  border-radius: 8px;
  min-height: 2rem;
}
.main_ui_auth_register__login-button svg,
.main_ui_auth_register__login-ldap-button svg, .main_ui_auth_register__submit-btn svg,
.main_ui_auth_register__register-btn svg,
.main_ui_auth_register__recover-btn svg {
  stroke: var(--button-primary-foreground-color-rest);
}
.main_ui_auth_register__login-button:focus-visible,
.main_ui_auth_register__login-ldap-button:focus-visible, .main_ui_auth_register__submit-btn:focus-visible,
.main_ui_auth_register__register-btn:focus-visible,
.main_ui_auth_register__recover-btn:focus-visible {
  outline: none;
  background-color: var(--button-primary-background-color-focus);
  border: 1px solid var(--button-primary-border-color-focus);
  color: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_register__login-button:focus-visible svg,
.main_ui_auth_register__login-ldap-button:focus-visible svg, .main_ui_auth_register__submit-btn:focus-visible svg,
.main_ui_auth_register__register-btn:focus-visible svg,
.main_ui_auth_register__recover-btn:focus-visible svg {
  stroke: var(--button-primary-foreground-color-focus);
}
.main_ui_auth_register__login-button:hover,
.main_ui_auth_register__login-ldap-button:hover, .main_ui_auth_register__submit-btn:hover,
.main_ui_auth_register__register-btn:hover,
.main_ui_auth_register__recover-btn:hover {
  background-color: var(--button-primary-background-color-hover);
  border: 1px solid var(--button-primary-border-color-hover);
  color: var(--button-primary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_register__login-button:hover svg,
.main_ui_auth_register__login-ldap-button:hover svg, .main_ui_auth_register__submit-btn:hover svg,
.main_ui_auth_register__register-btn:hover svg,
.main_ui_auth_register__recover-btn:hover svg {
  stroke: var(--button-primary-foreground-color-hover);
}
.main_ui_auth_register__login-button:active,
.main_ui_auth_register__login-ldap-button:active, .main_ui_auth_register__submit-btn:active,
.main_ui_auth_register__register-btn:active,
.main_ui_auth_register__recover-btn:active {
  background-color: var(--button-primary-background-color-active);
  border: 1px solid var(--button-primary-border-color-active);
  color: var(--button-primary-foreground-color-active);
  outline: none;
}
.main_ui_auth_register__login-button:active svg,
.main_ui_auth_register__login-ldap-button:active svg, .main_ui_auth_register__submit-btn:active svg,
.main_ui_auth_register__register-btn:active svg,
.main_ui_auth_register__recover-btn:active svg {
  stroke: var(--button-primary-foreground-color-active);
}
.main_ui_auth_register__login-button.disabled,
.main_ui_auth_register__login-ldap-button.disabled, .main_ui_auth_register__submit-btn.disabled,
.main_ui_auth_register__register-btn.disabled,
.main_ui_auth_register__recover-btn.disabled, [disabled].main_ui_auth_register__login-button,
[disabled].main_ui_auth_register__login-ldap-button, [disabled].main_ui_auth_register__submit-btn,
[disabled].main_ui_auth_register__register-btn,
[disabled].main_ui_auth_register__recover-btn, .main_ui_auth_register__login-button:disabled,
.main_ui_auth_register__login-ldap-button:disabled, .main_ui_auth_register__submit-btn:disabled,
.main_ui_auth_register__register-btn:disabled,
.main_ui_auth_register__recover-btn:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_register__go-back-link {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  border: 1px solid var(--button-secondary-border-color-rest);
  color: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_register__go-back-link svg {
  stroke: var(--button-secondary-foreground-color-rest);
}
.main_ui_auth_register__go-back-link:focus-visible {
  outline: none;
  background-color: var(--button-secondary-background-color-focus);
  border: 1px solid var(--button-secondary-border-color-focus);
  color: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_register__go-back-link:focus-visible svg {
  stroke: var(--button-secondary-foreground-color-focus);
}
.main_ui_auth_register__go-back-link:hover {
  background-color: var(--button-secondary-background-color-hover);
  border: 1px solid var(--button-secondary-border-color-hover);
  color: var(--button-secondary-foreground-color-hover);
  text-decoration: none;
}
.main_ui_auth_register__go-back-link:hover svg {
  stroke: var(--button-secondary-foreground-color-hover);
}
.main_ui_auth_register__go-back-link:active {
  outline: none;
  background-color: var(--button-secondary-background-color-active);
  border: 1px solid var(--button-secondary-border-color-active);
  color: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_register__go-back-link:active svg {
  stroke: var(--button-secondary-foreground-color-active);
}
.main_ui_auth_register__go-back-link.disabled, [disabled].main_ui_auth_register__go-back-link, .main_ui_auth_register__go-back-link:disabled {
  background-color: var(--button-background-color-disabled);
  border: 1px solid var(--button-border-color-disabled);
  color: var(--button-foreground-color-disabled);
  cursor: unset;
}

.main_ui_auth_register__button-radio {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 8px;
  color: var(--button-radio-foreground-color-rest);
  border-color: 1px solid var(--button-radio-background-color-rest);
}
.main_ui_auth_register__button-radio svg {
  stroke: var(--button-radio-foreground-color-rest);
}
.main_ui_auth_register__button-radio:focus-visible {
  outline: none;
  background-color: var(--button-radio-background-color-focus);
  border: 1px solid var(--button-radio-border-color-focus);
  color: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_register__button-radio:focus-visible svg {
  stroke: var(--button-radio-foreground-color-focus);
}
.main_ui_auth_register__button-radio:hover {
  background-color: var(--button-radio-background-color-rest);
  color: var(--button-radio-foreground-color-hover);
  border: 1px solid transparent;
}
.main_ui_auth_register__button-radio:hover svg {
  stroke: var(--button-radio-foreground-color-hover);
}
.main_ui_auth_register__button-radio:active {
  outline: none;
  border: 1px solid transparent;
  background-color: var(--button-radio-background-color-active);
  color: var(--button-radio-foreground-color-active);
}
.main_ui_auth_register__button-radio:active svg {
  stroke: var(--button-radio-foreground-color-active);
}

.main_ui_auth_register__button-warning {
  border: none;
  background: none;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  background-color: var(--button-warning-background-color-rest);
  border: 1px solid var(--button-warning-border-color-rest);
  color: var(--button-warning-foreground-color-rest);
}

.main_ui_auth_register__input-icon svg {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 1rem;
  width: 1rem;
  color: transparent;
  fill: none;
  stroke-width: 1px;
}

.main_ui_auth_register__input-icon svg {
  height: 0.75rem;
  width: 0.75rem;
  stroke-width: 1.33px;
}

.main_ui_auth_register__button-constraint {
  border: none;
  background: none;
  cursor: pointer;
  width: 2rem;
  height: 0.25rem;
  border-radius: 8px;
  background-color: var(--button-constraint-background-color-rest);
  padding: 0;
  margin: 0;
}
.main_ui_auth_register__button-constraint:hover {
  outline: 0.25rem solid var(--button-constraint-border-color-hover);
  background-color: var(--button-constraint-background-color-hover);
}

.main_ui_auth_register__input-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 0.75rem;
  height: 2rem;
}
.main_ui_auth_register__input-label {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  line-height: 1.2;
  text-transform: uppercase;
  font-weight: 500;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 1.25rem;
  padding-left: 0.5rem;
  height: 2rem;
  color: var(--input-foreground-color);
}

.main_ui_auth_register__modal-hint-base {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  color: var(--modal-title-foreground-color);
  border-top: 1px solid var(--modal-hint-border-color);
  border-bottom: 1px solid var(--modal-hint-border-color);
}

.main_ui_auth_register__auth-form-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.75rem;
}
.main_ui_auth_register__auth-form-wrapper form {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  margin-top: 0.75rem;
}

.main_ui_auth_register__auth-title-wrapper {
  width: 100%;
  padding-block-end: 0;
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_register__separator {
  border-color: var(--modal-separator-background-color);
  margin: 0;
}

.main_ui_auth_register__auth-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color-hover);
}

.main_ui_auth_register__auth-subtitle {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  color: var(--title-foreground-color);
}

.main_ui_auth_register__auth-tagline {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  margin: 0;
  color: var(--title-foreground-color);
}

.main_ui_auth_register__form-field {
  --input-width: 100%;
  --input-height: 2.5rem;
  --input-min-width: 100%;
}

.main_ui_auth_register__buttons-stack {
  display: grid;
  gap: 0.5rem;
}

.main_ui_auth_register__login-button,
.main_ui_auth_register__login-ldap-button {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_register__go-back {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
  padding: 0;
  border-block-start: none;
}

.main_ui_auth_register__go-back-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
}

.main_ui_auth_register__links {
  display: grid;
  gap: 1.5rem;
}

.main_ui_auth_register__register,
.main_ui_auth_register__account,
.main_ui_auth_register__recovery-request,
.main_ui_auth_register__demo-account {
  display: flex;
  justify-content: center;
  gap: 0.5rem;
  padding: 0;
}

.main_ui_auth_register__register-text,
.main_ui_auth_register__account-text,
.main_ui_auth_register__recovery-text,
.main_ui_auth_register__demo-account-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: right;
  color: var(--title-foreground-color);
}

.main_ui_auth_register__register-link,
.main_ui_auth_register__account-link,
.main_ui_auth_register__recovery-link,
.main_ui_auth_register__forgot-pass-link,
.main_ui_auth_register__demo-account-link {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  text-align: left;
  background-color: transparent;
  border: none;
  display: inline;
  color: var(--link-foreground-color);
}
.main_ui_auth_register__register-link:hover,
.main_ui_auth_register__account-link:hover,
.main_ui_auth_register__recovery-link:hover,
.main_ui_auth_register__forgot-pass-link:hover,
.main_ui_auth_register__demo-account-link:hover {
  text-decoration: underline;
}

.main_ui_auth_register__forgot-password {
  display: flex;
  justify-content: flex-end;
}

.main_ui_auth_register__submit-btn,
.main_ui_auth_register__register-btn,
.main_ui_auth_register__recover-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.688rem;
  font-weight: 500;
  line-height: 1.2;
  text-transform: uppercase;
  height: 2.5rem;
  width: 100%;
}

.main_ui_auth_register__login-btn {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.2;
  display: flex;
  align-items: center;
  gap: 0.375rem;
  width: 100%;
  border-radius: 8px;
  background-color: var(--button-secondary-background-color-rest);
  color: var(--button-foreground-color-focus);
}
.main_ui_auth_register__login-btn span {
  padding-block-start: 0.125rem;
}
.main_ui_auth_register__login-btn:hover {
  color: var(--button-foreground-color-focus);
  background-color: var(--button-secondary-background-color-hover);
}

.main_ui_auth_register__auth-buttons {
  display: flex;
  gap: 0.5rem;
}

.main_ui_auth_register__accept-terms-and-privacy-wrapper a {
  color: var(--color-foreground-secondary);
  font-weight: 700;
}

.main_ui_auth_register__checkbox-terms-and-privacy,
.main_ui_auth_register__checkbox-newsletter-updates {
  align-items: flex-start;
}

.main_ui_auth_register__register-form {
  gap: 1.5rem;
}

.main_ui_auth_register__register-success {
  gap: 1.5rem;
}
.main_ui_auth_register__register-success .main_ui_auth_register__auth-title {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.2;
}

.main_ui_auth_register__notification-icon {
  fill: var(--main-icon-foreground);
  display: flex;
  justify-content: center;
  margin-bottom: 2rem;
}
.main_ui_auth_register__notification-icon svg {
  width: 5.75rem;
  height: 5.75rem;
}

.main_ui_auth_register__notification-text {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.875rem;
  line-height: 1.4;
  font-weight: 400;
  color: var(--title-foreground-color);
}

.main_ui_auth_register__notification-text-email {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.2;
  font-size: 1.25rem;
  color: var(--register-confirmation-color);
  margin-inline: 2.25rem;
}

.main_ui_auth_register__logo-btn {
  height: 2.5rem;
}
.main_ui_auth_register__logo-btn svg {
  width: 7.5rem;
  height: 2.5rem;
  fill: var(--main-icon-foreground);
}

.main_ui_auth_register__logo-container {
  display: flex;
  justify-content: flex-start;
  width: 7.5rem;
  margin-block-end: 1.5rem;
}

.main_ui_auth_register__terms-register {
  font-family: "worksans", "vazirmatn", sans-serif;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.4;
  display: flex;
  gap: 0.25rem;
  justify-content: center;
  width: 100%;
}

.main_ui_auth_register__and-text {
  border-bottom: 1px solid transparent;
  color: var(--title-foreground-color);
}

.main_ui_auth_register__auth-link {
  color: var(--link-foreground-color);
}
.main_ui_auth_register__auth-link:hover {
  text-decoration: underline;
}