import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$util$webapi$observe_resize$$,$app$util$sse$progress_QMARK_$$,$app$main$data$dashboard$builtin_templates_fetched$$,$app$main$data$plugins$delay_open_plugin$$,$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$dashboard$stop_edit_file_name$$,$app$main$data$dashboard$start_edit_file_name$$,$app$main$data$dashboard$show_file_menu_with_position$$,$app$main$data$fonts$add_font$$,$app$main$data$dashboard$file_deleted$$,$app$main$data$dashboard$projects_fetched$$,$app$main$data$common$clear_progress$$,
$app$main$data$dashboard$deleted_files_fetched$$,$app$main$data$dashboard$recent_files_fetched$$,$app$main$data$project$files_fetched$$,$app$main$data$team$stats_fetched$$,$app$main$data$common$toggle_progress_visibility$$,$app$main$data$common$update_progress$$,$app$common$types$organization$apply_organization$$,$app$main$data$dashboard$toggle_file_select$$,$app$main$data$dashboard$clear_selected_files$$,$app$main$data$dashboard$hide_file_menu$$,$app$main$data$nitrate$add_team_to_org$$,$app$main$data$dashboard$set_file_shared$$,
$app$main$data$dashboard$delete_file$$,$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$dashboard$fetch_builtin_templates$$,$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$dashboard$fetch_projects$$,$app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$team$fetch_stats$$,$app$main$data$dashboard$rename_file$$,$app$main$data$fonts$calculate_family_to_id_mapping$$,$app$main$data$fonts$rename_and_regroup$$,
$app$main$data$fonts$merge_and_group_fonts$$,$app$main$data$fonts$update_font$$,$app$common$media$parse_font_style$$,$app$common$media$parse_font_weight$$,$app$main$data$fonts$delete_font_variant$$,$app$main$data$fonts$delete_font$$,$app$main$data$fonts$upload_font_variant$$,$app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$nitrate$remove_team_from_org$$,$app$main$data$team$delete_invitation$$,$app$main$data$nitrate$fetch_orgs_allowed$$,$app$main$data$dashboard$set_file_thumbnail$$,
$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$,$app$main$data$dashboard$handle_nitrate_change_sso$$,$app$main$data$common$go_to_dashboard_deleted$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$dashboard$open_selected_file$$,$app$main$ui$dashboard$team$webhooks_list_STAR_$$,$app$main$ui$dashboard$team$webhooks_hero_STAR_$$,$app$main$ui$dashboard$team$team_members_STAR_$$,$app$main$ui$dashboard$subscription$members_cta_STAR_$$,
$app$main$ui$dashboard$subscription$team_STAR_$$,$app$main$data$nitrate$show_change_team_org_modal$$,$app$main$data$nitrate$show_add_team_to_org_modal$$,$app$main$data$nitrate$show_remove_team_from_org_modal$$,$app$main$data$dashboard$restore_files$$,$app$main$data$dashboard$restore_project_immediately$$,$app$main$data$dashboard$restore_files_immediately$$,$app$main$data$dashboard$delete_files$$,$app$main$data$dashboard$delete_project_immediately$$,$app$main$data$dashboard$delete_files_immediately$$,
$app$main$data$dashboard$handle_organization_deleted$$,$app$main$data$dashboard$handle_user_org_change$$,$app$main$data$dashboard$handle_change_team_org$$,$app$main$data$dashboard$duplicate_file$$,$app$main$data$dashboard$create_file$$,$app$main$data$dashboard$create_project$$,$app$main$data$fonts$process_upload$$,$app$main$ui$dashboard$team$empty_invitation_table_STAR_$$,$app$main$ui$dashboard$team$webhooks_page_STAR_$$,$app$main$ui$dashboard$team$team_members_page_STAR_$$,$app$main$data$team$update_team_photo$$,
$app$main$ui$dashboard$team$team_settings_page_STAR_$$,$app$main$data$dashboard$handle_change_team_role$$,$app$main$data$dashboard$process_message$$,$app$main$data$dashboard$initialize$$,$app$main$fonts$render_font_styles$$,$app$main$data$dashboard$search$$,$app$main$ui$dashboard$team$invitation_section_STAR_$$,$app$main$ui$dashboard$team$team_invitations_page_STAR_$$,$app$main$ui$components$progress$progress_notification_widget_STAR_$$,$app$main$ui$components$portal$portal_on_document_STAR_$$,$app$main$ui$dashboard$file_menu$get_project_name$$,
$app$main$ui$dashboard$file_menu$get_project_id$$,$app$main$ui$dashboard$file_menu$get_team_name$$,$app$main$ui$dashboard$file_menu$group_by_team$$,$app$main$ui$dashboard$file_menu$file_menu_STAR_$$,$app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,$app$main$ui$dashboard$placeholder$empty_project_placeholder_STAR_$$,$app$main$ui$dashboard$placeholder$make_has_other_files_or_projects_ref$$,$app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$,$app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$,
$app$main$ui$dashboard$grid$persist_thumbnail$$,$app$main$ui$dashboard$grid$render_thumbnail$$,$app$main$ui$dashboard$grid$grid_item_thumbnail_STAR_$$,$app$main$ui$dashboard$grid$grid_item_library_STAR_$$,$app$main$ui$dashboard$grid$grid_item_metadata_STAR_$$,$app$main$ui$dashboard$grid$create_counter_element$$,$app$main$ui$dashboard$grid$grid_item_STAR_$$,$app$main$ui$dashboard$grid$grid_STAR_$$,$app$main$ui$dashboard$grid$line_grid_row$$,$app$main$ui$dashboard$grid$line_grid$$,$app$main$ui$dashboard$deleted$on_restore_project$$,
$app$main$ui$dashboard$deleted$on_delete_project$$,$app$main$ui$dashboard$deleted$header_STAR_$$,$app$main$ui$dashboard$deleted$project_context_menu_STAR_$$,$app$main$ui$dashboard$deleted$deleted_project_item_STAR_$$,$app$main$ui$dashboard$deleted$menu_STAR_$$,$app$main$ui$dashboard$deleted$deleted_section_STAR_$$,$app$main$ui$dashboard$pin_button$pin_button_STAR_$$,$app$main$ui$dashboard$files$header_STAR_$$,$app$main$ui$dashboard$files$files_section_STAR_$$,$app$main$ui$dashboard$fonts$use_page_title$$,
$app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$,$app$main$ui$dashboard$fonts$handle_font_upload$$,$app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$,$app$main$ui$dashboard$fonts$uploaded_fonts_STAR_$$,$app$main$ui$dashboard$fonts$installed_font_context_menu_STAR_$$,$app$main$ui$dashboard$fonts$installed_fonts_STAR_$$,$app$main$ui$dashboard$fonts$fonts_page_STAR_$$,$app$main$ui$dashboard$fonts$font_providers_page_STAR_$$,$app$main$ui$dashboard$libraries$libraries_page_STAR_$$,
$app$main$ui$dashboard$projects$project_item_STAR_$$,$app$main$ui$dashboard$projects$projects_section_STAR_$$,$app$main$ui$dashboard$search$search_page_STAR_$$,$app$main$ui$dashboard$templates$import_template_BANG_$$,$app$main$ui$dashboard$templates$title_STAR_$$,$app$main$ui$dashboard$templates$card_item_STAR_$$,$app$main$ui$dashboard$templates$card_item_link_STAR_$$,$app$main$ui$dashboard$templates$templates_section_STAR_$$,$app$main$ui$dashboard$dashboard_content_STAR_$$,$app$main$ui$dashboard$use_plugin_register$$,
$app$main$ui$dashboard$use_templates_import$$,$app$main$ui$dashboard$use_nitrate_entry_popup$$,$app$main$ui$dashboard$dashboard_STAR_$$,$app$main$data$common$initialize_progress_52678$$,$app$main$data$common$update_progress_52689$$,$app$main$data$common$toggle_progress_visibility_52696$$,$app$main$data$common$clear_progress_52703$$,$app$main$data$common$go_to_dashboard_deleted_52864$$,$app$main$data$team$stats_fetched_55579$$,$app$main$data$team$fetch_stats_55588$$,$app$main$data$team$update_team_photo_55612$$,
$app$main$data$team$delete_invitation_55701$$,$app$main$data$plugins$delay_open_plugin_66357$$,$app$main$data$fonts$add_font_56004$$,$app$main$data$fonts$update_font_56014$$,$app$main$data$fonts$delete_font_56027$$,$app$main$data$fonts$delete_font_variants_56043$$,$app$main$data$project$files_fetched_55847$$,$app$main$data$project$fetch_files_55876$$,$app$main$data$dashboard$initialize_73292$$,$app$main$data$dashboard$projects_fetched_73298$$,$app$main$data$dashboard$fetch_projects_73304$$,$app$main$data$dashboard$search_73308$$,
$app$main$data$dashboard$recent_files_fetched_73311$$,$app$main$data$dashboard$fetch_recent_files_73318$$,$app$main$data$dashboard$libraries_fetched_73321$$,$app$main$data$dashboard$fetch_builtin_templates_73324$$,$app$main$data$dashboard$deleted_files_fetched_73327$$,$app$main$data$dashboard$fetch_deleted_files_73332$$,$app$main$data$dashboard$clear_file_select_73335$$,$app$main$data$dashboard$toggle_file_select_73341$$,$app$main$data$dashboard$show_file_menu_with_position_73344$$,$app$main$data$dashboard$hide_file_menu_73350$$,
$app$main$data$dashboard$start_edit_file_menu_73353$$,$app$main$data$dashboard$stop_edit_file_name_73356$$,$app$main$data$dashboard$create_project_73364$$,$app$main$data$dashboard$file_deleted_73405$$,$app$main$data$dashboard$delete_file_73410$$,$app$main$data$dashboard$rename_file_73415$$,$app$main$data$dashboard$set_file_shared_73420$$,$app$main$data$dashboard$set_file_thumbnail_73425$$,$app$main$data$dashboard$create_file_73438$$,$app$main$data$dashboard$duplicate_file_73444$$,$app$main$data$dashboard$open_selected_file_73469$$,
$app$main$data$dashboard$handle_change_team_role_73475$$,$app$main$data$dashboard$handle_change_team_org_73480$$,$app$main$data$dashboard$handle_user_org_change_73486$$,$app$main$data$dashboard$handle_organization_deleted_73491$$,$app$main$data$dashboard$handle_nitrate_change_sso_73497$$,$app$main$data$dashboard$delete_files_73507$$,$app$main$data$dashboard$delete_files_immediately_73513$$,$app$main$data$dashboard$delete_project_immediately_73518$$,$app$main$data$dashboard$restore_files_73523$$,$app$main$data$dashboard$restore_files_immediately_73534$$,
$app$main$data$dashboard$restore_project_immediately_73552$$,$app$main$data$nitrate$remove_team_from_org_73772$$,$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$,$app$main$data$nitrate$add_team_to_org_73792$$,$app$main$data$nitrate$show_add_team_to_org_modal_73805$$,$app$main$data$nitrate$show_change_team_org_modal_73819$$,$cljs$cst$6395$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_dashboard$$,$cljs$cst$6377$search$$,$cljs$cst$6378$get_all_projects$$,$cljs$cst$6385$can_restore$$,
$cljs$cst$6376$is_default_team$$,$cljs$cst$6396$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$,$cljs$cst$6399$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard$$,$cljs$cst$6380$thumbnails_SLASH_generate_for_file_wasm$$,$cljs$cst$6387$has_files$$,$cljs$cst$6384$limit$$,$cljs$cst$6386$create_fn$$,$cljs$cst$6382$file_if$$,$cljs$cst$6389$font_family_tmp$$,$cljs$cst$6381$thumbnails_SLASH_generate_for_file$$,$cljs$cst$6393$app_DOT_main_DOT_ui_DOT_dashboard_DOT_libraries_SLASH_dashboard$$,
$cljs$cst$6383$sample$$,$cljs$cst$6390$download_font_family$$,$cljs$cst$6394$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$,$cljs$cst$6388$app_DOT_main_DOT_ui_DOT_dashboard_DOT_files_SLASH_dashboard$$,$cljs$cst$6391$download_font$$,$cljs$cst$6392$providers$$;
$app$util$webapi$observe_resize$$=function($node$jscomp$164$$){return $APP.$beicon$v2$core$create$$(function($subs$jscomp$9$$){var $obs$jscomp$2$$=new ResizeObserver(function($entries$jscomp$10$$){return $subs$jscomp$9$$.next($entries$jscomp$10$$)});$obs$jscomp$2$$.observe($node$jscomp$164$$);return function(){return $obs$jscomp$2$$.disconnect()}})};$app$util$sse$progress_QMARK_$$=function($event$jscomp$61$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("progress",$event$jscomp$61$$.type)};
$app$main$data$dashboard$builtin_templates_fetched$$=function($libraries$jscomp$103$$){typeof $app$main$data$dashboard$libraries_fetched_73321$$==="undefined"&&($app$main$data$dashboard$libraries_fetched_73321$$=function($libraries$jscomp$104$$,$meta73322$$){this.libraries=$libraries$jscomp$104$$;this.$meta73322$=$meta73322$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$libraries_fetched_73321$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$libraries_fetched_73321$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5032$app_DOT_main_DOT_data_DOT_dashboard_SLASH_libraries_fetched$$},$app$main$data$dashboard$libraries_fetched_73321$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73323$$,$meta73322__$1$$){return new $app$main$data$dashboard$libraries_fetched_73321$$(this.libraries,$meta73322__$1$$)},$app$main$data$dashboard$libraries_fetched_73321$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73322$},$app$main$data$dashboard$libraries_fetched_73321$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$libraries_fetched_73321$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2749$$,$state$jscomp$1047$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1047$$,$APP.$cljs$cst$5033$builtin_templates$$,this.libraries)});return new $app$main$data$dashboard$libraries_fetched_73321$$($libraries$jscomp$103$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$plugins$delay_open_plugin$$=function($plugin$jscomp$2$$){typeof $app$main$data$plugins$delay_open_plugin_66357$$==="undefined"&&($app$main$data$plugins$delay_open_plugin_66357$$=function($plugin$jscomp$3$$,$meta66358$$){this.$plugin$=$plugin$jscomp$3$$;this.$meta66358$=$meta66358$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$delay_open_plugin_66357$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$plugins$delay_open_plugin_66357$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3458$app_DOT_main_DOT_data_DOT_plugins_SLASH_delay_open_plugin$$},$app$main$data$plugins$delay_open_plugin_66357$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66359$$,$meta66358__$1$$){return new $app$main$data$plugins$delay_open_plugin_66357$$(this.$plugin$,$meta66358__$1$$)},$app$main$data$plugins$delay_open_plugin_66357$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66358$},$app$main$data$plugins$delay_open_plugin_66357$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$delay_open_plugin_66357$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1802$$,$state$jscomp$253$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$253$$,$APP.$cljs$cst$3459$app_DOT_main_DOT_data_DOT_plugins_SLASH_open_plugin$$,$APP.$cljs$cst$1725$plugin_id$$.$cljs$core$IFn$_invoke$arity$1$(this.$plugin$))});
return new $app$main$data$plugins$delay_open_plugin_66357$$($plugin$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$03$$=function(){return function(){function $G__29320__3$$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$):(0,$APP.$cljs$cst$1764$font_family$$)($x$jscomp$605$$,$y$jscomp$255$$,
$z$jscomp$96$$),$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$):(0,$APP.$cljs$cst$1767$font_weight$$)($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$),$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$3$($x$jscomp$605$$,$y$jscomp$255$$,$z$jscomp$96$$):(0,$APP.$cljs$cst$1768$font_style$$)($x$jscomp$605$$,
$y$jscomp$255$$,$z$jscomp$96$$)],null)}function $G__29320__2$$($x$jscomp$604$$,$y$jscomp$254$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$604$$,$y$jscomp$254$$):(0,$APP.$cljs$cst$1764$font_family$$)($x$jscomp$604$$,$y$jscomp$254$$),$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$604$$,
$y$jscomp$254$$):(0,$APP.$cljs$cst$1767$font_weight$$)($x$jscomp$604$$,$y$jscomp$254$$),$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$604$$,$y$jscomp$254$$):(0,$APP.$cljs$cst$1768$font_style$$)($x$jscomp$604$$,$y$jscomp$254$$)],null)}function $G__29320__1$$($x$jscomp$603$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$603$$):(0,$APP.$cljs$cst$1764$font_family$$)($x$jscomp$603$$),$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$603$$):(0,$APP.$cljs$cst$1767$font_weight$$)($x$jscomp$603$$),$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($x$jscomp$603$$):(0,$APP.$cljs$cst$1768$font_style$$)($x$jscomp$603$$)],
null)}function $G__29320__0$$(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$0$():(0,$APP.$cljs$cst$1764$font_family$$)(),$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$0$():(0,$APP.$cljs$cst$1767$font_weight$$)(),$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$0$?
$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$0$():(0,$APP.$cljs$cst$1768$font_style$$)()],null)}var $G__29320$$=null,$G__29320__4$$=function(){function $G__29321$$($x$jscomp$607$$,$y$jscomp$257$$,$z$jscomp$98$$,$var_args$jscomp$270$$){var $G__29322__i_args$jscomp$100$$=null;if(arguments.length>3){$G__29322__i_args$jscomp$100$$=0;for(var $G__29322__a$$=Array(arguments.length-3);$G__29322__i_args$jscomp$100$$<$G__29322__a$$.length;)$G__29322__a$$[$G__29322__i_args$jscomp$100$$]=arguments[$G__29322__i_args$jscomp$100$$+
3],++$G__29322__i_args$jscomp$100$$;$G__29322__i_args$jscomp$100$$=new $APP.$cljs$core$IndexedSeq$$($G__29322__a$$,0,null)}return $G__29321__delegate$$.call(this,$x$jscomp$607$$,$y$jscomp$257$$,$z$jscomp$98$$,$G__29322__i_args$jscomp$100$$)}function $G__29321__delegate$$($x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$1764$font_family$$,
$x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$1767$font_weight$$,$x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$),$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$cst$1768$font_style$$,$x$jscomp$606$$,$y$jscomp$256$$,$z$jscomp$97$$,$args$jscomp$99$$)],null)}$G__29321$$.$cljs$lang$maxFixedArity$=3;$G__29321$$.$cljs$lang$applyTo$=function($arglist__29323_args$jscomp$101$$){var $x$jscomp$608$$=
$APP.$cljs$core$first$$($arglist__29323_args$jscomp$101$$);$arglist__29323_args$jscomp$101$$=$APP.$cljs$core$next$$($arglist__29323_args$jscomp$101$$);var $y$jscomp$258$$=$APP.$cljs$core$first$$($arglist__29323_args$jscomp$101$$);$arglist__29323_args$jscomp$101$$=$APP.$cljs$core$next$$($arglist__29323_args$jscomp$101$$);var $z$jscomp$99$$=$APP.$cljs$core$first$$($arglist__29323_args$jscomp$101$$);$arglist__29323_args$jscomp$101$$=$APP.$cljs$core$rest$$($arglist__29323_args$jscomp$101$$);return $G__29321__delegate$$($x$jscomp$608$$,
$y$jscomp$258$$,$z$jscomp$99$$,$arglist__29323_args$jscomp$101$$)};$G__29321$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29321__delegate$$;return $G__29321$$}();$G__29320$$=function($x$jscomp$609$$,$y$jscomp$259$$,$z$jscomp$100$$,$var_args$jscomp$271$$){switch(arguments.length){case 0:return $G__29320__0$$.call(this);case 1:return $G__29320__1$$.call(this,$x$jscomp$609$$);case 2:return $G__29320__2$$.call(this,$x$jscomp$609$$,$y$jscomp$259$$);case 3:return $G__29320__3$$.call(this,$x$jscomp$609$$,
$y$jscomp$259$$,$z$jscomp$100$$);default:var $G__29324_G__29325__i$$=null;if(arguments.length>3){$G__29324_G__29325__i$$=0;for(var $G__29325__a$$=Array(arguments.length-3);$G__29324_G__29325__i$$<$G__29325__a$$.length;)$G__29325__a$$[$G__29324_G__29325__i$$]=arguments[$G__29324_G__29325__i$$+3],++$G__29324_G__29325__i$$;$G__29324_G__29325__i$$=new $APP.$cljs$core$IndexedSeq$$($G__29325__a$$,0,null)}return $G__29320__4$$.$cljs$core$IFn$_invoke$arity$variadic$($x$jscomp$609$$,$y$jscomp$259$$,$z$jscomp$100$$,
$G__29324_G__29325__i$$)}throw Error("Invalid arity: "+arguments.length);};$G__29320$$.$cljs$lang$maxFixedArity$=3;$G__29320$$.$cljs$lang$applyTo$=$G__29320__4$$.$cljs$lang$applyTo$;$G__29320$$.$cljs$core$IFn$_invoke$arity$0$=$G__29320__0$$;$G__29320$$.$cljs$core$IFn$_invoke$arity$1$=$G__29320__1$$;$G__29320$$.$cljs$core$IFn$_invoke$arity$2$=$G__29320__2$$;$G__29320$$.$cljs$core$IFn$_invoke$arity$3$=$G__29320__3$$;$G__29320$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__29320__4$$.$cljs$core$IFn$_invoke$arity$variadic$;
return $G__29320$$}()};
$app$main$data$dashboard$stop_edit_file_name$$=function(){typeof $app$main$data$dashboard$stop_edit_file_name_73356$$==="undefined"&&($app$main$data$dashboard$stop_edit_file_name_73356$$=function($meta73357$$){this.$meta73357$=$meta73357$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$stop_edit_file_name_73356$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$stop_edit_file_name_73356$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5049$app_DOT_main_DOT_data_DOT_dashboard_SLASH_stop_edit_file_name$$},
$app$main$data$dashboard$stop_edit_file_name_73356$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73358$$,$meta73357__$1$$){return new $app$main$data$dashboard$stop_edit_file_name_73356$$($meta73357__$1$$)},$app$main$data$dashboard$stop_edit_file_name_73356$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73357$},$app$main$data$dashboard$stop_edit_file_name_73356$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$stop_edit_file_name_73356$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2759$$,$state$jscomp$1056$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1056$$,$APP.$cljs$cst$2193$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2207$edition$$,!1)});return new $app$main$data$dashboard$stop_edit_file_name_73356$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$start_edit_file_name$$=function($file_id$jscomp$320$$){typeof $app$main$data$dashboard$start_edit_file_menu_73353$$==="undefined"&&($app$main$data$dashboard$start_edit_file_menu_73353$$=function($file_id$jscomp$321$$,$meta73354$$){this.$file_id$=$file_id$jscomp$321$$;this.$meta73354$=$meta73354$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$start_edit_file_menu_73353$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$start_edit_file_menu_73353$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5048$app_DOT_main_DOT_data_DOT_dashboard_SLASH_start_edit_file_menu$$},$app$main$data$dashboard$start_edit_file_menu_73353$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73355$$,$meta73354__$1$$){return new $app$main$data$dashboard$start_edit_file_menu_73353$$(this.$file_id$,$meta73354__$1$$)},$app$main$data$dashboard$start_edit_file_menu_73353$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73354$},$app$main$data$dashboard$start_edit_file_menu_73353$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$start_edit_file_menu_73353$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2758$$,$state$jscomp$1055$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1055$$,$APP.$cljs$cst$2193$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2207$edition$$,
!0,$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$file_id$]))});return new $app$main$data$dashboard$start_edit_file_menu_73353$$($file_id$jscomp$320$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$show_file_menu_with_position$$=function($file_id$jscomp$318$$,$pos$jscomp$125$$){typeof $app$main$data$dashboard$show_file_menu_with_position_73344$$==="undefined"&&($app$main$data$dashboard$show_file_menu_with_position_73344$$=function($file_id$jscomp$319$$,$pos$jscomp$126$$,$meta73345$$){this.$file_id$=$file_id$jscomp$319$$;this.pos=$pos$jscomp$126$$;this.$meta73345$=$meta73345$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$dashboard$show_file_menu_with_position_73344$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$show_file_menu_with_position_73344$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5045$app_DOT_main_DOT_data_DOT_dashboard_SLASH_show_file_menu_with_position$$},$app$main$data$dashboard$show_file_menu_with_position_73344$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73346$$,$meta73345__$1$$){return new $app$main$data$dashboard$show_file_menu_with_position_73344$$(this.$file_id$,
this.pos,$meta73345__$1$$)},$app$main$data$dashboard$show_file_menu_with_position_73344$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73345$},$app$main$data$dashboard$show_file_menu_with_position_73344$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$show_file_menu_with_position_73344$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2755$$,$state$jscomp$1052$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1052$$,
$APP.$cljs$cst$2193$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!0,$APP.$cljs$cst$5043$menu_pos$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.pos,$APP.$cljs$cst$1649$file_id$$,this.$file_id$]))});return new $app$main$data$dashboard$show_file_menu_with_position_73344$$($file_id$jscomp$318$$,$pos$jscomp$125$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$add_font$$=function($font$jscomp$33$$){typeof $app$main$data$fonts$add_font_56004$$==="undefined"&&($app$main$data$fonts$add_font_56004$$=function($font$jscomp$34$$,$meta56005$$){this.font=$font$jscomp$34$$;this.$meta56005$=$meta56005$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$add_font_56004$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_font_56004$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3554$app_DOT_main_DOT_data_DOT_fonts_SLASH_add_font$$},$app$main$data$fonts$add_font_56004$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56006$$,$meta56005__$1$$){return new $app$main$data$fonts$add_font_56004$$(this.font,$meta56005__$1$$)},$app$main$data$fonts$add_font_56004$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56005$},$app$main$data$fonts$add_font_56004$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$fonts$add_font_56004$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1854$$,$state$jscomp$292$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$292$$,$APP.$cljs$cst$2980$fonts$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.font),this.font)},$app$main$data$fonts$add_font_56004$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_font_56004$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1855_team_id$jscomp$84$$,$state$jscomp$293$$){$_$jscomp$1855_team_id$jscomp$84$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$293$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-font",$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1855_team_id$jscomp$84$$,$APP.$cljs$cst$1763$font_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.font),
$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$(this.font),$APP.$cljs$cst$1768$font_style$$,$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$(this.font),$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$(this.font)],null)))});return new $app$main$data$fonts$add_font_56004$$($font$jscomp$33$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$file_deleted$$=function($project_id$jscomp$18$$){typeof $app$main$data$dashboard$file_deleted_73405$$==="undefined"&&($app$main$data$dashboard$file_deleted_73405$$=function($project_id$jscomp$19$$,$meta73406$$){this.$project_id$=$project_id$jscomp$19$$;this.$meta73406$=$meta73406$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$file_deleted_73405$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$file_deleted_73405$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5065$app_DOT_main_DOT_data_DOT_dashboard_SLASH_file_deleted$$},$app$main$data$dashboard$file_deleted_73405$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73407$$,$meta73406__$1$$){return new $app$main$data$dashboard$file_deleted_73405$$(this.$project_id$,$meta73406__$1$$)},$app$main$data$dashboard$file_deleted_73405$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73406$},$app$main$data$dashboard$file_deleted_73405$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$file_deleted_73405$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2774$$,$state$jscomp$1065$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$1065$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1945$projects$$,this.$project_id$,
$APP.$cljs$cst$1080$count$$],null),$APP.$cljs$core$dec$$)});return new $app$main$data$dashboard$file_deleted_73405$$($project_id$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$projects_fetched$$=function($projects$jscomp$1$$){typeof $app$main$data$dashboard$projects_fetched_73298$$==="undefined"&&($app$main$data$dashboard$projects_fetched_73298$$=function($projects$jscomp$2$$,$meta73299$$){this.projects=$projects$jscomp$2$$;this.$meta73299$=$meta73299$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$projects_fetched_73298$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$projects_fetched_73298$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5022$app_DOT_main_DOT_data_DOT_dashboard_SLASH_projects_fetched$$},$app$main$data$dashboard$projects_fetched_73298$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73300$$,$meta73299__$1$$){return new $app$main$data$dashboard$projects_fetched_73298$$(this.projects,$meta73299__$1$$)},$app$main$data$dashboard$projects_fetched_73298$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73299$},$app$main$data$dashboard$projects_fetched_73298$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$projects_fetched_73298$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2743$$,$state$jscomp$1042$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$53$$,$map__73302__$1_p__73301$$){$map__73302__$1_p__73301$$=$APP.$cljs$core$__destructure_map$$($map__73302__$1_p__73301$$);
var $id$jscomp$819$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73302__$1_p__73301$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$assoc_in$$($state__$1$jscomp$53$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1945$projects$$,$id$jscomp$819$$],null),$map__73302__$1_p__73301$$)},$state$jscomp$1042$$,this.projects)});return new $app$main$data$dashboard$projects_fetched_73298$$($projects$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$clear_progress$$=function(){typeof $app$main$data$common$clear_progress_52703$$==="undefined"&&($app$main$data$common$clear_progress_52703$$=function($meta52704$$){this.$meta52704$=$meta52704$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$clear_progress_52703$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$clear_progress_52703$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2518$app_DOT_main_DOT_data_DOT_common_SLASH_clear_progress$$},$app$main$data$common$clear_progress_52703$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52705$$,$meta52704__$1$$){return new $app$main$data$common$clear_progress_52703$$($meta52704__$1$$)},$app$main$data$common$clear_progress_52703$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52704$},$app$main$data$common$clear_progress_52703$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$clear_progress_52703$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1549$$,$state$jscomp$129$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$129$$,$APP.$cljs$cst$2252$progress$$)});return new $app$main$data$common$clear_progress_52703$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$deleted_files_fetched$$=function($files$jscomp$16$$){typeof $app$main$data$dashboard$deleted_files_fetched_73327$$==="undefined"&&($app$main$data$dashboard$deleted_files_fetched_73327$$=function($files$jscomp$17$$,$meta73328$$){this.files=$files$jscomp$17$$;this.$meta73328$=$meta73328$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$deleted_files_fetched_73327$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$deleted_files_fetched_73327$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5036$app_DOT_main_DOT_data_DOT_dashboard_SLASH_deleted_files_fetched$$},$app$main$data$dashboard$deleted_files_fetched_73327$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73329$$,$meta73328__$1$$){return new $app$main$data$dashboard$deleted_files_fetched_73327$$(this.files,$meta73328__$1$$)},$app$main$data$dashboard$deleted_files_fetched_73327$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73328$},$app$main$data$dashboard$deleted_files_fetched_73327$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$deleted_files_fetched_73327$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2751_files__$1$jscomp$3_filtered_files$$,$state$jscomp$1048$$){var $now$jscomp$7$$=$APP.$app$common$time$now$$();$_$jscomp$2751_files__$1$jscomp$3_filtered_files$$=$APP.$cljs$core$filterv$$(function($file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$){$file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$=
$APP.$cljs$cst$5037$will_be_deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$);var $JSCompiler_temp$jscomp$2007$$;($JSCompiler_temp$jscomp$2007$$=$file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$==null)||($file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$=$APP.$cljs$core$compare$$($file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$,$now$jscomp$7$$),$JSCompiler_temp$jscomp$2007$$=$file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$<
0?!1:$file$jscomp$81_result$jscomp$inline_9686_will_be_deleted_at$$===0?!1:!0);return $JSCompiler_temp$jscomp$2007$$},this.files);$_$jscomp$2751_files__$1$jscomp$3_filtered_files$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$_$jscomp$2751_files__$1$jscomp$3_filtered_files$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1048$$,$APP.$cljs$cst$5038$deleted_files$$,
$_$jscomp$2751_files__$1$jscomp$3_filtered_files$$),$APP.$cljs$cst$1933$files$$,$APP.$app$common$data$merge$$,$_$jscomp$2751_files__$1$jscomp$3_filtered_files$$)});return new $app$main$data$dashboard$deleted_files_fetched_73327$$($files$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$recent_files_fetched$$=function($files$jscomp$14$$){typeof $app$main$data$dashboard$recent_files_fetched_73311$$==="undefined"&&($app$main$data$dashboard$recent_files_fetched_73311$$=function($files$jscomp$15$$,$meta73312$$){this.files=$files$jscomp$15$$;this.$meta73312$=$meta73312$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$recent_files_fetched_73311$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$recent_files_fetched_73311$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5028$app_DOT_main_DOT_data_DOT_dashboard_SLASH_recent_files_fetched$$},$app$main$data$dashboard$recent_files_fetched_73311$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73313$$,$meta73312__$1$$){return new $app$main$data$dashboard$recent_files_fetched_73311$$(this.files,$meta73312__$1$$)},$app$main$data$dashboard$recent_files_fetched_73311$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73312$},$app$main$data$dashboard$recent_files_fetched_73311$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$recent_files_fetched_73311$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2747_files__$1$jscomp$2$$,$state$jscomp$1045$$){$_$jscomp$2747_files__$1$jscomp$2$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.files);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1045$$,
$APP.$cljs$cst$5029$recent_files$$,$_$jscomp$2747_files__$1$jscomp$2$$),$APP.$cljs$cst$1933$files$$,$APP.$app$common$data$merge$$,$_$jscomp$2747_files__$1$jscomp$2$$)});return new $app$main$data$dashboard$recent_files_fetched_73311$$($files$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$files_fetched$$=function($project_id$jscomp$11$$,$files$jscomp$11$$){typeof $app$main$data$project$files_fetched_55847$$==="undefined"&&($app$main$data$project$files_fetched_55847$$=function($project_id$jscomp$12$$,$files$jscomp$12$$,$meta55848$$){this.$project_id$=$project_id$jscomp$12$$;this.files=$files$jscomp$12$$;this.$meta55848$=$meta55848$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$files_fetched_55847$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$files_fetched_55847$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3567$app_DOT_main_DOT_data_DOT_project_SLASH_files_fetched$$},$app$main$data$project$files_fetched_55847$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55849$$,$meta55848__$1$$){return new $app$main$data$project$files_fetched_55847$$(this.$project_id$,this.files,$meta55848__$1$$)},$app$main$data$project$files_fetched_55847$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55848$},$app$main$data$project$files_fetched_55847$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$files_fetched_55847$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1870$$,$state$jscomp$307$$){var $self__$jscomp$4111$$=this;return $APP.$app$common$data$update_in_when$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$307$$,$APP.$cljs$cst$1933$files$$,$APP.$cljs$core$merge$$,
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$self__$jscomp$4111$$.files)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1945$projects$$,$self__$jscomp$4111$$.$project_id$],null),function($project$jscomp$2$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$2$$,$APP.$cljs$cst$1080$count$$,$APP.$cljs$core$count$$($self__$jscomp$4111$$.files))})});return new $app$main$data$project$files_fetched_55847$$($project_id$jscomp$11$$,
$files$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$stats_fetched$$=function($team_id$jscomp$50$$,$stats$$){typeof $app$main$data$team$stats_fetched_55579$$==="undefined"&&($app$main$data$team$stats_fetched_55579$$=function($team_id$jscomp$51$$,$stats$jscomp$1$$,$meta55580$$){this.$team_id$=$team_id$jscomp$51$$;this.$stats$=$stats$jscomp$1$$;this.$meta55580$=$meta55580$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$stats_fetched_55579$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$stats_fetched_55579$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3336$app_DOT_main_DOT_data_DOT_team_SLASH_stats_fetched$$},$app$main$data$team$stats_fetched_55579$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55581$$,$meta55580__$1$$){return new $app$main$data$team$stats_fetched_55579$$(this.$team_id$,this.$stats$,$meta55580__$1$$)},$app$main$data$team$stats_fetched_55579$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55580$},$app$main$data$team$stats_fetched_55579$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$stats_fetched_55579$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1721$$,$state$jscomp$223$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$223$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2181$teams$$,
this.$team_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$3337$stats$$,this.$stats$)});return new $app$main$data$team$stats_fetched_55579$$($team_id$jscomp$50$$,$stats$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$toggle_progress_visibility$$=function(){typeof $app$main$data$common$toggle_progress_visibility_52696$$==="undefined"&&($app$main$data$common$toggle_progress_visibility_52696$$=function($meta52697$$){this.$meta52697$=$meta52697$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$toggle_progress_visibility_52696$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$toggle_progress_visibility_52696$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2517$app_DOT_main_DOT_data_DOT_common_SLASH_toggle_progress_visibility$$},$app$main$data$common$toggle_progress_visibility_52696$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52698$$,$meta52697__$1$$){return new $app$main$data$common$toggle_progress_visibility_52696$$($meta52697__$1$$)},$app$main$data$common$toggle_progress_visibility_52696$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52697$},$app$main$data$common$toggle_progress_visibility_52696$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$toggle_progress_visibility_52696$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1548$$,$state$jscomp$128$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$128$$,$APP.$cljs$cst$2252$progress$$,function($state__$1$jscomp$10$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$10$$,$APP.$cljs$cst$2357$visible$$,$APP.$cljs$core$not$$)})});return new $app$main$data$common$toggle_progress_visibility_52696$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$update_progress$$=function($p__52687$$){var $map__52688__$1$$=$APP.$cljs$core$__destructure_map$$($p__52687$$),$index$jscomp$212$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52688__$1$$,$APP.$cljs$cst$1801$index$$),$total$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52688__$1$$,$APP.$cljs$cst$2338$total$$);typeof $app$main$data$common$update_progress_52689$$==="undefined"&&($app$main$data$common$update_progress_52689$$=function($p__52687$jscomp$1$$,
$map__52688$jscomp$1$$,$params$jscomp$154$$,$index$jscomp$213$$,$total$jscomp$8$$,$meta52690$$){this.$p__52687$=$p__52687$jscomp$1$$;this.$map__52688$=$map__52688$jscomp$1$$;this.params=$params$jscomp$154$$;this.index=$index$jscomp$213$$;this.total=$total$jscomp$8$$;this.$meta52690$=$meta52690$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$update_progress_52689$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$update_progress_52689$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2515$app_DOT_main_DOT_data_DOT_common_SLASH_update_progress$$},$app$main$data$common$update_progress_52689$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52691$$,$meta52690__$1$$){return new $app$main$data$common$update_progress_52689$$(this.$p__52687$,this.$map__52688$,this.params,this.index,this.total,$meta52690__$1$$)},$app$main$data$common$update_progress_52689$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta52690$},$app$main$data$common$update_progress_52689$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$update_progress_52689$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1547$$,$state$jscomp$127$$){var $self__$jscomp$3320$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$127$$,$APP.$cljs$cst$2252$progress$$,function($state__$1$jscomp$9$$){var $healthy_QMARK__last_update$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$9$$,$APP.$cljs$cst$2514$last_update$$),$hints$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$9$$,$APP.$cljs$cst$2509$hints$$),$hint$jscomp$7_threshold$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$9$$,$APP.$cljs$cst$2510$slow_progress_threshold$$);$hint$jscomp$7_threshold$jscomp$1$$=($healthy_QMARK__last_update$$=$APP.$app$common$time$diff_ms$$($healthy_QMARK__last_update$$)<
$hint$jscomp$7_threshold$jscomp$1$$)?function(){var $fexpr__52693$$=$APP.$cljs$cst$2033$normal$$.$cljs$core$IFn$_invoke$arity$2$($hints$jscomp$3$$,$APP.$app$main$data$common$noop_fn$$);return $fexpr__52693$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__52693$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3320$$.params):$fexpr__52693$$($self__$jscomp$3320$$.params)}():function(){var $fexpr__52694$$=$APP.$cljs$cst$2516$slow$$.$cljs$core$IFn$_invoke$arity$2$($hints$jscomp$3$$,$APP.$app$main$data$common$noop_fn$$);
return $fexpr__52694$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__52694$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3320$$.params):$fexpr__52694$$($self__$jscomp$3320$$.params)}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$9$$,$APP.$cljs$cst$2252$progress$$,
$self__$jscomp$3320$$.index),$APP.$cljs$cst$2338$total$$,$self__$jscomp$3320$$.total),$APP.$cljs$cst$2514$last_update$$,$APP.$app$common$time$now$$()),$APP.$cljs$cst$2513$healthy$$,$healthy_QMARK__last_update$$),$APP.$cljs$cst$275$hint$$,$hint$jscomp$7_threshold$jscomp$1$$)})});return new $app$main$data$common$update_progress_52689$$($p__52687$$,$map__52688__$1$$,$map__52688__$1$$,$index$jscomp$212$$,$total$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$organization$apply_organization$$=function($team$jscomp$15$$,$organization$jscomp$2$$){var $id$jscomp$818$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($organization$jscomp$2$$);return $APP.$cljs$core$truth_$$($id$jscomp$818$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($team$jscomp$15$$,$APP.$cljs$cst$3297$organization$$,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$143$$,$k$jscomp$669$$){var $v$jscomp$628$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($organization$jscomp$2$$,
$k$jscomp$669$$);return $v$jscomp$628$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$143$$,$k$jscomp$669$$,$v$jscomp$628$$):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$143$$,$k$jscomp$669$$)},function(){var $or__5025__auto__$jscomp$968$$=$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$15$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$968$$)?$or__5025__auto__$jscomp$968$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$}(),
$APP.$app$common$types$organization$organization__GT_team_keys$$)):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$15$$,$APP.$cljs$cst$3297$organization$$)};
$app$main$data$dashboard$toggle_file_select$$=function($p__73339$$){var $map__73340__$1$$=$APP.$cljs$core$__destructure_map$$($p__73339$$),$id$jscomp$820$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73340__$1$$,$APP.$cljs$cst$266$id$$),$project_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73340__$1$$,$APP.$cljs$cst$2189$project_id$$);typeof $app$main$data$dashboard$toggle_file_select_73341$$==="undefined"&&($app$main$data$dashboard$toggle_file_select_73341$$=
function($p__73339$jscomp$1$$,$map__73340$jscomp$1$$,$file$jscomp$83$$,$id$jscomp$821$$,$project_id$jscomp$17$$,$meta73342$$){this.$p__73339$=$p__73339$jscomp$1$$;this.$map__73340$=$map__73340$jscomp$1$$;this.file=$file$jscomp$83$$;this.id=$id$jscomp$821$$;this.$project_id$=$project_id$jscomp$17$$;this.$meta73342$=$meta73342$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$toggle_file_select_73341$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_file_select_73341$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5044$app_DOT_main_DOT_data_DOT_dashboard_SLASH_toggle_file_select$$},$app$main$data$dashboard$toggle_file_select_73341$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73343$$,$meta73342__$1$$){return new $app$main$data$dashboard$toggle_file_select_73341$$(this.$p__73339$,this.$map__73340$,this.file,this.id,this.$project_id$,
$meta73342__$1$$)},$app$main$data$dashboard$toggle_file_select_73341$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73342$},$app$main$data$dashboard$toggle_file_select_73341$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$toggle_file_select_73341$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2754_selected_project_id$$,$state$jscomp$1051$$){var $self__$jscomp$6866$$=this;$_$jscomp$2754_selected_project_id$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1051$$,$APP.$cljs$cst$2192$selected_project$$);return $_$jscomp$2754_selected_project_id$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2754_selected_project_id$$,$self__$jscomp$6866$$.$project_id$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1051$$,$APP.$cljs$cst$2191$selected_files$$,function($p1__73338_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__73338_SHARP_$$,
$self__$jscomp$6866$$.id)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($p1__73338_SHARP_$$,$self__$jscomp$6866$$.id):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__73338_SHARP_$$,$self__$jscomp$6866$$.id)}),$APP.$cljs$cst$2192$selected_project$$,$self__$jscomp$6866$$.$project_id$):$state$jscomp$1051$$});return new $app$main$data$dashboard$toggle_file_select_73341$$($p__73339$$,$map__73340__$1$$,$map__73340__$1$$,$id$jscomp$820$$,$project_id$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$clear_selected_files$$=function(){typeof $app$main$data$dashboard$clear_file_select_73335$$==="undefined"&&($app$main$data$dashboard$clear_file_select_73335$$=function($meta73336$$){this.$meta73336$=$meta73336$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$clear_file_select_73335$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clear_file_select_73335$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5041$app_DOT_main_DOT_data_DOT_dashboard_SLASH_clear_file_select$$},$app$main$data$dashboard$clear_file_select_73335$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73337$$,$meta73336__$1$$){return new $app$main$data$dashboard$clear_file_select_73335$$($meta73336__$1$$)},$app$main$data$dashboard$clear_file_select_73335$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73336$},$app$main$data$dashboard$clear_file_select_73335$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$clear_file_select_73335$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2753$$,$state$jscomp$1050$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1050$$,$APP.$cljs$cst$2191$selected_files$$),$APP.$cljs$cst$2192$selected_project$$),$APP.$cljs$cst$2193$dashboard_local$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5042$menu_open$$,$APP.$cljs$cst$5043$menu_pos$$)});return new $app$main$data$dashboard$clear_file_select_73335$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$hide_file_menu$$=function(){typeof $app$main$data$dashboard$hide_file_menu_73350$$==="undefined"&&($app$main$data$dashboard$hide_file_menu_73350$$=function($meta73351$$){this.$meta73351$=$meta73351$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$hide_file_menu_73350$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$hide_file_menu_73350$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5047$app_DOT_main_DOT_data_DOT_dashboard_SLASH_hide_file_menu$$},$app$main$data$dashboard$hide_file_menu_73350$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73352$$,$meta73351__$1$$){return new $app$main$data$dashboard$hide_file_menu_73350$$($meta73351__$1$$)},$app$main$data$dashboard$hide_file_menu_73350$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73351$},$app$main$data$dashboard$hide_file_menu_73350$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$hide_file_menu_73350$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2757$$,$state$jscomp$1054$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1054$$,$APP.$cljs$cst$2193$dashboard_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!1)});return new $app$main$data$dashboard$hide_file_menu_73350$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$add_team_to_org$$=function($p__73789$$){var $map__73790__$1$$=$APP.$cljs$core$__destructure_map$$($p__73789$$),$team_id$jscomp$133$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73790__$1$$,$APP.$cljs$cst$1944$team_id$$),$organization_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73790__$1$$,$APP.$cljs$cst$3301$organization_id$$);typeof $app$main$data$nitrate$add_team_to_org_73792$$==="undefined"&&($app$main$data$nitrate$add_team_to_org_73792$$=
function($p__73789$jscomp$1$$,$map__73790$jscomp$1$$,$params$jscomp$366$$,$team_id$jscomp$134$$,$organization_id$jscomp$13$$,$meta73793$$){this.$p__73789$=$p__73789$jscomp$1$$;this.$map__73790$=$map__73790$jscomp$1$$;this.params=$params$jscomp$366$$;this.$team_id$=$team_id$jscomp$134$$;this.$organization_id$=$organization_id$jscomp$13$$;this.$meta73793$=$meta73793$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$add_team_to_org_73792$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$add_team_to_org_73792$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5200$app_DOT_main_DOT_data_DOT_nitrate_SLASH_add_team_to_org$$},$app$main$data$nitrate$add_team_to_org_73792$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73794$$,$meta73793__$1$$){return new $app$main$data$nitrate$add_team_to_org_73792$$(this.$p__73789$,this.$map__73790$,this.params,this.$team_id$,this.$organization_id$,
$meta73793__$1$$)},$app$main$data$nitrate$add_team_to_org_73792$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73793$},$app$main$data$nitrate$add_team_to_org_73792$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$add_team_to_org_73792$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$())},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5201$app_DOT_main_DOT_data_DOT_nitrate_SLASH_add_team_to_organization$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,this.$team_id$,$APP.$cljs$cst$3301$organization_id$$,this.$organization_id$],null)))});return new $app$main$data$nitrate$add_team_to_org_73792$$($p__73789$$,$map__73790__$1$$,$map__73790__$1$$,$team_id$jscomp$133$$,$organization_id$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$set_file_shared$$=function($p__73418$$){var $map__73419__$1$$=$APP.$cljs$core$__destructure_map$$($p__73418$$),$id$jscomp$840$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73419__$1$$,$APP.$cljs$cst$266$id$$),$is_shared$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73419__$1$$,$APP.$cljs$cst$2190$is_shared$$);typeof $app$main$data$dashboard$set_file_shared_73420$$==="undefined"&&($app$main$data$dashboard$set_file_shared_73420$$=function($p__73418$jscomp$1$$,
$map__73419$jscomp$1$$,$params$jscomp$343$$,$id$jscomp$841$$,$is_shared$jscomp$4$$,$meta73421$$){this.$p__73418$=$p__73418$jscomp$1$$;this.$map__73419$=$map__73419$jscomp$1$$;this.params=$params$jscomp$343$$;this.id=$id$jscomp$841$$;this.$is_shared$=$is_shared$jscomp$4$$;this.$meta73421$=$meta73421$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$set_file_shared_73420$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$set_file_shared_73420$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5069$app_DOT_main_DOT_data_DOT_dashboard_SLASH_set_file_shared$$},$app$main$data$dashboard$set_file_shared_73420$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73422$$,$meta73421__$1$$){return new $app$main$data$dashboard$set_file_shared_73420$$(this.$p__73418$,this.$map__73419$,this.params,this.id,this.$is_shared$,$meta73421__$1$$)},$app$main$data$dashboard$set_file_shared_73420$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73421$},$app$main$data$dashboard$set_file_shared_73420$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_shared_73420$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$4044$shared$$,this.$is_shared$],null)},$app$main$data$dashboard$set_file_shared_73420$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_shared_73420$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__73423__$jscomp$2781$$,$state$jscomp$1068$$){$G__73423__$jscomp$2781$$=$APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$$($state$jscomp$1068$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$files$$,this.id,$APP.$cljs$cst$2190$is_shared$$],null),$APP.$cljs$core$constantly$$(this.$is_shared$)),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5029$recent_files$$,this.id,$APP.$cljs$cst$2190$is_shared$$],null),$APP.$cljs$core$constantly$$(this.$is_shared$));return $APP.$cljs$core$not$$(this.$is_shared$)?$APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__73423__$jscomp$2781$$,$APP.$cljs$cst$2187$shared_files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])):
$G__73423__$jscomp$2781$$},$app$main$data$dashboard$set_file_shared_73420$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_shared_73420$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4045$set_file_shared$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
this.id,$APP.$cljs$cst$2190$is_shared$$,this.$is_shared$],null))),$APP.$cljs$core$truth_$$(this.$is_shared$)?$APP.$beicon$v2$core$map$$(function($summary$jscomp$1$$){return $APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2687$variants$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$1$$))>0?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"set-file-variants-shared",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"dashboard"],null)):null},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2491$get_file_summary$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null))):null)});return new $app$main$data$dashboard$set_file_shared_73420$$($p__73418$$,$map__73419__$1$$,$map__73419__$1$$,$id$jscomp$840$$,$is_shared$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_file$$=function($p__73408$$){var $map__73409__$1$$=$APP.$cljs$core$__destructure_map$$($p__73408$$),$id$jscomp$836$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73409__$1$$,$APP.$cljs$cst$266$id$$),$project_id$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73409__$1$$,$APP.$cljs$cst$2189$project_id$$);typeof $app$main$data$dashboard$delete_file_73410$$==="undefined"&&($app$main$data$dashboard$delete_file_73410$$=function($p__73408$jscomp$1$$,
$map__73409$jscomp$1$$,$params$jscomp$339$$,$id$jscomp$837$$,$project_id$jscomp$21$$,$meta73411$$){this.$p__73408$=$p__73408$jscomp$1$$;this.$map__73409$=$map__73409$jscomp$1$$;this.params=$params$jscomp$339$$;this.id=$id$jscomp$837$$;this.$project_id$=$project_id$jscomp$21$$;this.$meta73411$=$meta73411$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_file_73410$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$delete_file_73410$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5066$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_file$$},$app$main$data$dashboard$delete_file_73410$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73412$$,$meta73411__$1$$){return new $app$main$data$dashboard$delete_file_73410$$(this.$p__73408$,this.$map__73409$,this.params,this.id,this.$project_id$,$meta73411__$1$$)},$app$main$data$dashboard$delete_file_73410$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73411$},$app$main$data$dashboard$delete_file_73410$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_file_73410$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2775$$,$state$jscomp$1066$$){return $APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1066$$,
$APP.$cljs$cst$1933$files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])),$APP.$cljs$cst$2187$shared_files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id])),$APP.$cljs$cst$5029$recent_files$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id]))},$app$main$data$dashboard$delete_file_73410$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$delete_file_73410$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$dashboard$file_deleted$$,this.$project_id$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5067$delete_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$dashboard$delete_file_73410$$($p__73408$$,
$map__73409__$1$$,$map__73409__$1$$,$id$jscomp$836$$,$project_id$jscomp$20$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($team_id$jscomp$104$$){typeof $app$main$data$dashboard$fetch_deleted_files_73332$$==="undefined"&&($app$main$data$dashboard$fetch_deleted_files_73332$$=function($team_id$jscomp$105$$,$meta73333$$){this.$team_id$=$team_id$jscomp$105$$;this.$meta73333$=$meta73333$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_deleted_files_73332$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_deleted_files_73332$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5039$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_deleted_files$$},$app$main$data$dashboard$fetch_deleted_files_73332$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73334$$,$meta73333__$1$$){return new $app$main$data$dashboard$fetch_deleted_files_73332$$(this.$team_id$,$meta73333__$1$$)},$app$main$data$dashboard$fetch_deleted_files_73332$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73333$},$app$main$data$dashboard$fetch_deleted_files_73332$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_deleted_files_73332$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2752_or__5025__auto__$jscomp$inline_9688$$,$state$jscomp$1049_temp__5825__auto__$jscomp$267$$){$_$jscomp$2752_or__5025__auto__$jscomp$inline_9688$$=this.$team_id$;$state$jscomp$1049_temp__5825__auto__$jscomp$267$$=$APP.$cljs$core$truth_$$($_$jscomp$2752_or__5025__auto__$jscomp$inline_9688$$)?
$_$jscomp$2752_or__5025__auto__$jscomp$inline_9688$$:$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1049_temp__5825__auto__$jscomp$267$$);return $APP.$cljs$core$truth_$$($state$jscomp$1049_temp__5825__auto__$jscomp$267$$)?$APP.$beicon$v2$core$map$$($app$main$data$dashboard$deleted_files_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5040$get_team_deleted_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,
$state$jscomp$1049_temp__5825__auto__$jscomp$267$$],null))):null});return new $app$main$data$dashboard$fetch_deleted_files_73332$$($team_id$jscomp$104$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_builtin_templates$$=function(){typeof $app$main$data$dashboard$fetch_builtin_templates_73324$$==="undefined"&&($app$main$data$dashboard$fetch_builtin_templates_73324$$=function($meta73325$$){this.$meta73325$=$meta73325$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_builtin_templates_73324$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_builtin_templates_73324$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5034$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_builtin_templates$$},$app$main$data$dashboard$fetch_builtin_templates_73324$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73326$$,$meta73325__$1$$){return new $app$main$data$dashboard$fetch_builtin_templates_73324$$($meta73325__$1$$)},$app$main$data$dashboard$fetch_builtin_templates_73324$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73325$},$app$main$data$dashboard$fetch_builtin_templates_73324$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_builtin_templates_73324$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$dashboard$builtin_templates_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5035$get_builtin_templates$$))});return new $app$main$data$dashboard$fetch_builtin_templates_73324$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($team_id$jscomp$102$$){typeof $app$main$data$dashboard$fetch_recent_files_73318$$==="undefined"&&($app$main$data$dashboard$fetch_recent_files_73318$$=function($team_id$jscomp$103$$,$meta73319$$){this.$team_id$=$team_id$jscomp$103$$;this.$meta73319$=$meta73319$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_recent_files_73318$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_recent_files_73318$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5030$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_recent_files$$},$app$main$data$dashboard$fetch_recent_files_73318$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73320$$,$meta73319__$1$$){return new $app$main$data$dashboard$fetch_recent_files_73318$$(this.$team_id$,$meta73319__$1$$)},$app$main$data$dashboard$fetch_recent_files_73318$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73319$},$app$main$data$dashboard$fetch_recent_files_73318$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_recent_files_73318$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2748_or__5025__auto__$jscomp$inline_9690$$,$state$jscomp$1046_temp__5825__auto__$jscomp$266$$){$_$jscomp$2748_or__5025__auto__$jscomp$inline_9690$$=this.$team_id$;$state$jscomp$1046_temp__5825__auto__$jscomp$266$$=$APP.$cljs$core$truth_$$($_$jscomp$2748_or__5025__auto__$jscomp$inline_9690$$)?
$_$jscomp$2748_or__5025__auto__$jscomp$inline_9690$$:$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1046_temp__5825__auto__$jscomp$266$$);return $APP.$cljs$core$truth_$$($state$jscomp$1046_temp__5825__auto__$jscomp$266$$)?$APP.$beicon$v2$core$map$$($app$main$data$dashboard$recent_files_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5031$get_team_recent_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,
$state$jscomp$1046_temp__5825__auto__$jscomp$266$$],null))):null});return new $app$main$data$dashboard$fetch_recent_files_73318$$($team_id$jscomp$102$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$fetch_projects$$=function($team_id$jscomp$99$$){typeof $app$main$data$dashboard$fetch_projects_73304$$==="undefined"&&($app$main$data$dashboard$fetch_projects_73304$$=function($team_id$jscomp$100$$,$meta73305$$){this.$team_id$=$team_id$jscomp$100$$;this.$meta73305$=$meta73305$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$fetch_projects_73304$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$fetch_projects_73304$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5023$app_DOT_main_DOT_data_DOT_dashboard_SLASH_fetch_projects$$},$app$main$data$dashboard$fetch_projects_73304$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73306$$,$meta73305__$1$$){return new $app$main$data$dashboard$fetch_projects_73304$$(this.$team_id$,$meta73305__$1$$)},$app$main$data$dashboard$fetch_projects_73304$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73305$},$app$main$data$dashboard$fetch_projects_73304$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$fetch_projects_73304$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$dashboard$projects_fetched$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5024$get_projects$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,
this.$team_id$],null)))});return new $app$main$data$dashboard$fetch_projects_73304$$($team_id$jscomp$99$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$=function($project_id$jscomp$13$$){typeof $app$main$data$project$fetch_files_55876$$==="undefined"&&($app$main$data$project$fetch_files_55876$$=function($project_id$jscomp$14$$,$meta55877$$){this.$project_id$=$project_id$jscomp$14$$;this.$meta55877$=$meta55877$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$fetch_files_55876$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$fetch_files_55876$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3568$app_DOT_main_DOT_data_DOT_project_SLASH_fetch_files$$},$app$main$data$project$fetch_files_55876$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55878$$,$meta55877__$1$$){return new $app$main$data$project$fetch_files_55876$$(this.$project_id$,$meta55877__$1$$)},$app$main$data$project$fetch_files_55876$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55877$},$app$main$data$project$fetch_files_55876$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$fetch_files_55876$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1871_or__5025__auto__$jscomp$inline_9692$$,$state$jscomp$308_temp__5825__auto__$jscomp$196$$){$_$jscomp$1871_or__5025__auto__$jscomp$inline_9692$$=this.$project_id$;$state$jscomp$308_temp__5825__auto__$jscomp$196$$=$APP.$cljs$core$truth_$$($_$jscomp$1871_or__5025__auto__$jscomp$inline_9692$$)?
$_$jscomp$1871_or__5025__auto__$jscomp$inline_9692$$:$APP.$cljs$cst$2182$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$308_temp__5825__auto__$jscomp$196$$);return $APP.$cljs$core$truth_$$($state$jscomp$308_temp__5825__auto__$jscomp$196$$)?$APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$project$files_fetched$$,$state$jscomp$308_temp__5825__auto__$jscomp$196$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3569$get_project_files$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2189$project_id$$,$state$jscomp$308_temp__5825__auto__$jscomp$196$$],null))):null});return new $app$main$data$project$fetch_files_55876$$($project_id$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$fetch_stats$$=function(){typeof $app$main$data$team$fetch_stats_55588$$==="undefined"&&($app$main$data$team$fetch_stats_55588$$=function($meta55589$$){this.$meta55589$=$meta55589$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$fetch_stats_55588$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_stats_55588$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3338$app_DOT_main_DOT_data_DOT_team_SLASH_fetch_stats$$},
$app$main$data$team$fetch_stats_55588$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55590$$,$meta55589__$1$$){return new $app$main$data$team$fetch_stats_55588$$($meta55589__$1$$)},$app$main$data$team$fetch_stats_55588$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55589$},$app$main$data$team$fetch_stats_55588$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$fetch_stats_55588$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1722_team_id$jscomp$52$$,$state$jscomp$224$$){$_$jscomp$1722_team_id$jscomp$52$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$224$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$team$stats_fetched$$,$_$jscomp$1722_team_id$jscomp$52$$),$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3339$get_team_stats$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1722_team_id$jscomp$52$$],null)))});return new $app$main$data$team$fetch_stats_55588$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$rename_file$$=function($p__73413$$){var $map__73414__$1$$=$APP.$cljs$core$__destructure_map$$($p__73413$$),$id$jscomp$838$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73414__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$400$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73414__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$rename_file_73415$$==="undefined"&&($app$main$data$dashboard$rename_file_73415$$=function($p__73413$jscomp$1$$,
$map__73414$jscomp$1$$,$params$jscomp$341$$,$id$jscomp$839$$,$name$jscomp$401$$,$meta73416$$){this.$p__73413$=$p__73413$jscomp$1$$;this.$map__73414$=$map__73414$jscomp$1$$;this.params=$params$jscomp$341$$;this.id=$id$jscomp$839$$;this.name=$name$jscomp$401$$;this.$meta73416$=$meta73416$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$rename_file_73415$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73415$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5068$app_DOT_main_DOT_data_DOT_dashboard_SLASH_rename_file$$},$app$main$data$dashboard$rename_file_73415$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73417$$,$meta73416__$1$$){return new $app$main$data$dashboard$rename_file_73415$$(this.$p__73413$,this.$map__73414$,this.params,this.id,this.name,$meta73416__$1$$)},$app$main$data$dashboard$rename_file_73415$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73416$},$app$main$data$dashboard$rename_file_73415$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73415$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name],null)},$app$main$data$dashboard$rename_file_73415$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73415$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2778$$,$state$jscomp$1067$$){return $APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$$($APP.$app$common$data$update_in_when$$($state$jscomp$1067$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$files$$,this.id,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$constantly$$(this.name)),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2187$shared_files$$,
this.id,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$constantly$$(this.name)),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5029$recent_files$$,this.id,$APP.$cljs$cst$725$name$$],null),$APP.$cljs$core$constantly$$(this.name))},$app$main$data$dashboard$rename_file_73415$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$rename_file_73415$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $params__$1$jscomp$45$$=$APP.$cljs$core$select_keys$$(this.params,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$725$name$$],null));return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4539$rename_file$$,$params__$1$jscomp$45$$))});return new $app$main$data$dashboard$rename_file_73415$$($p__73413$$,$map__73414__$1$$,$map__73414__$1$$,
$id$jscomp$838$$,$name$jscomp$400$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$calculate_family_to_id_mapping$$=function($existing$jscomp$2$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__55988_SHARP_$$,$p2__55989_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55988_SHARP_$$,$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($p2__55989_SHARP_$$),$APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($p2__55989_SHARP_$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$vals$$($existing$jscomp$2$$))};
$app$main$data$fonts$rename_and_regroup$$=function($current_fonts$jscomp$1$$,$id$jscomp$446$$,$name$jscomp$282$$,$installed_fonts$jscomp$1$$){var $famdb$jscomp$1$$=$app$main$data$fonts$calculate_family_to_id_mapping$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$current_fonts$jscomp$1$$,$installed_fonts$jscomp$1$$]))),$font_id$jscomp$28$$=function(){var $or__5025__auto__$jscomp$661$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($famdb$jscomp$1$$,
$name$jscomp$282$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$661$$)?$or__5025__auto__$jscomp$661$$:$APP.$app$common$uuid$next$$()}();return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($current_fonts$jscomp$1$$,$id$jscomp$446$$,function($font$jscomp$32$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$32$$,$APP.$cljs$cst$1764$font_family$$,$name$jscomp$282$$),$APP.$cljs$cst$1763$font_id$$,
$font_id$jscomp$28$$)})};
$app$main$data$fonts$merge_and_group_fonts$$=function($G__56128_current_fonts_result$jscomp$271$$,$G__56126_famdb_installed_fonts$$,$G__56127_incoming_fonts_items$jscomp$33$$){$G__56126_famdb_installed_fonts$$=$app$main$data$fonts$calculate_family_to_id_mapping$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__56128_current_fonts_result$jscomp$271$$,$G__56126_famdb_installed_fonts$$])));for($G__56127_incoming_fonts_items$jscomp$33$$=$APP.$cljs$core$vals$$($G__56127_incoming_fonts_items$jscomp$33$$);;){var $id$jscomp$445_temp__5823__auto__$jscomp$162$$=
$APP.$cljs$core$first$$($G__56127_incoming_fonts_items$jscomp$33$$);if($APP.$cljs$core$truth_$$($id$jscomp$445_temp__5823__auto__$jscomp$162$$)){var $font_family$jscomp$6_map__55994__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$445_temp__5823__auto__$jscomp$162$$),$font$jscomp$31_item$jscomp$68$$=$font_family$jscomp$6_map__55994__$1$$;$id$jscomp$445_temp__5823__auto__$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_family$jscomp$6_map__55994__$1$$,$APP.$cljs$cst$266$id$$);
$font_family$jscomp$6_map__55994__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_family$jscomp$6_map__55994__$1$$,$APP.$cljs$cst$1764$font_family$$);var $font_id$jscomp$27_or__5025__auto__$jscomp$inline_9694$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__56126_famdb_installed_fonts$$,$font_family$jscomp$6_map__55994__$1$$);$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9694$$=$APP.$cljs$core$truth_$$($font_id$jscomp$27_or__5025__auto__$jscomp$inline_9694$$)?$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9694$$:
$APP.$app$common$uuid$next$$();$font$jscomp$31_item$jscomp$68$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$31_item$jscomp$68$$,$APP.$cljs$cst$1763$font_id$$,$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9694$$);$G__56126_famdb_installed_fonts$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56126_famdb_installed_fonts$$,$font_family$jscomp$6_map__55994__$1$$,$font_id$jscomp$27_or__5025__auto__$jscomp$inline_9694$$);$G__56127_incoming_fonts_items$jscomp$33$$=
$APP.$cljs$core$rest$$($G__56127_incoming_fonts_items$jscomp$33$$);$G__56128_current_fonts_result$jscomp$271$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__56128_current_fonts_result$jscomp$271$$,$id$jscomp$445_temp__5823__auto__$jscomp$162$$,$font$jscomp$31_item$jscomp$68$$)}else return $G__56128_current_fonts_result$jscomp$271$$}};
$app$main$data$fonts$update_font$$=function($p__56012$$){var $map__56013__$1$$=$APP.$cljs$core$__destructure_map$$($p__56012$$),$id$jscomp$447$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56013__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$283$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__56013__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$fonts$update_font_56014$$==="undefined"&&($app$main$data$fonts$update_font_56014$$=function($p__56012$jscomp$1$$,$map__56013$jscomp$1$$,
$params$jscomp$249$$,$id$jscomp$448$$,$name$jscomp$284$$,$meta56015$$){this.$p__56012$=$p__56012$jscomp$1$$;this.$map__56013$=$map__56013$jscomp$1$$;this.params=$params$jscomp$249$$;this.id=$id$jscomp$448$$;this.name=$name$jscomp$284$$;this.$meta56015$=$meta56015$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$update_font_56014$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$update_font_56014$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3555$app_DOT_main_DOT_data_DOT_fonts_SLASH_update_font$$},$app$main$data$fonts$update_font_56014$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56016$$,$meta56015__$1$$){return new $app$main$data$fonts$update_font_56014$$(this.$p__56012$,this.$map__56013$,this.params,this.id,this.name,$meta56015__$1$$)},$app$main$data$fonts$update_font_56014$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56015$},$app$main$data$fonts$update_font_56014$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$update_font_56014$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1856$$,$state$jscomp$294$$){var $self__$jscomp$4073$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$294$$,$APP.$cljs$cst$2980$fonts$$,$APP.$cljs$core$update_vals$$,function($font$jscomp$35$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4073$$.id,$APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$35$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($font$jscomp$35$$,$APP.$cljs$cst$1764$font_family$$,$self__$jscomp$4073$$.name):$font$jscomp$35$$})},$app$main$data$fonts$update_font_56014$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$update_font_56014$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1857_team_id$jscomp$85$$,$state$jscomp$295$$){$_$jscomp$1857_team_id$jscomp$85$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$295$$);
return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3556$update_font$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name,$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1857_team_id$jscomp$85$$],null)))});return new $app$main$data$fonts$update_font_56014$$($p__56012$$,$map__56013__$1$$,$map__56013__$1$$,$id$jscomp$447$$,$name$jscomp$283$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$media$parse_font_style$$=function($JSCompiler_inline_result$jscomp$2008_variant$jscomp$1$$){var $or__5025__auto__$jscomp$inline_9696$$=$APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(italic)(?:[-_\s]|$)/i,$JSCompiler_inline_result$jscomp$2008_variant$jscomp$1$$);$JSCompiler_inline_result$jscomp$2008_variant$jscomp$1$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9696$$)?$or__5025__auto__$jscomp$inline_9696$$:$APP.$cljs$core$re_seq$$(/italic$/i,$JSCompiler_inline_result$jscomp$2008_variant$jscomp$1$$);
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2008_variant$jscomp$1$$)?"italic":"normal"};
$app$common$media$parse_font_weight$$=function($variant$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(hairline|thin)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?100:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(extra\s*light|ultra\s*light)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?200:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(light)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?300:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(normal|regular)(?=(?:[-_\s]|$|italic\b))/i,
$variant$$))?400:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(medium)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?500:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(semi\s*bold|demi\s*bold)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?600:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(extra\s*bold|ultra\s*bold)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?800:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(bold)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?
700:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(extra\s*black|ultra\s*black)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?950:$APP.$cljs$core$truth_$$($APP.$cljs$core$re_seq$$(/(?:^|[-_\s])(black|heavy|solid)(?=(?:[-_\s]|$|italic\b))/i,$variant$$))?900:400};
$app$main$data$fonts$delete_font_variant$$=function($id$jscomp$449$$){typeof $app$main$data$fonts$delete_font_variants_56043$$==="undefined"&&($app$main$data$fonts$delete_font_variants_56043$$=function($id$jscomp$450$$,$meta56044$$){this.id=$id$jscomp$450$$;this.$meta56044$=$meta56044$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$delete_font_variants_56043$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$fonts$delete_font_variants_56043$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3559$app_DOT_main_DOT_data_DOT_fonts_SLASH_delete_font_variants$$},$app$main$data$fonts$delete_font_variants_56043$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56045$$,$meta56044__$1$$){return new $app$main$data$fonts$delete_font_variants_56043$$(this.id,$meta56044__$1$$)},$app$main$data$fonts$delete_font_variants_56043$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta56044$},$app$main$data$fonts$delete_font_variants_56043$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_variants_56043$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1861$$,$state$jscomp$298$$){var $self__$jscomp$4084$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$298$$,$APP.$cljs$cst$2980$fonts$$,function($variants$jscomp$7$$){return $APP.$app$common$data$removem$$(function($p__56050_variant$jscomp$15$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56050_variant$jscomp$15$$,
0,null);$p__56050_variant$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56050_variant$jscomp$15$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p__56050_variant$jscomp$15$$),$self__$jscomp$4084$$.id)},$variants$jscomp$7$$)})},$app$main$data$fonts$delete_font_variants_56043$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_variants_56043$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1862_team_id$jscomp$87$$,$state$jscomp$299$$){$_$jscomp$1862_team_id$jscomp$87$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$299$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3560$delete_font_variant$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1862_team_id$jscomp$87$$],
null))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-font-variant",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1862_team_id$jscomp$87$$],null))))});return new $app$main$data$fonts$delete_font_variants_56043$$($id$jscomp$449$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$delete_font$$=function($font_id$jscomp$29$$){typeof $app$main$data$fonts$delete_font_56027$$==="undefined"&&($app$main$data$fonts$delete_font_56027$$=function($font_id$jscomp$30$$,$meta56028$$){this.$font_id$=$font_id$jscomp$30$$;this.$meta56028$=$meta56028$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$delete_font_56027$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_56027$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3557$app_DOT_main_DOT_data_DOT_fonts_SLASH_delete_font$$},$app$main$data$fonts$delete_font_56027$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56029$$,$meta56028__$1$$){return new $app$main$data$fonts$delete_font_56027$$(this.$font_id$,$meta56028__$1$$)},$app$main$data$fonts$delete_font_56027$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56028$},$app$main$data$fonts$delete_font_56027$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_56027$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.$font_id$],null)},$app$main$data$fonts$delete_font_56027$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_56027$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1859$$,$state$jscomp$296$$){var $self__$jscomp$4079$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$296$$,$APP.$cljs$cst$2980$fonts$$,function($variants$jscomp$6$$){return $APP.$app$common$data$removem$$(function($p__56031_variant$jscomp$14$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56031_variant$jscomp$14$$,0,null);$p__56031_variant$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__56031_variant$jscomp$14$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($p__56031_variant$jscomp$14$$),
$self__$jscomp$4079$$.$font_id$)},$variants$jscomp$6$$)})},$app$main$data$fonts$delete_font_56027$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$delete_font_56027$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1860_team_id$jscomp$86$$,$state$jscomp$297$$){$_$jscomp$1860_team_id$jscomp$86$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$297$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3558$delete_font$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.$font_id$,$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1860_team_id$jscomp$86$$],null))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-font",$APP.$cljs$cst$1944$team_id$$,$_$jscomp$1860_team_id$jscomp$86$$,$APP.$cljs$cst$1763$font_id$$,this.$font_id$],null))))});return new $app$main$data$fonts$delete_font_56027$$($font_id$jscomp$29$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$upload_font_variant$$=function($map__55839__$1_p__55838$$){$map__55839__$1_p__55838$$=$APP.$cljs$core$__destructure_map$$($map__55839__$1_p__55838$$);var $data$jscomp$304$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55839__$1_p__55838$$,$APP.$cljs$cst$142$data$$),$team_id$jscomp$82$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55839__$1_p__55838$$,$APP.$cljs$cst$1944$team_id$$),$font_id$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55839__$1_p__55838$$,
$APP.$cljs$cst$1763$font_id$$),$font_family$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55839__$1_p__55838$$,$APP.$cljs$cst$1764$font_family$$),$font_weight$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55839__$1_p__55838$$,$APP.$cljs$cst$1767$font_weight$$),$font_style$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55839__$1_p__55838$$,$APP.$cljs$cst$1768$font_style$$);return $APP.$beicon$v2$core$mapcat$$(function($uploads$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3550$create_font_variant$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$82$$,$APP.$cljs$cst$1763$font_id$$,$font_id$jscomp$26$$,$APP.$cljs$cst$1764$font_family$$,$font_family$jscomp$5$$,$APP.$cljs$cst$1767$font_weight$$,$font_weight$jscomp$10$$,$APP.$cljs$cst$1768$font_style$$,$font_style$jscomp$11$$,$APP.$cljs$cst$3551$uploads$$,$uploads$$],null))},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$121$$,$p__55843_session_id$jscomp$4$$){var $mtype$jscomp$12$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55843_session_id$jscomp$4$$,0,null);$p__55843_session_id$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__55843_session_id$jscomp$4$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$121$$,$mtype$jscomp$12$$,$p__55843_session_id$jscomp$4$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($buffer$jscomp$81_p__55850$$){var $mtype$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$81_p__55850$$,
0,null);$buffer$jscomp$81_p__55850$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($buffer$jscomp$81_p__55850$$,1,null);return $APP.$beicon$v2$core$map$$(function($map__55855__$1_p__55854_session_id$jscomp$5$$){$map__55855__$1_p__55854_session_id$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($map__55855__$1_p__55854_session_id$jscomp$5$$);$map__55855__$1_p__55854_session_id$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55855__$1_p__55854_session_id$jscomp$5$$,
$APP.$cljs$cst$2343$session_id$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$mtype$jscomp$13$$,$map__55855__$1_p__55854_session_id$jscomp$5$$],null)},$APP.$app$main$data$uploads$upload_blob_chunked$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(new Blob([$buffer$jscomp$81_p__55850$$],{type:$mtype$jscomp$13$$}),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3538$chunk_size$$,10485760])))},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($data$jscomp$304$$)))))};
$app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52676$$){var $map__52677__$1$$=$APP.$cljs$core$__destructure_map$$($p__52676$$),$key$jscomp$329$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52677__$1$$,$APP.$cljs$cst$302$key$$),$index$jscomp$210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52677__$1$$,$APP.$cljs$cst$1801$index$$),$total$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52677__$1$$,
$APP.$cljs$cst$2338$total$$),$hints$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52677__$1$$,$APP.$cljs$cst$2509$hints$$),$slow_progress_threshold$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52677__$1$$,$APP.$cljs$cst$2510$slow_progress_threshold$$);typeof $app$main$data$common$initialize_progress_52678$$==="undefined"&&($app$main$data$common$initialize_progress_52678$$=function($p__52676$jscomp$1$$,$map__52677$jscomp$1$$,$params$jscomp$152$$,$key$jscomp$330$$,
$index$jscomp$211$$,$total$jscomp$6$$,$hints$jscomp$2$$,$slow_progress_threshold$jscomp$1$$,$meta52679$$){this.$p__52676$=$p__52676$jscomp$1$$;this.$map__52677$=$map__52677$jscomp$1$$;this.params=$params$jscomp$152$$;this.key=$key$jscomp$330$$;this.index=$index$jscomp$211$$;this.total=$total$jscomp$6$$;this.$hints$=$hints$jscomp$2$$;this.$slow_progress_threshold$=$slow_progress_threshold$jscomp$1$$;this.$meta52679$=$meta52679$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$common$initialize_progress_52678$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$initialize_progress_52678$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2511$app_DOT_main_DOT_data_DOT_common_SLASH_initialize_progress$$},$app$main$data$common$initialize_progress_52678$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52680$$,$meta52679__$1$$){return new $app$main$data$common$initialize_progress_52678$$(this.$p__52676$,
this.$map__52677$,this.params,this.key,this.index,this.total,this.$hints$,this.$slow_progress_threshold$,$meta52679__$1$$)},$app$main$data$common$initialize_progress_52678$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52679$},$app$main$data$common$initialize_progress_52678$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$initialize_progress_52678$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1546$$,
$state$jscomp$126$$){var $self__$jscomp$3316$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$126$$,$APP.$cljs$cst$2252$progress$$,function(){var $hint$jscomp$6$$=function(){var $fexpr__52681$$=$APP.$cljs$cst$2033$normal$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3316$$.$hints$,$APP.$app$main$data$common$noop_fn$$);return $fexpr__52681$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__52681$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$3316$$.params):$fexpr__52681$$($self__$jscomp$3316$$.params)}();
return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2509$hints$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$275$hint$$,$APP.$cljs$cst$2512$threshold$$,$APP.$cljs$cst$2513$healthy$$,$APP.$cljs$cst$2338$total$$,$APP.$cljs$cst$2514$last_update$$,$APP.$cljs$cst$2252$progress$$,$APP.$cljs$cst$2357$visible$$],[$self__$jscomp$3316$$.$hints$,$self__$jscomp$3316$$.key,$hint$jscomp$6$$,function(){var $or__5025__auto__$jscomp$444$$=$self__$jscomp$3316$$.$slow_progress_threshold$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$444$$)?
$or__5025__auto__$jscomp$444$$:5E3}(),!0,$self__$jscomp$3316$$.total,$APP.$app$common$time$now$$(),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3316$$.index,0),!0])})});return new $app$main$data$common$initialize_progress_52678$$($p__52676$$,$map__52677__$1$$,$map__52677__$1$$,$key$jscomp$329$$,$index$jscomp$210$$,$total$jscomp$5$$,$hints$jscomp$1$$,$slow_progress_threshold$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$remove_team_from_org$$=function($p__73770$$){var $map__73771__$1$$=$APP.$cljs$core$__destructure_map$$($p__73770$$),$team_id$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73771__$1$$,$APP.$cljs$cst$1944$team_id$$),$organization_id$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73771__$1$$,$APP.$cljs$cst$3301$organization_id$$),$organization_name$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73771__$1$$,
$APP.$cljs$cst$3302$organization_name$$);typeof $app$main$data$nitrate$remove_team_from_org_73772$$==="undefined"&&($app$main$data$nitrate$remove_team_from_org_73772$$=function($p__73770$jscomp$1$$,$map__73771$jscomp$1$$,$params$jscomp$364$$,$team_id$jscomp$130$$,$organization_id$jscomp$11$$,$organization_name$jscomp$5$$,$meta73773$$){this.$p__73770$=$p__73770$jscomp$1$$;this.$map__73771$=$map__73771$jscomp$1$$;this.params=$params$jscomp$364$$;this.$team_id$=$team_id$jscomp$130$$;this.$organization_id$=
$organization_id$jscomp$11$$;this.$organization_name$=$organization_name$jscomp$5$$;this.$meta73773$=$meta73773$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$remove_team_from_org_73772$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$remove_team_from_org_73772$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5194$app_DOT_main_DOT_data_DOT_nitrate_SLASH_remove_team_from_org$$},
$app$main$data$nitrate$remove_team_from_org_73772$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73774$$,$meta73773__$1$$){return new $app$main$data$nitrate$remove_team_from_org_73772$$(this.$p__73770$,this.$map__73771$,this.params,this.$team_id$,this.$organization_id$,this.$organization_name$,$meta73773__$1$$)},$app$main$data$nitrate$remove_team_from_org_73772$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73773$},$app$main$data$nitrate$remove_team_from_org_73772$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$remove_team_from_org_73772$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$92$$){var $code$jscomp$46$$=$APP.$cljs$cst$273$code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($cause$jscomp$92$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$46$$,$APP.$cljs$cst$5195$not_allowed$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3311$no_permission_modal$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5196$no_orgs_change$$],null))):$APP.$beicon$v2$core$throw$0$$($cause$jscomp$92$$)},$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$modal$hide$$())},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5194$app_DOT_main_DOT_data_DOT_nitrate_SLASH_remove_team_from_org$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1944$team_id$$,this.$team_id$,$APP.$cljs$cst$3301$organization_id$$,this.$organization_id$,$APP.$cljs$cst$3302$organization_name$$,this.$organization_name$],null))))});return new $app$main$data$nitrate$remove_team_from_org_73772$$($p__73770$$,$map__73771__$1$$,$map__73771__$1$$,$team_id$jscomp$129$$,$organization_id$jscomp$10$$,$organization_name$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$team$delete_invitation$$=function($p__55699$$){var $map__55700__$1$$=$APP.$cljs$core$__destructure_map$$($p__55699$$),$email$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55700__$1$$,$APP.$cljs$cst$3207$email$$),$team_id$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55700__$1$$,$APP.$cljs$cst$1944$team_id$$);typeof $app$main$data$team$delete_invitation_55701$$==="undefined"&&($app$main$data$team$delete_invitation_55701$$=function($p__55699$jscomp$1$$,
$map__55700$jscomp$1$$,$params$jscomp$216$$,$email$jscomp$7$$,$team_id$jscomp$67$$,$meta55702$$){this.$p__55699$=$p__55699$jscomp$1$$;this.$map__55700$=$map__55700$jscomp$1$$;this.params=$params$jscomp$216$$;this.email=$email$jscomp$7$$;this.$team_id$=$team_id$jscomp$67$$;this.$meta55702$=$meta55702$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$delete_invitation_55701$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$team$delete_invitation_55701$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3368$app_DOT_main_DOT_data_DOT_team_SLASH_delete_invitation$$},$app$main$data$team$delete_invitation_55701$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55703$$,$meta55702__$1$$){return new $app$main$data$team$delete_invitation_55701$$(this.$p__55699$,this.$map__55700$,this.params,this.email,this.$team_id$,$meta55702__$1$$)},$app$main$data$team$delete_invitation_55701$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55702$},$app$main$data$team$delete_invitation_55701$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$delete_invitation_55701$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $map__55704_on_success$jscomp$17$$=$APP.$cljs$core$meta$$(this.params),$map__55704__$1_on_error$jscomp$21$$=$APP.$cljs$core$__destructure_map$$($map__55704_on_success$jscomp$17$$);$map__55704_on_success$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55704__$1_on_error$jscomp$21$$,
$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__55704__$1_on_error$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__55704__$1_on_error$jscomp$21$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55704__$1_on_error$jscomp$21$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($map__55704_on_success$jscomp$17$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3369$delete_team_invitation$$,
this.params)))});return new $app$main$data$team$delete_invitation_55701$$($p__55699$$,$map__55700__$1$$,$map__55700__$1$$,$email$jscomp$6$$,$team_id$jscomp$66$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$fetch_orgs_allowed$$=function($team_id$jscomp$135$$,$orgs$$){var $add_anybody_orgs$$=$APP.$cljs$core$filterv$$(function($p1__73797_SHARP_$$){return $APP.$app$common$types$nitrate_permissions$allowed_QMARK_$$($APP.$cljs$cst$3293$add_anybody_to_team$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3295$org_perms$$,$p1__73797_SHARP_$$],null))},$orgs$$),$org_ids_to_check_orgs_to_check$$=$APP.$cljs$core$filterv$$(function($p1__73798_SHARP_$$){return!$APP.$app$common$types$nitrate_permissions$allowed_QMARK_$$($APP.$cljs$cst$3293$add_anybody_to_team$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3295$org_perms$$,$p1__73798_SHARP_$$],null))},$orgs$$);$org_ids_to_check_orgs_to_check$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$org_ids_to_check_orgs_to_check$$);return $APP.$cljs$core$empty_QMARK_$$($org_ids_to_check_orgs_to_check$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($org$jscomp$3$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($org$jscomp$3$$),!0],null)}),$orgs$$)):$APP.$beicon$v2$core$map$$(function($checked_orgs$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($org$jscomp$4$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($org$jscomp$4$$),!0],null)}),$add_anybody_orgs$$),$checked_orgs$$]))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5202$all_team_members_in_orgs$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$135$$,$APP.$cljs$cst$5203$organization_ids$$,$org_ids_to_check_orgs_to_check$$],null)))};
$app$main$data$dashboard$set_file_thumbnail$$=function($file_id$jscomp$322$$,$thumbnail_id$$){typeof $app$main$data$dashboard$set_file_thumbnail_73425$$==="undefined"&&($app$main$data$dashboard$set_file_thumbnail_73425$$=function($file_id$jscomp$323$$,$thumbnail_id$jscomp$1$$,$meta73426$$){this.$file_id$=$file_id$jscomp$323$$;this.$thumbnail_id$=$thumbnail_id$jscomp$1$$;this.$meta73426$=$meta73426$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$set_file_thumbnail_73425$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_thumbnail_73425$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5070$app_DOT_main_DOT_data_DOT_dashboard_SLASH_set_file_thumbnail$$},$app$main$data$dashboard$set_file_thumbnail_73425$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73427$$,$meta73426__$1$$){return new $app$main$data$dashboard$set_file_thumbnail_73425$$(this.$file_id$,this.$thumbnail_id$,$meta73426__$1$$)},$app$main$data$dashboard$set_file_thumbnail_73425$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73426$},$app$main$data$dashboard$set_file_thumbnail_73425$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$set_file_thumbnail_73425$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2783$$,$state$jscomp$1069$$){var $self__$jscomp$6949$$=this;return $APP.$app$common$data$update_when$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$data$update_in_when$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$1069$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$files$$,$self__$jscomp$6949$$.$file_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2584$thumbnail_id$$,$self__$jscomp$6949$$.$thumbnail_id$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5029$recent_files$$,$self__$jscomp$6949$$.$file_id$],null),$APP.$cljs$core$assoc$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2584$thumbnail_id$$,$self__$jscomp$6949$$.$thumbnail_id$])),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5038$deleted_files$$,$self__$jscomp$6949$$.$file_id$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2584$thumbnail_id$$,$self__$jscomp$6949$$.$thumbnail_id$])),$APP.$cljs$cst$5071$dashboard_search_result$$,
function($files$jscomp$18$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73424_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6949$$.$file_id$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73424_SHARP_$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__73424_SHARP_$$,$APP.$cljs$cst$2584$thumbnail_id$$,$self__$jscomp$6949$$.$thumbnail_id$):$p1__73424_SHARP_$$},$files$jscomp$18$$)})});return new $app$main$data$dashboard$set_file_thumbnail_73425$$($file_id$jscomp$322$$,
$thumbnail_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$=function($itemsize_limit__$1$jscomp$1$$){var $width_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$th_size_width$jscomp$84$$=$APP.$cljs$core$_deref$$($width_STAR_$$),$rowref$$=(0,$APP.$rumext$v2$use_ref$$)();$itemsize_limit__$1$jscomp$1$$=Math.max(1,Math.min(10,$APP.$app$common$math$floor$$($th_size_width$jscomp$84$$!=null?$th_size_width$jscomp$84$$/($itemsize_limit__$1$jscomp$1$$!=null?
$itemsize_limit__$1$jscomp$1$$:$th_size_width$jscomp$84$$>=1030?280:230):0)));$th_size_width$jscomp$84$$=$APP.$cljs$core$truth_$$($th_size_width$jscomp$84$$)?$APP.$app$common$math$floor$$(($th_size_width$jscomp$84$$-32-($itemsize_limit__$1$jscomp$1$$-1)*24)/$itemsize_limit__$1$jscomp$1$$-12):null;var $th_size__$1$$=$APP.$cljs$core$even_QMARK_$$($th_size_width$jscomp$84$$|0)?$th_size_width$jscomp$84$$:$th_size_width$jscomp$84$$-1;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($th_size__$1$$)],
function(){if($APP.$cljs$core$truth_$$($th_size__$1$$)){var $node$jscomp$285$$=$APP.$rumext$v2$ref_val$$($rowref$$);$node$jscomp$285$$.style.setProperty("--th-width",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($th_size__$1$$),"px"].join(""));return $node$jscomp$285$$.style.setProperty("--th-height",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$math$ceil$$(2/3*$th_size__$1$$)),"px"].join(""))}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $mnt_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!0),$sub$jscomp$14$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($entries$jscomp$12_row_width$$){$entries$jscomp$12_row_width$$=$APP.$cljs$core$first$$($entries$jscomp$12_row_width$$).contentRect.width;return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($mnt_QMARK_$$))?$APP.$cljs$core$reset_BANG_$$($width_STAR_$$,$entries$jscomp$12_row_width$$):null},$app$util$webapi$observe_resize$$($APP.$rumext$v2$ref_val$$($rowref$$)));
return function(){$APP.$cljs$core$_vreset_BANG_$$($mnt_QMARK_$$,!1);return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$14$$)}});return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rowref$$,$itemsize_limit__$1$jscomp$1$$],null)};
$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$=function($and__5023__auto__$jscomp$654_team$jscomp$25$$,$editors$jscomp$3_profile$jscomp$37$$){var $seats$jscomp$2_subscription$jscomp$7$$=$APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$654_team$jscomp$25$$),$subscription_type$jscomp$7$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($seats$jscomp$2_subscription$jscomp$7$$);$seats$jscomp$2_subscription$jscomp$7$$=
$APP.$cljs$cst$5233$seats$$.$cljs$core$IFn$_invoke$arity$1$($seats$jscomp$2_subscription$jscomp$7$$);$editors$jscomp$3_profile$jscomp$37$$=$APP.$cljs$core$count$$($APP.$cljs$cst$3225$editors$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($editors$jscomp$3_profile$jscomp$37$$))));$and__5023__auto__$jscomp$654_team$jscomp$25$$=$APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$654_team$jscomp$25$$));
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$654_team$jscomp$25$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$7$$,"unlimited")&&$seats$jscomp$2_subscription$jscomp$7$$<25&&$editors$jscomp$3_profile$jscomp$37$$-$seats$jscomp$2_subscription$jscomp$7$$>=4:$and__5023__auto__$jscomp$654_team$jscomp$25$$};
$app$main$data$dashboard$handle_nitrate_change_sso$$=function($p__73495$$){var $map__73496__$1$$=$APP.$cljs$core$__destructure_map$$($p__73495$$),$organization_id$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73496__$1$$,$APP.$cljs$cst$3301$organization_id$$);typeof $app$main$data$dashboard$handle_nitrate_change_sso_73497$$==="undefined"&&($app$main$data$dashboard$handle_nitrate_change_sso_73497$$=function($p__73495$jscomp$1$$,$map__73496$jscomp$1$$,$organization_id$jscomp$8$$,
$meta73498$$){this.$p__73495$=$p__73495$jscomp$1$$;this.$map__73496$=$map__73496$jscomp$1$$;this.$organization_id$=$organization_id$jscomp$8$$;this.$meta73498$=$meta73498$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_nitrate_change_sso_73497$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_nitrate_change_sso_73497$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5090$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_nitrate_change_sso$$},$app$main$data$dashboard$handle_nitrate_change_sso_73497$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73499$$,$meta73498__$1$$){return new $app$main$data$dashboard$handle_nitrate_change_sso_73497$$(this.$p__73495$,this.$map__73496$,this.$organization_id$,$meta73498__$1$$)},$app$main$data$dashboard$handle_nitrate_change_sso_73497$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73498$},$app$main$data$dashboard$handle_nitrate_change_sso_73497$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_nitrate_change_sso_73497$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2801_team_id$jscomp$113$$,$org_id_state$jscomp$1081_team$jscomp$19$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)?($_$jscomp$2801_team_id$jscomp$113$$=
$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($org_id_state$jscomp$1081_team$jscomp$19$$),$org_id_state$jscomp$1081_team$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($org_id_state$jscomp$1081_team$jscomp$19$$,$APP.$cljs$cst$2181$teams$$),$_$jscomp$2801_team_id$jscomp$113$$),$org_id_state$jscomp$1081_team$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($org_id_state$jscomp$1081_team$jscomp$19$$,
$APP.$cljs$cst$3297$organization$$),$APP.$cljs$cst$266$id$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$organization_id$,$org_id_state$jscomp$1081_team$jscomp$19$$)?$APP.$beicon$v2$core$mapcat$$(function($authorized_p__73500$$){var $map__73501__$1_redirect_uri$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($authorized_p__73500$$);$authorized_p__73500$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73501__$1_redirect_uri$jscomp$3$$,$APP.$cljs$cst$5091$authorized$$);
$map__73501__$1_redirect_uri$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73501__$1_redirect_uri$jscomp$3$$,$APP.$cljs$cst$3405$redirect_uri$$);return $APP.$cljs$core$truth_$$($authorized_p__73500$$)?$APP.$beicon$v2$core$empty$$():$APP.$cljs$core$truth_$$($map__73501__$1_redirect_uri$jscomp$3$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1584$uri$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__73501__$1_redirect_uri$jscomp$3$$)]))):$APP.$beicon$v2$core$empty$$()},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5092$check_nitrate_sso$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$_$jscomp$2801_team_id$jscomp$113$$,$APP.$cljs$cst$1991$url$$,$APP.$app$util$globals$location$$.href],null))):null):null});return new $app$main$data$dashboard$handle_nitrate_change_sso_73497$$($p__73495$$,
$map__73496__$1$$,$organization_id$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_dashboard_deleted$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($p__52862$$){var $map__52863__$1$$=$APP.$cljs$core$__destructure_map$$($p__52862$$),$team_id$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52863__$1$$,$APP.$cljs$cst$1944$team_id$$);typeof $app$main$data$common$go_to_dashboard_deleted_52864$$==="undefined"&&($app$main$data$common$go_to_dashboard_deleted_52864$$=function($p__52862$jscomp$1$$,$map__52863$jscomp$1$$,$options$jscomp$478$$,
$team_id$jscomp$24$$,$meta52865$$){this.$p__52862$=$p__52862$jscomp$1$$;this.$map__52863$=$map__52863$jscomp$1$$;this.options=$options$jscomp$478$$;this.$team_id$=$team_id$jscomp$24$$;this.$meta52865$=$meta52865$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_dashboard_deleted_52864$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_deleted_52864$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2546$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_dashboard_deleted$$},$app$main$data$common$go_to_dashboard_deleted_52864$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52866$$,$meta52865__$1$$){return new $app$main$data$common$go_to_dashboard_deleted_52864$$(this.$p__52862$,this.$map__52863$,this.options,this.$team_id$,$meta52865__$1$$)},$app$main$data$common$go_to_dashboard_deleted_52864$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52865$},
$app$main$data$common$go_to_dashboard_deleted_52864$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_dashboard_deleted_52864$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1562_profile$jscomp$4$$,$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$){$_$jscomp$1562_profile$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$,$APP.$cljs$cst$1931$profile$$);
$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,this.$team_id$)?$APP.$cljs$cst$2507$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1562_profile$jscomp$4$$):$APP.$cljs$core$uuid_QMARK_$$(this.$team_id$)?this.$team_id$:$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$);$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$hide$$(),$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2547$dashboard_deleted$$,$params$jscomp$159_state$jscomp$141_team_id__$1$jscomp$6$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.options])))});return new $app$main$data$common$go_to_dashboard_deleted_52864$$($p__52862$$,
$map__52863__$1$$,$map__52863__$1$$,$team_id$jscomp$23$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$open_selected_file$$=function(){typeof $app$main$data$dashboard$open_selected_file_73469$$==="undefined"&&($app$main$data$dashboard$open_selected_file_73469$$=function($meta73470$$){this.$meta73470$=$meta73470$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$open_selected_file_73469$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$open_selected_file_73469$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5084$app_DOT_main_DOT_data_DOT_dashboard_SLASH_open_selected_file$$},$app$main$data$dashboard$open_selected_file_73469$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73471$$,$meta73470__$1$$){return new $app$main$data$dashboard$open_selected_file_73469$$($meta73470__$1$$)},$app$main$data$dashboard$open_selected_file_73469$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73470$},$app$main$data$dashboard$open_selected_file_73469$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$open_selected_file_73469$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2795_vec__73472$$,$file_id$jscomp$324_state$jscomp$1076$$){$_$jscomp$2795_vec__73472$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$324_state$jscomp$1076$$,$APP.$cljs$cst$2191$selected_files$$);$file_id$jscomp$324_state$jscomp$1076$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2795_vec__73472$$,
0,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($_$jscomp$2795_vec__73472$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$324_state$jscomp$1076$$]))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$dashboard$open_selected_file_73469$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$team$webhooks_list_STAR_$$=function($props_74098$$){var $permissions$jscomp$26$$=$props_74098$$.permissions;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-rows main_ui_dashboard_team__webhook-table",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$56$$,$webhook$jscomp$2$$){$out_arr__44092__auto__$jscomp$56$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$webhook_item_STAR_$$,
{webhook:$webhook$jscomp$2$$,permissions:$permissions$jscomp$26$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($webhook$jscomp$2$$)??"")));return $out_arr__44092__auto__$jscomp$56$$},[],$props_74098$$.webhooks)})};
$app$main$ui$dashboard$team$webhooks_hero_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__webhooks-hero-container",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_dashboard_team__hero-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.webhooks")}),$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{className:"main_ui_dashboard_team__hero-desc",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.description")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5264$webhook$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$))},className:"main_ui_dashboard_team__hero-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.create")})]})};
$app$main$ui$dashboard$team$team_members_STAR_$$=function($owner$jscomp$5_props_73984$$){var $profile$jscomp$48$$=$owner$jscomp$5_props_73984$$.profile,$team$jscomp$44$$=$owner$jscomp$5_props_73984$$.team,$members$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$44$$,$APP.$cljs$cst$3321$members$$),$total_members$jscomp$1$$=$APP.$cljs$core$count$$($members$jscomp$10$$);$owner$jscomp$5_props_73984$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($members$jscomp$10$$)],
function(){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1603$is_owner$$,$members$jscomp$10$$)});var $members__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$44$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1603$is_owner$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$,$APP.$cljs$cst$3321$members$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$44$$))))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__dashboard-table main_ui_dashboard_team__team-members",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__title-field-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.member")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-field main_ui_dashboard_team__title-field-role",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.role")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-rows",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$team_member_STAR_$$,{member:$owner$jscomp$5_props_73984$$,team:$team$jscomp$44$$,profile:$profile$jscomp$48$$,totalMembers:$total_members$jscomp$1$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$53$$,$item$jscomp$107$$){$out_arr__44092__auto__$jscomp$53$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$team_member_STAR_$$,
{member:$item$jscomp$107$$,team:$team$jscomp$44$$,profile:$profile$jscomp$48$$,totalMembers:$total_members$jscomp$1$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$107$$)??"")));return $out_arr__44092__auto__$jscomp$53$$},[],$members__$1$$)]})]})};
$app$main$ui$dashboard$subscription$members_cta_STAR_$$=function(){return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$cta$cta_STAR_$$,{className:"main_ui_dashboard_subscription__members-cta",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.unlimited-members-extra-editors-cta-title"),children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"span",className:"main_ui_dashboard_subscription__cta-message",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.unlimited-members-extra-editors-cta-text")})})};
$app$main$ui$dashboard$subscription$team_STAR_$$=function($go_to_manage_subscription_props_73897_subscription$jscomp$4$$){var $is_owner$$=$go_to_manage_subscription_props_73897_subscription$jscomp$4$$.isOwner;$go_to_manage_subscription_props_73897_subscription$jscomp$4$$=$APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($go_to_manage_subscription_props_73897_subscription$jscomp$4$$.team);var $subscription_type$jscomp$3$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($go_to_manage_subscription_props_73897_subscription$jscomp$4$$),
$subscription_is_trial$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("trialing",$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($go_to_manage_subscription_props_73897_subscription$jscomp$4$$));$go_to_manage_subscription_props_73897_subscription$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-subscription-management",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1371$section$$,"team-settings"],null)));var $href$jscomp$15_href__$1$jscomp$1$$=encodeURIComponent($APP.$app$util$globals$location$$.href);$href$jscomp$15_href__$1$jscomp$1$$=["payments/subscriptions/show?returnUrl\x3d",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($href$jscomp$15_href__$1$jscomp$1$$)].join("");
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav_raw$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2473$href$$,$href$jscomp$15_href__$1$jscomp$1$$])))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_subscription__team",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_subscription__team-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.dashboard.team-plan")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_subscription__team-text",children:function(){switch($subscription_type$jscomp$3$$){case "professional":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.professional");case "unlimited":return $subscription_is_trial$jscomp$2$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited-trial"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.unlimited");
case "enterprise":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.enterprise");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$3$$)].join(""));}}()}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_owner$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$3$$,"professional"):$is_owner$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_to_manage_subscription_props_73897_subscription$jscomp$4$$,
"data-testid":"manage-subscription-link",className:"main_ui_dashboard_subscription__manage-subscription-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.settings.manage-your-subscription")}):null]})};
$app$main$data$nitrate$show_change_team_org_modal$$=function($p__73817$$){var $map__73818__$1$$=$APP.$cljs$core$__destructure_map$$($p__73817$$),$team_id$jscomp$138$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73818__$1$$,$APP.$cljs$cst$1944$team_id$$);typeof $app$main$data$nitrate$show_change_team_org_modal_73819$$==="undefined"&&($app$main$data$nitrate$show_change_team_org_modal_73819$$=function($p__73817$jscomp$1$$,$map__73818$jscomp$1$$,$team_id$jscomp$139$$,$meta73820$$){this.$p__73817$=
$p__73817$jscomp$1$$;this.$map__73818$=$map__73818$jscomp$1$$;this.$team_id$=$team_id$jscomp$139$$;this.$meta73820$=$meta73820$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$show_change_team_org_modal_73819$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_change_team_org_modal_73819$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5218$app_DOT_main_DOT_data_DOT_nitrate_SLASH_show_change_team_org_modal$$},
$app$main$data$nitrate$show_change_team_org_modal_73819$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73821$$,$meta73820__$1$$){return new $app$main$data$nitrate$show_change_team_org_modal_73819$$(this.$p__73817$,this.$map__73818$,this.$team_id$,$meta73820__$1$$)},$app$main$data$nitrate$show_change_team_org_modal_73819$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73820$},$app$main$data$nitrate$show_change_team_org_modal_73819$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_change_team_org_modal_73819$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2843$$,$state$jscomp$1106$$){var $self__$jscomp$7143$$=this,$profile_id$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1106$$,$APP.$cljs$cst$1931$profile$$),$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$mapcat$$(function($teams$jscomp$10$$){function $on_confirm$jscomp$1$$($organization_id$jscomp$15$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$add_team_to_org$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7143$$.$team_id$,$APP.$cljs$cst$3301$organization_id$$,$organization_id$jscomp$15$$],null)))}var $all_orgs$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$team$team__GT_organization$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73812_SHARP_$$){var $and__5023__auto__$jscomp$646$$=$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($p1__73812_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$646$$)?
$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($p1__73812_SHARP_$$):$and__5023__auto__$jscomp$646$$},$teams$jscomp$10$$)),$orgs_by_move_source_org$jscomp$1_team$jscomp$23$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73813_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73813_SHARP_$$),$self__$jscomp$7143$$.$team_id$)},$teams$jscomp$10$$));$orgs_by_move_source_org$jscomp$1_team$jscomp$23$$=
$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($orgs_by_move_source_org$jscomp$1_team$jscomp$23$$);var $current_org_id$jscomp$1$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($orgs_by_move_source_org$jscomp$1_team$jscomp$23$$),$move_perm$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($orgs_by_move_source_org$jscomp$1_team$jscomp$23$$,$APP.$cljs$cst$1728$permissions$$),$APP.$cljs$cst$3281$move_teams$$),$source_owner_id$$=
$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($orgs_by_move_source_org$jscomp$1_team$jscomp$23$$);$orgs_by_move_source_org$jscomp$1_team$jscomp$23$$=function(){switch($move_perm$$){case "never":return $APP.$cljs$core$PersistentVector$EMPTY$$;case "myOrganizations":return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73814_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($source_owner_id$$,$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73814_SHARP_$$))},
$all_orgs$jscomp$1$$);default:return $all_orgs$jscomp$1$$}}();var $orgs$jscomp$2$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($is_own_QMARK_$jscomp$1_org$jscomp$6$$){var $perm$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($is_own_QMARK_$jscomp$1_org$jscomp$6$$,$APP.$cljs$cst$1728$permissions$$),$APP.$cljs$cst$3279$create_teams$$);$is_own_QMARK_$jscomp$1_org$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$26$$,
$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($is_own_QMARK_$jscomp$1_org$jscomp$6$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($perm$jscomp$1$$,"any")||$is_own_QMARK_$jscomp$1_org$jscomp$6$$},$orgs_by_move_source_org$jscomp$1_team$jscomp$23$$),$selectable_orgs$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73815_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_org_id$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73815_SHARP_$$))},
$orgs$jscomp$2$$);return $APP.$cljs$core$empty_QMARK_$$($selectable_orgs$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$teams_fetched$$($teams$jscomp$10$$),$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3311$no_permission_modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5196$no_orgs_change$$],null))):$APP.$beicon$v2$core$mapcat$$(function($orgs_allowed$jscomp$2$$){var $valid_orgs$jscomp$1$$=$APP.$cljs$core$filterv$$(function($p1__73816_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($orgs_allowed$jscomp$2$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73816_SHARP_$$))===!0},$selectable_orgs$$),$extra_props$jscomp$3$$=$APP.$cljs$core$count$$($orgs$jscomp$2$$)<$APP.$cljs$core$count$$($all_orgs$jscomp$1$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5205$info_message_key$$,"dashboard.select-org-modal.permission-info"],null):null;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$teams_fetched$$($teams$jscomp$10$$),$APP.$cljs$core$empty_QMARK_$$($valid_orgs$jscomp$1$$)?
$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3317$alert$$,$APP.$cljs$cst$5217$hide_actions_QMARK_$$,!0,$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.add.no-valid-orgs"),$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.change-org-modal.title")],null)):$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5206$select_organization_modal$$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$5207$choose_key$$,$APP.$cljs$cst$5208$placeholder_key$$,$APP.$cljs$cst$5209$title_key$$,$APP.$cljs$cst$5210$organizations$$,$APP.$cljs$cst$5211$current_organization_id$$,$APP.$cljs$cst$5212$cancel_key$$,$APP.$cljs$cst$5213$orgs_allowed$$,$APP.$cljs$cst$5214$on_confirm$$,$APP.$cljs$cst$5215$accept_key$$],
[$self__$jscomp$7143$$.$team_id$,"dashboard.change-org-modal.choose","dashboard.change-org-modal.select","dashboard.change-org-modal.title",$selectable_orgs$$,$current_org_id$jscomp$1$$,"labels.cancel",$orgs_allowed$jscomp$2$$,$on_confirm$jscomp$1$$,"dashboard.change-org-modal.accept"]),$extra_props$jscomp$3$$]))))},$app$main$data$nitrate$fetch_orgs_allowed$$($self__$jscomp$7143$$.$team_id$,$selectable_orgs$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3308$get_teams$$))});
return new $app$main$data$nitrate$show_change_team_org_modal_73819$$($p__73817$$,$map__73818__$1$$,$team_id$jscomp$138$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$show_add_team_to_org_modal$$=function($p__73803$$){var $map__73804__$1$$=$APP.$cljs$core$__destructure_map$$($p__73803$$),$team_id$jscomp$136$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73804__$1$$,$APP.$cljs$cst$1944$team_id$$);typeof $app$main$data$nitrate$show_add_team_to_org_modal_73805$$==="undefined"&&($app$main$data$nitrate$show_add_team_to_org_modal_73805$$=function($p__73803$jscomp$1$$,$map__73804$jscomp$1$$,$team_id$jscomp$137$$,$meta73806$$){this.$p__73803$=
$p__73803$jscomp$1$$;this.$map__73804$=$map__73804$jscomp$1$$;this.$team_id$=$team_id$jscomp$137$$;this.$meta73806$=$meta73806$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$show_add_team_to_org_modal_73805$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_add_team_to_org_modal_73805$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5204$app_DOT_main_DOT_data_DOT_nitrate_SLASH_show_add_team_to_org_modal$$},
$app$main$data$nitrate$show_add_team_to_org_modal_73805$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73807$$,$meta73806__$1$$){return new $app$main$data$nitrate$show_add_team_to_org_modal_73805$$(this.$p__73803$,this.$map__73804$,this.$team_id$,$meta73806__$1$$)},$app$main$data$nitrate$show_add_team_to_org_modal_73805$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73806$},$app$main$data$nitrate$show_add_team_to_org_modal_73805$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_add_team_to_org_modal_73805$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2842$$,$state$jscomp$1105$$){var $self__$jscomp$7139$$=this,$profile_id$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1105$$,$APP.$cljs$cst$1931$profile$$),$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$mapcat$$(function($teams$jscomp$9$$){function $show_select_modal$$($orgs_allowed$$){var $extra_props$jscomp$2$$=
$APP.$cljs$core$count$$($orgs$jscomp$1$$)<$APP.$cljs$core$count$$($all_orgs$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5205$info_message_key$$,"dashboard.select-org-modal.permission-info"],null):null;return $APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5206$select_organization_modal$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1944$team_id$$,
$APP.$cljs$cst$5207$choose_key$$,$APP.$cljs$cst$5208$placeholder_key$$,$APP.$cljs$cst$5209$title_key$$,$APP.$cljs$cst$5210$organizations$$,$APP.$cljs$cst$5211$current_organization_id$$,$APP.$cljs$cst$5212$cancel_key$$,$APP.$cljs$cst$5213$orgs_allowed$$,$APP.$cljs$cst$5214$on_confirm$$,$APP.$cljs$cst$5215$accept_key$$],[$self__$jscomp$7139$$.$team_id$,"dashboard.select-org-modal.choose","dashboard.select-org-modal.select","dashboard.select-org-modal.title",$orgs$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$22$$,
$APP.$cljs$cst$3297$organization$$),$APP.$cljs$cst$266$id$$),"labels.cancel",$orgs_allowed$$,$on_confirm$$,"dashboard.select-org-modal.accept"]),$extra_props$jscomp$2$$])))}function $on_confirm$$($organization_id$jscomp$14$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$add_team_to_org$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7139$$.$team_id$,$APP.$cljs$cst$3301$organization_id$$,$organization_id$jscomp$14$$],
null)))}var $all_orgs$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$team$team__GT_organization$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73799_SHARP_$$){var $and__5023__auto__$jscomp$645$$=$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($p1__73799_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$645$$)?$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($p1__73799_SHARP_$$):$and__5023__auto__$jscomp$645$$},
$teams$jscomp$9$$)),$orgs$jscomp$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($is_own_QMARK__org$jscomp$5$$){var $perm$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($is_own_QMARK__org$jscomp$5$$,$APP.$cljs$cst$1728$permissions$$),$APP.$cljs$cst$3279$create_teams$$);$is_own_QMARK__org$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$25$$,$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($is_own_QMARK__org$jscomp$5$$));
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($perm$$,"any")||$is_own_QMARK__org$jscomp$5$$},$all_orgs$$),$team$jscomp$22$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__73800_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73800_SHARP_$$),$self__$jscomp$7139$$.$team_id$)},$teams$jscomp$9$$));return $APP.$cljs$core$empty_QMARK_$$($orgs$jscomp$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$teams_fetched$$($teams$jscomp$9$$),
$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3311$no_permission_modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5216$no_orgs_create$$],null))):$APP.$beicon$v2$core$mapcat$$(function($orgs_allowed$jscomp$1$$){var $valid_orgs$$=$APP.$cljs$core$filterv$$(function($p1__73801_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($orgs_allowed$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73801_SHARP_$$))===
!0},$orgs$jscomp$1$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$teams_fetched$$($teams$jscomp$9$$),$APP.$cljs$core$empty_QMARK_$$($valid_orgs$$)?$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3317$alert$$,$APP.$cljs$cst$5217$hide_actions_QMARK_$$,!0,$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.add.no-valid-orgs"),
$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.select-org-modal.title")],null)):$show_select_modal$$($orgs_allowed$jscomp$1$$))},$app$main$data$nitrate$fetch_orgs_allowed$$($self__$jscomp$7139$$.$team_id$,$orgs$jscomp$1$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3308$get_teams$$))});return new $app$main$data$nitrate$show_add_team_to_org_modal_73805$$($p__73803$$,$map__73804__$1$$,$team_id$jscomp$136$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$nitrate$show_remove_team_from_org_modal$$=function($p__73781$$){var $map__73782__$1$$=$APP.$cljs$core$__destructure_map$$($p__73781$$),$team_id$jscomp$131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73782__$1$$,$APP.$cljs$cst$1944$team_id$$);typeof $app$main$data$nitrate$show_remove_team_from_org_modal_73783$$==="undefined"&&($app$main$data$nitrate$show_remove_team_from_org_modal_73783$$=function($p__73781$jscomp$1$$,$map__73782$jscomp$1$$,$team_id$jscomp$132$$,$meta73784$$){this.$p__73781$=
$p__73781$jscomp$1$$;this.$map__73782$=$map__73782$jscomp$1$$;this.$team_id$=$team_id$jscomp$132$$;this.$meta73784$=$meta73784$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5197$app_DOT_main_DOT_data_DOT_nitrate_SLASH_show_remove_team_from_org_modal$$},
$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73785$$,$meta73784__$1$$){return new $app$main$data$nitrate$show_remove_team_from_org_modal_73783$$(this.$p__73781$,this.$map__73782$,this.$team_id$,$meta73784__$1$$)},$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73784$},$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$nitrate$show_remove_team_from_org_modal_73783$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2840$$,$state$jscomp$1104$$){var $self__$jscomp$7131$$=this,$profile_id$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1104$$,$APP.$cljs$cst$1931$profile$$),$APP.$cljs$cst$266$id$$);return $APP.$app$main$data$team$with_refreshed_team$$($self__$jscomp$7131$$.$team_id$,
function($team$jscomp$21$$){var $source_org$$=$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$21$$),$can_move_QMARK_$$=$APP.$app$common$types$nitrate_permissions$allowed_QMARK_$$($APP.$cljs$cst$3292$move_team$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3295$org_perms$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3294$owner_id$$,$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($source_org$$),$APP.$cljs$cst$1728$permissions$$,
$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($source_org$$)],null),$APP.$cljs$cst$2321$profile_id$$,$profile_id$jscomp$24$$,$APP.$cljs$cst$3286$team_perms$$,$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$21$$),$APP.$cljs$cst$3287$target_org_same_owner_QMARK_$$,!1],null));return(0,$APP.$beicon$v2$core$of$$)($can_move_QMARK_$$?$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.remove-team-org.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.remove-team-org.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$21$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($source_org$$)])),$APP.$cljs$cst$275$hint$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.remove-team-org.info"),$APP.$cljs$cst$5198$hint_level$$,$APP.$cljs$cst$205$default$$,$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.remove-team-org.accept"),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$remove_team_from_org$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1944$team_id$$,
$self__$jscomp$7131$$.$team_id$,$APP.$cljs$cst$3301$organization_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($source_org$$),$APP.$cljs$cst$3302$organization_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($source_org$$)],null)))},$APP.$cljs$cst$2488$accept_style$$,$APP.$cljs$cst$5199$danger$$],null)):$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3311$no_permission_modal$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$5196$no_orgs_change$$],null)))})});return new $app$main$data$nitrate$show_remove_team_from_org_modal_73783$$($p__73781$$,$map__73782__$1$$,$team_id$jscomp$131$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$restore_files$$=function($p__73521$$){var $map__73522__$1$$=$APP.$cljs$core$__destructure_map$$($p__73521$$),$team_id$jscomp$120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$1944$team_id$$),$ids$jscomp$269$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$1729$ids$$),$on_success$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$2499$on_success$$),
$on_error$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73522__$1$$,$APP.$cljs$cst$1300$on_error$$);typeof $app$main$data$dashboard$restore_files_73523$$==="undefined"&&($app$main$data$dashboard$restore_files_73523$$=function($p__73521$jscomp$1$$,$map__73522$jscomp$1$$,$team_id$jscomp$121$$,$ids$jscomp$270$$,$on_success$jscomp$43$$,$on_error$jscomp$49$$,$meta73524$$){this.$p__73521$=$p__73521$jscomp$1$$;this.$map__73522$=$map__73522$jscomp$1$$;this.$team_id$=$team_id$jscomp$121$$;
this.ids=$ids$jscomp$270$$;this.$on_success$=$on_success$jscomp$43$$;this.$on_error$=$on_error$jscomp$49$$;this.$meta73524$=$meta73524$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$restore_files_73523$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_files_73523$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5096$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_files$$},
$app$main$data$dashboard$restore_files_73523$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73525$$,$meta73524__$1$$){return new $app$main$data$dashboard$restore_files_73523$$(this.$p__73521$,this.$map__73522$,this.$team_id$,this.ids,this.$on_success$,this.$on_error$,$meta73524__$1$$)},$app$main$data$dashboard$restore_files_73523$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73524$},$app$main$data$dashboard$restore_files_73523$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_files_73523$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7019$$=this;return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2510$slow_progress_threshold$$,1E3,$APP.$cljs$cst$2338$total$$,
$APP.$cljs$core$count$$($self__$jscomp$7019$$.ids),$APP.$cljs$cst$2509$hints$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2252$progress$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.restoring-files")},$APP.$cljs$cst$2516$slow$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.slow-restore")}],null)],null)]))),function(){var $stream$jscomp$101$$=$APP.$beicon$v2$core$share$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2270$app_DOT_util_DOT_sse_SLASH_restore_deleted_team_files$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7019$$.$team_id$,$APP.$cljs$cst$1729$ids$$,$self__$jscomp$7019$$.ids],null)));return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$beicon$v2$core$mapcat$$(function($event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$){$event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$=$APP.$app$util$sse$get_payload$$($event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$);
if($APP.$cljs$core$truth_$$($event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$)){var $map__73526__$1_total$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$);$event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73526__$1_total$jscomp$16$$,$APP.$cljs$cst$1801$index$$);$map__73526__$1_total$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73526__$1_total$jscomp$16$$,
$APP.$cljs$cst$2338$total$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$)?$map__73526__$1_total$jscomp$16$$:$event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$common$update_progress$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1801$index$$,$event$jscomp$151_index$jscomp$382_temp__5823__auto__$jscomp$196$$,$APP.$cljs$cst$2338$total$$,$map__73526__$1_total$jscomp$16$$],
null))):$APP.$beicon$v2$core$empty$$()}return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$filter$$($app$util$sse$progress_QMARK_$$,$stream$jscomp$101$$))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$82$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$()),$self__$jscomp$7019$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$7019$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$82$$):
$self__$jscomp$7019$$.$on_error$($error$jscomp$82$$))},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$(),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$7019$$.$team_id$),$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($self__$jscomp$7019$$.$team_id$),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$7019$$.$team_id$)),$self__$jscomp$7019$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$?
$self__$jscomp$7019$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$7019$$.$on_success$())},$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$stream$jscomp$101$$)))))}())});return new $app$main$data$dashboard$restore_files_73523$$($p__73521$$,$map__73522__$1$$,$team_id$jscomp$120$$,$ids$jscomp$269$$,$on_success$jscomp$42$$,$on_error$jscomp$48$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$restore_project_immediately$$=function($p__73550$$){var $map__73551__$1$$=$APP.$cljs$core$__destructure_map$$($p__73550$$),$team_id$jscomp$124$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73551__$1$$,$APP.$cljs$cst$1944$team_id$$),$id$jscomp$848$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73551__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$409$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73551__$1$$,$APP.$cljs$cst$725$name$$);
typeof $app$main$data$dashboard$restore_project_immediately_73552$$==="undefined"&&($app$main$data$dashboard$restore_project_immediately_73552$$=function($p__73550$jscomp$1$$,$map__73551$jscomp$1$$,$project$jscomp$14$$,$team_id$jscomp$125$$,$id$jscomp$849$$,$name$jscomp$410$$,$meta73553$$){this.$p__73550$=$p__73550$jscomp$1$$;this.$map__73551$=$map__73551$jscomp$1$$;this.project=$project$jscomp$14$$;this.$team_id$=$team_id$jscomp$125$$;this.id=$id$jscomp$849$$;this.name=$name$jscomp$410$$;this.$meta73553$=
$meta73553$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$restore_project_immediately_73552$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_project_immediately_73552$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5098$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_project_immediately$$},$app$main$data$dashboard$restore_project_immediately_73552$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73554$$,$meta73553__$1$$){return new $app$main$data$dashboard$restore_project_immediately_73552$$(this.$p__73550$,this.$map__73551$,this.project,this.$team_id$,this.id,this.name,$meta73553__$1$$)},$app$main$data$dashboard$restore_project_immediately_73552$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73553$},$app$main$data$dashboard$restore_project_immediately_73552$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_project_immediately_73552$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2807_ids$jscomp$273$$,$state$jscomp$1085$$){var $self__$jscomp$7027$$=this;$_$jscomp$2807_ids$jscomp$273$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$145$$,$file_id$jscomp$326$$,$file$jscomp$87$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$87$$),$self__$jscomp$7027$$.id)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$145$$,$file_id$jscomp$326$$):$acc$jscomp$145$$},
$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1085$$,$APP.$cljs$cst$5038$deleted_files$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-files",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7027$$.$team_id$,
$APP.$cljs$cst$2189$project_id$$,$self__$jscomp$7027$$.id,$APP.$cljs$cst$5078$num_files$$,$APP.$cljs$core$count$$($_$jscomp$2807_ids$jscomp$273$$)],null)),$app$main$data$dashboard$restore_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7027$$.$team_id$,$APP.$cljs$cst$1729$ids$$,$_$jscomp$2807_ids$jscomp$273$$,$APP.$cljs$cst$2499$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$7027$$.name]))))},$APP.$cljs$cst$1300$on_error$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-restoring-project",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$7027$$.name]))))}],null)))});return new $app$main$data$dashboard$restore_project_immediately_73552$$($p__73550$$,
$map__73551__$1$$,$map__73551__$1$$,$team_id$jscomp$124$$,$id$jscomp$848$$,$name$jscomp$409$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$restore_files_immediately$$=function($p__73532$$){var $map__73533__$1$$=$APP.$cljs$core$__destructure_map$$($p__73532$$),$team_id$jscomp$122$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73533__$1$$,$APP.$cljs$cst$1944$team_id$$),$ids$jscomp$271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73533__$1$$,$APP.$cljs$cst$1729$ids$$);typeof $app$main$data$dashboard$restore_files_immediately_73534$$==="undefined"&&($app$main$data$dashboard$restore_files_immediately_73534$$=
function($p__73532$jscomp$1$$,$map__73533$jscomp$1$$,$team_id$jscomp$123$$,$ids$jscomp$272$$,$meta73535$$){this.$p__73532$=$p__73532$jscomp$1$$;this.$map__73533$=$map__73533$jscomp$1$$;this.$team_id$=$team_id$jscomp$123$$;this.ids=$ids$jscomp$272$$;this.$meta73535$=$meta73535$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$restore_files_immediately_73534$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$restore_files_immediately_73534$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5097$app_DOT_main_DOT_data_DOT_dashboard_SLASH_restore_files_immediately$$},$app$main$data$dashboard$restore_files_immediately_73534$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73536$$,$meta73535__$1$$){return new $app$main$data$dashboard$restore_files_immediately_73534$$(this.$p__73532$,this.$map__73533$,this.$team_id$,this.ids,$meta73535__$1$$)},
$app$main$data$dashboard$restore_files_immediately_73534$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73535$},$app$main$data$dashboard$restore_files_immediately_73534$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$restore_files_immediately_73534$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2806$$,$state$jscomp$1084$$){var $self__$jscomp$7023$$=this,$deleted_files$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1084$$,
$APP.$cljs$cst$5038$deleted_files$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-files",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7023$$.$team_id$,$APP.$cljs$cst$5078$num_files$$,$APP.$cljs$core$count$$($self__$jscomp$7023$$.ids)],null)),$app$main$data$dashboard$restore_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7023$$.$team_id$,$APP.$cljs$cst$1729$ids$$,$self__$jscomp$7023$$.ids,$APP.$cljs$cst$2499$on_success$$,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($self__$jscomp$7023$$.ids))){var $fname$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($deleted_files$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($self__$jscomp$7023$$.ids),
$APP.$cljs$cst$725$name$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-success-notification",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fname$jscomp$1$$]))))}return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-files-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($self__$jscomp$7023$$.ids)]))))},$APP.$cljs$cst$1300$on_error$$,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($self__$jscomp$7023$$.ids))){var $fname$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($deleted_files$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($self__$jscomp$7023$$.ids),
$APP.$cljs$cst$725$name$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-restore-file",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fname$jscomp$2$$]))))}return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.errors.error-on-restore-files")))}],null)))});return new $app$main$data$dashboard$restore_files_immediately_73534$$($p__73532$$,
$map__73533__$1$$,$team_id$jscomp$122$$,$ids$jscomp$271$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_files$$=function($p__73505$$){var $map__73506__$1$$=$APP.$cljs$core$__destructure_map$$($p__73505$$),$team_id$jscomp$114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73506__$1$$,$APP.$cljs$cst$1944$team_id$$),$ids$jscomp$264$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73506__$1$$,$APP.$cljs$cst$1729$ids$$),$on_success$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73506__$1$$,$APP.$cljs$cst$2499$on_success$$),
$on_error$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73506__$1$$,$APP.$cljs$cst$1300$on_error$$);typeof $app$main$data$dashboard$delete_files_73507$$==="undefined"&&($app$main$data$dashboard$delete_files_73507$$=function($p__73505$jscomp$1$$,$map__73506$jscomp$1$$,$team_id$jscomp$115$$,$ids$jscomp$265$$,$on_success$jscomp$39$$,$on_error$jscomp$45$$,$meta73508$$){this.$p__73505$=$p__73505$jscomp$1$$;this.$map__73506$=$map__73506$jscomp$1$$;this.$team_id$=$team_id$jscomp$115$$;
this.ids=$ids$jscomp$265$$;this.$on_success$=$on_success$jscomp$39$$;this.$on_error$=$on_error$jscomp$45$$;this.$meta73508$=$meta73508$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_files_73507$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_73507$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5093$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_files$$},
$app$main$data$dashboard$delete_files_73507$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73509$$,$meta73508__$1$$){return new $app$main$data$dashboard$delete_files_73507$$(this.$p__73505$,this.$map__73506$,this.$team_id$,this.ids,this.$on_success$,this.$on_error$,$meta73508__$1$$)},$app$main$data$dashboard$delete_files_73507$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73508$},$app$main$data$dashboard$delete_files_73507$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_73507$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7007$$=this,$stream$jscomp$100$$=$APP.$beicon$v2$core$share$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2275$app_DOT_util_DOT_sse_SLASH_permanently_delete_team_files$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7007$$.$team_id$,$APP.$cljs$cst$1729$ids$$,
$self__$jscomp$7007$$.ids],null)));return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$initialize_progress$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2510$slow_progress_threshold$$,1E3,$APP.$cljs$cst$2338$total$$,$APP.$cljs$core$count$$($self__$jscomp$7007$$.ids),$APP.$cljs$cst$2509$hints$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2252$progress$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.deleting-files")},$APP.$cljs$cst$2516$slow$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.progress-notification.slow-delete")}],null)],null)]))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$empty$$,$APP.$beicon$v2$core$mapcat$$(function($event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$){$event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$=
$APP.$app$util$sse$get_payload$$($event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$);if($APP.$cljs$core$truth_$$($event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$)){var $map__73510__$1_total$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$);$event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73510__$1_total$jscomp$15$$,$APP.$cljs$cst$1801$index$$);
$map__73510__$1_total$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73510__$1_total$jscomp$15$$,$APP.$cljs$cst$2338$total$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$)?$map__73510__$1_total$jscomp$15$$:$event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$common$update_progress$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1801$index$$,
$event$jscomp$150_index$jscomp$381_temp__5823__auto__$jscomp$195$$,$APP.$cljs$cst$2338$total$$,$map__73510__$1_total$jscomp$15$$],null))):$APP.$beicon$v2$core$empty$$()}return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$filter$$($app$util$sse$progress_QMARK_$$,$stream$jscomp$100$$))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error$jscomp$81$$){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$()),$self__$jscomp$7007$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$?
$self__$jscomp$7007$$.$on_error$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$81$$):$self__$jscomp$7007$$.$on_error$($error$jscomp$81$$))},$APP.$beicon$v2$core$merge_map$$(function(){return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$common$clear_progress$$(),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$7007$$.$team_id$),$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($self__$jscomp$7007$$.$team_id$),$app$main$data$dashboard$fetch_projects$$($self__$jscomp$7007$$.$team_id$)),
$self__$jscomp$7007$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$?$self__$jscomp$7007$$.$on_success$.$cljs$core$IFn$_invoke$arity$0$():$self__$jscomp$7007$$.$on_success$())},$APP.$beicon$v2$core$map$$($APP.$app$util$sse$get_payload$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$sse$end_of_stream_QMARK_$$,$stream$jscomp$100$$)))))});return new $app$main$data$dashboard$delete_files_73507$$($p__73505$$,$map__73506__$1$$,$team_id$jscomp$114$$,$ids$jscomp$264$$,$on_success$jscomp$38$$,$on_error$jscomp$44$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_project_immediately$$=function($p__73516$$){var $map__73517__$1$$=$APP.$cljs$core$__destructure_map$$($p__73516$$),$team_id$jscomp$118$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73517__$1$$,$APP.$cljs$cst$1944$team_id$$),$id$jscomp$846$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73517__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$407$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73517__$1$$,$APP.$cljs$cst$725$name$$);
typeof $app$main$data$dashboard$delete_project_immediately_73518$$==="undefined"&&($app$main$data$dashboard$delete_project_immediately_73518$$=function($p__73516$jscomp$1$$,$map__73517$jscomp$1$$,$project$jscomp$12$$,$team_id$jscomp$119$$,$id$jscomp$847$$,$name$jscomp$408$$,$meta73519$$){this.$p__73516$=$p__73516$jscomp$1$$;this.$map__73517$=$map__73517$jscomp$1$$;this.project=$project$jscomp$12$$;this.$team_id$=$team_id$jscomp$119$$;this.id=$id$jscomp$847$$;this.name=$name$jscomp$408$$;this.$meta73519$=
$meta73519$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_project_immediately_73518$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_project_immediately_73518$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5095$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_project_immediately$$},$app$main$data$dashboard$delete_project_immediately_73518$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73520$$,$meta73519__$1$$){return new $app$main$data$dashboard$delete_project_immediately_73518$$(this.$p__73516$,this.$map__73517$,this.project,this.$team_id$,this.id,this.name,$meta73519__$1$$)},$app$main$data$dashboard$delete_project_immediately_73518$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73519$},$app$main$data$dashboard$delete_project_immediately_73518$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_project_immediately_73518$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2804_ids$jscomp$268$$,$state$jscomp$1083$$){var $self__$jscomp$7015$$=this;$_$jscomp$2804_ids$jscomp$268$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$144$$,$file_id$jscomp$325$$,$file$jscomp$86$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$86$$),$self__$jscomp$7015$$.id)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$144$$,$file_id$jscomp$325$$):$acc$jscomp$144$$},
$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1083$$,$APP.$cljs$cst$5038$deleted_files$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-files",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7015$$.$team_id$,
$APP.$cljs$cst$2189$project_id$$,$self__$jscomp$7015$$.id,$APP.$cljs$cst$5078$num_files$$,$APP.$cljs$core$count$$($_$jscomp$2804_ids$jscomp$268$$)],null)),$app$main$data$dashboard$delete_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7015$$.$team_id$,$APP.$cljs$cst$1729$ids$$,$_$jscomp$2804_ids$jscomp$268$$,$APP.$cljs$cst$2499$on_success$$,function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$7015$$.name]))))},$APP.$cljs$cst$1300$on_error$$,function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-delete-project",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$7015$$.name]))))}],null)))});return new $app$main$data$dashboard$delete_project_immediately_73518$$($p__73516$$,
$map__73517__$1$$,$map__73517__$1$$,$team_id$jscomp$118$$,$id$jscomp$846$$,$name$jscomp$407$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$delete_files_immediately$$=function($p__73511$$){var $map__73512__$1$$=$APP.$cljs$core$__destructure_map$$($p__73511$$),$team_id$jscomp$116$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73512__$1$$,$APP.$cljs$cst$1944$team_id$$),$ids$jscomp$266$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73512__$1$$,$APP.$cljs$cst$1729$ids$$);typeof $app$main$data$dashboard$delete_files_immediately_73513$$==="undefined"&&($app$main$data$dashboard$delete_files_immediately_73513$$=
function($p__73511$jscomp$1$$,$map__73512$jscomp$1$$,$params$jscomp$356$$,$team_id$jscomp$117$$,$ids$jscomp$267$$,$meta73514$$){this.$p__73511$=$p__73511$jscomp$1$$;this.$map__73512$=$map__73512$jscomp$1$$;this.params=$params$jscomp$356$$;this.$team_id$=$team_id$jscomp$117$$;this.ids=$ids$jscomp$267$$;this.$meta73514$=$meta73514$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$delete_files_immediately_73513$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_immediately_73513$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5094$app_DOT_main_DOT_data_DOT_dashboard_SLASH_delete_files_immediately$$},$app$main$data$dashboard$delete_files_immediately_73513$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73515$$,$meta73514__$1$$){return new $app$main$data$dashboard$delete_files_immediately_73513$$(this.$p__73511$,this.$map__73512$,this.params,
this.$team_id$,this.ids,$meta73514__$1$$)},$app$main$data$dashboard$delete_files_immediately_73513$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73514$},$app$main$data$dashboard$delete_files_immediately_73513$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$delete_files_immediately_73513$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2803$$,$state$jscomp$1082$$){var $self__$jscomp$7011$$=this,$deleted_files$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1082$$,$APP.$cljs$cst$5038$deleted_files$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-files",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard:trash",$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7011$$.$team_id$,$APP.$cljs$cst$5078$num_files$$,$APP.$cljs$core$count$$($self__$jscomp$7011$$.ids)],
null)),$app$main$data$dashboard$delete_files$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1944$team_id$$,$self__$jscomp$7011$$.$team_id$,$APP.$cljs$cst$1729$ids$$,$self__$jscomp$7011$$.ids,$APP.$cljs$cst$2499$on_success$$,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($self__$jscomp$7011$$.ids))){var $fname$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($deleted_files$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($self__$jscomp$7011$$.ids),$APP.$cljs$cst$725$name$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-success-notification",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$fname$$]))))}return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-files-success-notification",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($self__$jscomp$7011$$.ids)]))))},$APP.$cljs$cst$1300$on_error$$,function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.errors.error-on-delete-files")))}],null)))});return new $app$main$data$dashboard$delete_files_immediately_73513$$($p__73511$$,$map__73512__$1$$,$map__73512__$1$$,$team_id$jscomp$116$$,$ids$jscomp$266$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$handle_organization_deleted$$=function($p__73489$$){var $map__73490__$1$$=$APP.$cljs$core$__destructure_map$$($p__73489$$),$organization_id$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73490__$1$$,$APP.$cljs$cst$3301$organization_id$$),$organization_name$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73490__$1$$,$APP.$cljs$cst$3302$organization_name$$),$teams$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73490__$1$$,$APP.$cljs$cst$2181$teams$$),
$deleted_teams$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73490__$1$$,$APP.$cljs$cst$5088$deleted_teams$$);typeof $app$main$data$dashboard$handle_organization_deleted_73491$$==="undefined"&&($app$main$data$dashboard$handle_organization_deleted_73491$$=function($p__73489$jscomp$1$$,$map__73490$jscomp$1$$,$organization_id$jscomp$6$$,$organization_name$jscomp$3$$,$teams$jscomp$8$$,$deleted_teams$jscomp$1$$,$meta73492$$){this.$p__73489$=$p__73489$jscomp$1$$;this.$map__73490$=$map__73490$jscomp$1$$;
this.$organization_id$=$organization_id$jscomp$6$$;this.$organization_name$=$organization_name$jscomp$3$$;this.teams=$teams$jscomp$8$$;this.$deleted_teams$=$deleted_teams$jscomp$1$$;this.$meta73492$=$meta73492$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_organization_deleted_73491$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_organization_deleted_73491$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5089$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_organization_deleted$$},$app$main$data$dashboard$handle_organization_deleted_73491$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73493$$,$meta73492__$1$$){return new $app$main$data$dashboard$handle_organization_deleted_73491$$(this.$p__73489$,this.$map__73490$,this.$organization_id$,this.$organization_name$,this.teams,this.$deleted_teams$,$meta73492__$1$$)},$app$main$data$dashboard$handle_organization_deleted_73491$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73492$},$app$main$data$dashboard$handle_organization_deleted_73491$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_organization_deleted_73491$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$,$fetch_QMARK__state$jscomp$1080$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$)){$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$=
$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($fetch_QMARK__state$jscomp$1080$$);var $current_org_id_current_team$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fetch_QMARK__state$jscomp$1080$$,$APP.$cljs$cst$2181$teams$$),$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$);$current_org_id_current_team$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_org_id_current_team$$,
$APP.$cljs$cst$3297$organization$$),$APP.$cljs$cst$266$id$$);var $notify_QMARK__teams_set$$=$APP.$cljs$core$set$$(this.teams);$notify_QMARK__teams_set$$=$APP.$cljs$core$contains_QMARK_$$($notify_QMARK__teams_set$$,$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$);$fetch_QMARK__state$jscomp$1080$$=$APP.$cljs$core$some$$($APP.$cljs$cst$2181$teams$$.$cljs$core$IFn$_invoke$arity$1$($fetch_QMARK__state$jscomp$1080$$),this.teams);$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$=
$APP.$cljs$core$some$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$]),this.$deleted_teams$);$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$=$APP.$cljs$core$truth_$$($_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$)?$_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$organization_id$,
$current_org_id_current_team$$);return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$($_$jscomp$2800_go_to_default_QMARK__or__5025__auto__$jscomp$inline_9698_team_id$jscomp$112$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$205$default$$],null)]))):null,$notify_QMARK__teams_set$$?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.org-deleted",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$organization_name$])),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2364$timeout$$,null],null))):null,$APP.$cljs$core$truth_$$($fetch_QMARK__state$jscomp$1080$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$()):null)}return null});return new $app$main$data$dashboard$handle_organization_deleted_73491$$($p__73489$$,$map__73490__$1$$,$organization_id$jscomp$5$$,$organization_name$jscomp$2$$,$teams$jscomp$7$$,$deleted_teams$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$handle_user_org_change$$=function($p__73484$$){var $map__73485__$1$$=$APP.$cljs$core$__destructure_map$$($p__73484$$),$organization_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73485__$1$$,$APP.$cljs$cst$3301$organization_id$$),$organization_name$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73485__$1$$,$APP.$cljs$cst$3302$organization_name$$),$notification$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73485__$1$$,
$APP.$cljs$cst$2370$notification$$);typeof $app$main$data$dashboard$handle_user_org_change_73486$$==="undefined"&&($app$main$data$dashboard$handle_user_org_change_73486$$=function($p__73484$jscomp$1$$,$map__73485$jscomp$1$$,$organization_id$jscomp$4$$,$organization_name$jscomp$1$$,$notification$jscomp$5$$,$meta73487$$){this.$p__73484$=$p__73484$jscomp$1$$;this.$map__73485$=$map__73485$jscomp$1$$;this.$organization_id$=$organization_id$jscomp$4$$;this.$organization_name$=$organization_name$jscomp$1$$;
this.notification=$notification$jscomp$5$$;this.$meta73487$=$meta73487$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_user_org_change_73486$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_user_org_change_73486$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5087$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_user_org_change$$},
$app$main$data$dashboard$handle_user_org_change_73486$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73488$$,$meta73487__$1$$){return new $app$main$data$dashboard$handle_user_org_change_73486$$(this.$p__73484$,this.$map__73485$,this.$organization_id$,this.$organization_name$,this.notification,$meta73487__$1$$)},$app$main$data$dashboard$handle_user_org_change_73486$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73487$},$app$main$data$dashboard$handle_user_org_change_73486$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_user_org_change_73486$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$,$state$jscomp$1079_team$jscomp$18$$){$JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$=this.notification;$JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$):$JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$)?($JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$=
$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1079_team$jscomp$18$$),$state$jscomp$1079_team$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1079_team$jscomp$18$$,$APP.$cljs$cst$2181$teams$$),$JSCompiler_inline_result$jscomp$2009__$jscomp$2799_and__5023__auto__$jscomp$inline_9700_team_id$jscomp$111$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$(this.notification,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$organization_name$])),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2364$timeout$$,null],null)),$APP.$app$main$data$team$fetch_teams$$(),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$organization_id$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1079_team$jscomp$18$$,
$APP.$cljs$cst$3297$organization$$),$APP.$cljs$cst$266$id$$))?$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$205$default$$],null)])):null)):null});return new $app$main$data$dashboard$handle_user_org_change_73486$$($p__73484$$,$map__73485__$1$$,$organization_id$jscomp$3$$,$organization_name$$,$notification$jscomp$4$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$handle_change_team_org$$=function($p__73478$$){var $map__73479__$1$$=$APP.$cljs$core$__destructure_map$$($p__73478$$),$team$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73479__$1$$,$APP.$cljs$cst$2503$team$$),$notification$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73479__$1$$,$APP.$cljs$cst$2370$notification$$);typeof $app$main$data$dashboard$handle_change_team_org_73480$$==="undefined"&&($app$main$data$dashboard$handle_change_team_org_73480$$=
function($p__73478$jscomp$1$$,$map__73479$jscomp$1$$,$team$jscomp$17$$,$notification$jscomp$3$$,$meta73481$$){this.$p__73478$=$p__73478$jscomp$1$$;this.$map__73479$=$map__73479$jscomp$1$$;this.team=$team$jscomp$17$$;this.notification=$notification$jscomp$3$$;this.$meta73481$=$meta73481$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5086$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_change_team_org$$},$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73482$$,$meta73481__$1$$){return new $app$main$data$dashboard$handle_change_team_org_73480$$(this.$p__73478$,this.$map__73479$,this.team,this.notification,$meta73481__$1$$)},$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73481$},$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2797_organization$jscomp$3$$,$JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$){$JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$);
$_$jscomp$2797_organization$jscomp$3$$=$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$(this.team);var $and__5023__auto__$jscomp$inline_9702_and__5023__auto____$1$jscomp$inline_9703$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$);$and__5023__auto__$jscomp$inline_9702_and__5023__auto____$1$jscomp$inline_9703$$?($and__5023__auto__$jscomp$inline_9702_and__5023__auto____$1$jscomp$inline_9703$$=this.notification,$JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9702_and__5023__auto____$1$jscomp$inline_9703$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.team),$JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$):$and__5023__auto__$jscomp$inline_9702_and__5023__auto____$1$jscomp$inline_9703$$):$JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$=$and__5023__auto__$jscomp$inline_9702_and__5023__auto____$1$jscomp$inline_9703$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2010_current_team_id$jscomp$1_state$jscomp$1077$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$(this.notification,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2797_organization$jscomp$3$$)])),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$2364$timeout$$,null],null))):null},$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_org_73480$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2798_team_id$jscomp$110$$,$state$jscomp$1078$$){if($APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1234$nitrate$$)){$_$jscomp$2798_team_id$jscomp$110$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.team);var $team_name$jscomp$2$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.team),$organization$jscomp$4$$=$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$(this.team);return $APP.$app$common$data$update_in_when$$($state$jscomp$1078$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2181$teams$$,
$_$jscomp$2798_team_id$jscomp$110$$],null),function($G__73483_team__$1$$){$G__73483_team__$1$$=$app$common$types$organization$apply_organization$$($G__73483_team__$1$$,$organization$jscomp$4$$);return $APP.$cljs$core$truth_$$($team_name$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__73483_team__$1$$,$APP.$cljs$cst$725$name$$,$team_name$jscomp$2$$):$G__73483_team__$1$$})}return $state$jscomp$1078$$});return new $app$main$data$dashboard$handle_change_team_org_73480$$($p__73478$$,
$map__73479__$1$$,$team$jscomp$16$$,$notification$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$duplicate_file$$=function($p__73442$$){var $map__73443__$1$$=$APP.$cljs$core$__destructure_map$$($p__73442$$),$id$jscomp$844$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73443__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$404$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73443__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$duplicate_file_73444$$==="undefined"&&($app$main$data$dashboard$duplicate_file_73444$$=function($p__73442$jscomp$1$$,
$map__73443$jscomp$1$$,$params$jscomp$347$$,$id$jscomp$845$$,$name$jscomp$405$$,$meta73445$$){this.$p__73442$=$p__73442$jscomp$1$$;this.$map__73443$=$map__73443$jscomp$1$$;this.params=$params$jscomp$347$$;this.id=$id$jscomp$845$$;this.name=$name$jscomp$405$$;this.$meta73445$=$meta73445$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$duplicate_file_73444$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$duplicate_file_73444$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5075$app_DOT_main_DOT_data_DOT_dashboard_SLASH_duplicate_file$$},$app$main$data$dashboard$duplicate_file_73444$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73446$$,$meta73445__$1$$){return new $app$main$data$dashboard$duplicate_file_73444$$(this.$p__73442$,this.$map__73443$,this.params,this.id,this.name,$meta73445__$1$$)},$app$main$data$dashboard$duplicate_file_73444$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73445$},$app$main$data$dashboard$duplicate_file_73444$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$duplicate_file_73444$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2788_map__73447_on_success$jscomp$35$$,$new_name$jscomp$34_state$jscomp$1072_unames$jscomp$17$$){$_$jscomp$2788_map__73447_on_success$jscomp$35$$=$APP.$cljs$core$meta$$(this.params);var $map__73447__$1_on_error$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2788_map__73447_on_success$jscomp$35$$);
$_$jscomp$2788_map__73447_on_success$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73447__$1_on_error$jscomp$41$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__73447__$1_on_error$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73447__$1_on_error$jscomp$41$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);$new_name$jscomp$34_state$jscomp$1072_unames$jscomp$17$$=$APP.$app$common$files$helpers$get_used_names$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_name$jscomp$34_state$jscomp$1072_unames$jscomp$17$$,
$APP.$cljs$cst$1933$files$$));$new_name$jscomp$34_state$jscomp$1072_unames$jscomp$17$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(this.name,$new_name$jscomp$34_state$jscomp$1072_unames$jscomp$17$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1633$suffix_fn$$,function($copy_count$jscomp$4$$){return" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.copy-suffix")??"")+(($copy_count$jscomp$4$$>
1?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($copy_count$jscomp$4$$)].join(""):null)??"")}]));return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73447__$1_on_error$jscomp$41$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$dashboard$file_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2788_map__73447_on_success$jscomp$35$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5076$duplicate_file$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,this.id,$APP.$cljs$cst$725$name$$,$new_name$jscomp$34_state$jscomp$1072_unames$jscomp$17$$],null)))))});return new $app$main$data$dashboard$duplicate_file_73444$$($p__73442$$,$map__73443__$1$$,$map__73443__$1$$,$id$jscomp$844$$,$name$jscomp$404$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$create_file$$=function($p__73436$$){var $map__73437__$1$$=$APP.$cljs$core$__destructure_map$$($p__73436$$),$project_id$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73437__$1$$,$APP.$cljs$cst$2189$project_id$$),$name$jscomp$402$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73437__$1$$,$APP.$cljs$cst$725$name$$);typeof $app$main$data$dashboard$create_file_73438$$==="undefined"&&($app$main$data$dashboard$create_file_73438$$=function($p__73436$jscomp$1$$,
$map__73437$jscomp$1$$,$params$jscomp$345$$,$project_id$jscomp$25$$,$name$jscomp$403$$,$meta73439$$){this.$p__73436$=$p__73436$jscomp$1$$;this.$map__73437$=$map__73437$jscomp$1$$;this.params=$params$jscomp$345$$;this.$project_id$=$project_id$jscomp$25$$;this.name=$name$jscomp$403$$;this.$meta73439$=$meta73439$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$create_file_73438$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$create_file_73438$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5073$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_file$$},$app$main$data$dashboard$create_file_73438$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73440$$,$meta73439__$1$$){return new $app$main$data$dashboard$create_file_73438$$(this.$p__73436$,this.$map__73437$,this.params,this.$project_id$,this.name,$meta73439__$1$$)},$app$main$data$dashboard$create_file_73438$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73439$},$app$main$data$dashboard$create_file_73438$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_file_73438$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2189$project_id$$,this.$project_id$],null)},$app$main$data$dashboard$create_file_73438$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_file_73438$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($it$jscomp$275_map__73441_on_success$jscomp$34$$,$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$){var $self__$jscomp$6959$$=this,$it__$1$jscomp$151$$=this;$it$jscomp$275_map__73441_on_success$jscomp$34$$=$APP.$cljs$core$meta$$($self__$jscomp$6959$$.params);var $map__73441__$1_on_error$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($it$jscomp$275_map__73441_on_success$jscomp$34$$);$it$jscomp$275_map__73441_on_success$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73441__$1_on_error$jscomp$40$$,
$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$map__73441__$1_on_error$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__73441__$1_on_error$jscomp$40$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);var $files$jscomp$19_name__$1$jscomp$15$$=$APP.$app$main$data$helpers$lookup_team_files$cljs$0core$0IFn$0_invoke$0arity$02$$($features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$,$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$)),
$unames$jscomp$16$$=$APP.$app$common$files$helpers$get_used_names$$($files$jscomp$19_name__$1$jscomp$15$$),$base_name$jscomp$6$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file-prefix");$files$jscomp$19_name__$1$jscomp$15$$=function(){var $or__5025__auto__$jscomp$971$$=$self__$jscomp$6959$$.name;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$971$$)?$or__5025__auto__$jscomp$971$$:$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_name$jscomp$6$$,
$unames$jscomp$16$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1634$immediate_suffix_QMARK_$$,!0]))}();$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$=$APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$,$APP.$cljs$cst$227$features$$),$APP.$app$common$features$frontend_only_features$$);$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$6959$$.params,$APP.$cljs$cst$725$name$$,$files$jscomp$19_name__$1$jscomp$15$$),$APP.$cljs$cst$227$features$$,$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($map__73441__$1_on_error$jscomp$40$$,$APP.$beicon$v2$core$map$$(function($p1__73435_SHARP_$$){return $APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$file_created$$($p1__73435_SHARP_$$),
$APP.$cljs$core$meta$$($it__$1$jscomp$151$$))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($it$jscomp$275_map__73441_on_success$jscomp$34$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5074$create_file$$,$features__$1$jscomp$24_params__$1$jscomp$47_state$jscomp$1071$$))))});return new $app$main$data$dashboard$create_file_73438$$($p__73436$$,$map__73437__$1$$,$map__73437__$1$$,$project_id$jscomp$24$$,$name$jscomp$402$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$create_project$$=function(){typeof $app$main$data$dashboard$create_project_73364$$==="undefined"&&($app$main$data$dashboard$create_project_73364$$=function($meta73365$$){this.$meta73365$=$meta73365$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$create_project_73364$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_project_73364$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5052$app_DOT_main_DOT_data_DOT_dashboard_SLASH_create_project$$},$app$main$data$dashboard$create_project_73364$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73366$$,$meta73365__$1$$){return new $app$main$data$dashboard$create_project_73364$$($meta73365__$1$$)},$app$main$data$dashboard$create_project_73364$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73365$},$app$main$data$dashboard$create_project_73364$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$create_project_73364$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$,$params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$){$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$);
$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$=$APP.$app$main$data$helpers$lookup_team_projects$cljs$0core$0IFn$0_invoke$0arity$02$$($params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$,$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$);$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$=
$APP.$app$common$files$helpers$get_used_names$$($_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$);var $base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-project-prefix");$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$,
$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1634$immediate_suffix_QMARK_$$,!0]));$params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$);$params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$725$name$$,$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$,$APP.$cljs$cst$1944$team_id$$,$params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$],null);$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$=$APP.$cljs$core$meta$$($params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$);$base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$=
$APP.$cljs$core$__destructure_map$$($_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$);$_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$,$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$identity$$);$base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$,$APP.$cljs$cst$1300$on_error$$,$APP.$beicon$v2$core$throw$0$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($base_name$jscomp$5_map__73367__$1_on_error$jscomp$37$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$dashboard$project_created$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2762_map__73367_name$jscomp$395_on_success$jscomp$31_projects$jscomp$3_team_id$jscomp$106_unames$jscomp$14$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5053$create_project$$,$params$jscomp$328_state$jscomp$1058_team_id__$1$jscomp$12$$))))});return new $app$main$data$dashboard$create_project_73364$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$process_upload$$=function($blobs_fonts$jscomp$13$$,$team_id$jscomp$83$$){function $parse_mtype$$($G__55950_ba_u8$$){$G__55950_ba_u8$$=new Uint8Array($G__55950_ba_u8$$,0,4);a:{for(var $l__5614__auto__$jscomp$inline_9705$$=$G__55950_ba_u8$$.length,$i$jscomp$inline_9706$$=0,$G__56114$jscomp$inline_9709_ret$jscomp$inline_9707$$="";;)if($i$jscomp$inline_9706$$<$l__5614__auto__$jscomp$inline_9705$$){var $G__56113$jscomp$inline_9708$$=$i$jscomp$inline_9706$$+1;$G__56114$jscomp$inline_9709_ret$jscomp$inline_9707$$=
[$G__56114$jscomp$inline_9709_ret$jscomp$inline_9707$$,$i$jscomp$inline_9706$$===0?"":" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__55950_ba_u8$$[$i$jscomp$inline_9706$$].toString(8))].join("");$i$jscomp$inline_9706$$=$G__56113$jscomp$inline_9708$$}else{$G__55950_ba_u8$$=$G__56114$jscomp$inline_9709_ret$jscomp$inline_9707$$;break a}$G__55950_ba_u8$$=void 0}switch($G__55950_ba_u8$$){case "117 124 124 117":return"font/otf";case "0 1 0 0":return"font/ttf";case "167 117 106 106":return"font/woff";
case "167 117 106 62":return"font/woff2";default:throw Error(["No matching clause: ",$G__55950_ba_u8$$].join(""));}}$blobs_fonts$jscomp$13$$=$APP.$beicon$v2$core$mapcat$$(function($blob$jscomp$22$$){return $APP.$beicon$v2$core$mapcat$$(function($map__55969__$1_p__55968$$){$map__55969__$1_p__55968$$=$APP.$cljs$core$__destructure_map$$($map__55969__$1_p__55968$$);var $type$jscomp$450$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55969__$1_p__55968$$,$APP.$cljs$cst$139$type$$),$error$jscomp$69$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55969__$1_p__55968$$,$APP.$cljs$cst$849$error$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($type$jscomp$450$$)?$type$jscomp$450$$:$error$jscomp$69$$)?(0,$APP.$beicon$v2$core$of$$)($map__55969__$1_p__55968$$):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,
$blob$jscomp$22$$.name],null))},$APP.$beicon$v2$core$map$$(function($data$jscomp$307$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$142$data$$,$data$jscomp$307$$,$APP.$cljs$cst$725$name$$,$blob$jscomp$22$$.name,$APP.$cljs$cst$139$type$$,$parse_mtype$$($data$jscomp$307$$)],null)},$APP.$app$util$webapi$read_file_as_array_buffer$$($blob$jscomp$22$$))))},$APP.$beicon$v2$core$from$$($blobs_fonts$jscomp$13$$));var $errors$jscomp$16$$=$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$122$$,
$font$jscomp$30$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$122$$,["'",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$30$$)),"'"].join(""))},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$filter$$(function($p1__55865_SHARP_$$){return $APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($p1__55865_SHARP_$$)!=null},$blobs_fonts$jscomp$13$$));$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($errors$jscomp$16$$,
function($p1__55866_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$not_empty$$($p1__55866_SHARP_$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$cljs$core$count$$($p1__55866_SHARP_$$)>1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font-plural",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$p1__55866_SHARP_$$)])):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$first$$($p1__55866_SHARP_$$)])))):null});return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($res$jscomp$38$$,$existing$jscomp$1_p__55935_tmp_id$$){var $map__55936__$1$$=$APP.$cljs$core$__destructure_map$$($existing$jscomp$1_p__55935_tmp_id$$),$content$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55936__$1$$,
$APP.$cljs$cst$1642$content$$),$key_fn$jscomp$11$$=$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$03$$();$existing$jscomp$1_p__55935_tmp_id$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55862_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key_fn$jscomp$11$$($map__55936__$1$$),$key_fn$jscomp$11$$($p1__55862_SHARP_$$))},$APP.$cljs$core$vals$$($res$jscomp$38$$));if($APP.$cljs$core$truth_$$($existing$jscomp$1_p__55935_tmp_id$$))return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$38$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($existing$jscomp$1_p__55935_tmp_id$$),function($existing__$1$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($existing__$1$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$157$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$157$$)),$APP.$cljs$cst$3553$names$$,$APP.$cljs$core$conj$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$157$$))});$existing$jscomp$1_p__55935_tmp_id$$=$APP.$app$common$uuid$next$$();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($res$jscomp$38$$,$existing$jscomp$1_p__55935_tmp_id$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55936__$1$$,
$APP.$cljs$cst$266$id$$,$existing$jscomp$1_p__55935_tmp_id$$),$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$83$$),$APP.$cljs$cst$3553$names$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$157$$)])),$APP.$cljs$cst$142$data$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$157$$),$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$157$$)])),
$APP.$cljs$cst$1642$content$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$map$$(function($p__55917_type$jscomp$448$$){var $data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$=$APP.$cljs$core$__destructure_map$$($p__55917_type$jscomp$448$$),$font$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$,$APP.$cljs$cst$2727$font$$);$p__55917_type$jscomp$448$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$,
$APP.$cljs$cst$139$type$$);var $name$jscomp$280$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$,$APP.$cljs$cst$725$name$$);$data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$,$APP.$cljs$cst$142$data$$);if($APP.$cljs$core$truth_$$($font$jscomp$27$$)){var $base_name$jscomp$2_family$jscomp$6$$=function(){var $or__5025__auto__$jscomp$656$$=
$font$jscomp$27$$.getEnglishName("preferredFamily");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$656$$)?$or__5025__auto__$jscomp$656$$:$font$jscomp$27$$.getEnglishName("fontFamily")}(),$family_name_raw_family_name_variant$jscomp$13$$=function(){var $or__5025__auto__$jscomp$657$$=$font$jscomp$27$$.getEnglishName("preferredSubfamily");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$657$$)?$or__5025__auto__$jscomp$657$$:$font$jscomp$27$$.getEnglishName("fontSubfamily")}(),$height_warning_QMARK__hhea_ascender$$=
$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.hhea.ascender),$hhea_descender$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.hhea.descender),$win_descent$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.usWinDescent),$os2_ascent$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.sTypoAscender),$os2_descent$$=$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.sTypoDescender),$f_selection$$=($font$jscomp$27$$.tables.os2.fsSelection&128)!=0;$height_warning_QMARK__hhea_ascender$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($height_warning_QMARK__hhea_ascender$$,
$APP.$cljs$core$abs$$($font$jscomp$27$$.tables.os2.usWinAscent))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hhea_descender$$,$win_descent$$)||$f_selection$$&&($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($height_warning_QMARK__hhea_ascender$$,$os2_ascent$$)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hhea_descender$$,$os2_descent$$));$data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$=new Uint8Array($data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1642$content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$142$data$$,$data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$,$APP.$cljs$cst$725$name$$,$name$jscomp$280$$,$APP.$cljs$cst$139$type$$,$p__55917_type$jscomp$448$$],null),$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$core$truth_$$($base_name$jscomp$2_family$jscomp$6$$)?$base_name$jscomp$2_family$jscomp$6$$:"",$APP.$cljs$cst$1767$font_weight$$,$app$common$media$parse_font_weight$$($family_name_raw_family_name_variant$jscomp$13$$),
$APP.$cljs$cst$1768$font_style$$,$app$common$media$parse_font_style$$($family_name_raw_family_name_variant$jscomp$13$$),$APP.$cljs$cst$2018$variant_name$$,$family_name_raw_family_name_variant$jscomp$13$$,$APP.$cljs$cst$3552$height_warning_QMARK_$$,$height_warning_QMARK__hhea_ascender$$],null)}$base_name$jscomp$2_family$jscomp$6$$=$APP.$cuerdas$core$replace$$($name$jscomp$280$$,/\.[^.]+$/,"");$family_name_raw_family_name_variant$jscomp$13$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($APP.$cuerdas$core$replace$$($base_name$jscomp$2_family$jscomp$6$$,
/(^|[-_\s])(extra\s*black|ultra\s*black|extra\s*bold|ultra\s*bold|semi\s*bold|demi\s*bold|extra\s*light|ultra\s*light|hairline|thin|light|normal|regular|medium|bold|black|heavy|solid|italic)([-_\s]|$)/i,"$1$3"),/[-_\s]+/," "));$family_name_raw_family_name_variant$jscomp$13$$=$APP.$cuerdas$core$blank_QMARK_$$($family_name_raw_family_name_variant$jscomp$13$$)?$base_name$jscomp$2_family$jscomp$6$$:$family_name_raw_family_name_variant$jscomp$13$$;$data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$=new Uint8Array($data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1642$content$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$142$data$$,$data$jscomp$305_data__$1$jscomp$13_map__55919__$1$$,$APP.$cljs$cst$725$name$$,$name$jscomp$280$$,$APP.$cljs$cst$139$type$$,$p__55917_type$jscomp$448$$],null),$APP.$cljs$cst$1764$font_family$$,$family_name_raw_family_name_variant$jscomp$13$$,$APP.$cljs$cst$1767$font_weight$$,$app$common$media$parse_font_weight$$($base_name$jscomp$2_family$jscomp$6$$),
$APP.$cljs$cst$1768$font_style$$,$app$common$media$parse_font_style$$($base_name$jscomp$2_family$jscomp$6$$),$APP.$cljs$cst$3552$height_warning_QMARK_$$,!1],null)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$beicon$v2$core$map$$(function($map__55963__$1_p__55962$$){$map__55963__$1_p__55962$$=$APP.$cljs$core$__destructure_map$$($map__55963__$1_p__55962$$);var $data$jscomp$306$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55963__$1_p__55962$$,$APP.$cljs$cst$142$data$$),
$type$jscomp$449$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55963__$1_p__55962$$,$APP.$cljs$cst$139$type$$),$name$jscomp$281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55963__$1_p__55962$$,$APP.$cljs$cst$725$name$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$449$$,"font/woff2"))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55963__$1_p__55962$$,$APP.$cljs$cst$2727$font$$,null);try{return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__55963__$1_p__55962$$,
$APP.$cljs$cst$2727$font$$,$APP.$shadow$js$shim$module$0opentype$$.parse($data$jscomp$306$$))}catch($e55965$$){return $APP.$app$common$logging$enabled_QMARK_$$("app.main.data.fonts",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,
$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$2$("skipping file %s, unsupported format",$name$jscomp$281$$):$APP.$cuerdas$core$format$$("skipping file %s, unsupported format",$name$jscomp$281$$)],null)],null)}),null,"app.main.data.fonts",$APP.$cljs$cst$1162$warn$$,!1),null}},$APP.$beicon$v2$core$filter$$(function($p1__55868_SHARP_$$){return $APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($p1__55868_SHARP_$$)==null},
$blobs_fonts$jscomp$13$$)))))};
$app$main$ui$dashboard$team$empty_invitation_table_STAR_$$=function($on_invite_member$jscomp$1_props_73990_route$jscomp$10$$){var $can_invite$jscomp$2$$=$on_invite_member$jscomp$1_props_73990_route$jscomp$10$$.canInvite,$team$jscomp$46$$=$on_invite_member$jscomp$1_props_73990_route$jscomp$10$$.team;$on_invite_member$jscomp$1_props_73990_route$jscomp$10$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);var $invite_email$jscomp$6$$=$APP.$cljs$cst$3314$invite_email$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2278$query_params$$.$cljs$core$IFn$_invoke$arity$1$($on_invite_member$jscomp$1_props_73990_route$jscomp$10$$));$on_invite_member$jscomp$1_props_73990_route$jscomp$10$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$46$$),$APP.$rumext$v2$adapt$$($invite_email$jscomp$6$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$check_and_invite_members$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$46$$),$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$2503$team$$,
$APP.$cljs$cst$3314$invite_email$$,$invite_email$jscomp$6$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__empty-invitations",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.no-invitations")}),$can_invite$jscomp$2$$?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.no-invitations-gather-people")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__empty-invitations-buttons",children:(0,$APP.$rumext$v2$jsx$$)("a",{role:"button",onClick:$on_invite_member$jscomp$1_props_73990_route$jscomp$10$$,"data-testid":"invite-member",className:"main_ui_dashboard_team__btn-empty-invitations",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invite-profile")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__blank-space"})],null):(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_team__no-permission-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invitations.no-permission")})]})};
$app$main$ui$dashboard$team$webhooks_page_STAR_$$=function($props_74099_webhooks$jscomp$3$$){var $team$jscomp$51$$=$props_74099_webhooks$jscomp$3$$.team;$props_74099_webhooks$jscomp$3$$=$APP.$cljs$cst$1216$webhooks$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$51$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$51$$)],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-webhooks",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$51$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$51$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_webhooks$$())});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{team:$team$jscomp$51$$,section:$APP.$cljs$cst$5244$dashboard_team_webhooks$$}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_dashboard_team__dashboard-container main_ui_dashboard_team__dashboard-team-webhooks",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhooks_hero_STAR_$$,
{}),$APP.$cljs$core$empty_QMARK_$$($props_74099_webhooks$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__webhooks-empty",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.empty.no-webhooks")}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.webhooks.empty.add-one")})]}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhooks_list_STAR_$$,
{webhooks:$props_74099_webhooks$jscomp$3$$,permissions:$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$51$$)})]})})]})};
$app$main$ui$dashboard$team$team_members_page_STAR_$$=function($props_73985$$){var $profile$jscomp$49$$=$props_73985$$.profile,$team$jscomp$45$$=$props_73985$$.team;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$45$$))],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-members",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$45$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$45$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$45$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{section:$APP.$cljs$cst$5241$dashboard_team_members$$,team:$team$jscomp$45$$,profile:$profile$jscomp$49$$}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_dashboard_team__dashboard-container main_ui_dashboard_team__dashboard-team-members",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_members_STAR_$$,{profile:$profile$jscomp$49$$,team:$team$jscomp$45$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$664$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1224$subscriptions$$);return $and__5023__auto__$jscomp$664$$?$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$($team$jscomp$45$$,$profile$jscomp$49$$):$and__5023__auto__$jscomp$664$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$members_cta_STAR_$$,{team:$team$jscomp$45$$}):null]})]})};
$app$main$data$team$update_team_photo$$=function($file$jscomp$41$$){typeof $app$main$data$team$update_team_photo_55612$$==="undefined"&&($app$main$data$team$update_team_photo_55612$$=function($file$jscomp$42$$,$meta55613$$){this.file=$file$jscomp$42$$;this.$meta55613$=$meta55613$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$team$update_team_photo_55612$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_team_photo_55612$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3343$app_DOT_main_DOT_data_DOT_team_SLASH_update_team_photo$$},$app$main$data$team$update_team_photo_55612$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55614$$,$meta55613__$1$$){return new $app$main$data$team$update_team_photo_55612$$(this.file,$meta55613__$1$$)},$app$main$data$team$update_team_photo_55612$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55613$},$app$main$data$team$update_team_photo_55612$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$team$update_team_photo_55612$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1725$$,$state$jscomp$227$$){var $team_id$jscomp$56$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$227$$);$APP.$app$main$data$media$notify_start_loading$$();return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__55608_SHARP_$$){$APP.$app$main$data$media$notify_finished_loading$$();
return $APP.$app$main$data$media$process_error$$($p1__55608_SHARP_$$)},$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$team$fetch_teams$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"update-team-photo",$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$56$$],null)))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$media$notify_finished_loading$$,
$APP.$beicon$v2$core$mapcat$$(function($p1__55610_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2295$update_team_photo$$,$p1__55610_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__55609_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$1944$team_id$$],[$p1__55609_SHARP_$$,$team_id$jscomp$56$$])},$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,(0,$APP.$beicon$v2$core$of$$)(this.file)))))))});
return new $app$main$data$team$update_team_photo_55612$$($file$jscomp$41$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$team$team_settings_page_STAR_$$=function($nitrate_QMARK_$jscomp$2_props_74100$$){function $on_file_selected$$($file$jscomp$91$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$update_team_photo$$($file$jscomp$91$$))}var $team$jscomp$52$$=$nitrate_QMARK_$jscomp$2_props_74100$$.team;$nitrate_QMARK_$jscomp$2_props_74100$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1234$nitrate$$);var $finput$$=(0,$APP.$rumext$v2$use_ref$$)(),
$members$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$52$$,$APP.$cljs$cst$3321$members$$),$stats$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$52$$,$APP.$cljs$cst$3337$stats$$),$owner$jscomp$6$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1603$is_owner$$,$members$jscomp$11$$),$permissions$jscomp$27$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$),$can_edit$jscomp$2$$=
function(){var $or__5025__auto__$jscomp$1012$$=$APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$27$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1012$$)?$or__5025__auto__$jscomp$1012$$:$APP.$cljs$cst$1602$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$27$$)}(),$on_image_click_organizations$jscomp$1_profile$jscomp$55$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$profile_id$jscomp$27$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_image_click_organizations$jscomp$1_profile$jscomp$55$$),
$all_organizations$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$teams$$),$all_organizations__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($all_organizations$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$team$team__GT_organization$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3297$organization$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5017$is_default$$,
$APP.$cljs$core$vals$$($all_organizations$$))))});$on_image_click_organizations$jscomp$1_profile$jscomp$55$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($all_organizations__$1$$),$APP.$rumext$v2$adapt$$($profile_id$jscomp$27$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($is_owner_QMARK_$jscomp$1_org$jscomp$8$$){var $perm$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($is_owner_QMARK_$jscomp$1_org$jscomp$8$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1728$permissions$$,$APP.$cljs$cst$3279$create_teams$$],null));$is_owner_QMARK_$jscomp$1_org$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($profile_id$jscomp$27$$,$APP.$cljs$cst$3294$owner_id$$.$cljs$core$IFn$_invoke$arity$1$($is_owner_QMARK_$jscomp$1_org$jscomp$8$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($perm$jscomp$2$$,"any")||$is_owner_QMARK_$jscomp$1_org$jscomp$8$$},
$all_organizations__$1$$)});var $can_change_organization_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($all_organizations__$1$$)],function(){return $APP.$cljs$core$count$$($all_organizations__$1$$)>1}),$can_add_to_organization_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_image_click_organizations$jscomp$1_profile$jscomp$55$$),$APP.$rumext$v2$adapt$$($all_organizations__$1$$)],function(){return $APP.$cljs$core$count$$($all_organizations__$1$$)>
0&&$APP.$cljs$core$not$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$))}),$show_org_options_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_org_options_menu_QMARK_$$=$APP.$cljs$core$_deref$$($show_org_options_menu_STAR_$$),$on_show_options_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$206$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$206$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_org_options_menu_STAR_$$,
$APP.$cljs$core$not$$)}),$close_org_options_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_org_options_menu_STAR_$$,!1)});$on_image_click_organizations$jscomp$1_profile$jscomp$55$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($finput$$))});var $on_remove_team_from_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$52$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$show_remove_team_from_org_modal$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)],null)))}),$on_add_team_to_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$52$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$show_add_team_to_org_modal$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)],null)))}),$on_change_team_org$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$52$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$nitrate$show_change_team_org_modal$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)],
null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$52$$)],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-settings",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$team$fetch_members$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$team$fetch_stats$$()]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,
{section:$APP.$cljs$cst$5242$dashboard_team_settings$$,team:$team$jscomp$52$$}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_dashboard_team__dashboard-team-settings",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__settings-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block main_ui_dashboard_team__info-block",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__team-icon",children:[$APP.$cljs$core$truth_$$($can_edit$jscomp$2$$)?
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_image_click_organizations$jscomp$1_profile$jscomp$55$$,className:"main_ui_dashboard_team__update-overlay",children:$APP.$app$main$ui$dashboard$team$image_icon$$}):null,(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_team_photo_url$$($team$jscomp$52$$),className:"main_ui_dashboard_team__team-image"}),$APP.$cljs$core$truth_$$($can_edit$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{accept:"image/jpeg,image/png",
multi:!1,ref:$finput$$,"on-selected":$on_file_selected$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-info")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)})]}),$nitrate_QMARK_$jscomp$2_props_74100$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization")}),function(){var $JSCompiler_temp_const$jscomp$2012_organization$jscomp$9$$=$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$2012_organization$jscomp$9$$)){var $JSCompiler_temp$jscomp$2011_JSCompiler_temp_const$jscomp$2013$$=
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$org_avatar$org_avatar_STAR_$$,{org:$APP.$app$main$data$team$team__GT_organization$$($team$jscomp$52$$),size:"xxxl"});$JSCompiler_temp_const$jscomp$2012_organization$jscomp$9$$=(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$2012_organization$jscomp$9$$)});var $JSCompiler_inline_result$jscomp$2014_and__5023__auto__$jscomp$inline_9711$$=
$APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$27$$);$JSCompiler_inline_result$jscomp$2014_and__5023__auto__$jscomp$inline_9711$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2014_and__5023__auto__$jscomp$inline_9711$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$52$$)):$JSCompiler_inline_result$jscomp$2014_and__5023__auto__$jscomp$inline_9711$$;$JSCompiler_temp$jscomp$2011_JSCompiler_temp_const$jscomp$2013$$=
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-content",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__org-block-content",children:[$JSCompiler_temp$jscomp$2011_JSCompiler_temp_const$jscomp$2013$$,$JSCompiler_temp_const$jscomp$2012_organization$jscomp$9$$,$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2014_and__5023__auto__$jscomp$inline_9711$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"ghost",type:"button",className:($APP.$cljs$core$not$$($show_org_options_menu_QMARK_$$)?"main_ui_dashboard_team__org-options-btn":"")+" "+($APP.$cljs$core$truth_$$($show_org_options_menu_QMARK_$$)?"main_ui_dashboard_team__org-options-btn-open":""),onClick:$on_show_options_click$$,children:[$APP.$app$main$ui$dashboard$team$org_menu_icon$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_org_options_menu_QMARK_$$,"on-close":$close_org_options_menu$$,"dropdown-id":"org-options",
children:(0,$APP.$rumext$v2$jsxs$$)("ul",{role:"listbox",className:"main_ui_dashboard_team__org-dropdown",children:[$APP.$cljs$core$truth_$$($can_change_organization_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_change_team_org$$,className:"main_ui_dashboard_team__org-dropdown-item",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.change")}):null,(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_remove_team_from_org$$,className:"main_ui_dashboard_team__org-dropdown-item",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.remove")})]})})]})}):null]})})}else $JSCompiler_temp$jscomp$2011_JSCompiler_temp_const$jscomp$2013$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-content",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.none")})}),
$APP.$cljs$core$truth_$$($can_add_to_organization_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-content",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_add_team_to_org$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-organization.add")})})}):null]});return $JSCompiler_temp$jscomp$2011_JSCompiler_temp_const$jscomp$2013$$}()]}):null,
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-members")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[(0,$APP.$rumext$v2$jsx$$)("img",{src:$APP.$app$config$resolve_profile_photo_url$$($owner$jscomp$6$$),className:"main_ui_dashboard_team__owner-icon"}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($owner$jscomp$6$$))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.owner")),")"].join("")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[$APP.$app$main$ui$dashboard$team$user_icon$$,
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.num-of-members",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($members$jscomp$11$$)]))})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__block-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.team-projects")}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__block-content",children:[$APP.$app$main$ui$dashboard$team$group_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-projects",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$cst$1945$projects$$.$cljs$core$IFn$_invoke$arity$1$($stats$jscomp$2$$)-1)]))})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_team__block-content",children:[$APP.$app$main$ui$dashboard$team$document_icon$$,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_team__block-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$cst$1933$files$$.$cljs$core$IFn$_invoke$arity$1$($stats$jscomp$2$$))]))})]})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1224$subscriptions$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$team_STAR_$$,{isOwner:$APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$27$$),team:$team$jscomp$52$$}):null]})})]})};
$app$main$data$dashboard$handle_change_team_role$$=function($params$jscomp$353$$){typeof $app$main$data$dashboard$handle_change_team_role_73475$$==="undefined"&&($app$main$data$dashboard$handle_change_team_role_73475$$=function($params$jscomp$354$$,$meta73476$$){this.params=$params$jscomp$354$$;this.$meta73476$=$meta73476$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$handle_change_team_role_73475$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_role_73475$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5085$app_DOT_main_DOT_data_DOT_dashboard_SLASH_handle_change_team_role$$},$app$main$data$dashboard$handle_change_team_role_73475$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73477$$,$meta73476__$1$$){return new $app$main$data$dashboard$handle_change_team_role_73475$$(this.params,$meta73476__$1$$)},$app$main$data$dashboard$handle_change_team_role_73475$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73476$},$app$main$data$dashboard$handle_change_team_role_73475$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$handle_change_team_role_73475$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$change_team_role$$(this.params),$APP.$app$main$data$modal$hide$$())});return new $app$main$data$dashboard$handle_change_team_role_73475$$($params$jscomp$353$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$dashboard$process_message$$=function($map__73503__$1_p__73502$$){$map__73503__$1_p__73502$$=$APP.$cljs$core$__destructure_map$$($map__73503__$1_p__73502$$);var $G__73504$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73503__$1_p__73502$$,$APP.$cljs$cst$139$type$$);switch($G__73504$$ instanceof $APP.$cljs$core$Keyword$$?$G__73504$$.$fqn$:null){case "notification":return $APP.$app$main$data$common$handle_notification$$($map__73503__$1_p__73502$$);case "team-role-change":return $app$main$data$dashboard$handle_change_team_role$$($map__73503__$1_p__73502$$);
case "team-membership-change":return $APP.$app$main$data$common$team_membership_change$$($map__73503__$1_p__73502$$);case "team-org-change":return $app$main$data$dashboard$handle_change_team_org$$($map__73503__$1_p__73502$$);case "user-org-change":return $app$main$data$dashboard$handle_user_org_change$$($map__73503__$1_p__73502$$);case "organization-deleted":return $app$main$data$dashboard$handle_organization_deleted$$($map__73503__$1_p__73502$$);case "organization-change-sso":return $app$main$data$dashboard$handle_nitrate_change_sso$$($map__73503__$1_p__73502$$);
default:return null}};
$app$main$data$dashboard$initialize$$=function($team_id$jscomp$96$$){typeof $app$main$data$dashboard$initialize_73292$$==="undefined"&&($app$main$data$dashboard$initialize_73292$$=function($team_id$jscomp$97$$,$meta73293$$){this.$team_id$=$team_id$jscomp$97$$;this.$meta73293$=$meta73293$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$dashboard$initialize_73292$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$initialize_73292$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5020$app_DOT_main_DOT_data_DOT_dashboard_SLASH_initialize$$},$app$main$data$dashboard$initialize_73292$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73294$$,$meta73293__$1$$){return new $app$main$data$dashboard$initialize_73292$$(this.$team_id$,$meta73293__$1$$)},$app$main$data$dashboard$initialize_73292$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73293$},$app$main$data$dashboard$initialize_73292$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$initialize_73292$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2742_stopper$jscomp$40$$,$state$jscomp$1041$$,$stream$jscomp$99$$){$_$jscomp$2742_stopper$jscomp$40$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5021$app_DOT_main_DOT_data_DOT_dashboard_SLASH_finalize$$),$stream$jscomp$99$$);var $profile_id$jscomp$22$$=$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1041$$);
return $APP.$beicon$v2$core$take_until$$($_$jscomp$2742_stopper$jscomp$40$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$dashboard$fetch_projects$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$dashboard$fetch_projects$$.$cljs$core$IFn$_invoke$arity$1$(this.$team_id$):$app$main$data$dashboard$fetch_projects$$(this.$team_id$),$APP.$app$main$data$fonts$fetch_fonts$$(this.$team_id$)),$APP.$beicon$v2$core$map$$($app$main$data$dashboard$process_message$$,$APP.$beicon$v2$core$filter$$(function($map__73297__$1_p__73296_topic$jscomp$1$$){$map__73297__$1_p__73296_topic$jscomp$1$$=
$APP.$cljs$core$__destructure_map$$($map__73297__$1_p__73296_topic$jscomp$1$$);$map__73297__$1_p__73296_topic$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73297__$1_p__73296_topic$jscomp$1$$,$APP.$cljs$cst$4418$topic$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__73297__$1_p__73296_topic$jscomp$1$$,$APP.$app$common$uuid$zero$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__73297__$1_p__73296_topic$jscomp$1$$,$profile_id$jscomp$22$$)},
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3392$app_DOT_main_DOT_data_DOT_websocket_SLASH_message$$),$stream$jscomp$99$$))))))});return new $app$main$data$dashboard$initialize_73292$$($team_id$jscomp$96$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$fonts$render_font_styles$$=function($font_refs$$){return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$108$$,$css$jscomp$4$$){return""+($acc$jscomp$108$$??"")+"\n"+($css$jscomp$4$$??"")},"",$APP.$beicon$v2$core$mapcat$$($APP.$app$main$fonts$fetch_font_css$$,$APP.$beicon$v2$core$from$$($font_refs$$)))};
$app$main$data$dashboard$search$$=function($params$jscomp$326_params__$1$jscomp$42$$){$params$jscomp$326_params__$1$jscomp$42$$=(0,$APP.$app$main$data$dashboard$check_search_params$$)($params$jscomp$326_params__$1$jscomp$42$$);typeof $app$main$data$dashboard$search_73308$$==="undefined"&&($app$main$data$dashboard$search_73308$$=function($params$jscomp$327$$,$meta73309$$){this.params=$params$jscomp$327$$;this.$meta73309$=$meta73309$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$dashboard$search_73308$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$search_73308$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5025$app_DOT_main_DOT_data_DOT_dashboard_SLASH_search$$},$app$main$data$dashboard$search_73308$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73310$$,$meta73309__$1$$){return new $app$main$data$dashboard$search_73308$$(this.params,$meta73309__$1$$)},$app$main$data$dashboard$search_73308$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73309$},$app$main$data$dashboard$search_73308$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$dashboard$search_73308$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2745$$,$state$jscomp$1043$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1043$$,$APP.$cljs$cst$5026$search_result$$)},$app$main$data$dashboard$search_73308$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$dashboard$search_73308$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2746_params__$1$jscomp$43_team_id$jscomp$101$$,$state$jscomp$1044$$){$_$jscomp$2746_params__$1$jscomp$43_team_id$jscomp$101$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1044$$);$_$jscomp$2746_params__$1$jscomp$43_team_id$jscomp$101$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.params,$APP.$cljs$cst$1944$team_id$$,$_$jscomp$2746_params__$1$jscomp$43_team_id$jscomp$101$$);
return $APP.$beicon$v2$core$map$$(function($result$jscomp$329$$){return function($p1__73307_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__73307_SHARP_$$,$APP.$cljs$cst$5026$search_result$$,$result$jscomp$329$$)}},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5027$search_files$$,$_$jscomp$2746_params__$1$jscomp$43_team_id$jscomp$101$$))});return new $app$main$data$dashboard$search_73308$$($params$jscomp$326_params__$1$jscomp$42$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$team$invitation_section_STAR_$$=function($on_delete$jscomp$4_props_74039$$){function $on_error$jscomp$60$$($form$jscomp$177_map__74058__$1$$){$form$jscomp$177_map__74058__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$ex_data$$($form$jscomp$177_map__74058__$1$$));var $type$jscomp$597$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$177_map__74058__$1$$,$APP.$cljs$cst$139$type$$),$code$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$177_map__74058__$1$$,
$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2261$validation$$,$type$jscomp$597$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5245$profile_is_muted$$,$code$jscomp$51$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.profile-is-muted")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()])):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2261$validation$$,$type$jscomp$597$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5246$max_invitations_by_request$$,$code$jscomp$51$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.maximum-invitations-by-request-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2512$threshold$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$177_map__74058__$1$$)])))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2572$restriction$$,$type$jscomp$597$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3435$max_quote_reached$$,$code$jscomp$51$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.max-quote-reached",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2883$target$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$177_map__74058__$1$$)])))):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5247$member_is_muted$$,$code$jscomp$51$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5248$email_has_permanent_bounces$$,$code$jscomp$51$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5249$email_has_complaints$$,$code$jscomp$51$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.email-spam-or-permanent-bounces",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$177_map__74058__$1$$)])))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}var $profile$jscomp$50$$=$on_delete$jscomp$4_props_74039$$.profile,
$team$jscomp$47$$=$on_delete$jscomp$4_props_74039$$.team,$permissions$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$47$$,$APP.$cljs$cst$1728$permissions$$),$invitations$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$47$$,$APP.$cljs$cst$3325$invitations$$)),$team_id$jscomp$145$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$47$$,$APP.$cljs$cst$266$id$$),
$can_invite_QMARK_$jscomp$2$$=$APP.$app$main$data$nitrate$can_send_invitations_QMARK_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3297$organization$$,$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$47$$),$APP.$cljs$cst$2321$profile_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$50$$),$APP.$cljs$cst$3298$team_permissions$$,$permissions$jscomp$22$$],null)),$selected$jscomp$132$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),
$sort_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5262$field$$,null,$APP.$cljs$cst$1979$direction$$,$APP.$cljs$cst$5263$asc$$],null)),$selected_invitations$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$132$$),$APP.$rumext$v2$adapt$$($invitations$jscomp$5$$)],function(){return $APP.$cljs$core$filterv$$(function($p1__74033_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($selected$jscomp$132$$),
$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($p1__74033_SHARP_$$))},$APP.$cljs$core$_deref$$($invitations$jscomp$5$$))}),$on_select_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_invite_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($selected$jscomp$132$$)],function($email$jscomp$16$$){return $can_invite_QMARK_$jscomp$2$$?$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($selected$jscomp$132$$),$email$jscomp$16$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$132$$,
$APP.$cljs$core$disj$$,$email$jscomp$16$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$132$$,$APP.$cljs$core$conj$$,$email$jscomp$16$$):null}),$on_confirm_delete$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$132$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$145$$)],function(){for(var $c__5548__auto___74118_seq__74040_74105$$=$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($selected$jscomp$132$$)),$G__74120_chunk__74041_74106$$=
null,$G__74121_count__74042_74107$$=0,$G__74119_i__74043_74108$$=0;;)if($G__74119_i__74043_74108$$<$G__74121_count__74042_74107$$){var $email_74109_seq__74040_74117__$1$$=$G__74120_chunk__74041_74106$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__74119_i__74043_74108$$),$params_74110_temp__5825__auto___74116$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3207$email$$,$email_74109_seq__74040_74117__$1$$,$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$145$$],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_invitation$$($APP.$cljs$core$with_meta$$($params_74110_temp__5825__auto___74116$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-deleted")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_invitations$$(),$APP.$app$main$data$modal$hide$$()]))}}($c__5548__auto___74118_seq__74040_74105$$,
$G__74120_chunk__74041_74106$$,$G__74121_count__74042_74107$$,$G__74119_i__74043_74108$$,$params_74110_temp__5825__auto___74116$$,$email_74109_seq__74040_74117__$1$$,$permissions$jscomp$22$$,$invitations$jscomp$5$$,$team_id$jscomp$145$$,$can_invite_QMARK_$jscomp$2$$,$selected$jscomp$132$$,$sort_state$$,$selected_invitations$$,$on_select_change$jscomp$1$$,$profile$jscomp$50$$,$team$jscomp$47$$)],null))));$G__74119_i__74043_74108$$+=1}else if($params_74110_temp__5825__auto___74116$$=$APP.$cljs$core$seq$$($c__5548__auto___74118_seq__74040_74105$$)){$email_74109_seq__74040_74117__$1$$=
$params_74110_temp__5825__auto___74116$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($email_74109_seq__74040_74117__$1$$))$c__5548__auto___74118_seq__74040_74105$$=$APP.$cljs$core$_chunked_first$$($email_74109_seq__74040_74117__$1$$),$G__74119_i__74043_74108$$=$APP.$cljs$core$_chunked_rest$$($email_74109_seq__74040_74117__$1$$),$G__74120_chunk__74041_74106$$=$c__5548__auto___74118_seq__74040_74105$$,$G__74121_count__74042_74107$$=$APP.$cljs$core$count$$($c__5548__auto___74118_seq__74040_74105$$),$c__5548__auto___74118_seq__74040_74105$$=
$G__74119_i__74043_74108$$;else{var $email_74123$$=$APP.$cljs$core$first$$($email_74109_seq__74040_74117__$1$$),$params_74124$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3207$email$$,$email_74123$$,$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$145$$],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$team$delete_invitation$$($APP.$cljs$core$with_meta$$($params_74124$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,
function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-deleted")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_invitations$$(),$APP.$app$main$data$modal$hide$$()]))}}($c__5548__auto___74118_seq__74040_74105$$,$G__74120_chunk__74041_74106$$,
$G__74121_count__74042_74107$$,$G__74119_i__74043_74108$$,$params_74124$$,$email_74123$$,$email_74109_seq__74040_74117__$1$$,$params_74110_temp__5825__auto___74116$$,$permissions$jscomp$22$$,$invitations$jscomp$5$$,$team_id$jscomp$145$$,$can_invite_QMARK_$jscomp$2$$,$selected$jscomp$132$$,$sort_state$$,$selected_invitations$$,$on_select_change$jscomp$1$$,$profile$jscomp$50$$,$team$jscomp$47$$)],null))));$c__5548__auto___74118_seq__74040_74105$$=$APP.$cljs$core$next$$($email_74109_seq__74040_74117__$1$$);
$G__74120_chunk__74041_74106$$=null;$G__74121_count__74042_74107$$=0}$G__74119_i__74043_74108$$=0}else break;return $APP.$cljs$core$reset_BANG_$$($selected$jscomp$132$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)});$on_delete$jscomp$4_props_74039$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_invitations$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$145$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5256$invitation_modal$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1938$selected$$,$selected_invitations$$,$APP.$cljs$cst$4945$delete$$,!0,$APP.$cljs$cst$5214$on_confirm$$,$on_confirm_delete$$],null)))});var $on_resend_success$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("notifications.invitation-email-sent")),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$team$fetch_invitations$$()]));return $APP.$cljs$core$reset_BANG_$$($selected$jscomp$132$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$)}),$on_confirm_resend$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_invitations$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$145$$),$APP.$rumext$v2$adapt$$($on_resend_success$$)],function(){$APP.$app$main$data$modal$hide_BANG_$$();
var $params$jscomp$376$$=$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3325$invitations$$,$selected_invitations$$,$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$145$$,$APP.$cljs$cst$3355$resend_QMARK_$$,!0],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$on_resend_success$$,$APP.$cljs$cst$1300$on_error$$,$on_error$jscomp$60$$],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$team$create_invitations$$($params$jscomp$376$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$cst$2503$team$$],null)))}),$on_resend$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$145$$),$APP.$rumext$v2$adapt$$($selected_invitations$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5256$invitation_modal$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1938$selected$$,$selected_invitations$$,$APP.$cljs$cst$5214$on_confirm$$,$on_confirm_resend$$],null)))}),$on_order_by_status$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($sort_state$$)],function(){var $current_field$$=$APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$current_direction$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$new_direction$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_field$$,$APP.$cljs$cst$109$status$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_direction$$,$APP.$cljs$cst$5263$asc$$)?$APP.$cljs$cst$2709$desc$$:$APP.$cljs$cst$5263$asc$$:$APP.$cljs$cst$5263$asc$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($sort_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5262$field$$,$APP.$cljs$cst$109$status$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1979$direction$$,
$new_direction$$]));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($invitations$jscomp$5$$,function($p1__74037_SHARP__sorted$jscomp$1$$){$p1__74037_SHARP__sorted$jscomp$1$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5255$expired$$,$APP.$cljs$cst$3207$email$$),$p1__74037_SHARP__sorted$jscomp$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_direction$$,$APP.$cljs$cst$2709$desc$$)?
$APP.$cljs$core$reverse$$($p1__74037_SHARP__sorted$jscomp$1$$):$p1__74037_SHARP__sorted$jscomp$1$$})}),$on_order_by_role$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($sort_state$$)],function(){var $current_field$jscomp$1$$=$APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$current_direction$jscomp$1$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$new_direction$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_field$jscomp$1$$,$APP.$cljs$cst$2501$role$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_direction$jscomp$1$$,$APP.$cljs$cst$5263$asc$$)?$APP.$cljs$cst$2709$desc$$:$APP.$cljs$cst$5263$asc$$:$APP.$cljs$cst$5263$asc$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($sort_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5262$field$$,$APP.$cljs$cst$2501$role$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1979$direction$$,
$new_direction$jscomp$1$$]));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($invitations$jscomp$5$$,function($p1__74038_SHARP__sorted$jscomp$2$$){$p1__74038_SHARP__sorted$jscomp$2$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2501$role$$,$APP.$cljs$cst$3207$email$$),$p1__74038_SHARP__sorted$jscomp$2$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_direction$jscomp$1$$,$APP.$cljs$cst$2709$desc$$)?
$APP.$cljs$core$reverse$$($p1__74038_SHARP__sorted$jscomp$2$$):$p1__74038_SHARP__sorted$jscomp$2$$})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$47$$)],function(){$APP.$cljs$core$reset_BANG_$$($invitations$jscomp$5$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$47$$,$APP.$cljs$cst$3325$invitations$$));return $APP.$cljs$core$reset_BANG_$$($sort_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5262$field$$,
null,$APP.$cljs$cst$1979$direction$$,$APP.$cljs$cst$5263$asc$$],null))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__invitations",children:[!$can_invite_QMARK_$jscomp$2$$&&$APP.$cljs$core$seq$$($APP.$cljs$core$_deref$$($invitations$jscomp$5$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__empty-invitations",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__no-permission-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.invitations.no-permission")})}):
null,$can_invite_QMARK_$jscomp$2$$&&$APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($selected$jscomp$132$$))>0?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__invitations-actions",children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("team.invitations-selected",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($selected$jscomp$132$$)))]))}),
(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$on_resend$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.resend-invitation")})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$on_delete$jscomp$4_props_74039$$,variant:"destructive","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete-invitation"),
icon:"delete"})]})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__table-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__title-field-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.invitations")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__title-field-role",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.role"),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"action",className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$2501$role$$)?"main_ui_dashboard_team__sort-active":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$2501$role$$)?"main_ui_dashboard_team__sort-inactive":""),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.order-invitations-by-role"),
icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$2501$role$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$5263$asc$$)?"arrow-down":"arrow-up":"arrow-down",onClick:$on_order_by_role$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_team__title-field-status",
children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.status"),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$109$status$$)?"main_ui_dashboard_team__sort-active":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$APP.$cljs$cst$109$status$$)?"main_ui_dashboard_team__sort-inactive":""),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.order-invitations-by-status"),icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5262$field$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),$APP.$cljs$cst$109$status$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($sort_state$$)),
$APP.$cljs$cst$5263$asc$$)?"arrow-down":"arrow-up":"arrow-down",onClick:$on_order_by_status$$})]})]}),$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$_deref$$($invitations$jscomp$5$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$empty_invitation_table_STAR_$$,{canInvite:$can_invite_QMARK_$jscomp$2$$,team:$team$jscomp$47$$}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_team__table-rows",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$55$$,
$invitation$jscomp$2$$){$out_arr__44092__auto__$jscomp$55$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$invitation_row_STAR_$$,{invitation:$invitation$jscomp$2$$,canInvite:$can_invite_QMARK_$jscomp$2$$,teamId:$team_id$jscomp$145$$,selected:$selected$jscomp$132$$,onSelectChange:$on_select_change$jscomp$1$$},$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($invitation$jscomp$2$$)));return $out_arr__44092__auto__$jscomp$55$$},[],$APP.$cljs$core$_deref$$($invitations$jscomp$5$$))})]})};
$app$main$ui$dashboard$team$team_invitations_page_STAR_$$=function($props_74086$$){var $profile$jscomp$53$$=$props_74086$$.profile,$team$jscomp$50$$=$props_74086$$.team;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$50$$)],function(){return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.team-invitations",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$50$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$50$$)])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$50$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_invitations$$())});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$team$header$$,{section:$APP.$cljs$cst$5243$dashboard_team_invitations$$,team:$team$jscomp$50$$,profile:$profile$jscomp$53$$}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_dashboard_team__dashboard-team-invitations",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$invitation_section_STAR_$$,{team:$team$jscomp$50$$,profile:$profile$jscomp$53$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$668$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1224$subscriptions$$);return $and__5023__auto__$jscomp$668$$?$app$main$ui$dashboard$subscription$show_subscription_members_banner_QMARK_$$($team$jscomp$50$$,$profile$jscomp$53$$):$and__5023__auto__$jscomp$668$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$members_cta_STAR_$$,{team:$team$jscomp$50$$}):null]})]})};
$app$main$ui$components$progress$progress_notification_widget_STAR_$$=function(){var $state$jscomp$1250_total$jscomp$25$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$progress$$),$error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);$error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$,$APP.$cljs$cst$3208$theme$$,"dark");var $background_clr$jscomp$1_default_theme_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("dark",$error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$);$error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$=$APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1250_total$jscomp$25$$);var $color$jscomp$242_healthy_QMARK_$jscomp$3$$=$APP.$cljs$cst$2513$healthy$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1250_total$jscomp$25$$),$visible_QMARK_$jscomp$8$$=$APP.$cljs$cst$2357$visible$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1250_total$jscomp$25$$),
$progress$jscomp$2$$=$APP.$cljs$cst$2252$progress$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1250_total$jscomp$25$$),$hint$jscomp$30$$=$APP.$cljs$cst$275$hint$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1250_total$jscomp$25$$);$state$jscomp$1250_total$jscomp$25$$=$APP.$cljs$cst$2338$total$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1250_total$jscomp$25$$);var $pwidth$jscomp$1$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$)?280:$progress$jscomp$2$$*
280/$state$jscomp$1250_total$jscomp$25$$;$color$jscomp$242_healthy_QMARK_$jscomp$3$$=$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$)?"#ff3277":$APP.$cljs$core$truth_$$($color$jscomp$242_healthy_QMARK_$jscomp$3$$)?$background_clr$jscomp$1_default_theme_QMARK_$$?"#7efff5":"#6911d4":$APP.$cljs$core$not$$($color$jscomp$242_healthy_QMARK_$jscomp$3$$)?"#fe4811":null;$background_clr$jscomp$1_default_theme_QMARK_$$=$background_clr$jscomp$1_default_theme_QMARK_$$?"#2e3434":
"#eef0f2";var $toggle_detail_visibility$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$toggle_progress_visibility$$())});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$8$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_progress__progress-modal "+($APP.$cljs$core$truth_$$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$)?
"main_ui_components_progress__has-error":""),children:[$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$)?$app$main$ui$components$progress$error_icon$$:$app$main$ui$components$progress$neutral_icon$$,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_components_progress__title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_components_progress__title-text",children:$hint$jscomp$30$$}),$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$)?
(0,$APP.$rumext$v2$jsx$$)("button",{className:"main_ui_components_progress__retry-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.retry")}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_progress__progress",children:""+($progress$jscomp$2$$??"")+" / "+($state$jscomp$1250_total$jscomp$25$$??"")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_detail_visibility$jscomp$1$$,className:"main_ui_components_progress__progress-close-button",children:$app$main$ui$components$progress$close_icon$$}),
$APP.$cljs$core$truth_$$($error_QMARK_$jscomp$4_profile$jscomp$89_theme$jscomp$32$$)?null:(0,$APP.$rumext$v2$jsx$$)("svg",{height:4,width:280,className:"main_ui_components_progress__progress-bar",children:(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("path",{d:"M0 0 L280 0",stroke:$background_clr$jscomp$1_default_theme_QMARK_$$,strokeWidth:30}),(0,$APP.$rumext$v2$jsx$$)("path",{d:"M0 0 L280 0",stroke:$color$jscomp$242_healthy_QMARK_$jscomp$3$$,strokeWidth:30,fill:"transparent",
strokeDasharray:280,strokeDashoffset:280-$pwidth$jscomp$1$$,style:{transition:"stroke-dashoffset 1s ease-in-out"}})]})})]}):null})};
$app$main$ui$components$portal$portal_on_document_STAR_$$=function($children$jscomp$315_props_82520$$){$children$jscomp$315_props_82520$$=$children$jscomp$315_props_82520$$.children;var $container$jscomp$97$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$205$default$$);return(0,$APP.$rumext$v2$portal$$)((0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$children$jscomp$315_props_82520$$}),$container$jscomp$97$$)};
$app$main$ui$dashboard$file_menu$get_project_name$$=function($project$jscomp$23$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$23$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$23$$)};$app$main$ui$dashboard$file_menu$get_project_id$$=function($project$jscomp$24$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$24$$))};
$app$main$ui$dashboard$file_menu$get_team_name$$=function($team$jscomp$75$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$75$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$75$$)};
$app$main$ui$dashboard$file_menu$group_by_team$$=function($projects$jscomp$7$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($teams$jscomp$21$$,$project$jscomp$25$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($teams$jscomp$21$$,$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),function($p1__82527_SHARP_$$){return $p1__82527_SHARP_$$==null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),
$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$2504$team_name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),$APP.$cljs$cst$5017$is_default$$,$cljs$cst$6376$is_default_team$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$25$$),$APP.$cljs$cst$1945$projects$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$project$jscomp$25$$],null)],null):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__82527_SHARP_$$,$APP.$cljs$cst$1945$projects$$,
$APP.$cljs$core$conj$$,$project$jscomp$25$$)})},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$projects$jscomp$7$$)};
$app$main$ui$dashboard$file_menu$file_menu_STAR_$$=function($options$jscomp$645_props_82544_sub_options$jscomp$2$$){function $on_delete_immediately$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-file-forever-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$)])),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$delete_files_immediately$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1944$team_id$$,$current_team_id$jscomp$3$$,$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,$files$jscomp$34$$)],null)))}],null)))}function $on_restore_immediately$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard-restore-file-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard-restore-file-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$)])),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),
$APP.$cljs$cst$2488$accept_style$$,$APP.$cljs$cst$2489$primary$$,$APP.$cljs$cst$2490$on_accept$$,$restore_fn$$],null)))}function $restore_fn$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$restore_files_immediately$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$current_team_id$jscomp$3$$,$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$app$common$data$xf_COLON_map_id$$,$files$jscomp$34$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-success-notification",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$)]))),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_projects$$($current_team_id$jscomp$3$$),$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($current_team_id$jscomp$3$$)]))},$APP.$cljs$cst$1300$on_error$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.errors.error-on-restore-file",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$)]))))}],null))))}function $on_export_binary_files$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$exports$files$open_export_dialog$$($files$jscomp$34$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)))}
function $on_del_shared$$($event$jscomp$743$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$743$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$743$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5721$delete_shared_libraries$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$5722$unpublish$$,$APP.$cljs$cst$1729$ids$$,
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2490$on_accept$$,$del_shared$$,$APP.$cljs$cst$5723$count_libraries$$,$file_count$$],null)))}function $on_add_shared$jscomp$1$$($event$jscomp$742$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$742$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$show_shared_dialog$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$),
$add_shared$jscomp$2$$))}function $del_shared$$(){return $APP.$cljs$core$run_BANG_$$(function($p1__82539_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$set_file_shared$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__82539_SHARP_$$,$APP.$cljs$cst$2190$is_shared$$,!1)))},$files$jscomp$34$$)}function $add_shared$jscomp$2$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$set_file_shared$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$192$$,
$APP.$cljs$cst$2190$is_shared$$,!0)))}function $on_move$jscomp$3$$($team_id$jscomp$168$$,$project_id$jscomp$40$$){var $params$jscomp$442$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$40$$],null);return function(){var $num_shared$jscomp$1$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82536_SHARP_$$){return $APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($p1__82536_SHARP_$$)},$files$jscomp$34$$);return 0<$APP.$cljs$core$count$$($num_shared$jscomp$1$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$168$$,$current_team_id$jscomp$3$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5721$delete_shared_libraries$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$1804$move$$,$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2490$on_accept$$,function(){return $on_move_accept$$($params$jscomp$442$$,$team_id$jscomp$168$$,$project_id$jscomp$40$$)},$APP.$cljs$cst$5723$count_libraries$$,
$APP.$cljs$core$count$$($num_shared$jscomp$1$$)],null))):$on_move_accept$$($params$jscomp$442$$,$team_id$jscomp$168$$,$project_id$jscomp$40$$)}}function $on_move_accept$$($params$jscomp$441$$,$team_id$jscomp$167$$,$project_id$jscomp$39$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$move_files$$($APP.$cljs$core$with_meta$$($params$jscomp$441$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,function(){return $on_move_success$jscomp$1$$($team_id$jscomp$167$$,
$project_id$jscomp$39$$)}],null))))}function $on_move_success$jscomp$1$$($team_id$jscomp$166$$,$project_id$jscomp$38$$){$multi_QMARK_$jscomp$2$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-files"))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-file")));
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($navigate$jscomp$1$$)?$navigate$jscomp$1$$:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$166$$,$current_team_id$jscomp$3$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2189$project_id$$,
$project_id$jscomp$38$$,$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$166$$],null)]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$166$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))}function $on_delete$jscomp$15$$($event$jscomp$741_num_shared$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$741_num_shared$$);
$event$jscomp$741_num_shared$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82534_SHARP_$$){return $APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($p1__82534_SHARP_$$)},$files$jscomp$34$$);return 0<$APP.$cljs$core$count$$($event$jscomp$741_num_shared$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$5721$delete_shared_libraries$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$4945$delete$$,$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$files$jscomp$34$$),$APP.$cljs$cst$2490$on_accept$$,$on_delete_accept$jscomp$1$$,$APP.$cljs$cst$5723$count_libraries$$,$APP.$cljs$core$count$$($event$jscomp$741_num_shared$$)],null))):$multi_QMARK_$jscomp$2$$?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-file-multi-confirm.title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-file-multi-confirm.message",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-file-multi-confirm.accept",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$2490$on_accept$$,$on_delete_accept$jscomp$1$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-file-confirm.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-file-confirm.message"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-file-confirm.accept"),$APP.$cljs$cst$2490$on_accept$$,$on_delete_accept$jscomp$1$$],null)))}
function $on_delete_accept$jscomp$1$$(){$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$dashboard$delete_file$$,$files$jscomp$34$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.success-delete-file",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)]))),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))}function $on_duplicate$jscomp$4$$(){$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$dashboard$duplicate_file$$,$files$jscomp$34$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.success-duplicate-file",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)]))))}function $on_new_tab$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$),
$APP.$cljs$cst$2467$app_DOT_main_DOT_router_SLASH_new_window$$,!0],null)])))}var $left$jscomp$38$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.left,$navigate$jscomp$1$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.navigate,$on_close$jscomp$42$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.onClose,$top$jscomp$20$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.top,$can_edit$jscomp$5$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.canEdit,$on_edit$jscomp$10$$=
$options$jscomp$645_props_82544_sub_options$jscomp$2$$.onEdit,$parent_id$jscomp$112$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.parentId,$files$jscomp$34$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.files,$can_restore$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.canRestore,$origin$jscomp$75$$=$options$jscomp$645_props_82544_sub_options$jscomp$2$$.origin,$is_lib_page_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5352$libraries$$,
$origin$jscomp$75$$),$is_search_page_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$6377$search$$,$origin$jscomp$75$$),$top__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($top$jscomp$20$$)?$top$jscomp$20$$:0,$left__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($left$jscomp$38$$)?$left$jscomp$38$$:0,$file$jscomp$192$$=$APP.$cljs$core$first$$($files$jscomp$34$$),$file_count$$=$APP.$cljs$core$count$$($files$jscomp$34$$),$multi_QMARK_$jscomp$2$$=$file_count$$>1,$current_team_id$jscomp$3$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$),$teams_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$teams$jscomp$22$$=$APP.$cljs$core$_deref$$($teams_STAR_$$),$current_team$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($teams$jscomp$22$$,$current_team_id$jscomp$3$$),$other_teams$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82532_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82532_SHARP_$$),
$current_team_id$jscomp$3$$)},$APP.$cljs$core$vals$$($teams$jscomp$22$$)),$file_project_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2189$project_id$$),$files$jscomp$34$$),$current_projects$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__82533_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($file_project_ids$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82533_SHARP_$$))},
$APP.$cljs$cst$1945$projects$$.$cljs$core$IFn$_invoke$arity$1$($current_team$jscomp$1$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__82540_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($teams_STAR_$$,$p1__82540_SHARP_$$)},$APP.$beicon$v2$core$map$$($app$main$ui$dashboard$file_menu$group_by_team$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$6378$get_all_projects$$)))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$42$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5169$dropdown_SLASH_open$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,"file-menu"],null)));var $stream$jscomp$109$$=$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__82541_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("file-menu",
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__82541_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5169$dropdown_SLASH_open$$),$APP.$app$main$store$stream$$)))),$subs$jscomp$33$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$04$$($stream$jscomp$109$$,null,null,$on_close$jscomp$42$$);return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$33$$)}});
$options$jscomp$645_props_82544_sub_options$jscomp$2$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82569$$($s__82572$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__82572__$2_temp__5825__auto__$jscomp$471$$=$APP.$cljs$core$seq$$($s__82572$$);if($s__82572__$2_temp__5825__auto__$jscomp$471$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82572__$2_temp__5825__auto__$jscomp$471$$)){var $JSCompiler_inline_result$jscomp$2015_c__5501__auto__$jscomp$62$$=
$APP.$cljs$core$_chunked_first$$($s__82572__$2_temp__5825__auto__$jscomp$471$$),$size__5502__auto__$jscomp$62$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2015_c__5501__auto__$jscomp$62$$),$b__82574_project$jscomp$26$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$62$$);a:{for(var $i__82573$jscomp$inline_9713$$=0;;)if($i__82573$jscomp$inline_9713$$<$size__5502__auto__$jscomp$62$$){var $project$jscomp$inline_9714_x$jscomp$inline_14133$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2015_c__5501__auto__$jscomp$62$$,
$i__82573$jscomp$inline_9713$$),$b$jscomp$inline_14132$$=$b__82574_project$jscomp$26$$;$project$jscomp$inline_9714_x$jscomp$inline_14133$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($project$jscomp$inline_9714_x$jscomp$inline_14133$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($project$jscomp$inline_9714_x$jscomp$inline_14133$$),$APP.$cljs$cst$2413$handler$$,$on_move$jscomp$3$$($current_team_id$jscomp$3$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$inline_9714_x$jscomp$inline_14133$$))],null);$b$jscomp$inline_14132$$.add($project$jscomp$inline_9714_x$jscomp$inline_14133$$);$i__82573$jscomp$inline_9713$$+=1}else{$JSCompiler_inline_result$jscomp$2015_c__5501__auto__$jscomp$62$$=!0;break a}$JSCompiler_inline_result$jscomp$2015_c__5501__auto__$jscomp$62$$=void 0}return $JSCompiler_inline_result$jscomp$2015_c__5501__auto__$jscomp$62$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82574_project$jscomp$26$$),
$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82569$$($APP.$cljs$core$_chunked_rest$$($s__82572__$2_temp__5825__auto__$jscomp$471$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82574_project$jscomp$26$$),null)}$b__82574_project$jscomp$26$$=$APP.$cljs$core$first$$($s__82572__$2_temp__5825__auto__$jscomp$471$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($b__82574_project$jscomp$26$$),
$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($b__82574_project$jscomp$26$$),$APP.$cljs$cst$2413$handler$$,$on_move$jscomp$3$$($current_team_id$jscomp$3$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__82574_project$jscomp$26$$))],null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82569$$($APP.$cljs$core$rest$$($s__82572__$2_temp__5825__auto__$jscomp$471$$)))}return null}},null,null)}($current_projects$$)}(),$APP.$cljs$core$seq$$($other_teams$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.move-to-other-team"),$APP.$cljs$cst$266$id$$,"move-to-other-team",$APP.$cljs$cst$873$options$$,function(){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577$$($s__82578$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$472$$=
$APP.$cljs$core$seq$$($s__82578$$);if($temp__5825__auto__$jscomp$472$$){var $s__82578__$2$$=$temp__5825__auto__$jscomp$472$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82578__$2$$)){var $c__5501__auto__$jscomp$63$$=$APP.$cljs$core$_chunked_first$$($s__82578__$2$$),$size__5502__auto__$jscomp$63$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$63$$),$b__82580$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$63$$);return function(){for(var $i__82579$$=0;;)if($i__82579$$<$size__5502__auto__$jscomp$63$$){var $team$jscomp$77$$=
$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$63$$,$i__82579$$);$APP.$cljs$core$chunk_append$$($b__82580$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_team_name$$($team$jscomp$77$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($team$jscomp$77$$),$APP.$cljs$cst$873$options$$,function(){return function($i__82579$jscomp$1$$,$team$jscomp$78$$,$c__5501__auto__$jscomp$64$$,$size__5502__auto__$jscomp$64$$,$b__82580$jscomp$1$$,
$s__82578__$2$jscomp$1$$,$temp__5825__auto__$jscomp$473$$,$is_lib_page_QMARK_$jscomp$1$$,$is_search_page_QMARK_$jscomp$1$$,$top__$1$jscomp$4$$,$left__$1$jscomp$5$$,$file$jscomp$193$$,$file_count$jscomp$1$$,$multi_QMARK_$jscomp$3$$,$current_team_id$jscomp$4$$,$teams_STAR_$jscomp$1$$,$teams$jscomp$23$$,$current_team$jscomp$2$$,$other_teams$jscomp$1$$,$file_project_ids$jscomp$1$$,$current_projects$jscomp$1$$,$on_new_tab$jscomp$1$$,$on_duplicate$jscomp$5$$,$on_delete_accept$jscomp$2$$,$on_delete$jscomp$16$$,
$on_move_success$jscomp$2$$,$on_move_accept$jscomp$1$$,$on_move$jscomp$4$$,$add_shared$jscomp$3$$,$del_shared$jscomp$1$$,$on_add_shared$jscomp$2$$,$on_del_shared$jscomp$1$$,$on_export_binary_files$jscomp$1$$,$restore_fn$jscomp$1$$,$on_restore_immediately$jscomp$1$$,$on_delete_immediately$jscomp$1$$,$left$jscomp$39$$,$navigate$jscomp$2$$,$on_close$jscomp$43$$,$top$jscomp$21$$,$can_edit$jscomp$6$$,$on_edit$jscomp$11$$,$parent_id$jscomp$113$$,$files$jscomp$35$$,$can_restore$jscomp$1$$,$origin$jscomp$76$$){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577_$_iter__82581$$($s__82582$$){return new $APP.$cljs$core$LazySeq$$(null,
function($i__82579$jscomp$2$$,$team$jscomp$79$$,$c__5501__auto__$jscomp$65$$,$size__5502__auto__$jscomp$65$$,$b__82580$jscomp$2$$,$s__82578__$2$jscomp$2$$,$temp__5825__auto__$jscomp$474$$,$is_lib_page_QMARK_$jscomp$2$$,$is_search_page_QMARK_$jscomp$2$$,$top__$1$jscomp$5$$,$left__$1$jscomp$6$$,$file$jscomp$194$$,$file_count$jscomp$2$$,$multi_QMARK_$jscomp$4$$,$current_team_id$jscomp$5$$,$teams_STAR_$jscomp$2$$,$teams$jscomp$24$$,$current_team$jscomp$3$$,$other_teams$jscomp$2$$,$file_project_ids$jscomp$2$$,
$current_projects$jscomp$2$$,$on_new_tab$jscomp$2$$,$on_duplicate$jscomp$6$$,$on_delete_accept$jscomp$3$$,$on_delete$jscomp$17$$,$on_move_success$jscomp$3$$,$on_move_accept$jscomp$2$$,$on_move$jscomp$5$$){return function(){for(;;){var $s__82582__$2_temp__5825__auto____$1$jscomp$28$$=$APP.$cljs$core$seq$$($s__82582$$);if($s__82582__$2_temp__5825__auto____$1$jscomp$28$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82582__$2_temp__5825__auto____$1$jscomp$28$$)){var $JSCompiler_inline_result$jscomp$2016_c__5501__auto____$1$jscomp$1$$=
$APP.$cljs$core$_chunked_first$$($s__82582__$2_temp__5825__auto____$1$jscomp$28$$),$size__5502__auto____$1$jscomp$1$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2016_c__5501__auto____$1$jscomp$1$$),$b__82584_sub_project$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto____$1$jscomp$1$$);a:{for(var $i__82583$jscomp$inline_9716$$=0;;)if($i__82583$jscomp$inline_9716$$<$size__5502__auto____$1$jscomp$1$$){var $sub_project$jscomp$inline_9717_x$jscomp$inline_14136$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2016_c__5501__auto____$1$jscomp$1$$,
$i__82583$jscomp$inline_9716$$),$b$jscomp$inline_14135$$=$b__82584_sub_project$$;$sub_project$jscomp$inline_9717_x$jscomp$inline_14136$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($sub_project$jscomp$inline_9717_x$jscomp$inline_14136$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($sub_project$jscomp$inline_9717_x$jscomp$inline_14136$$),$APP.$cljs$cst$2413$handler$$,$on_move$jscomp$5$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$79$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_project$jscomp$inline_9717_x$jscomp$inline_14136$$))],null);$b$jscomp$inline_14135$$.add($sub_project$jscomp$inline_9717_x$jscomp$inline_14136$$);$i__82583$jscomp$inline_9716$$+=1}else{$JSCompiler_inline_result$jscomp$2016_c__5501__auto____$1$jscomp$1$$=!0;break a}$JSCompiler_inline_result$jscomp$2016_c__5501__auto____$1$jscomp$1$$=void 0}return $JSCompiler_inline_result$jscomp$2016_c__5501__auto____$1$jscomp$1$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82584_sub_project$$),
$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577_$_iter__82581$$($APP.$cljs$core$_chunked_rest$$($s__82582__$2_temp__5825__auto____$1$jscomp$28$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82584_sub_project$$),null)}$b__82584_sub_project$$=$APP.$cljs$core$first$$($s__82582__$2_temp__5825__auto____$1$jscomp$28$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($b__82584_sub_project$$),
$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($b__82584_sub_project$$),$APP.$cljs$cst$2413$handler$$,$on_move$jscomp$5$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$79$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__82584_sub_project$$))],null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577_$_iter__82581$$($APP.$cljs$core$rest$$($s__82582__$2_temp__5825__auto____$1$jscomp$28$$)))}return null}}}($i__82579$jscomp$1$$,
$team$jscomp$78$$,$c__5501__auto__$jscomp$64$$,$size__5502__auto__$jscomp$64$$,$b__82580$jscomp$1$$,$s__82578__$2$jscomp$1$$,$temp__5825__auto__$jscomp$473$$,$is_lib_page_QMARK_$jscomp$1$$,$is_search_page_QMARK_$jscomp$1$$,$top__$1$jscomp$4$$,$left__$1$jscomp$5$$,$file$jscomp$193$$,$file_count$jscomp$1$$,$multi_QMARK_$jscomp$3$$,$current_team_id$jscomp$4$$,$teams_STAR_$jscomp$1$$,$teams$jscomp$23$$,$current_team$jscomp$2$$,$other_teams$jscomp$1$$,$file_project_ids$jscomp$1$$,$current_projects$jscomp$1$$,
$on_new_tab$jscomp$1$$,$on_duplicate$jscomp$5$$,$on_delete_accept$jscomp$2$$,$on_delete$jscomp$16$$,$on_move_success$jscomp$2$$,$on_move_accept$jscomp$1$$,$on_move$jscomp$4$$,$add_shared$jscomp$3$$,$del_shared$jscomp$1$$,$on_add_shared$jscomp$2$$,$on_del_shared$jscomp$1$$,$on_export_binary_files$jscomp$1$$,$restore_fn$jscomp$1$$,$on_restore_immediately$jscomp$1$$,$on_delete_immediately$jscomp$1$$,$left$jscomp$39$$,$navigate$jscomp$2$$,$on_close$jscomp$43$$,$top$jscomp$21$$,$can_edit$jscomp$6$$,$on_edit$jscomp$11$$,
$parent_id$jscomp$113$$,$files$jscomp$35$$,$can_restore$jscomp$1$$,$origin$jscomp$76$$),null,null)}}($i__82579$$,$team$jscomp$77$$,$c__5501__auto__$jscomp$63$$,$size__5502__auto__$jscomp$63$$,$b__82580$$,$s__82578__$2$$,$temp__5825__auto__$jscomp$472$$,$is_lib_page_QMARK_$$,$is_search_page_QMARK_$$,$top__$1$jscomp$3$$,$left__$1$jscomp$4$$,$file$jscomp$192$$,$file_count$$,$multi_QMARK_$jscomp$2$$,$current_team_id$jscomp$3$$,$teams_STAR_$$,$teams$jscomp$22$$,$current_team$jscomp$1$$,$other_teams$$,
$file_project_ids$$,$current_projects$$,$on_new_tab$$,$on_duplicate$jscomp$4$$,$on_delete_accept$jscomp$1$$,$on_delete$jscomp$15$$,$on_move_success$jscomp$1$$,$on_move_accept$$,$on_move$jscomp$3$$,$add_shared$jscomp$2$$,$del_shared$$,$on_add_shared$jscomp$1$$,$on_del_shared$$,$on_export_binary_files$$,$restore_fn$$,$on_restore_immediately$$,$on_delete_immediately$$,$left$jscomp$38$$,$navigate$jscomp$1$$,$on_close$jscomp$42$$,$top$jscomp$20$$,$can_edit$jscomp$5$$,$on_edit$jscomp$10$$,$parent_id$jscomp$112$$,
$files$jscomp$34$$,$can_restore$$,$origin$jscomp$75$$)($APP.$cljs$cst$1945$projects$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$77$$))}()],null));$i__82579$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82580$$),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577$$($APP.$cljs$core$_chunked_rest$$($s__82578__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82580$$),null)}var $team$jscomp$76$$=$APP.$cljs$core$first$$($s__82578__$2$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_team_name$$($team$jscomp$76$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($team$jscomp$76$$),$APP.$cljs$cst$873$options$$,function(){return function($team$jscomp$80$$,$s__82578__$2$jscomp$3$$,$temp__5825__auto__$jscomp$475$$,$is_lib_page_QMARK_$jscomp$3$$,$is_search_page_QMARK_$jscomp$3$$,$top__$1$jscomp$6$$,$left__$1$jscomp$7$$,$file$jscomp$195$$,$file_count$jscomp$3$$,$multi_QMARK_$jscomp$5$$,$current_team_id$jscomp$6$$,
$teams_STAR_$jscomp$3$$,$teams$jscomp$25$$,$current_team$jscomp$4$$,$other_teams$jscomp$3$$,$file_project_ids$jscomp$3$$,$current_projects$jscomp$3$$,$on_new_tab$jscomp$3$$,$on_duplicate$jscomp$7$$,$on_delete_accept$jscomp$4$$,$on_delete$jscomp$18$$,$on_move_success$jscomp$4$$,$on_move_accept$jscomp$3$$,$on_move$jscomp$6$$){return function $app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577_$_iter__82586$$($s__82587$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__82587__$2_temp__5825__auto____$1$jscomp$29$$=
$APP.$cljs$core$seq$$($s__82587$$);if($s__82587__$2_temp__5825__auto____$1$jscomp$29$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__82587__$2_temp__5825__auto____$1$jscomp$29$$)){var $JSCompiler_inline_result$jscomp$2017_c__5501__auto__$jscomp$66$$=$APP.$cljs$core$_chunked_first$$($s__82587__$2_temp__5825__auto____$1$jscomp$29$$),$size__5502__auto__$jscomp$66$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$2017_c__5501__auto__$jscomp$66$$),$b__82589_sub_project$jscomp$2$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$66$$);
a:{for(var $i__82588$jscomp$inline_9719$$=0;;)if($i__82588$jscomp$inline_9719$$<$size__5502__auto__$jscomp$66$$){var $sub_project$jscomp$inline_9720_x$jscomp$inline_14139$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$2017_c__5501__auto__$jscomp$66$$,$i__82588$jscomp$inline_9719$$),$b$jscomp$inline_14138$$=$b__82589_sub_project$jscomp$2$$;$sub_project$jscomp$inline_9720_x$jscomp$inline_14139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($sub_project$jscomp$inline_9720_x$jscomp$inline_14139$$),
$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($sub_project$jscomp$inline_9720_x$jscomp$inline_14139$$),$APP.$cljs$cst$2413$handler$$,$on_move$jscomp$6$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$80$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_project$jscomp$inline_9720_x$jscomp$inline_14139$$))],null);$b$jscomp$inline_14138$$.add($sub_project$jscomp$inline_9720_x$jscomp$inline_14139$$);$i__82588$jscomp$inline_9719$$+=1}else{$JSCompiler_inline_result$jscomp$2017_c__5501__auto__$jscomp$66$$=
!0;break a}$JSCompiler_inline_result$jscomp$2017_c__5501__auto__$jscomp$66$$=void 0}return $JSCompiler_inline_result$jscomp$2017_c__5501__auto__$jscomp$66$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82589_sub_project$jscomp$2$$),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577_$_iter__82586$$($APP.$cljs$core$_chunked_rest$$($s__82587__$2_temp__5825__auto____$1$jscomp$29$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__82589_sub_project$jscomp$2$$),null)}$b__82589_sub_project$jscomp$2$$=
$APP.$cljs$core$first$$($s__82587__$2_temp__5825__auto____$1$jscomp$29$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$app$main$ui$dashboard$file_menu$get_project_name$$($b__82589_sub_project$jscomp$2$$),$APP.$cljs$cst$266$id$$,$app$main$ui$dashboard$file_menu$get_project_id$$($b__82589_sub_project$jscomp$2$$),$APP.$cljs$cst$2413$handler$$,$on_move$jscomp$6$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$80$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($b__82589_sub_project$jscomp$2$$))],
null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577_$_iter__82586$$($APP.$cljs$core$rest$$($s__82587__$2_temp__5825__auto____$1$jscomp$29$$)))}return null}},null,null)}}($team$jscomp$76$$,$s__82578__$2$$,$temp__5825__auto__$jscomp$472$$,$is_lib_page_QMARK_$$,$is_search_page_QMARK_$$,$top__$1$jscomp$3$$,$left__$1$jscomp$4$$,$file$jscomp$192$$,$file_count$$,$multi_QMARK_$jscomp$2$$,$current_team_id$jscomp$3$$,$teams_STAR_$$,$teams$jscomp$22$$,$current_team$jscomp$1$$,$other_teams$$,
$file_project_ids$$,$current_projects$$,$on_new_tab$$,$on_duplicate$jscomp$4$$,$on_delete_accept$jscomp$1$$,$on_delete$jscomp$15$$,$on_move_success$jscomp$1$$,$on_move_accept$$,$on_move$jscomp$3$$,$add_shared$jscomp$2$$,$del_shared$$,$on_add_shared$jscomp$1$$,$on_del_shared$$,$on_export_binary_files$$,$restore_fn$$,$on_restore_immediately$$,$on_delete_immediately$$,$left$jscomp$38$$,$navigate$jscomp$1$$,$on_close$jscomp$42$$,$top$jscomp$20$$,$can_edit$jscomp$5$$,$on_edit$jscomp$10$$,$parent_id$jscomp$112$$,
$files$jscomp$34$$,$can_restore$$,$origin$jscomp$75$$)($APP.$cljs$cst$1945$projects$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$76$$))}()],null),$app$main$ui$dashboard$file_menu$file_menu_STAR__$_iter__82577$$($APP.$cljs$core$rest$$($s__82578__$2$$)))}return null}},null,null)}($other_teams$$)}()],null)],null):null);$options$jscomp$645_props_82544_sub_options$jscomp$2$$=$APP.$cljs$core$truth_$$($can_restore$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.file-menu.restore-files-option",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)])),$APP.$cljs$cst$266$id$$,"restore-file",$APP.$cljs$cst$2413$handler$$,$on_restore_immediately$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.file-menu.delete-files-permanently-option",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$$)])),$APP.$cljs$cst$266$id$$,"delete-file",$APP.$cljs$cst$2413$handler$$,$on_delete_immediately$$],null)],null):$multi_QMARK_$jscomp$2$$?new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($can_edit$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.duplicate-multi",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"duplicate-multi",$APP.$cljs$cst$2413$handler$$,$on_duplicate$jscomp$4$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1059$$=$APP.$cljs$core$seq$$($current_projects$$)||$APP.$cljs$core$seq$$($other_teams$$);return $and__5023__auto__$jscomp$1059$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1059$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.move-to-multi",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"file-move-multi",$APP.$cljs$cst$873$options$$,$options$jscomp$645_props_82544_sub_options$jscomp$2$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.export-binary-multi",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),
$APP.$cljs$cst$266$id$$,"file-binary-export-multi",$APP.$cljs$cst$2413$handler$$,$on_export_binary_files$$],null),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1060$$=$APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1060$$)?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1060$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.unpublish-multi-files",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"file-unpublish-multi",$APP.$cljs$cst$2413$handler$$,$on_del_shared$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1061$$=!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1061$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1061$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.delete-multi-files",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_count$$])),$APP.$cljs$cst$266$id$$,"file-delete-multi",$APP.$cljs$cst$2413$handler$$,$on_delete$jscomp$15$$],null):null],null):new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.open-in-new-tab"),$APP.$cljs$cst$266$id$$,"file-open-new-tab",$APP.$cljs$cst$2413$handler$$,
$on_new_tab$$],null),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1062$$=!$is_search_page_QMARK_$$;return $and__5023__auto__$jscomp$1062$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1062$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),$APP.$cljs$cst$266$id$$,"file-rename",$APP.$cljs$cst$2413$handler$$,$on_edit$jscomp$10$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1063$$=
!$is_search_page_QMARK_$$;return $and__5023__auto__$jscomp$1063$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1063$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.duplicate"),$APP.$cljs$cst$266$id$$,"file-duplicate",$APP.$cljs$cst$2413$handler$$,$on_duplicate$jscomp$4$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$=
!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$?($and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$=!$is_search_page_QMARK_$$)?($and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$=$APP.$cljs$core$seq$$($current_projects$$)||$APP.$cljs$core$seq$$($other_teams$$))?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$:
$and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$:$and__5023__auto__$jscomp$1064_and__5023__auto____$1$jscomp$172_and__5023__auto____$2$jscomp$56$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.move-to"),$APP.$cljs$cst$266$id$$,"file-move-to",$APP.$cljs$cst$873$options$$,$options$jscomp$645_props_82544_sub_options$jscomp$2$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1065$$=
!$is_search_page_QMARK_$$;return $and__5023__auto__$jscomp$1065$$?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1065$$}())?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$192$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.unpublish-shared"),$APP.$cljs$cst$266$id$$,"file-del-shared",$APP.$cljs$cst$2413$handler$$,$on_del_shared$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.add-shared"),$APP.$cljs$cst$266$id$$,"file-add-shared",$APP.$cljs$cst$2413$handler$$,$on_add_shared$jscomp$1$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1477$separator$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.download-binary-file"),$APP.$cljs$cst$266$id$$,
"download-binary-file",$APP.$cljs$cst$2413$handler$$,$on_export_binary_files$$],null),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1066_and__5023__auto____$1$jscomp$173$$=!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1066_and__5023__auto____$1$jscomp$173$$?($and__5023__auto__$jscomp$1066_and__5023__auto____$1$jscomp$173$$=!$is_search_page_QMARK_$$)?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1066_and__5023__auto____$1$jscomp$173$$:$and__5023__auto__$jscomp$1066_and__5023__auto____$1$jscomp$173$$}())?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$1477$separator$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1067_and__5023__auto____$1$jscomp$174$$=!$is_lib_page_QMARK_$$;return $and__5023__auto__$jscomp$1067_and__5023__auto____$1$jscomp$174$$?($and__5023__auto__$jscomp$1067_and__5023__auto____$1$jscomp$174$$=!$is_search_page_QMARK_$$)?$can_edit$jscomp$5$$:$and__5023__auto__$jscomp$1067_and__5023__auto____$1$jscomp$174$$:
$and__5023__auto__$jscomp$1067_and__5023__auto____$1$jscomp$174$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$266$id$$,"file-delete",$APP.$cljs$cst$2413$handler$$,$on_delete$jscomp$15$$],null):null],null);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,{onClose:$on_close$jscomp$42$$,fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($top__$1$jscomp$3$$,
0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($left__$1$jscomp$4$$,0),show:!0,minWidth:!0,top:$top__$1$jscomp$3$$,left:$left__$1$jscomp$4$$,options:$options$jscomp$645_props_82544_sub_options$jscomp$2$$,origin:$parent_id$jscomp$112$$})};
$app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$=function($children$jscomp$316_props_82525$$){var $title$jscomp$54$$,$subtitle$jscomp$1$$,$props$jscomp$401$$;({className:$class$$jscomp$84_props__$1$jscomp$104$$,title:$title$jscomp$54$$,subtitle:$subtitle$jscomp$1$$,type:$decoration_type_or__5025__auto__$jscomp$inline_9722_type$jscomp$727$$,children:$children$jscomp$316_props_82525$$,...$props$jscomp$401$$}=$children$jscomp$316_props_82525$$);var $class$$jscomp$84_props__$1$jscomp$104$$=
{...$props$jscomp$401$$,className:""+($class$$jscomp$84_props__$1$jscomp$104$$??"")+" main_ui_ds_product_empty_placeholder__empty-placeholder","data-testid":"empty-placeholder"};var $decoration_type_or__5025__auto__$jscomp$inline_9722_type$jscomp$727$$="empty-placeholder-"+($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($decoration_type_or__5025__auto__$jscomp$inline_9722_type$jscomp$727$$)?$decoration_type_or__5025__auto__$jscomp$inline_9722_type$jscomp$727$$:1)??
"");return(0,$APP.$rumext$v2$create_element$$)("div",$class$$jscomp$84_props__$1$jscomp$104$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:""+($decoration_type_or__5025__auto__$jscomp$inline_9722_type$jscomp$727$$??"")+"-left",className:"main_ui_ds_product_empty_placeholder__svg-decor"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_empty_placeholder__text-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"title-medium",className:"main_ui_ds_product_empty_placeholder__placeholder-title",children:$title$jscomp$54$$}),$APP.$cljs$core$truth_$$($subtitle$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-large",children:$subtitle$jscomp$1$$}):null,$children$jscomp$316_props_82525$$]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$raw_svg$raw_svg_STAR_$$,{id:""+($decoration_type_or__5025__auto__$jscomp$inline_9722_type$jscomp$727$$??
"")+"-right",className:"main_ui_ds_product_empty_placeholder__svg-decor"}))};
$app$main$ui$dashboard$placeholder$empty_project_placeholder_STAR_$$=function($on_create$jscomp$1_props_82556$$){var $on_finish_import$jscomp$4$$=$on_create$jscomp$1_props_82556$$.onFinishImport,$project_id$jscomp$41$$=$on_create$jscomp$1_props_82556$$.projectId;$on_create$jscomp$1_props_82556$$=$on_create$jscomp$1_props_82556$$.onCreate;var $file_input$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_add_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-libraries-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1371$section$$,"empty-placeholder-projects"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/penpothub/libraries-templates")}),$on_import$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($file_input$jscomp$1$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_create$jscomp$1_props_82556$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.add-file"),className:"main_ui_dashboard_placeholder__empty-project-card",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.create")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.start")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_import$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.import"),className:"main_ui_dashboard_placeholder__empty-project-card",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.import")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.import-penpot")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_add_library$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.go-to-libraries"),className:"main_ui_dashboard_placeholder__empty-project-card",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.add-library")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__empty-project-card-subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.explore")})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$import$0$import_form_STAR_$$,
{ref:$file_input$jscomp$1$$,projectId:$project_id$jscomp$41$$,onFinishImport:$on_finish_import$jscomp$4$$})]})};
$app$main$ui$dashboard$placeholder$make_has_other_files_or_projects_ref$$=function($team_id$jscomp$169$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1251$$){var $files$jscomp$38_or__5025__auto__$jscomp$1456$$=function(){var $projects$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1251$$,$APP.$cljs$cst$1945$projects$$);return $APP.$cljs$core$some$$(function($p__82561_project$jscomp$28$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82561_project$jscomp$28$$,
0,null);$p__82561_project$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82561_project$jscomp$28$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($p__82561_project$jscomp$28$$),$team_id$jscomp$169$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($p__82561_project$jscomp$28$$))},$projects$jscomp$8$$)}();if($APP.$cljs$core$truth_$$($files$jscomp$38_or__5025__auto__$jscomp$1456$$))return $files$jscomp$38_or__5025__auto__$jscomp$1456$$;
$files$jscomp$38_or__5025__auto__$jscomp$1456$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1251$$,$APP.$cljs$cst$1933$files$$);return $APP.$cljs$core$some$$(function($file$jscomp$196_p__82567$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file$jscomp$196_p__82567$$,0,null);$file$jscomp$196_p__82567$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file$jscomp$196_p__82567$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$196_p__82567$$),
$team_id$jscomp$169$$)},$files$jscomp$38_or__5025__auto__$jscomp$1456$$)},$APP.$app$main$store$state$$)};
$app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$=function($origin$jscomp$79_props_82576$$){var $on_finish_import$jscomp$5$$=$origin$jscomp$79_props_82576$$.onFinishImport,$project_id$jscomp$42$$=$origin$jscomp$79_props_82576$$.projectId,$team_id$jscomp$170$$=$origin$jscomp$79_props_82576$$.teamId,$limit$jscomp$8$$=$origin$jscomp$79_props_82576$$.limit,$can_edit$jscomp$9$$=$origin$jscomp$79_props_82576$$.canEdit,$is_dragging$$=$origin$jscomp$79_props_82576$$.isDragging,$create_fn$$=
$origin$jscomp$79_props_82576$$.createFn;$origin$jscomp$79_props_82576$$=$origin$jscomp$79_props_82576$$.origin;var $on_click$jscomp$64$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($create_fn$$)],function(){return $create_fn$$.$cljs$core$IFn$_invoke$arity$1$?$create_fn$$.$cljs$core$IFn$_invoke$arity$1$("dashboard:empty-folder-placeholder"):$create_fn$$("dashboard:empty-folder-placeholder")}),$show_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$show_text_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_text_STAR_$$),$on_mouse_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_text_STAR_$$,!0)}),$on_mouse_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_text_STAR_$$,null)}),$has_other_QMARK__has_other_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$170$$)],
function(){return $app$main$ui$dashboard$placeholder$make_has_other_files_or_projects_ref$$($team_id$jscomp$170$$)});$has_other_QMARK__has_other_STAR_$$=$APP.$rumext$v2$deref$$($has_other_QMARK__has_other_STAR_$$);return $is_dragging$$===!0?(0,$APP.$rumext$v2$jsx$$)("ul",{style:{gridTemplateColumns:["repeat(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($limit$jscomp$8$$),", 1fr)"].join("")},className:"main_ui_dashboard_placeholder__grid-row main_ui_dashboard_placeholder__no-wrap",children:(0,$APP.$rumext$v2$jsx$$)("li",
{className:"main_ui_dashboard_placeholder__grid-item main_ui_dashboard_placeholder__grid-empty-placeholder main_ui_dashboard_placeholder__dragged"})}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5352$libraries$$,$origin$jscomp$79_props_82576$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-libraries-title"),type:2,subtitle:$APP.$cljs$core$truth_$$($can_edit$jscomp$9$$)?
null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-libraries-subtitle-viewer-role"),className:"main_ui_dashboard_placeholder__empty-placeholder-libraries",children:$APP.$cljs$core$truth_$$($can_edit$jscomp$9$$)?$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-libraries"),className:"main_ui_dashboard_placeholder__placeholder-markdown",tagName:"span"}):null}):
$APP.$cljs$core$not$$($has_other_QMARK__has_other_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$empty_project_placeholder_STAR_$$,{onCreate:$on_click$jscomp$64$$,onFinishImport:$on_finish_import$jscomp$5$$,projectId:$project_id$jscomp$42$$}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_placeholder__grid-empty-placeholder",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_click$jscomp$64$$,onMouseEnter:$on_mouse_enter$$,onMouseLeave:$on_mouse_leave$$,
className:"main_ui_dashboard_placeholder__create-new",children:$APP.$cljs$core$truth_$$($show_text_QMARK_$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-project.create"):$APP.$app$main$ui$icons$add$$})})};
$app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$=function(){return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{width:32,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),className:"main_ui_dashboard_placeholder__placeholder-loader",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_placeholder__placeholder-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.loading-files")})})};
$app$main$ui$dashboard$grid$persist_thumbnail$$=function($file_id$jscomp$451$$,$revn$jscomp$10$$,$blob$jscomp$40$$){return $APP.$beicon$v2$core$map$$($APP.$cljs$cst$266$id$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2268$create_file_thumbnail$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$451$$,$APP.$cljs$cst$2279$revn$$,$revn$jscomp$10$$,$APP.$cljs$cst$1644$media$$,$blob$jscomp$40$$],null)))};
$app$main$ui$dashboard$grid$render_thumbnail$$=function($file_id$jscomp$452$$,$revn$jscomp$11$$){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3139$cmd$$,$cljs$cst$6380$thumbnails_SLASH_generate_for_file_wasm$$,$APP.$cljs$cst$2279$revn$$,$revn$jscomp$11$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$452$$,
$APP.$cljs$cst$290$width$$,252],null)):$APP.$beicon$v2$core$mapcat$$(function($fonts$jscomp$41_p__82617$$){var $map__82618__$1$$=$APP.$cljs$core$__destructure_map$$($fonts$jscomp$41_p__82617$$);$fonts$jscomp$41_p__82617$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__82618__$1$$,$APP.$cljs$cst$2980$fonts$$);return $APP.$beicon$v2$core$map$$(function($styles$jscomp$34$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__82618__$1$$,$APP.$cljs$cst$2951$styles$$,
$styles$jscomp$34$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,252]))},$app$main$fonts$render_font_styles$$($fonts$jscomp$41_p__82617$$))},$APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3139$cmd$$,$cljs$cst$6381$thumbnails_SLASH_generate_for_file$$,$APP.$cljs$cst$2279$revn$$,$revn$jscomp$11$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$452$$,$APP.$cljs$cst$290$width$$,
252],null)))};
$app$main$ui$dashboard$grid$grid_item_thumbnail_STAR_$$=function($can_restore$jscomp$4_props_82619$$){var $bg_color$jscomp$1_file$jscomp$197$$=$can_restore$jscomp$4_props_82619$$.file,$can_edit$jscomp$10$$=$can_restore$jscomp$4_props_82619$$.canEdit;$can_restore$jscomp$4_props_82619$$=$can_restore$jscomp$4_props_82619$$.canRestore;var $file_id$jscomp$454$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$197$$,$APP.$cljs$cst$266$id$$),$revn$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$197$$,
$APP.$cljs$cst$2279$revn$$),$thumbnail_id$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$197$$,$APP.$cljs$cst$2584$thumbnail_id$$);$bg_color$jscomp$1_file$jscomp$197$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bg_color$jscomp$1_file$jscomp$197$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2066$background$$);var $container$jscomp$98$$=(0,$APP.$rumext$v2$use_ref$$)(),$visible_QMARK_$jscomp$9$$=
$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($container$jscomp$98$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$454$$),$APP.$rumext$v2$adapt$$($revn$jscomp$13$$),$APP.$rumext$v2$adapt$$($visible_QMARK_$jscomp$9$$),$APP.$rumext$v2$adapt$$($thumbnail_id$jscomp$2$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit$jscomp$10$$)?$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$9$$)?
$APP.$cljs$core$not$$($thumbnail_id$jscomp$2$$):$visible_QMARK_$jscomp$9$$:$can_edit$jscomp$10$$)){var $subscription$jscomp$10$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($thumbnail_id__$1$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$set_file_thumbnail$$($file_id$jscomp$454$$,$thumbnail_id__$1$$))},function($cause$jscomp$113$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.dashboard.grid",$APP.$cljs$cst$849$error$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unable to render thumbnail"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$6382$file_if$$,$file_id$jscomp$454$$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2279$revn$$,$revn$jscomp$13$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$141$message$$,$APP.$cljs$core$ex_message$$($cause$jscomp$113$$)],null)],null)}),null,"app.main.ui.dashboard.grid",$APP.$cljs$cst$849$error$$,!1);return null},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$dashboard$grid$persist_thumbnail$$,
$file_id$jscomp$454$$,$revn$jscomp$13$$),$APP.$beicon$v2$core$mapcat$$($APP.$app$main$rasterizer$render$$,$app$main$ui$dashboard$grid$render_thumbnail$$($file_id$jscomp$454$$,$revn$jscomp$13$$))));return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$dispose_BANG_$$,$subscription$jscomp$10$$)}return null});return(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundColor:$bg_color$jscomp$1_file$jscomp$197$$},ref:$container$jscomp$98$$,className:"main_ui_dashboard_grid__grid-item-th "+
($APP.$cljs$core$truth_$$($can_restore$jscomp$4_props_82619$$)?"main_ui_dashboard_grid__deleted-item":""),children:$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$9$$)?$APP.$cljs$core$truth_$$($thumbnail_id$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("img",{draggable:""+($can_edit$jscomp$10$$??""),src:$APP.$app$config$resolve_media$$($thumbnail_id$jscomp$2$$),loading:"lazy",decoding:"async",className:"main_ui_dashboard_grid__grid-item-thumbnail-image"}):$APP.$cljs$core$truth_$$($can_edit$jscomp$10$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,
{className:"main_ui_dashboard_grid__grid-loader",draggable:""+($can_edit$jscomp$10$$??""),overlay:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):null:null})};
$app$main$ui$dashboard$grid$grid_item_library_STAR_$$=function($can_restore$jscomp$5_props_82622$$){var $file$jscomp$198$$=$can_restore$jscomp$5_props_82622$$.file;$can_restore$jscomp$5_props_82622$$=$can_restore$jscomp$5_props_82622$$.canRestore;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$198$$)],function(){if($APP.$cljs$core$truth_$$($file$jscomp$198$$)){var $font_ids$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1763$font_id$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$198$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4049$library_summary$$,$APP.$cljs$cst$2223$typographies$$,$cljs$cst$6383$sample$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$));return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,$font_ids$$)}return null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__grid-item-th main_ui_dashboard_grid__library "+
($APP.$cljs$core$truth_$$($can_restore$jscomp$5_props_82622$$)?"main_ui_dashboard_grid__deleted-item":""),children:$file$jscomp$198$$==null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{className:"main_ui_dashboard_grid__grid-loader",overlay:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):function(){var $summary$jscomp$7_typographies$jscomp$15$$=$APP.$cljs$cst$4049$library_summary$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$198$$),
$components$jscomp$25$$=$APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$),$colors$jscomp$27$$=$APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$);$summary$jscomp$7_typographies$jscomp$15$$=$APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)===
0&&$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)===0&&$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$)===0?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components")}),
(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",0,")"]})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",
children:[" (",0,")"]})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",0,")"]})]})})]}):null,$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)>
0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$),
")"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$246$$,$JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$){var $JSCompiler_temp_const$jscomp$2019$$=$out_arr__44092__auto__$jscomp$246$$.push,$root_id$jscomp$inline_9724$$=$APP.$cljs$cst$2070$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$);
$JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg$$,{"root-shape":$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1636$objects$$,$root_id$jscomp$inline_9724$$],
null)),objects:$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$),className:"main_ui_dashboard_grid__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$)})})]},
["assets-component-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$))].join(""));$JSCompiler_temp_const$jscomp$2019$$.call($out_arr__44092__auto__$jscomp$246$$,$JSCompiler_inline_result$jscomp$2021_component$jscomp$137$$);return $out_arr__44092__auto__$jscomp$246$$},[],$cljs$cst$6383$sample$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)),$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$)>
$APP.$cljs$core$count$$($cljs$cst$6383$sample$$.$cljs$core$IFn$_invoke$arity$1$($components$jscomp$25$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__item-name",children:"(...)"})})}):null]})]}):null,$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)>0?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__asset-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$),")"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__asset-list",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$247$$,$JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$){var $JSCompiler_temp_const$jscomp$2022$$=$out_arr__44092__auto__$jscomp$247$$.push,$default_name$jscomp$inline_9726$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$))?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$cst$139$type$$],null))):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$))?$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$):$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$);
$JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list-item main_ui_dashboard_grid__color-item",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,{color:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$),$APP.$cljs$cst$266$id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$),$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$)],null),mini:!0}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__name-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__color-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$)}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$),$default_name$jscomp$inline_9726$$)?null:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__color-value",children:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$)})]})]},["assets-color-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$))].join(""));
$JSCompiler_temp_const$jscomp$2022$$.call($out_arr__44092__auto__$jscomp$247$$,$JSCompiler_inline_result$jscomp$2024_color$jscomp$243$$);return $out_arr__44092__auto__$jscomp$247$$},[],$cljs$cst$6383$sample$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)),$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$)>$APP.$cljs$core$count$$($cljs$cst$6383$sample$$.$cljs$core$IFn$_invoke$arity$1$($colors$jscomp$27$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__item-name",children:"(...)"})})}):null]})]}):null,$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$)>0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-section",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography")}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_grid__num-assets",children:[" (",$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$),")"]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$248$$,
$typography$jscomp$40$$){$out_arr__44092__auto__$jscomp$248$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$),fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$)},
className:"main_ui_dashboard_grid__typography-sample",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$),className:"main_ui_dashboard_grid__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$)})})]},
["assets-typography-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$40$$))].join("")));return $out_arr__44092__auto__$jscomp$248$$},[],$cljs$cst$6383$sample$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$)),$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$)>$APP.$cljs$core$count$$($cljs$cst$6383$sample$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$7_typographies$jscomp$15$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__asset-list-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_grid__item-name",children:"(...)"})})}):null]})]}):null]})}()})};
$app$main$ui$dashboard$grid$grid_item_metadata_STAR_$$=function($JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$){$JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$=$JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$.file;var $or__5025__auto__$jscomp$inline_9728$$=$APP.$cljs$cst$5037$will_be_deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$);
$JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9728$$)?$or__5025__auto__$jscomp$inline_9728$$:$APP.$cljs$cst$1743$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$);$JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$=$APP.$app$common$time$timeago$$($JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$);
return(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.deleted.will-be-deleted-at",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$])),className:"main_ui_dashboard_grid__date",children:$JSCompiler_inline_result$jscomp$2025_file$jscomp$199_props_82633_time$jscomp$8$$})};
$app$main$ui$dashboard$grid$create_counter_element$$=function($file_count$jscomp$4$$){var $counter_el$jscomp$2$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("div");$APP.$app$util$dom$set_property_BANG_$$($counter_el$jscomp$2$$,"class","main_ui_dashboard_grid__drag-counter");$APP.$app$util$dom$set_text_BANG_$$($counter_el$jscomp$2$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($file_count$jscomp$4$$));return $counter_el$jscomp$2$$};
$app$main$ui$dashboard$grid$grid_item_STAR_$$=function($origin$jscomp$80_props_82644$$){var $file$jscomp$200$$=$origin$jscomp$80_props_82644$$.file,$can_edit$jscomp$11$$=$origin$jscomp$80_props_82644$$.canEdit,$selected_files$jscomp$1$$=$origin$jscomp$80_props_82644$$.selectedFiles,$can_restore$jscomp$6$$=$origin$jscomp$80_props_82644$$.canRestore;$origin$jscomp$80_props_82644$$=$origin$jscomp$80_props_82644$$.origin;var $file_id$jscomp$455$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$200$$,
$APP.$cljs$cst$266$id$$),$state$jscomp$1252$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$),$menu_pos$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1252$$,$APP.$cljs$cst$5043$menu_pos$$),$menu_open_QMARK_$jscomp$3$$=function(){var $and__5023__auto__$jscomp$1069$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1252$$,$APP.$cljs$cst$5042$menu_open$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1069$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$455$$,
$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1252$$)):$and__5023__auto__$jscomp$1069$$}(),$selected_QMARK_$jscomp$24$$=$APP.$cljs$core$contains_QMARK_$$($selected_files$jscomp$1$$,$file_id$jscomp$455$$),$selected_num$$=$APP.$cljs$core$count$$($selected_files$jscomp$1$$),$node_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(),$menu_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$is_library_view_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$80_props_82644$$,
$APP.$cljs$cst$5352$libraries$$),$on_menu_close$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$hide_file_menu$$())}),$on_select$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$24$$),$APP.$rumext$v2$adapt$$($selected_num$$)],function($event$jscomp$744$$){return!$selected_QMARK_$jscomp$24$$||$selected_num$$>
1?($APP.$app$util$dom$stop_propagation$$($event$jscomp$744$$),$event$jscomp$744$$.shiftKey||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$toggle_file_select$$($file$jscomp$200$$))):null}),$on_navigate$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$455$$),$APP.$rumext$v2$adapt$$($can_restore$jscomp$6$$)],
function($event$jscomp$745$$){return $APP.$cljs$core$truth_$$($can_restore$jscomp$6$$)?null:$APP.$cljs$core$truth_$$($APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$745$$),$APP.$rumext$v2$ref_val$$($menu_ref$$)))?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$455$$])))}),
$on_drag_start$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$24$$),$APP.$rumext$v2$adapt$$($selected_num$$)],function($event$jscomp$746$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$hide_file_menu$$());if($APP.$cljs$core$truth_$$($can_edit$jscomp$11$$)){var $offset$jscomp$222$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$746$$.nativeEvent),$item_el$jscomp$1$$=$APP.$rumext$v2$ref_val$$($node_ref$jscomp$6$$),
$counter_el$jscomp$3$$=$app$main$ui$dashboard$grid$create_counter_element$$($selected_QMARK_$jscomp$24$$?$selected_num$$:1);$selected_QMARK_$jscomp$24$$||($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$toggle_file_select$$($file$jscomp$200$$)));$APP.$app$util$dom$dnd$set_data_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$746$$,
"penpot/files","dummy");$APP.$app$util$dom$dnd$set_allowed_effect_BANG_$$($event$jscomp$746$$);$APP.$app$util$dom$append_child_BANG_$$($item_el$jscomp$1$$,$counter_el$jscomp$3$$);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($event$jscomp$746$$,$item_el$jscomp$1$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$222$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$222$$));return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$child_QMARK_$$($counter_el$jscomp$3$$,
$item_el$jscomp$1$$))){$item_el$jscomp$1$$!=null&&$item_el$jscomp$1$$.removeChild($counter_el$jscomp$3$$);var $JSCompiler_temp$jscomp$660$$=$item_el$jscomp$1$$}else $JSCompiler_temp$jscomp$660$$=null;return $JSCompiler_temp$jscomp$660$$})}return null}),$on_menu_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$200$$),$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$24$$)],function($JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$){$APP.$app$util$dom$stop_propagation$$($JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$);
$selected_QMARK_$jscomp$24$$||($JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$.shiftKey||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$toggle_file_select$$($file$jscomp$200$$)));var $client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$);
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$)==null&&$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$)==null?($client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$)),$JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$=
$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$),$client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$),$JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$,
$JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$)):$JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$=$client_position_points$jscomp$inline_9733_x$jscomp$inline_9735$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$show_file_menu_with_position$$($file_id$jscomp$455$$,$JSCompiler_temp$jscomp$2026_event$jscomp$747_y$jscomp$inline_9734$$))}),$on_context_menu$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$5$$)],
function($event$jscomp$748$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$748$$);return $on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$748$$):$on_menu_click$jscomp$5$$($event$jscomp$748$$)}),$edit$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$200$$)],function($name$jscomp$505_name_82770__$1$$){$name$jscomp$505_name_82770__$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$505_name_82770__$1$$);
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$505_name_82770__$1$$,"")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$rename_file$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($file$jscomp$200$$,$APP.$cljs$cst$725$name$$,$name$jscomp$505_name_82770__$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$stop_edit_file_name$$())}),$on_edit$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$200$$)],
function($event$jscomp$749$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$749$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$start_edit_file_name$$($file_id$jscomp$455$$))}),$on_key_down$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_navigate$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_select$jscomp$8$$)],function($event$jscomp$750$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$750$$);
$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$750$$))&&($on_navigate$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_navigate$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$750$$):$on_navigate$jscomp$1$$($event$jscomp$750$$));return $event$jscomp$750$$.shiftKey?$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$750$$);
if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$))return $or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$;$or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$=(0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($event$jscomp$750$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$))return $or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$;
$or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$750$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$)?$or__5025__auto__$jscomp$1458_or__5025__auto____$1$jscomp$164_or__5025__auto____$2$jscomp$42$$:(0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($event$jscomp$750$$)}())?$on_select$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?
$on_select$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$750$$):$on_select$jscomp$8$$($event$jscomp$750$$):null:null}),$on_menu_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$5$$)],function($event$jscomp$751$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$751$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$751$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$751$$),
$on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$751$$):$on_menu_click$jscomp$5$$($event$jscomp$751$$)):null});return(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_grid__grid-item main_ui_dashboard_grid__project-th "+($is_library_view_QMARK_$$?"main_ui_dashboard_grid__library":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{onDoubleClick:$on_navigate$jscomp$1$$,role:"button","aria-label":$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$200$$),
className:($selected_QMARK_$jscomp$24$$?"main_ui_dashboard_grid__selected":"")+" "+($is_library_view_QMARK_$$?"main_ui_dashboard_grid__library":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__overlay"}),$is_library_view_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_library_STAR_$$,{file:$file$jscomp$200$$,canRestore:$can_restore$jscomp$6$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_thumbnail_STAR_$$,{file:$file$jscomp$200$$,
canEdit:$can_edit$jscomp$11$$,canRestore:$can_restore$jscomp$6$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1070$$=$APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$200$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1070$$)?!$is_library_view_QMARK_$$:$and__5023__auto__$jscomp$1070$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_grid__item-badge",children:$APP.$app$main$ui$icons$library$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_grid__info-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_grid__item-info",children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1071$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$455$$,$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1252$$));return $and__5023__auto__$jscomp$1071$$?$APP.$cljs$cst$2207$edition$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1252$$):
$and__5023__auto__$jscomp$1071$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$200$$),"on-end":$edit$jscomp$17$$,"max-length":250}):(0,$APP.$rumext$v2$jsx$$)("h3",{children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$200$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_metadata_STAR_$$,{file:$file$jscomp$200$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_grid__project-th-actions "+($APP.$cljs$core$truth_$$($menu_open_QMARK_$jscomp$3$$)?"main_ui_dashboard_grid__force-display":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{role:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),tabIndex:"0",className:"main_ui_dashboard_grid__project-th-icon main_ui_dashboard_grid__menu",children:[$app$main$ui$dashboard$grid$menu_icon$$,$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$24$$?
$menu_open_QMARK_$jscomp$3$$:$selected_QMARK_$jscomp$24$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$portal$portal_on_document_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$file_menu$file_menu_STAR_$$,{parentId:""+($file_id$jscomp$455$$??"")+"-action-menu",origin:$origin$jscomp$80_props_82644$$,top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($menu_pos$$),onClose:$on_menu_close$jscomp$3$$,canRestore:$can_restore$jscomp$6$$,files:$APP.$cljs$core$vals$$($selected_files$jscomp$1$$),
onEdit:$on_edit$jscomp$14$$,canEdit:$can_edit$jscomp$11$$,left:24+$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($menu_pos$$),navigate:!0})}):null],id:""+($file_id$jscomp$455$$??"")+"-action-menu",onClick:$on_menu_click$jscomp$5$$,ref:$menu_ref$$,onKeyDown:$on_menu_key_down$$})})]})],onContextMenu:$on_context_menu$jscomp$31$$,draggable:""+($can_edit$jscomp$11$$??""),onClick:$on_select$jscomp$8$$,title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$200$$),ref:$node_ref$jscomp$6$$,
onDragStart:$on_drag_start$jscomp$6$$,onKeyDown:$on_key_down$jscomp$31$$})})};
$app$main$ui$dashboard$grid$grid_STAR_$$=function($node_ref$jscomp$7_props_82664$$){var $limit$jscomp$9$$=$node_ref$jscomp$7_props_82664$$.limit,$can_edit$jscomp$12$$=$node_ref$jscomp$7_props_82664$$.canEdit,$on_finish_import$jscomp$6_project$jscomp$29$$=$node_ref$jscomp$7_props_82664$$.project,$selected_files$jscomp$2$$=$node_ref$jscomp$7_props_82664$$.selectedFiles,$create_fn$jscomp$1$$=$node_ref$jscomp$7_props_82664$$.createFn,$files$jscomp$39$$=$node_ref$jscomp$7_props_82664$$.files,$can_restore$jscomp$7$$=
$node_ref$jscomp$7_props_82664$$.canRestore,$origin$jscomp$81$$=$node_ref$jscomp$7_props_82664$$.origin,$dragging_QMARK_$jscomp$12$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$project_id$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_finish_import$jscomp$6_project$jscomp$29$$,$APP.$cljs$cst$266$id$$),$team_id$jscomp$171$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_finish_import$jscomp$6_project$jscomp$29$$,$APP.$cljs$cst$1944$team_id$$);
$node_ref$jscomp$7_props_82664$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$on_finish_import$jscomp$6_project$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$43$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$171$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$43$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$171$$),
$app$main$data$dashboard$clear_selected_files$$()]))});var $import_files$$=$APP.$app$main$ui$dashboard$import$0$use_import_file$$($project_id$jscomp$43$$,$on_finish_import$jscomp$6_project$jscomp$29$$),$on_scroll$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$hide_file_menu$$())}),$on_drag_enter$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$409$$){var $JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$;
if($JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$=$APP.$cljs$core$truth_$$($can_edit$jscomp$12$$)){if($JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$=$APP.$cljs$core$not$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$409$$,"penpot/files")))$JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$409$$,"Files"),$JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$)?$JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$:
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$409$$,"application/x-moz-file");$JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$)}return $JSCompiler_inline_result$jscomp$2028_JSCompiler_temp$jscomp$2027_and__5023__auto__$jscomp$inline_9737_or__5025__auto__$jscomp$inline_9738$$?
($APP.$app$util$dom$prevent_default$$($e$jscomp$409$$),$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!0)):null}),$on_drag_over$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$410$$){var $JSCompiler_inline_result$jscomp$2029_or__5025__auto__$jscomp$inline_9740$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$410$$,"Files");$JSCompiler_inline_result$jscomp$2029_or__5025__auto__$jscomp$inline_9740$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2029_or__5025__auto__$jscomp$inline_9740$$)?
$JSCompiler_inline_result$jscomp$2029_or__5025__auto__$jscomp$inline_9740$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$410$$,"application/x-moz-file");return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2029_or__5025__auto__$jscomp$inline_9740$$)?$APP.$app$util$dom$prevent_default$$($e$jscomp$410$$):null}),$on_drag_leave$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$411$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$411$$))?
null:$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!1)}),$on_drop$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__82665_e$jscomp$412$$){if($APP.$cljs$core$truth_$$($can_edit$jscomp$12$$)){var $JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$;if($JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$=$APP.$cljs$core$not$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82665_e$jscomp$412$$,
"penpot/files")))$JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82665_e$jscomp$412$$,"Files"),$JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$)?$JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$:
$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82665_e$jscomp$412$$,"application/x-moz-file");return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2030_and__5023__auto__$jscomp$inline_9742_or__5025__auto__$jscomp$inline_9743$$)?($APP.$app$util$dom$prevent_default$$($G__82665_e$jscomp$412$$),$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$12$$,!1),$G__82665_e$jscomp$412$$=$G__82665_e$jscomp$412$$.dataTransfer.files,$import_files$$.$cljs$core$IFn$_invoke$arity$1$?$import_files$$.$cljs$core$IFn$_invoke$arity$1$($G__82665_e$jscomp$412$$):
$import_files$$($G__82665_e$jscomp$412$$)):null}return $APP.$app$util$dom$prevent_default$$($G__82665_e$jscomp$412$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{onDragEnter:$on_drag_enter$jscomp$10$$,onDragLeave:$on_drag_leave$jscomp$8$$,className:"main_ui_dashboard_grid__dashboard-grid",children:$files$jscomp$39$$==null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$,{}):$APP.$cljs$core$seq$$($files$jscomp$39$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$249$$,
$p__82666_slice$jscomp$1$$){var $index$jscomp$586$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82666_slice$jscomp$1$$,0,null);$p__82666_slice$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__82666_slice$jscomp$1$$,1,null);$out_arr__44092__auto__$jscomp$249$$.push((0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_dashboard_grid__grid-row",children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$12$$))?(0,$APP.$rumext$v2$jsx$$)("li",
{className:"main_ui_dashboard_grid__grid-item"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$25$$,$item$jscomp$143$$){$out_arr__44092__auto____$1$jscomp$25$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_STAR_$$,{file:$item$jscomp$143$$,origin:$origin$jscomp$81$$,selectedFiles:$selected_files$jscomp$2$$,canEdit:$can_edit$jscomp$12$$,canRestore:$can_restore$jscomp$7$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$143$$)??
"")));return $out_arr__44092__auto____$1$jscomp$25$$},[],$p__82666_slice$jscomp$1$$)]},""+($index$jscomp$586$$??"")));return $out_arr__44092__auto__$jscomp$249$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partition_all$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$9$$,$limit$jscomp$9$$,$files$jscomp$39$$))):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$,{limit:$limit$jscomp$9$$,canEdit:$can_edit$jscomp$12$$,
createFn:$create_fn$jscomp$1$$,origin:$origin$jscomp$81$$,projectId:$project_id$jscomp$43$$,teamId:$team_id$jscomp$171$$,onFinishImport:$on_finish_import$jscomp$6_project$jscomp$29$$}),onDrop:$on_drop$jscomp$21$$,onDragOver:$on_drag_over$jscomp$4$$,dragabble:""+($can_edit$jscomp$12$$??""),ref:$node_ref$jscomp$7_props_82664$$,onScroll:$on_scroll$jscomp$1$$})};
$app$main$ui$dashboard$grid$line_grid_row$$=function($files$jscomp$40_map__82679_props_82676$$){$files$jscomp$40_map__82679_props_82676$$=$APP.$rumext$v2$util$wrap_props$$($files$jscomp$40_map__82679_props_82676$$);var $limit__$1$jscomp$2_map__82679__$1$$=$APP.$cljs$core$__destructure_map$$($files$jscomp$40_map__82679_props_82676$$);$files$jscomp$40_map__82679_props_82676$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,$APP.$cljs$cst$1933$files$$);var $selected_files$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,$APP.$cljs$cst$2191$selected_files$$),$dragging_QMARK_$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,$APP.$cljs$cst$5472$dragging_QMARK_$$),$limit$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,$cljs$cst$6384$limit$$),$can_edit$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,
$APP.$cljs$cst$1601$can_edit$$),$can_restore$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,$cljs$cst$6385$can_restore$$);$limit__$1$jscomp$2_map__82679__$1$$=$APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$13$$)?$limit$jscomp$10$$-1:$limit$jscomp$10$$;return(0,$APP.$rumext$v2$jsxs$$)("ul",{style:{gridTemplateColumns:"repeat("+($limit$jscomp$10$$??"")+", 1fr)"},className:"main_ui_dashboard_grid__grid-row main_ui_dashboard_grid__no-wrap",children:[$APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$13$$)?
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_dashboard_grid__grid-item main_ui_dashboard_grid__dragged"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$250$$,$item$jscomp$144$$){$out_arr__44092__auto__$jscomp$250$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_item_STAR_$$,{id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$144$$),file:$item$jscomp$144$$,selectedFiles:$selected_files$jscomp$3$$,
canEdit:$can_edit$jscomp$13$$,canRestore:$can_restore$jscomp$8$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$144$$)??"")));return $out_arr__44092__auto__$jscomp$250$$},[],$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($limit__$1$jscomp$2_map__82679__$1$$,$files$jscomp$40_map__82679_props_82676$$))]})};
$app$main$ui$dashboard$grid$line_grid$$=function($files$jscomp$41_map__82685_props_82684$$){$files$jscomp$41_map__82685_props_82684$$=$APP.$rumext$v2$util$wrap_props$$($files$jscomp$41_map__82685_props_82684$$);var $can_restore$jscomp$9_map__82685__$1$$=$APP.$cljs$core$__destructure_map$$($files$jscomp$41_map__82685_props_82684$$),$on_finish_import$jscomp$7_project$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,$APP.$cljs$cst$2238$project$$),
$on_drag_enter$jscomp$11_team$jscomp$81$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,$APP.$cljs$cst$2503$team$$);$files$jscomp$41_map__82685_props_82684$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,$APP.$cljs$cst$1933$files$$);var $limit$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,$cljs$cst$6384$limit$$),$create_fn$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,
$cljs$cst$6386$create_fn$$),$can_edit$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,$APP.$cljs$cst$1601$can_edit$$);$can_restore$jscomp$9_map__82685__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_restore$jscomp$9_map__82685__$1$$,$cljs$cst$6385$can_restore$$);var $dragging_QMARK_$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$project_id$jscomp$44$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_finish_import$jscomp$7_project$jscomp$30$$),
$team_id$jscomp$172$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_drag_enter$jscomp$11_team$jscomp$81$$),$selected_files$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_files$$),$selected_project$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_project$$);$on_finish_import$jscomp$7_project$jscomp$30$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$172$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$172$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});var $import_files$jscomp$1$$=$APP.$app$main$ui$dashboard$import$0$use_import_file$$($project_id$jscomp$44$$,$on_finish_import$jscomp$7_project$jscomp$30$$);$on_drag_enter$jscomp$11_team$jscomp$81$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_project$jscomp$1$$),$APP.$rumext$v2$adapt$$($can_edit$jscomp$14$$)],function($e$jscomp$413$$){if($APP.$cljs$core$truth_$$($can_edit$jscomp$14$$)){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$413$$,
"penpot/files")))return $APP.$app$util$dom$prevent_default$$($e$jscomp$413$$),$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1462$$=$APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$413$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1462$$)?$or__5025__auto__$jscomp$1462$$:$e$jscomp$413$$.relatedTarget==null}())?null:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_project$jscomp$1$$,$project_id$jscomp$44$$)?$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$14$$,
!0):null;if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1463$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$413$$,"Files");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1463$$)?$or__5025__auto__$jscomp$1463$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$413$$,"application/x-moz-file")}()))return $APP.$app$util$dom$prevent_default$$($e$jscomp$413$$),$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$14$$,!0)}return null});var $on_drag_over$jscomp$5$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$414$$){var $JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$414$$,"penpot/files");$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$)||($JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$414$$,"Files"),$JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$)?$JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$414$$,"application/x-moz-file"));
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2031_or__5025__auto__$jscomp$inline_9745_or__5025__auto____$1$jscomp$inline_9746$$)?$APP.$app$util$dom$prevent_default$$($e$jscomp$414$$):null}),$on_drag_leave$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$415$$){return $APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($e$jscomp$415$$))?null:$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$14$$,!1)}),$on_drop_success$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$172$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.success-move-file")),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$172$$),
$app$main$data$dashboard$clear_selected_files$$()]))}),$on_drop$jscomp$22$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$41_map__82685_props_82684$$),$APP.$rumext$v2$adapt$$($selected_files$jscomp$4$$),$APP.$rumext$v2$adapt$$($can_edit$jscomp$14$$)],function($G__82693_data$jscomp$508_e$jscomp$416$$){if($APP.$cljs$core$truth_$$($can_edit$jscomp$14$$)){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82693_data$jscomp$508_e$jscomp$416$$,
"penpot/files"))){if($APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$14$$,!1),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_project$jscomp$1$$,$project_id$jscomp$44$$))return $G__82693_data$jscomp$508_e$jscomp$416$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($selected_files$jscomp$4$$)),$APP.$cljs$cst$2189$project_id$$,
$project_id$jscomp$44$$],null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$move_files$$($APP.$cljs$core$with_meta$$($G__82693_data$jscomp$508_e$jscomp$416$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,$on_drop_success$jscomp$1$$],null))))}else{var $JSCompiler_inline_result$jscomp$2032_or__5025__auto__$jscomp$inline_9748$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82693_data$jscomp$508_e$jscomp$416$$,"Files");
$JSCompiler_inline_result$jscomp$2032_or__5025__auto__$jscomp$inline_9748$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2032_or__5025__auto__$jscomp$inline_9748$$)?$JSCompiler_inline_result$jscomp$2032_or__5025__auto__$jscomp$inline_9748$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($G__82693_data$jscomp$508_e$jscomp$416$$,"application/x-moz-file");if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2032_or__5025__auto__$jscomp$inline_9748$$))return $APP.$app$util$dom$prevent_default$$($G__82693_data$jscomp$508_e$jscomp$416$$),
$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$14$$,!1),$G__82693_data$jscomp$508_e$jscomp$416$$=$G__82693_data$jscomp$508_e$jscomp$416$$.dataTransfer.files,$import_files$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$import_files$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__82693_data$jscomp$508_e$jscomp$416$$):$import_files$jscomp$1$$($G__82693_data$jscomp$508_e$jscomp$416$$)}return null}return $APP.$app$util$dom$prevent_default$$($G__82693_data$jscomp$508_e$jscomp$416$$)});return(0,$APP.$rumext$v2$jsx$$)("div",
{dragabble:""+($can_edit$jscomp$14$$??""),onDragEnter:$on_drag_enter$jscomp$11_team$jscomp$81$$,onDragOver:$on_drag_over$jscomp$5$$,onDragLeave:$on_drag_leave$jscomp$9$$,onDrop:$on_drop$jscomp$22$$,className:"main_ui_dashboard_grid__dashboard-grid",children:$files$jscomp$41_map__82685_props_82684$$==null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$loading_placeholder_STAR_$$,{}):$APP.$cljs$core$seq$$($files$jscomp$41_map__82685_props_82684$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$line_grid_row$$,
{files:$files$jscomp$41_map__82685_props_82684$$,"team-id":$team_id$jscomp$172$$,"selected-files":$selected_files$jscomp$4$$,"dragging?":$APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$14$$),"can-edit":$can_edit$jscomp$14$$,limit:$limit$jscomp$11$$,"can-restore":$can_restore$jscomp$9_map__82685__$1$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$placeholder$empty_grid_placeholder_STAR_$$,{isDragging:$APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$14$$),limit:$limit$jscomp$11$$,canEdit:$can_edit$jscomp$14$$,
createFn:$create_fn$jscomp$2$$,projectId:$project_id$jscomp$44$$,teamId:$team_id$jscomp$172$$,onFinishImport:$on_finish_import$jscomp$7_project$jscomp$30$$})})};
$app$main$ui$dashboard$deleted$on_restore_project$$=function($project$jscomp$31$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-project-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-project-confirmation.description",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$31$$)])),$APP.$cljs$cst$2488$accept_style$$,$APP.$cljs$cst$2489$primary$$,$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$restore_project_immediately$$($project$jscomp$31$$))}],
null)))};
$app$main$ui$dashboard$deleted$on_delete_project$$=function($project$jscomp$32$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-project-forever-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$32$$)])),
$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$delete_project_immediately$$($project$jscomp$32$$))}],null)))};
$app$main$ui$dashboard$deleted$header_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_deleted__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-deleted-title",className:"main_ui_dashboard_deleted__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.projects-title")})})})};
$app$main$ui$dashboard$deleted$project_context_menu_STAR_$$=function($props_83117_top__$1$jscomp$7$$){var $show$jscomp$8$$=$props_83117_top__$1$jscomp$7$$.show,$left$jscomp$42_left__$1$jscomp$8$$=$props_83117_top__$1$jscomp$7$$.left,$on_close$jscomp$46$$=$props_83117_top__$1$jscomp$7$$.onClose,$options$jscomp$646_project$jscomp$33$$=$props_83117_top__$1$jscomp$7$$.project;$props_83117_top__$1$jscomp$7$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_83117_top__$1$jscomp$7$$.top,
0);$left$jscomp$42_left__$1$jscomp$8$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$42_left__$1$jscomp$8$$,0);var $on_restore_project$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$646_project$jscomp$33$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$deleted$on_restore_project$$,$options$jscomp$646_project$jscomp$33$$)),$on_delete_project$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$646_project$jscomp$33$$)],
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$dashboard$deleted$on_delete_project$$,$options$jscomp$646_project$jscomp$33$$));$options$jscomp$646_project$jscomp$33$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_restore_project$$),$APP.$rumext$v2$adapt$$($on_delete_project$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-project-button"),$APP.$cljs$cst$266$id$$,"project-restore",$APP.$cljs$cst$2413$handler$$,$on_restore_project$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-project-button"),$APP.$cljs$cst$266$id$$,"project-delete",$APP.$cljs$cst$2413$handler$$,$on_delete_project$$],null)],null)});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,
{onClose:$on_close$jscomp$46$$,show:$show$jscomp$8$$,fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83117_top__$1$jscomp$7$$,0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$42_left__$1$jscomp$8$$,0),minWidth:!0,top:$props_83117_top__$1$jscomp$7$$,left:$left$jscomp$42_left__$1$jscomp$8$$,options:$options$jscomp$646_project$jscomp$33$$})};
$app$main$ui$dashboard$deleted$deleted_project_item_STAR_$$=function($project_files_props_83119$$){var $project$jscomp$34$$=$project_files_props_83119$$.project;$project_files_props_83119$$=$APP.$cljs$core$filterv$$(function($p1__83118_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83118_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$))},$project_files_props_83119$$.files);
var $empty_QMARK_$jscomp$3$$=$APP.$cljs$core$empty_QMARK_$$($project_files_props_83119$$),$selected_files$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_files$$),$dstate$jscomp$1_rowref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$),$edit_id$jscomp$3$$=$APP.$cljs$cst$5051$project_for_edit$$.$cljs$core$IFn$_invoke$arity$1$($dstate$jscomp$1_rowref$jscomp$1$$),$local$jscomp$33$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$5042$menu_open$$,!1,$APP.$cljs$cst$5043$menu_pos$$,null,$APP.$cljs$cst$2207$edition$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$),$edit_id$jscomp$3$$)],null)}),$limit$jscomp$12_vec__83123$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$dstate$jscomp$1_rowref$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$12_vec__83123$$,
0,null);$limit$jscomp$12_vec__83123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$12_vec__83123$$,1,null);var $on_menu_click$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$){$APP.$app$util$dom$prevent_default$$($JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$);var $client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$);
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$)==null&&$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$)==null?($client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$)),$JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$=
$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$),$client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$),$JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$,
$JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$)):$JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$=$client_position$jscomp$1_points$jscomp$inline_9750_x$jscomp$inline_9752$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$33$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5043$menu_pos$$,$JSCompiler_temp$jscomp$2033_event$jscomp$752_y$jscomp$inline_9751$$]))}),
$on_menu_close$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$33$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!1)}),$handle_menu_click$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$6$$)],function($event$jscomp$753$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$753$$))?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$753$$),$on_menu_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$753$$):$on_menu_click$jscomp$6$$($event$jscomp$753$$)):null});return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_dashboard_deleted__dashboard-project-row",children:[(0,$APP.$rumext$v2$jsx$$)("header",{className:"main_ui_dashboard_deleted__project",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__project-name-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)("h2",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$),className:"main_ui_dashboard_deleted__project-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$)}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2582$deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$34$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__info-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_deleted__project-actions",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_menu_click$jscomp$6$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),"data-testid":"project-options",onKeyDown:$handle_menu_click$$,className:"main_ui_dashboard_deleted__options-btn",children:$app$main$ui$dashboard$deleted$menu_icon$$})}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$5042$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$)))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$project_context_menu_STAR_$$,{project:$project$jscomp$34$$,show:$APP.$cljs$cst$5042$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$)),left:24+$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5043$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$))),top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5043$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$33$$))),
onClose:$on_menu_close$jscomp$4$$}):null]}):null]})}),(0,$APP.$rumext$v2$jsx$$)("div",{ref:$dstate$jscomp$1_rowref$jscomp$1$$,className:"main_ui_dashboard_deleted__grid-container",children:$empty_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-title"),className:"main_ui_dashboard_deleted__placeholder-placement",type:1,subtitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-subtitle")}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{project:$project$jscomp$34$$,files:$project_files_props_83119$$,origin:$APP.$cljs$cst$2552$deleted$$,canEdit:!1,canRestore:!0,limit:$limit$jscomp$12_vec__83123$$,selectedFiles:$selected_files$jscomp$5$$})})]})};
$app$main$ui$dashboard$deleted$menu_STAR_$$=function($props_83139_section$jscomp$38$$){var $team_id$jscomp$173$$=$props_83139_section$jscomp$38$$.teamId;$props_83139_section$jscomp$38$$=$props_83139_section$jscomp$38$$.section;var $on_recent_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$173$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,
$team_id$jscomp$173$$])))}),$on_deleted_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$173$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_dashboard_deleted$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$173$$])))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_deleted__nav",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__nav-inside",children:[(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"recent-tab",onClick:$on_recent_click$$,className:"main_ui_dashboard_deleted__nav-option "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83139_section$jscomp$38$$,$APP.$cljs$cst$2533$dashboard_recent$$)?"main_ui_dashboard_deleted__selected":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.recent")}),(0,$APP.$rumext$v2$jsx$$)("div",
{variant:"ghost",type:"button","data-testid":"deleted-tab",onClick:$on_deleted_click$$,className:"main_ui_dashboard_deleted__nav-option "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83139_section$jscomp$38$$,$APP.$cljs$cst$2547$dashboard_deleted$$)?"main_ui_dashboard_deleted__selected":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.deleted")})]})})};
$app$main$ui$dashboard$deleted$deleted_section_STAR_$$=function($projects__$1_props_83161$$){var $projects$jscomp$9$$=$projects__$1_props_83161$$.projects,$team$jscomp$82$$=$projects__$1_props_83161$$.team,$deleted_map$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$deleted$ref_COLON_deleted_files$$);$projects__$1_props_83161$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$9$$),$APP.$rumext$v2$adapt$$($deleted_map$$)],function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1743$modified_at$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($project$jscomp$35$$){return $APP.$cljs$core$truth_$$($deleted_map$$)?$APP.$cljs$core$some$$(function($p1__83146_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$35$$),$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83146_SHARP_$$))},$APP.$cljs$core$vals$$($deleted_map$$)):null},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($project$jscomp$36$$){var $or__5025__auto__$jscomp$1466$$=
$APP.$cljs$cst$2582$deleted_at$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1466$$)?$or__5025__auto__$jscomp$1466$$:$APP.$cljs$core$truth_$$($deleted_map$$)?$APP.$cljs$core$some$$(function($p1__83144_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$36$$),$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83144_SHARP_$$))},
$APP.$cljs$core$vals$$($deleted_map$$)):null},$projects$jscomp$9$$)))))});var $team_id$jscomp$174$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$82$$,$APP.$cljs$cst$266$id$$),$deletion_days$$=function(){var $profile$jscomp$90$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$subscription_type$jscomp$12$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$82$$)),$nitrate_type$jscomp$1$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$90$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3226$subscription$$,$APP.$cljs$cst$139$type$$],null));return $APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$90$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["enterprise",null,"nitrate",null],null),null),$nitrate_type$jscomp$1$$)?
90:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$12$$,"unlimited")?30:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$12$$,"enterprise")?90:7}(),$on_delete_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$174$$),$APP.$rumext$v2$adapt$$($deleted_map$$)],function(){var $temp__5825__auto__$jscomp$476$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$),$deleted_map$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$476$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.delete-all-forever-confirmation.description",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($temp__5825__auto__$jscomp$476$$)])),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.delete-forever-confirmation.title"),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$delete_files_immediately$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$174$$,$APP.$cljs$cst$1729$ids$$,$temp__5825__auto__$jscomp$476$$],null)))}],null))):null}),$on_restore_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$174$$),$APP.$rumext$v2$adapt$$($deleted_map$$)],function(){var $temp__5825__auto__$jscomp$477$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$key$$),
$deleted_map$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$477$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-all-confirmation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.restore-all-confirmation.description",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($temp__5825__auto__$jscomp$477$$)])),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue"),$APP.$cljs$cst$2488$accept_style$$,$APP.$cljs$cst$2489$primary$$,$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$restore_files_immediately$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$174$$,$APP.$cljs$cst$1729$ids$$,$temp__5825__auto__$jscomp$477$$],null)))}],null))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$174$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_projects$$($team_id$jscomp$174$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_deleted_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$174$$),
$app$main$data$dashboard$clear_selected_files$$()]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$header_STAR_$$,{team:$team$jscomp$82$$}),(0,$APP.$rumext$v2$jsx$$)("section",{"data-testid":"deleted-page-section",className:"main_ui_dashboard_deleted__dashboard-container main_ui_dashboard_deleted__no-bg",children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__no-bg",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$menu_STAR_$$,{teamId:$team_id$jscomp$174$$,section:$APP.$cljs$cst$2547$dashboard_deleted$$}),$APP.$cljs$core$seq$$($projects__$1_props_83161$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__deleted-info-content",children:[(0,$APP.$rumext$v2$jsxs$$)("p",{className:"main_ui_dashboard_deleted__deleted-info",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.trash-info-text-part1"),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_deleted__info-text-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.trash-info-text-part2",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$deletion_days$$]))}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.trash-info-text-part3"),(0,$APP.$rumext$v2$jsx$$)("br",{}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.trash-info-text-part4")]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_deleted__deleted-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"ghost",type:"button",onClick:$on_restore_all$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.restore-all-deleted-button")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"destructive",type:"button",icon:"delete",onClick:$on_delete_all$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.clear-trash-button")})]})]}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$251$$,$p__83199$$){var $map__83201__$1$$=$APP.$cljs$core$__destructure_map$$($p__83199$$),$id$jscomp$1068$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83201__$1$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$251$$.push(function(){var $files$jscomp$43$$=$APP.$cljs$core$truth_$$($deleted_map$$)?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1743$modified_at$$,
function($p1__83160_SHARP_$$,$p2__83159_SHARP_$$){return $APP.$cljs$core$compare$$($p2__83159_SHARP_$$,$p1__83160_SHARP_$$)},$APP.$cljs$core$filterv$$(function($p1__83158_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1068$$,$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83158_SHARP_$$))},$APP.$cljs$core$vals$$($deleted_map$$))):null;return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$deleted_project_item_STAR_$$,{project:$map__83201__$1$$,
files:$files$jscomp$43$$},$id$jscomp$1068$$)}());return $out_arr__44092__auto__$jscomp$251$$},[],$projects__$1_props_83161$$)]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_deleted__deleted-info-content",children:(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_deleted__deleted-info",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.deleted.empty-state-description")})})]})})})]})};
$app$main$ui$dashboard$pin_button$pin_button_STAR_$$=function($props_83110_props__$1$jscomp$105$$){var $aria_label$jscomp$11_aria_label__$1$jscomp$1$$=$props_83110_props__$1$jscomp$105$$["aria-label"],$class$__$1$jscomp$13_is_pinned$jscomp$2$$=$props_83110_props__$1$jscomp$105$$.isPinned,$class$$jscomp$85$$=$props_83110_props__$1$jscomp$105$$.className;$aria_label$jscomp$11_aria_label__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($aria_label$jscomp$11_aria_label__$1$jscomp$1$$)?$aria_label$jscomp$11_aria_label__$1$jscomp$1$$:
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.pin-unpin");$class$__$1$jscomp$13_is_pinned$jscomp$2$$=""+(($APP.$cljs$core$truth_$$($class$$jscomp$85$$)?$class$$jscomp$85$$:"")??"")+" main_ui_dashboard_pin_button__button "+($APP.$cljs$core$truth_$$($class$__$1$jscomp$13_is_pinned$jscomp$2$$)?"main_ui_dashboard_pin_button__button-active":"");$props_83110_props__$1$jscomp$105$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props_83110_props__$1$jscomp$105$$),
"isPinned"),"className",$class$__$1$jscomp$13_is_pinned$jscomp$2$$),"aria-label",$aria_label$jscomp$11_aria_label__$1$jscomp$1$$);return(0,$APP.$rumext$v2$create_element$$)("button",$props_83110_props__$1$jscomp$105$$,$app$main$ui$dashboard$pin_button$pin_icon$$)};
$app$main$ui$dashboard$files$header_STAR_$$=function($on_menu_close$jscomp$5_props_83120$$){var $can_edit$jscomp$15$$=$on_menu_close$jscomp$5_props_83120$$.canEdit,$project$jscomp$38$$=$on_menu_close$jscomp$5_props_83120$$.project,$create_fn$jscomp$3$$=$on_menu_close$jscomp$5_props_83120$$.createFn,$project_id$jscomp$45$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),$local$jscomp$34$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$5042$menu_open$$,!1,$APP.$cljs$cst$2207$edition$$,!1],null)),$on_create_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($create_fn$jscomp$3$$)],function($event$jscomp$754$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$754$$);return $create_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$create_fn$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$("dashboard:header"):$create_fn$jscomp$3$$("dashboard:header")}),$on_menu_click$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$755$$){var $position$jscomp$253$$=
$APP.$app$util$dom$get_client_position$$($event$jscomp$755$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$755$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$34$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5043$menu_pos$$,$position$jscomp$253$$]))});$on_menu_close$jscomp$5_props_83120$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$34$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!1)});var $on_edit$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$34$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2207$edition$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5042$menu_open$$,!1]))}),$toggle_pin$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$38$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$toggle_project_pin$$($project$jscomp$38$$))}),$on_import$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$45$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$45$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});
return(0,$APP.$rumext$v2$jsxs$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_files__dashboard-header",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$))?(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-drafts-title",className:"main_ui_dashboard_files__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts")})}):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1075$$=
$APP.$cljs$cst$2207$edition$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1075$$)?$can_edit$jscomp$15$$:$and__5023__auto__$jscomp$1075$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),"on-end":function($name$jscomp$506_name__$1$jscomp$25$$){$name$jscomp$506_name__$1$jscomp$25$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$506_name__$1$jscomp$25$$);
$APP.$cuerdas$core$empty_QMARK_$$($name$jscomp$506_name__$1$jscomp$25$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$rename_project$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$38$$,$APP.$cljs$cst$725$name$$,$name$jscomp$506_name__$1$jscomp$25$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"project"],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$34$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2207$edition$$,!1)},"max-length":250}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_files__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{onDoubleClick:$on_edit$jscomp$15$$,"data-testid":"project-title",id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$)})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_files__dashboard-header-actions",
children:[$can_edit$jscomp$15$$?(0,$APP.$rumext$v2$jsx$$)("a",{tabIndex:"0",onClick:$on_create_click$$,"data-testid":"new-file",onKeyDown:function($event$jscomp$756$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$756$$))?$on_create_click$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$756$$):$on_create_click$$($event$jscomp$756$$):null},className:"main_ui_dashboard_files__btn-secondary main_ui_dashboard_files__btn-small main_ui_dashboard_files__new-file",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file")}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$))?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$pin_button$pin_button_STAR_$$,{tabIndex:0,isPinned:$APP.$cljs$cst$5018$is_pinned$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$38$$),onClick:$toggle_pin$jscomp$1$$,onKeyDown:function($event$jscomp$757$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$757$$))?
$toggle_pin$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_pin$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$757$$):$toggle_pin$jscomp$1$$($event$jscomp$757$$):null}}),$can_edit$jscomp$15$$?(0,$APP.$rumext$v2$jsx$$)("div",{tabIndex:"0",onClick:$on_menu_click$jscomp$7$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),onKeyDown:function($event$jscomp$758$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$758$$))?
$on_menu_click$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$758$$):$on_menu_click$jscomp$7$$($event$jscomp$758$$):null},className:"main_ui_dashboard_files__icon",children:$app$main$ui$dashboard$files$menu_icon$$}):null,$can_edit$jscomp$15$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$project_menu$project_menu_STAR_$$,{project:$project$jscomp$38$$,show:$APP.$cljs$cst$5042$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$)),
left:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5043$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$)))-180,top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5043$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$34$$))),onEdit:$on_edit$jscomp$15$$,onClose:$on_menu_close$jscomp$5_props_83120$$,onImport:$on_import$jscomp$2$$}):null]})]})};
$app$main$ui$dashboard$files$files_section_STAR_$$=function($props_83143_team$jscomp$83$$){var $project$jscomp$39$$=$props_83143_team$jscomp$83$$.project;$props_83143_team$jscomp$83$$=$props_83143_team$jscomp$83$$.team;var $files$jscomp$44$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$project_id$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$39$$,$APP.$cljs$cst$266$id$$),$files__$1$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$46$$),
$APP.$rumext$v2$adapt$$($files$jscomp$44$$)],function(){return $APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1743$modified_at$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83141_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($project_id$jscomp$46$$,$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83141_SHARP_$$))},$APP.$cljs$core$vals$$($files$jscomp$44$$))))}),$can_edit_QMARK_$jscomp$15$$=
$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($props_83143_team$jscomp$83$$)),$project_id__$1$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$),$is_draft_proyect$$=$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$),$limit$jscomp$13_vec__83155$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$rowref$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$13_vec__83155$$,0,null);$limit$jscomp$13_vec__83155$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$13_vec__83155$$,1,null);var $file_count$jscomp$5$$=function(){var $or__5025__auto__$jscomp$1469$$=$APP.$cljs$core$count$$($files__$1$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1469$$)?$or__5025__auto__$jscomp$1469$$:0}(),$empty_state_viewer$$=$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$15$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$file_count$jscomp$5$$),$selected_files$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_files$$),$on_file_created$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file_data$jscomp$125_page_id$jscomp$473$$){var $file_id$jscomp$456$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$125_page_id$jscomp$473$$);$file_data$jscomp$125_page_id$jscomp$473$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file_data$jscomp$125_page_id$jscomp$473$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2236$pages$$,0],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$456$$,$APP.$cljs$cst$2051$page_id$$,$file_data$jscomp$125_page_id$jscomp$473$$])))}),$create_file$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$39$$)],function($origin$jscomp$82$$){var $mdata$jscomp$26$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,$on_file_created$$],null),$params$jscomp$444$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2189$project_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($app$main$data$dashboard$create_file$$($APP.$cljs$core$with_meta$$($params$jscomp$444$$,
$mdata$jscomp$26$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$82$$,$cljs$cst$6387$has_files$$,$file_count$jscomp$5$$>0],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$39$$)],function(){if($APP.$cljs$core$truth_$$($project$jscomp$39$$)){var $pname$jscomp$26$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$))?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$39$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$pname$jscomp$26$$])))}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id__$1$jscomp$4$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id__$1$jscomp$4$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6388$app_DOT_main_DOT_ui_DOT_dashboard_DOT_files_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_drafts_libraries$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$files$header_STAR_$$,{team:$props_83143_team$jscomp$83$$,canEdit:$can_edit_QMARK_$jscomp$15$$,project:$project$jscomp$39$$,createFn:$create_file$$}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$rowref$jscomp$2$$,className:"main_ui_dashboard_files__dashboard-container main_ui_dashboard_files__no-bg",children:$empty_state_viewer$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$cljs$core$truth_$$($is_draft_proyect$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-title"),className:"main_ui_dashboard_files__placeholder-placement",type:1,subtitle:$APP.$cljs$core$truth_$$($is_draft_proyect$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-subtitle"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-subtitle")}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{project:$project$jscomp$39$$,files:$files__$1$jscomp$6$$,selectedFiles:$selected_files$jscomp$6$$,canEdit:$can_edit_QMARK_$jscomp$15$$,origin:$APP.$cljs$cst$1933$files$$,createFn:$create_file$$,limit:$limit$jscomp$13_vec__83155$$})})]})};
$app$main$ui$dashboard$fonts$use_page_title$$=function($team$jscomp$84$$,$section$jscomp$39$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$84$$)],function(){if($APP.$cljs$core$truth_$$($team$jscomp$84$$)){var $tname$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$84$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$84$$),
$G__83126__$1$$=$section$jscomp$39$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$39$$.$fqn$:null;switch($G__83126__$1$$){case "fonts":return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.fonts",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$1$$])));case "providers":return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.font-providers",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$1$$])));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83126__$1$$)].join(""));}}else return null})};$app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$=function($font$jscomp$55$$){return $APP.$cljs$core$contains_QMARK_$$($font$jscomp$55$$,$cljs$cst$6389$font_family_tmp$$)&&$APP.$cuerdas$core$blank_QMARK_$$($cljs$cst$6389$font_family_tmp$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$55$$))};
$app$main$ui$dashboard$fonts$handle_font_upload$$=function($map__83136__$1_p__83135$$){$map__83136__$1_p__83135$$=$APP.$cljs$core$__destructure_map$$($map__83136__$1_p__83135$$);var $id$jscomp$1069$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83136__$1_p__83135$$,$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$map$$(function($font$jscomp$56$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1069$$,$font$jscomp$56$$],
null)},$APP.$beicon$v2$core$delay_at_least$$(2E3,$app$main$data$fonts$upload_font_variant$$($map__83136__$1_p__83135$$)))};
$app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$=function($props_83138_variant$jscomp$29$$){$props_83138_variant$jscomp$29$$=$props_83138_variant$jscomp$29$$.variant;return(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$common$media$font_display_variant$$($APP.$cljs$cst$2018$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($props_83138_variant$jscomp$29$$),$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($props_83138_variant$jscomp$29$$),$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($props_83138_variant$jscomp$29$$))})};
$app$main$ui$dashboard$fonts$uploaded_fonts_STAR_$$=function($disable_upload_all_QMARK__props_83145$$){var $installed_fonts$jscomp$2$$=$disable_upload_all_QMARK__props_83145$$.installedFonts,$on_upload_all_team$jscomp$86$$=$disable_upload_all_QMARK__props_83145$$.team,$fonts_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$fonts$jscomp$42$$=$APP.$cljs$core$_deref$$($fonts_STAR_$$),$font_vals$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$42$$)],
function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$fonts$jscomp$42$$))}),$team_id$jscomp$175$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($on_upload_all_team$jscomp$86$$),$input_ref$jscomp$16$$=(0,$APP.$rumext$v2$use_ref$$)(),$uploading_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),
$uploading$$=$APP.$cljs$core$_deref$$($uploading_STAR_$$);$disable_upload_all_QMARK__props_83145$$=$APP.$cljs$core$some$$($app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$,$fonts$jscomp$42$$);var $problematic_fonts_QMARK_$$=$APP.$cljs$core$some$$($APP.$cljs$cst$3552$height_warning_QMARK_$$,$APP.$cljs$core$vals$$($fonts$jscomp$42$$)),$on_click$jscomp$65$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$16$$))}),
$on_selected$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$175$$),$APP.$rumext$v2$adapt$$($installed_fonts$jscomp$2$$)],function($blobs$jscomp$4$$){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$392$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($fonts_STAR_$$,$app$main$data$fonts$merge_and_group_fonts$$,$installed_fonts$jscomp$2$$,$result$jscomp$392$$)},function($error$jscomp$153$$){return console.error("error",
$error$jscomp$153$$)},$app$main$data$fonts$process_upload$$($blobs$jscomp$4$$,$team_id$jscomp$175$$))}),$on_upload$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$42$$)],function($event$jscomp$759_id$jscomp$1070$$){$event$jscomp$759_id$jscomp$1070$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$759_id$jscomp$1070$$),"id"));var $item$jscomp$146$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$42$$,
$event$jscomp$759_id$jscomp$1070$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,$APP.$cljs$core$conj$$,$event$jscomp$759_id$jscomp$1070$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($font$jscomp$57_p__83170$$){var $previous_id$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$57_p__83170$$,0,null);$font$jscomp$57_p__83170$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$57_p__83170$$,
1,null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$previous_id$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,$APP.$cljs$core$disj$$,$previous_id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$add_font$$($font$jscomp$57_p__83170$$))},function($cause$jscomp$114$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$first$$($APP.$cljs$cst$3553$names$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$146$$))]))));return console.error("Unexpected error on uploading font",$cause$jscomp$114$$)},$app$main$ui$dashboard$fonts$handle_font_upload$$($item$jscomp$146$$))}),$on_blur_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($installed_fonts$jscomp$2$$)],function($event$jscomp$760_id$jscomp$1071$$){var $name$jscomp$507_target$jscomp$172$$=
$APP.$app$util$dom$get_current_target$$($event$jscomp$760_id$jscomp$1071$$);$event$jscomp$760_id$jscomp$1071$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($name$jscomp$507_target$jscomp$172$$,"id"));$name$jscomp$507_target$jscomp$172$$=$APP.$app$util$dom$get_value$$($name$jscomp$507_target$jscomp$172$$);var $JSCompiler_inline_result$jscomp$2034_and__5023__auto__$jscomp$inline_9754$$=($JSCompiler_inline_result$jscomp$2034_and__5023__auto__$jscomp$inline_9754$$=!$APP.$cuerdas$core$blank_QMARK_$$($name$jscomp$507_target$jscomp$172$$))?
$APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$font$schema_COLON_font_family$$,$name$jscomp$507_target$jscomp$172$$):$JSCompiler_inline_result$jscomp$2034_and__5023__auto__$jscomp$inline_9754$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2034_and__5023__auto__$jscomp$inline_9754$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($fonts_STAR_$$,$app$main$data$fonts$rename_and_regroup$$,$event$jscomp$760_id$jscomp$1071$$,$name$jscomp$507_target$jscomp$172$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$installed_fonts$jscomp$2$$])):null}),$on_change_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$761_target$jscomp$173$$){$event$jscomp$761_target$jscomp$173$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$761_target$jscomp$173$$);var $id$jscomp$1072$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($event$jscomp$761_target$jscomp$173$$,"id"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($fonts_STAR_$$,
$APP.$cljs$core$update$$,$id$jscomp$1072$$,$APP.$cljs$core$assoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$6389$font_family_tmp$$,$APP.$app$util$dom$get_value$$($event$jscomp$761_target$jscomp$173$$)]))}),$on_delete$jscomp$19$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_upload_all_team$jscomp$86$$)],function($event$jscomp$762_id$jscomp$1073$$){$event$jscomp$762_id$jscomp$1073$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$762_id$jscomp$1073$$),
"id"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$event$jscomp$762_id$jscomp$1073$$)});$on_upload_all_team$jscomp$86$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_vals$$)],function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($font$jscomp$58_p__83195$$){var $previous_id$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$58_p__83195$$,
0,null);$font$jscomp$58_p__83195$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$58_p__83195$$,1,null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$previous_id$jscomp$1$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,$APP.$cljs$core$disj$$,$previous_id$jscomp$1$$);return $APP.$cljs$core$truth_$$($font$jscomp$58_p__83195$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$add_font$$($font$jscomp$58_p__83195$$)):
null},$APP.$beicon$v2$core$mapcat$$(function($p__83200$$){var $map__83202__$1$$=$APP.$cljs$core$__destructure_map$$($p__83200$$),$id$jscomp$1074$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83202__$1$$,$APP.$cljs$cst$266$id$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$115$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.bad-font",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$first$$($APP.$cljs$cst$3553$names$$.$cljs$core$IFn$_invoke$arity$1$($map__83202__$1$$))]))));console.error("Unexpected error on uploading font",$cause$jscomp$115$$);return(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1074$$,null],null))},$app$main$ui$dashboard$fonts$handle_font_upload$$($map__83202__$1$$))},$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83140_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($uploading_STAR_$$,
$APP.$cljs$core$conj$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83140_SHARP_$$))},$APP.$beicon$v2$core$from$$($font_vals$$))))});var $on_dismis_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$42$$)],function(){return $APP.$cljs$core$run_BANG_$$(function($p1__83142_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($fonts_STAR_$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83142_SHARP_$$))},
$APP.$cljs$core$vals$$($fonts$jscomp$42$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__dashboard-fonts-upload",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__dashboard-fonts-hero",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__desc",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.upload-custom-fonts")}),$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,
{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.hero-text1")}),(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_click$jscomp$65$$,tabIndex:"0",className:"main_ui_dashboard_fonts__btn-primary",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.add-custom-font")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{"input-id":"font-upload",accept:$app$main$ui$dashboard$fonts$accept_font_types$$,
multi:!0,ref:$input_ref$jscomp$16$$,"on-selected":$on_selected$jscomp$2$$})]}),$APP.$cljs$core$truth_$$($APP.$app$config$terms_of_service_uri$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.fonts.hero-text2",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$terms_of_service_uri$$])),level:$APP.$cljs$cst$205$default$$,"is-html":!0}):
null,$APP.$cljs$core$truth_$$($problematic_fonts_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$context_notification$context_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.warning-text"),level:$APP.$cljs$cst$2354$warning$$,"is-html":!0}):null]})}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$seq$$($fonts$jscomp$42$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__font-item main_ui_dashboard_fonts__table-row",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.fonts.fonts-added",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($fonts$jscomp$42$$))]))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_upload_all_team$jscomp$86$$,"data-testid":"upload-all",
disabled:$disable_upload_all_QMARK__props_83145$$,className:"main_ui_dashboard_fonts__btn-primary "+($APP.$cljs$core$truth_$$($disable_upload_all_QMARK__props_83145$$)?"main_ui_dashboard_fonts__disabled":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.upload-all")})}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_dismis_all$$,"data-testid":"dismiss-all",className:"main_ui_dashboard_fonts__btn-secondary",children:(0,$APP.$rumext$v2$jsx$$)("span",
{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.dismiss-all")})})]})]}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$252$$,$p__83203$$){var $map__83204__$1$$=$APP.$cljs$core$__destructure_map$$($p__83203$$),$id$jscomp$1075$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83204__$1$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$252$$.push(function(){var $uploading_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($uploading$$,
$id$jscomp$1075$$),$disable_upload_QMARK_$$=$uploading_QMARK_$$||$app$main$ui$dashboard$fonts$bad_font_family_tmp_QMARK_$$($map__83204__$1$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__font-item main_ui_dashboard_fonts__table-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__family",children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"text","data-id":""+($id$jscomp$1075$$??""),onBlur:$on_blur_name$$,
onChange:$on_change_name$$,defaultValue:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($map__83204__$1$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__variants",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_fonts__label",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$,{variant:$map__83204__$1$$})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__filenames",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$26$$,$item__$1$jscomp$3$$){$out_arr__44092__auto____$1$jscomp$26$$.push((0,$APP.$rumext$v2$jsx$$)("span",{children:$item__$1$jscomp$3$$},"name-"+($item__$1$jscomp$3$$??"")));return $out_arr__44092__auto____$1$jscomp$26$$},[],$APP.$cljs$cst$3553$names$$.$cljs$core$IFn$_invoke$arity$1$($map__83204__$1$$))}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",
children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$3552$height_warning_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__83204__$1$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__failure",children:$APP.$app$main$ui$icons$msg_neutral$$}):null,(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_upload$$,"data-id":""+($id$jscomp$1075$$??""),disabled:$disable_upload_QMARK_$$,className:"main_ui_dashboard_fonts__btn-primary main_ui_dashboard_fonts__upload-button "+
($disable_upload_QMARK_$$?"main_ui_dashboard_fonts__disabled":""),children:$uploading_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.uploading"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.upload")}),(0,$APP.$rumext$v2$jsx$$)("span",{"data-id":""+($id$jscomp$1075$$??""),onClick:$on_delete$jscomp$19$$,className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__close",children:$APP.$app$main$ui$icons$close$$})]})]},""+($id$jscomp$1075$$??""))}());
return $out_arr__44092__auto__$jscomp$252$$},[],$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1764$font_family$$,$font_vals$$))]})]})};
$app$main$ui$dashboard$fonts$installed_font_context_menu_STAR_$$=function($options$jscomp$647_props_83205$$){var $is_open$jscomp$15$$=$options$jscomp$647_props_83205$$.isOpen,$on_download$jscomp$3$$=$options$jscomp$647_props_83205$$.onDownload,$on_close$jscomp$47$$=$options$jscomp$647_props_83205$$.onClose,$on_delete$jscomp$20$$=$options$jscomp$647_props_83205$$.onDelete,$on_edit$jscomp$16$$=$options$jscomp$647_props_83205$$.onEdit;$options$jscomp$647_props_83205$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_edit$jscomp$16$$),
$APP.$rumext$v2$adapt$$($on_download$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$20$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit"),$APP.$cljs$cst$266$id$$,"font-edit",$APP.$cljs$cst$2413$handler$$,$on_edit$jscomp$16$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.download-simple"),$APP.$cljs$cst$266$id$$,"font-download",$APP.$cljs$cst$2413$handler$$,$on_download$jscomp$3$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$266$id$$,"font-delete",$APP.$cljs$cst$2413$handler$$,$on_delete$jscomp$20$$],null)],null)});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,
{onClose:$on_close$jscomp$47$$,show:$is_open$jscomp$15$$,fixed:!1,minWidth:!0,top:-15,left:-115,options:$options$jscomp$647_props_83205$$})};
$app$main$ui$dashboard$fonts$installed_fonts_STAR_$$=function($on_change$jscomp$104_props_83230$$){function $matches_QMARK_$jscomp$4$$($p1__83229_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($p1__83229_SHARP_$$)),$APP.$cljs$core$_deref$$($sterm$$))}var $fonts$jscomp$43$$=$on_change$jscomp$104_props_83230$$.fonts,$can_edit$jscomp$17$$=$on_change$jscomp$104_props_83230$$.canEdit,$sterm$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("");
$on_change$jscomp$104_props_83230$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$766_val$jscomp$235$$){$event$jscomp$766_val$jscomp$235$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$766_val$jscomp$235$$);return $APP.$cljs$core$reset_BANG_$$($sterm$$,$APP.$cuerdas$core$lower$$($event$jscomp$766_val$jscomp$235$$))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__dashboard-installed-fonts",children:$APP.$cljs$core$seq$$($fonts$jscomp$43$$)?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("h3",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.installed-fonts")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__installed-fonts-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__family",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.font-family")}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__variants",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.font-variants")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__search-input",children:(0,$APP.$rumext$v2$jsx$$)("input",{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.search-font"),defaultValue:"",onChange:$on_change$jscomp$104_props_83230$$})})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$254$$,
$p__83247_variants$jscomp$12$$){var $font_id$jscomp$42$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83247_variants$jscomp$12$$,0,null);$p__83247_variants$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__83247_variants$jscomp$12$$,1,null);$out_arr__44092__auto__$jscomp$254$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$installed_font_STAR_$$,{fontId:$font_id$jscomp$42$$,canEdit:$can_edit$jscomp$17$$,variants:$p__83247_variants$jscomp$12$$},""+
($font_id$jscomp$42$$??"")+"-installed"));return $out_arr__44092__auto__$jscomp$254$$},[],$APP.$cljs$core$group_by$$($APP.$cljs$cst$1763$font_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($matches_QMARK_$jscomp$4$$,$APP.$cljs$core$vals$$($fonts$jscomp$43$$))))]}):$fonts$jscomp$43$$==null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__fonts-placeholder",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__icon",children:$APP.$app$main$ui$icons$loader$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.loading-fonts")})]}):$can_edit$jscomp$17$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__fonts-placeholder",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__icon",children:$APP.$app$main$ui$icons$text$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.empty-placeholder")})]}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.empty-placeholder-viewer"),subtitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.empty-placeholder-viewer-sub"),type:2})})};
$app$main$ui$dashboard$fonts$fonts_page_STAR_$$=function($props_83251_team$jscomp$87$$){$props_83251_team$jscomp$87$$=$props_83251_team$jscomp$87$$.team;var $fonts$jscomp$44$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$fonts$ref_COLON_fonts$$),$can_edit$jscomp$18_permissions$jscomp$43$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($props_83251_team$jscomp$87$$);$can_edit$jscomp$18_permissions$jscomp$43$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($can_edit$jscomp$18_permissions$jscomp$43$$);
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$header_STAR_$$,{team:$props_83251_team$jscomp$87$$,section:$APP.$cljs$cst$2980$fonts$$}),(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_dashboard_fonts__dashboard-container main_ui_dashboard_fonts__dashboard-fonts",children:[$can_edit$jscomp$18_permissions$jscomp$43$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$uploaded_fonts_STAR_$$,{team:$props_83251_team$jscomp$87$$,
installedFonts:$fonts$jscomp$44$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$installed_fonts_STAR_$$,{team:$props_83251_team$jscomp$87$$,fonts:$fonts$jscomp$44$$,canEdit:$can_edit$jscomp$18_permissions$jscomp$43$$})]})]})};
$app$main$ui$dashboard$fonts$font_providers_page_STAR_$$=function($props_83256$$){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$header_STAR_$$,{team:$props_83256$$.team,section:$cljs$cst$6392$providers$$}),(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_dashboard_fonts__dashboard-container",children:(0,$APP.$rumext$v2$jsx$$)("span",{children:"font providers"})})]})};
$app$main$ui$dashboard$libraries$libraries_page_STAR_$$=function($can_edit$jscomp$19_props_83112$$){var $default_project$jscomp$1$$=$can_edit$jscomp$19_props_83112$$.defaultProject,$team$jscomp$89$$=$can_edit$jscomp$19_props_83112$$.team,$files$jscomp$46$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$shared_files$$),$team_id$jscomp$176$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$89$$,$APP.$cljs$cst$266$id$$);$can_edit$jscomp$19_props_83112$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$89$$));
var $files__$1$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$46$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$176$$)],function(){return $APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1743$modified_at$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83111_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$176$$,$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83111_SHARP_$$))},
$APP.$cljs$core$vals$$($files$jscomp$46$$))))}),$selected_files$jscomp$7$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$libraries$ref_COLON_selected_files$$),$limit$jscomp$14_vec__83113$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(350),$rowref$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$14_vec__83113$$,0,null);$limit$jscomp$14_vec__83113$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$14_vec__83113$$,
1,null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$89$$)],function(){var $tname$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$89$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$89$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.shared-libraries",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$2$$])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$176$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$176$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});
$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6393$app_DOT_main_DOT_ui_DOT_dashboard_DOT_libraries_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_drafts_libraries$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_libraries__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-libraries-title",className:"main_ui_dashboard_libraries__dashboard-title",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-title")})})}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$rowref$jscomp$3$$,className:"main_ui_dashboard_libraries__dashboard-container main_ui_dashboard_libraries__no-bg main_ui_dashboard_libraries__dashboard-shared",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{files:$files__$1$jscomp$7$$,selectedFiles:$selected_files$jscomp$7$$,project:$default_project$jscomp$1$$,
origin:$APP.$cljs$cst$5352$libraries$$,limit:$limit$jscomp$14_vec__83113$$,canEdit:$can_edit$jscomp$19_props_83112$$})})]})};
$app$main$ui$dashboard$projects$project_item_STAR_$$=function($files$jscomp$47_props_83223$$){var $is_first$$=$files$jscomp$47_props_83223$$.isFirst,$can_edit$jscomp$21$$=$files$jscomp$47_props_83223$$.canEdit,$project$jscomp$40$$=$files$jscomp$47_props_83223$$.project,$team$jscomp$91$$=$files$jscomp$47_props_83223$$.team;$files$jscomp$47_props_83223$$=$files$jscomp$47_props_83223$$.files;var $project_id$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$40$$,$APP.$cljs$cst$266$id$$),
$team_id$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$91$$,$APP.$cljs$cst$266$id$$),$file_count$jscomp$6$$=function(){var $or__5025__auto__$jscomp$1470$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1470$$)?$or__5025__auto__$jscomp$1470$$:0}(),$is_draft_QMARK_$$=$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),$empty_QMARK_$jscomp$4$$=
$APP.$cljs$core$not$$($can_edit$jscomp$21$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$file_count$jscomp$6$$),$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$dashboard_local$$);$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$=$APP.$cljs$cst$5051$project_for_edit$$.$cljs$core$IFn$_invoke$arity$1$($dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$);var $local$jscomp$35$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$5042$menu_open$$,!1,$APP.$cljs$cst$5043$menu_pos$$,null,$APP.$cljs$cst$2207$edition$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$)],null)),$limit$jscomp$15_vec__83226$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$15_vec__83226$$,
0,null);$limit$jscomp$15_vec__83226$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$15_vec__83226$$,1,null);var $on_nav$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$47$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2189$project_id$$,
$project_id$jscomp$47$$])))}),$toggle_pin$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$40$$)],function($event$jscomp$768$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$768$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$toggle_project_pin$$($project$jscomp$40$$))}),$on_menu_click$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$){$APP.$app$util$dom$prevent_default$$($JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$);
var $client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$);$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$)==null&&$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$)==null?($client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$=
$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$)),$JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$),$client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$),
$JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$,$JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$)):$JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$=$client_position$jscomp$2_points$jscomp$inline_9756_x$jscomp$inline_9758$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$35$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5043$menu_pos$$,$JSCompiler_temp$jscomp$2035_event$jscomp$769_y$jscomp$inline_9757$$]))}),$on_menu_close$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$35$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5042$menu_open$$,!1)}),$on_edit_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$35$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2207$edition$$,!0)}),$on_edit$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project$jscomp$40$$)],function($name$jscomp$510_name__$1$jscomp$26$$){$name$jscomp$510_name__$1$jscomp$26$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$510_name__$1$jscomp$26$$);$APP.$cuerdas$core$empty_QMARK_$$($name$jscomp$510_name__$1$jscomp$26$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$dashboard$rename_project$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($project$jscomp$40$$,
$APP.$cljs$cst$725$name$$,$name$jscomp$510_name__$1$jscomp$26$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($local$jscomp$35$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2207$edition$$,!1)}),$on_file_created$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1078_p__83237$$){var $data$jscomp$509_map__83241__$1_page_id$jscomp$474$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$1078_p__83237$$);$id$jscomp$1078_p__83237$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$509_map__83241__$1_page_id$jscomp$474$$,$APP.$cljs$cst$266$id$$);$data$jscomp$509_map__83241__$1_page_id$jscomp$474$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$509_map__83241__$1_page_id$jscomp$474$$,$APP.$cljs$cst$142$data$$);$data$jscomp$509_map__83241__$1_page_id$jscomp$474$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$509_map__83241__$1_page_id$jscomp$474$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2236$pages$$,0],null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1078_p__83237$$,$APP.$cljs$cst$2051$page_id$$,$data$jscomp$509_map__83241__$1_page_id$jscomp$474$$])))}),
$create_file$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$47$$),$APP.$rumext$v2$adapt$$($on_file_created$jscomp$1$$)],function($origin$jscomp$83$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($app$main$data$dashboard$create_file$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$47$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2499$on_success$$,$on_file_created$jscomp$1$$],null))),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$origin$jscomp$83$$,$cljs$cst$6387$has_files$$,$file_count$jscomp$6$$>0],null)))}),$on_create_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($create_file$jscomp$1$$)],function(){return $create_file$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$create_file$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$("dashboard:grid-header-plus-button"):
$create_file$jscomp$1$$("dashboard:grid-header-plus-button")}),$on_import$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$47$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$177$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$47$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$177$$),
$app$main$data$dashboard$fetch_projects$$($team_id$jscomp$177$$),$app$main$data$dashboard$clear_selected_files$$()]))}),$handle_create_click$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_create_click$jscomp$1$$)],function($event$jscomp$770$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$770$$))?$on_create_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_create_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$770$$):
$on_create_click$jscomp$1$$($event$jscomp$770$$):null}),$handle_menu_click$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$8$$)],function($event$jscomp$771$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$771$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$771$$),$on_menu_click$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$771$$):
$on_menu_click$jscomp$8$$($event$jscomp$771$$)):null}),$title_width$$=100/$limit$jscomp$15_vec__83226$$;return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_dashboard_projects__dashboard-project-row "+($APP.$cljs$core$truth_$$($is_first$$)?"main_ui_dashboard_projects__first":""),children:[(0,$APP.$rumext$v2$jsx$$)("header",{className:"main_ui_dashboard_projects__project",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__project-name-wrapper",children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$2207$edition$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$35$$)))?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$inline_edition$inline_edition$$,{content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),"on-end":$on_edit$jscomp$18$$,"max-length":250}):(0,$APP.$rumext$v2$jsx$$)("h2",{onClick:$on_nav$$,style:{maxWidth:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($title_width$$),"%"].join("")},title:$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),onContextMenu:$APP.$cljs$core$truth_$$($can_edit$jscomp$21$$)?$on_menu_click$jscomp$8$$:null,className:"main_ui_dashboard_projects__project-name",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.drafts"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$)}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__info-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_projects__info",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-files",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($file_count$jscomp$6$$)])))}),function(){var $time$jscomp$9$$=
$APP.$app$common$time$timeago$$($APP.$cljs$cst$1743$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$));return(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_projects__recent-files-row-title-info",children:[", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($time$jscomp$9$$)].join("")})}()]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__project-actions "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$5018$is_pinned$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?
"main_ui_dashboard_projects__pinned-project":""),children:[$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$))?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$pin_button$pin_button_STAR_$$,{className:"main_ui_dashboard_projects__pin-button",isPinned:$APP.$cljs$cst$5018$is_pinned$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$40$$),onClick:$toggle_pin$jscomp$2$$,tabIndex:0}),$can_edit$jscomp$21$$?(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$on_create_click$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-file"),"data-testid":"project-new-file",onKeyDown:$handle_create_click$$,className:"main_ui_dashboard_projects__add-file-btn",children:$app$main$ui$dashboard$projects$add_icon$$}):null,$can_edit$jscomp$21$$?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_menu_click$jscomp$8$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.options"),"data-testid":"project-options",onKeyDown:$handle_menu_click$jscomp$1$$,className:"main_ui_dashboard_projects__options-btn",children:$app$main$ui$dashboard$projects$menu_icon$$}):null]}),$can_edit$jscomp$21$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$dashboard$project_menu$project_menu_STAR_$$,{project:$project$jscomp$40$$,show:$APP.$cljs$cst$5042$menu_open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$35$$)),
left:24+$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5043$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$35$$))),top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5043$menu_pos$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($local$jscomp$35$$))),onEdit:$on_edit_open$jscomp$1$$,onClose:$on_menu_close$jscomp$7$$,onImport:$on_import$jscomp$3$$}):null]})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{ref:$dstate$jscomp$2_edit_id$jscomp$4_rowref$jscomp$4$$,
className:"main_ui_dashboard_projects__grid-container",children:$empty_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$empty_placeholder$empty_placeholder_STAR_$$,{title:$is_draft_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-title"),className:"main_ui_dashboard_projects__placeholder-placement",type:1,subtitle:$is_draft_QMARK_$$?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-drafts-subtitle"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.empty-placeholder-files-subtitle")}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$line_grid$$,{project:$project$jscomp$40$$,team:$team$jscomp$91$$,files:$files$jscomp$47_props_83223$$,"create-fn":$create_file$jscomp$1$$,"can-edit":$can_edit$jscomp$21$$,limit:$limit$jscomp$15_vec__83226$$})}),$limit$jscomp$15_vec__83226$$>
0&&$file_count$jscomp$6$$>$limit$jscomp$15_vec__83226$$?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_nav$$,tabIndex:"0",onKeyDown:function($event$jscomp$772$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$772$$))?$on_nav$$.$cljs$core$IFn$_invoke$arity$0$?$on_nav$$.$cljs$core$IFn$_invoke$arity$0$():$on_nav$$():null},className:"main_ui_dashboard_projects__show-more",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_projects__placeholder-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.show-all-files")}),$app$main$ui$dashboard$projects$show_more_icon$$]}):null]})};
$app$main$ui$dashboard$projects$projects_section_STAR_$$=function($on_close$jscomp$49_permisions_props_83266$$){var $profile$jscomp$91_show_deleted_QMARK_$$=$on_close$jscomp$49_permisions_props_83266$$.profile,$projects$jscomp$10$$=$on_close$jscomp$49_permisions_props_83266$$.projects,$team$jscomp$92$$=$on_close$jscomp$49_permisions_props_83266$$.team,$team_id$jscomp$178$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$92$$,$APP.$cljs$cst$266$id$$),$recent_map$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$projects$ref_COLON_recent_files$$);
$on_close$jscomp$49_permisions_props_83266$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$92$$);var $can_edit$jscomp$22$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($on_close$jscomp$49_permisions_props_83266$$),$can_invite$jscomp$3$$=$APP.$app$main$data$nitrate$can_send_invitations_QMARK_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3297$organization$$,$APP.$cljs$cst$3297$organization$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$92$$),
$APP.$cljs$cst$2321$profile_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$91_show_deleted_QMARK_$$),$APP.$cljs$cst$3298$team_permissions$$,$on_close$jscomp$49_permisions_props_83266$$],null)),$show_team_hero_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$global$$,$cljs$cst$6394$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$,!0)}),
$show_team_hero_QMARK_$$=$APP.$cljs$core$_deref$$($show_team_hero_STAR_$$),$my_penpot_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2507$default_team_id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$91_show_deleted_QMARK_$$),$team_id$jscomp$178$$),$default_team_QMARK_$$=$APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$92$$);$profile$jscomp$91_show_deleted_QMARK_$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($on_close$jscomp$49_permisions_props_83266$$);
var $projects__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$10$$)],function(){return $APP.$cljs$core$reverse$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1743$modified_at$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2582$deleted_at$$,$projects$jscomp$10$$)))});$on_close$jscomp$49_permisions_props_83266$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($show_team_hero_STAR_$$,
!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"dont-show-team-up-hero",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard"],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_team_hero_QMARK_$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,
$APP.$cljs$core$assoc$$,$cljs$cst$6394$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$,$show_team_hero_QMARK_$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$92$$)],function(){var $tname$jscomp$3$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$92$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$92$$);
return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.projects",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$3$$])))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$178$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$178$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6395$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_projects$$);return $APP.$cljs$core$seq$$($projects__$1$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$header_STAR_$$,{canEdit:$can_edit$jscomp$22$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_projects__projects-container",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_team_hero_QMARK_$$)?$can_invite$jscomp$3$$&&$APP.$cljs$core$not$$($default_team_QMARK_$$):$show_team_hero_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$team_hero_STAR_$$,{team:$team$jscomp$92$$,onClose:$on_close$jscomp$49_permisions_props_83266$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_projects__dashboard-container main_ui_dashboard_projects__no-bg main_ui_dashboard_projects__dashboard-projects "+($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1078_and__5023__auto____$1$jscomp$176$$=!$my_penpot_QMARK_$$;return $and__5023__auto__$jscomp$1078_and__5023__auto____$1$jscomp$176$$?($and__5023__auto__$jscomp$1078_and__5023__auto____$1$jscomp$176$$=$APP.$cljs$core$not$$($default_team_QMARK_$$))?$APP.$cljs$core$truth_$$($show_team_hero_QMARK_$$)?
$can_invite$jscomp$3$$:$show_team_hero_QMARK_$$:$and__5023__auto__$jscomp$1078_and__5023__auto____$1$jscomp$176$$:$and__5023__auto__$jscomp$1078_and__5023__auto____$1$jscomp$176$$}())?"main_ui_dashboard_projects__with-team-hero":""),children:[$APP.$cljs$core$truth_$$($profile$jscomp$91_show_deleted_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$menu_STAR_$$,{teamId:$team_id$jscomp$178$$,section:$APP.$cljs$cst$2533$dashboard_recent$$}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$255$$,
$p__83283$$){var $map__83284__$1$$=$APP.$cljs$core$__destructure_map$$($p__83283$$),$id$jscomp$1079$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83284__$1$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$255$$.push(function(){var $files$jscomp$48$$=$APP.$cljs$core$truth_$$($recent_map$$)?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1743$modified_at$$,function($p1__83265_SHARP_$$,$p2__83264_SHARP_$$){return $APP.$cljs$core$compare$$($p2__83264_SHARP_$$,
$p1__83265_SHARP_$$)},$APP.$cljs$core$filterv$$(function($p1__83263_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1079$$,$APP.$cljs$cst$2189$project_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83263_SHARP_$$))},$APP.$cljs$core$vals$$($recent_map$$))):null;return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$project_item_STAR_$$,{project:$map__83284__$1$$,team:$team$jscomp$92$$,files:$files$jscomp$48$$,canEdit:$can_edit$jscomp$22$$,isFirst:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__83284__$1$$,
$APP.$cljs$core$first$$($projects__$1$jscomp$1$$))},$id$jscomp$1079$$)}());return $out_arr__44092__auto__$jscomp$255$$},[],$projects__$1$jscomp$1$$)]})]})})]}):null};
$app$main$ui$dashboard$search$search_page_STAR_$$=function($props_83183_result$jscomp$393$$){var $team$jscomp$93$$=$props_83183_result$jscomp$393$$.team,$search_term__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_83183_result$jscomp$393$$.searchTerm,"");$props_83183_result$jscomp$393$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$search$ref_COLON_search_result$$);var $selected$jscomp$219$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$search$ref_COLON_selected$$),
$limit$jscomp$16_vec__83192$$=$app$main$ui$hooks$use_dynamic_grid_item_width$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$rowref$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$16_vec__83192$$,0,null);$limit$jscomp$16_vec__83192$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($limit$jscomp$16_vec__83192$$,1,null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$93$$)],function(){if($APP.$cljs$core$truth_$$($team$jscomp$93$$)){var $tname$jscomp$4$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$93$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.your-penpot"):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$93$$);return $APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.dashboard.search",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tname$jscomp$4$$])))}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($search_term__$1$jscomp$1$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$search$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2527$search_term$$,$search_term__$1$jscomp$1$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$clear_selected_files$$()]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("header",{"data-testid":"dashboard-header",
className:"main_ui_dashboard_search__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-search-title",className:"main_ui_dashboard_search__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.title-search")})})}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$rowref$jscomp$5$$,className:"main_ui_dashboard_search__dashboard-container main_ui_dashboard_search__search main_ui_dashboard_search__no-bg",
children:$APP.$cljs$core$empty_QMARK_$$($search_term__$1$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_search__grid-empty-placeholder main_ui_dashboard_search__search",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.type-something")})]}):
$props_83183_result$jscomp$393$$==null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_search__grid-empty-placeholder main_ui_dashboard_search__search",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.searching-for",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$search_term__$1$jscomp$1$$]))})]}):
$APP.$cljs$core$empty_QMARK_$$($props_83183_result$jscomp$393$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_search__grid-empty-placeholder main_ui_dashboard_search__search",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_search__text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("dashboard.no-matches-for",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$search_term__$1$jscomp$1$$]))})]}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$grid$grid_STAR_$$,{files:$props_83183_result$jscomp$393$$,selectedFiles:$selected$jscomp$219$$,origin:$cljs$cst$6377$search$$,limit:$limit$jscomp$16_vec__83192$$})})]})};
$app$main$ui$dashboard$templates$import_template_BANG_$$=function($template$jscomp$9$$,$team_id$jscomp$179$$,$project_id$jscomp$48$$,$default_project_id$jscomp$1$$,$section$jscomp$41$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-template-launch",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"dashboard",$APP.$cljs$cst$2414$template$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($template$jscomp$9$$),$APP.$cljs$cst$1371$section$$,$section$jscomp$41$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5453$import$$,$APP.$cljs$cst$2189$project_id$$,$APP.$cljs$core$truth_$$($project_id$jscomp$48$$)?$project_id$jscomp$48$$:
$default_project_id$jscomp$1$$,$APP.$cljs$cst$1933$files$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$2414$template$$,$template$jscomp$9$$,$APP.$cljs$cst$5454$on_finish_import$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$179$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-template-finish",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$2414$template$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($template$jscomp$9$$),$APP.$cljs$cst$1371$section$$,$section$jscomp$41$$],null)),$project_id$jscomp$48$$!=null?null:$APP.$app$main$data$common$go_to_dashboard_recent$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1944$team_id$$,
$team_id$jscomp$179$$,$APP.$cljs$cst$2189$project_id$$,$default_project_id$jscomp$1$$]))]))}],null))]))};
$app$main$ui$dashboard$templates$title_STAR_$$=function($on_key_down$jscomp$33_props_83246$$){var $is_collapsed$jscomp$1$$=$on_key_down$jscomp$33_props_83246$$.isCollapsed,$on_click$jscomp$67$$=$on_key_down$jscomp$33_props_83246$$.onClick;$on_key_down$jscomp$33_props_83246$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$67$$)],function($event$jscomp$773$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$773$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$773$$),
$APP.$app$util$dom$prevent_default$$($event$jscomp$773$$),$on_click$jscomp$67$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$67$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$773$$):$on_click$jscomp$67$$($event$jscomp$773$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__title",children:(0,$APP.$rumext$v2$jsxs$$)("button",{tabIndex:"0",onClick:$on_click$jscomp$67$$,onKeyDown:$on_key_down$jscomp$33_props_83246$$,className:"main_ui_dashboard_templates__title-btn",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates")}),$is_collapsed$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_templates__title-icon-container",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-icon-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.show")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-icon main_ui_dashboard_templates__title-icon-collapsed",children:$app$main$ui$dashboard$templates$arrow_icon$$})]}):(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_dashboard_templates__title-icon-container",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__title-icon-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.hide")}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_dashboard_templates__title-icon",children:$app$main$ui$dashboard$templates$arrow_icon$$})]})]})})};
$app$main$ui$dashboard$templates$card_item_STAR_$$=function($id$jscomp$1080_props_83252$$){var $on_import$jscomp$4$$=$id$jscomp$1080_props_83252$$.onImport,$collapsed$jscomp$4$$=$id$jscomp$1080_props_83252$$.collapsed,$index$jscomp$587$$=$id$jscomp$1080_props_83252$$.index,$item$jscomp$151$$=$id$jscomp$1080_props_83252$$.item,$is_visible$jscomp$3$$=$id$jscomp$1080_props_83252$$.isVisible;$id$jscomp$1080_props_83252$$="card-container-"+($index$jscomp$587$$??"");var $href$jscomp$21$$=$APP.$app$common$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"images/thumbnails/template-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$151$$)??"")+".jpg"])),$hover_QMARK_$jscomp$12$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_click$jscomp$68$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_import$jscomp$4$$)],function($event$jscomp$774$$){return $on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$151$$,
$event$jscomp$774$$):$on_import$jscomp$4$$($item$jscomp$151$$,$event$jscomp$774$$)}),$on_key_down$jscomp$34$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_import$jscomp$4$$)],function($event$jscomp$775$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$775$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$775$$),$on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_import$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$151$$,
$event$jscomp$775$$):$on_import$jscomp$4$$($item$jscomp$151$$,$event$jscomp$775$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{tabIndex:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1472$$=$APP.$cljs$core$not$$($is_visible$jscomp$3$$);return $or__5025__auto__$jscomp$1472$$?$or__5025__auto__$jscomp$1472$$:$collapsed$jscomp$4$$}())?"-1":"0",id:$id$jscomp$1080_props_83252$$,"data-index":$index$jscomp$587$$,className:"main_ui_dashboard_templates__card-container",children:(0,$APP.$rumext$v2$jsxs$$)("a",
{onClick:$on_click$jscomp$68$$,onMouseDown:$APP.$app$util$dom$prevent_default$$,onMouseEnter:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$12$$,!0)},onMouseLeave:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$12$$,!1)},onKeyDown:$on_key_down$jscomp$34$$,className:"main_ui_dashboard_templates__template-card",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__img-container",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:""+
($href$jscomp$21$$??""),alt:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$151$$),loading:"lazy",decoding:"async"})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_templates__card-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_templates__card-text",children:$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover_QMARK_$jscomp$12$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.template.add-to-project"):
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$151$$)}),$app$main$ui$dashboard$templates$download_icon$$]})]})})};
$app$main$ui$dashboard$templates$card_item_link_STAR_$$=function($id$jscomp$1081_props_83258$$){var $collapsed$jscomp$5$$=$id$jscomp$1081_props_83258$$.collapsed,$section$jscomp$42$$=$id$jscomp$1081_props_83258$$.section,$is_visible$jscomp$4$$=$id$jscomp$1081_props_83258$$.isVisible;$id$jscomp$1081_props_83258$$="card-container-"+($id$jscomp$1081_props_83258$$.total??"");var $on_click$jscomp$69$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($section$jscomp$42$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-libraries-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"dashboard",$APP.$cljs$cst$1371$section$$,$section$jscomp$42$$],null)))}),$on_key_down$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$69$$)],
function($event$jscomp$776$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$776$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$776$$),$on_click$jscomp$69$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$69$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$776$$):$on_click$jscomp$69$$($event$jscomp$776$$)):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__card-container",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_templates__template-card",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__img-container",children:(0,$APP.$rumext$v2$jsx$$)("a",{id:$id$jscomp$1081_props_83258$$,tabIndex:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1473$$=$APP.$cljs$core$not$$($is_visible$jscomp$4$$);return $or__5025__auto__$jscomp$1473$$?$or__5025__auto__$jscomp$1473$$:$collapsed$jscomp$5$$}())?"-1":"0",href:"https://penpot.app/libraries-templates",
target:"_blank",onClick:$on_click$jscomp$69$$,onKeyDown:$on_key_down$jscomp$35$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_templates__template-link",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__template-link-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_templates__template-link-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.explore")})]})})})})})};
$app$main$ui$dashboard$templates$templates_section_STAR_$$=function($props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$){var $project_id$jscomp$49$$=$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$.projectId,$profile$jscomp$92$$=$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$.profile,$team_id$jscomp$180$$=$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$.teamId,$default_project_id$jscomp$2$$=$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$.defaultProjectId,
$templates$$=$APP.$rumext$v2$deref$$($app$main$ui$dashboard$templates$builtin_templates$$),$templates__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($templates$$)],function(){return $APP.$cljs$core$filterv$$(function($p1__83271_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83271_SHARP_$$),"welcome")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83271_SHARP_$$),
"tutorial-for-beginners")},$templates$$)});$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$);$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],
null));var $section$jscomp$43$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$,$APP.$cljs$cst$2523$dashboard_files$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($project_id$jscomp$49$$,$default_project_id$jscomp$2$$)?"dashboard-drafts":"dashboard-project":$APP.$cljs$core$name$$($props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$),$collapsed_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$global$$,
$cljs$cst$6396$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$)}),$collapsed$jscomp$6$$=$APP.$cljs$core$_deref$$($collapsed_STAR_$jscomp$1$$),$can_move$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$257$left$$,!1,$APP.$cljs$cst$258$right$$,!0],null));$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$=$APP.$cljs$core$count$$($templates__$1$$);var $content_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(),
$on_toggle_collapse$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_STAR_$jscomp$1$$,$APP.$cljs$core$not$$)}),$on_wheel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$777_event_STAR_$$){$event$jscomp$777_event_STAR_$$=$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$($event$jscomp$777_event_STAR_$$);var $deltaY$$=$event$jscomp$777_event_STAR_$$.spinY,
$node$jscomp$482$$=$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$);return $APP.$cljs$core$abs$$($deltaY$$)>$APP.$cljs$core$abs$$($event$jscomp$777_event_STAR_$$.spinX)?$node$jscomp$482$$.scrollBy({left:300*$deltaY$$,mode:"smooth"}):null}),$on_scroll$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($client_width_e$jscomp$417$$){var $scroll$jscomp$5_scroll_available$$=(0,$APP.$app$util$dom$get_target_scroll$$)($client_width_e$jscomp$417$$),$scroll_left$$=$APP.$cljs$cst$1564$scroll_left$$.$cljs$core$IFn$_invoke$arity$1$($scroll$jscomp$5_scroll_available$$);
$scroll$jscomp$5_scroll_available$$=$APP.$cljs$cst$1566$scroll_width$$.$cljs$core$IFn$_invoke$arity$1$($scroll$jscomp$5_scroll_available$$)-$scroll_left$$;$client_width_e$jscomp$417$$=$APP.$app$util$dom$get_client_size$$($APP.$app$util$dom$get_target$$($client_width_e$jscomp$417$$)).width;return $APP.$cljs$core$reset_BANG_$$($can_move$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$257$left$$,$scroll_left$$>0,$APP.$cljs$cst$258$right$$,$scroll$jscomp$5_scroll_available$$>$client_width_e$jscomp$417$$],
null))}),$on_move_left$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$778$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$right_arrow_QMARK_$$)($event$jscomp$778$$))?$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(300,0):$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(-300,0)}),$on_move_right$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$779$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$left_arrow_QMARK_$$)($event$jscomp$779$$))?
$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(-300,0):$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$).scrollBy(300,0)}),$on_import_template$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_project_id$jscomp$2$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$49$$),$APP.$rumext$v2$adapt$$($section$jscomp$43$$),$APP.$rumext$v2$adapt$$($templates__$1$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$180$$)],function($template$jscomp$10$$){return $app$main$ui$dashboard$templates$import_template_BANG_$$($template$jscomp$10$$,
$team_id$jscomp$180$$,$project_id$jscomp$49$$,$default_project_id$jscomp$2$$,$section$jscomp$43$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($templates__$1$$)],function(){var $content$jscomp$274$$=$APP.$rumext$v2$ref_val$$($content_ref$jscomp$1$$);if($content$jscomp$274$$!=null&&$templates__$1$$!=null){$content$jscomp$274$$.scrollTo({behavior:"instant",left:0,top:0});var $event$jscomp$inline_9764$$=new Event("scroll");return $content$jscomp$274$$!=
null?$content$jscomp$274$$.dispatchEvent($event$jscomp$inline_9764$$):null}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$92$$),$APP.$rumext$v2$adapt$$($collapsed$jscomp$6$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$global$$,$APP.$cljs$core$assoc$$,$cljs$cst$6396$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$,$collapsed$jscomp$6$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($profile$jscomp$92$$)?
$APP.$cljs$core$not$$($collapsed$jscomp$6$$):$profile$jscomp$92$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$fetch_builtin_templates$$()):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_templates__dashboard-templates-section "+($APP.$cljs$core$truth_$$($collapsed$jscomp$6$$)?"main_ui_dashboard_templates__collapsed":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$title_STAR_$$,{onClick:$on_toggle_collapse$jscomp$3$$,
isCollapsed:$collapsed$jscomp$6$$}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_dashboard_templates__content-description",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.description")}),(0,$APP.$rumext$v2$jsxs$$)("div",{onScroll:$on_scroll$jscomp$2$$,onWheel:$on_wheel$jscomp$1$$,ref:$content_ref$jscomp$1$$,className:"main_ui_dashboard_templates__content",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$256$$,
$index$jscomp$588$$){$out_arr__44092__auto__$jscomp$256$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$card_item_STAR_$$,{onImport:$on_import_template$$,item:$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($templates__$1$$,$index$jscomp$588$$),index:$index$jscomp$588$$,isVisible:!0,collapsed:$collapsed$jscomp$6$$},$index$jscomp$588$$));return $out_arr__44092__auto__$jscomp$256$$},[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($templates__$1$$))),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$card_item_link_STAR_$$,{isVisible:!0,collapsed:$collapsed$jscomp$6$$,section:$section$jscomp$43$$,total:$props_83275_route$jscomp$21_route_name$jscomp$1_total$jscomp$27$$})]}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($can_move$$)))?(0,$APP.$rumext$v2$jsx$$)("button",{tabIndex:$collapsed$jscomp$6$$?"-1":"0",onClick:$on_move_left$$,onKeyDown:$on_move_left$$,className:"main_ui_dashboard_templates__move-button main_ui_dashboard_templates__move-left",
children:$app$main$ui$dashboard$templates$arrow_icon$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($can_move$$)))?(0,$APP.$rumext$v2$jsx$$)("button",{tabIndex:$APP.$cljs$core$truth_$$($collapsed$jscomp$6$$)?"-1":"0",onClick:$on_move_right$$,onKeyDown:$on_move_right$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"),className:"main_ui_dashboard_templates__move-button main_ui_dashboard_templates__move-right",
children:$app$main$ui$dashboard$templates$arrow_icon$$}):null]})};
$app$main$ui$dashboard$dashboard_content_STAR_$$=function($clear_selected_fn_props_83305$$){var $default_project$jscomp$2$$=$clear_selected_fn_props_83305$$.defaultProject,$profile$jscomp$93$$=$clear_selected_fn_props_83305$$.profile,$projects$jscomp$11$$=$clear_selected_fn_props_83305$$.projects,$search_term$jscomp$7$$=$clear_selected_fn_props_83305$$.searchTerm,$section$jscomp$44$$=$clear_selected_fn_props_83305$$.section,$project$jscomp$42$$=$clear_selected_fn_props_83305$$.project,$team$jscomp$94$$=
$clear_selected_fn_props_83305$$.team,$container$jscomp$99$$=(0,$APP.$rumext$v2$use_ref$$)(),$content_width$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$project_id$jscomp$50$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$42$$),$team_id$jscomp$181$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$94$$),$permissions$jscomp$44$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$94$$),$default_project_id$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_project$jscomp$2$$,$APP.$cljs$cst$266$id$$),$on_resize$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($content_width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$99$$),"clientWidth"))});$clear_selected_fn_props_83305$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$clear_selected_files$$())});
var $show_templates_QMARK_$$=function(){var $and__5023__auto__$jscomp$1080$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1189$dashboard_templates_section$$);return $and__5023__auto__$jscomp$1080$$?$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$):$and__5023__auto__$jscomp$1080$$}(),$show_deleted_QMARK_$jscomp$1$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$44$$),$section__$1$jscomp$2$$=$APP.$cljs$core$not$$($show_deleted_QMARK_$jscomp$1$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$44$$,$APP.$cljs$cst$2547$dashboard_deleted$$)?$APP.$cljs$cst$2533$dashboard_recent$$:$section$jscomp$44$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$9$$=$APP.$goog$events$listen$$(window,"resize",$on_resize$jscomp$7$$);return function(){return $APP.$goog$events$unlistenByKey$$($key1$jscomp$9$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$($on_resize$jscomp$7$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$clear_selected_fn_props_83305$$,ref:$container$jscomp$99$$,className:"main_ui_dashboard__dashboard-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$progress$progress_notification_widget_STAR_$$,{}),function(){switch($section__$1$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$section__$1$jscomp$2$$.$fqn$:null){case "dashboard-recent":return $APP.$cljs$core$seq$$($projects$jscomp$11$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$projects$projects_section_STAR_$$,{team:$team$jscomp$94$$,projects:$projects$jscomp$11$$,profile:$profile$jscomp$93$$}),$show_templates_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$templates_section_STAR_$$,{profile:$profile$jscomp$93$$,projectId:$project_id$jscomp$50$$,teamId:$team_id$jscomp$181$$,defaultProjectId:$default_project_id$jscomp$3$$,contentWidth:$APP.$cljs$core$_deref$$($content_width$$)}):null]}):null;
case "dashboard-fonts":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$fonts_page_STAR_$$,{team:$team$jscomp$94$$});case "dashboard-font-providers":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$font_providers_page_STAR_$$,{team:$team$jscomp$94$$});case "dashboard-files":return $APP.$cljs$core$truth_$$($project$jscomp$42$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$files$files_section_STAR_$$,{team:$team$jscomp$94$$,
project:$project$jscomp$42$$}),$show_templates_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$templates$templates_section_STAR_$$,{profile:$profile$jscomp$93$$,teamId:$team_id$jscomp$181$$,projectId:$project_id$jscomp$50$$,defaultProjectId:$default_project_id$jscomp$3$$,contentWidth:$APP.$cljs$core$_deref$$($content_width$$)}):null]}):null;case "dashboard-search":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$search$search_page_STAR_$$,{team:$team$jscomp$94$$,searchTerm:$search_term$jscomp$7$$});
case "dashboard-libraries":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$libraries$libraries_page_STAR_$$,{team:$team$jscomp$94$$,defaultProject:$default_project$jscomp$2$$});case "dashboard-members":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_members_page_STAR_$$,{team:$team$jscomp$94$$,profile:$profile$jscomp$93$$});case "dashboard-invitations":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_invitations_page_STAR_$$,{team:$team$jscomp$94$$,profile:$profile$jscomp$93$$});
case "dashboard-webhooks":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$webhooks_page_STAR_$$,{team:$team$jscomp$94$$});case "dashboard-settings":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$team$team_settings_page_STAR_$$,{team:$team$jscomp$94$$,profile:$profile$jscomp$93$$});case "dashboard-deleted":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$deleted$deleted_section_STAR_$$,{team:$team$jscomp$94$$,projects:$projects$jscomp$11$$,profile:$profile$jscomp$93$$});default:return null}}()]})};
$app$main$ui$dashboard$use_plugin_register$$=function($plugin_url$jscomp$4$$,$team_id$jscomp$182$$,$project_id$jscomp$51$$){function $open_permissions_dialog$$($plugin$jscomp$13$$){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5107$plugin_permissions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3455$plugin$$,$plugin$jscomp$13$$,$APP.$cljs$cst$2490$on_accept$$,function(){$APP.$app$plugins$register$install_plugin_BANG_$$($plugin$jscomp$13$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2533$dashboard_recent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$182$$],null)),$open_try_out_dialog$$($plugin$jscomp$13$$)]))},$APP.$cljs$cst$5108$on_close$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2533$dashboard_recent$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$182$$],null))]))}],null))}function $open_try_out_dialog$$($plugin$jscomp$12$$){return $APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5109$plugin_try_out$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3455$plugin$$,
$plugin$jscomp$12$$,$APP.$cljs$cst$2490$on_accept$$,function(){var $JSCompiler_temp_const$jscomp$inline_14142$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$inline_14143$$=$APP.$app$main$data$modal$hide$$();var $JSCompiler_inline_result$jscomp$inline_14144_data$jscomp$inline_14145$$=$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$51$$,$APP.$cljs$cst$725$name$$,
""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plugins.try-plugin")??"")+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$12$$)??"")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2499$on_success$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($navegate_file_BANG_$$,$plugin$jscomp$12$$)],null));$JSCompiler_inline_result$jscomp$inline_14144_data$jscomp$inline_14145$$=$APP.$cljs$core$with_meta$$($app$main$data$dashboard$create_file$$($JSCompiler_inline_result$jscomp$inline_14144_data$jscomp$inline_14145$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"plugin-try-out"],null));return $JSCompiler_temp_const$jscomp$inline_14142$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_temp_const$jscomp$inline_14143$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_inline_result$jscomp$inline_14144_data$jscomp$inline_14145$$]))},$APP.$cljs$cst$5108$on_close$$,$APP.$app$main$data$modal$hide_BANG_$$],null))}function $navegate_file_BANG_$$($plugin$jscomp$10$$,
$p__83307_project_id__$1$jscomp$5$$){var $data$jscomp$510_map__83308__$1$$=$APP.$cljs$core$__destructure_map$$($p__83307_project_id__$1$jscomp$5$$);$p__83307_project_id__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__83308__$1$$,$APP.$cljs$cst$2189$project_id$$);var $id$jscomp$1082$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__83308__$1$$,$APP.$cljs$cst$266$id$$);$data$jscomp$510_map__83308__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__83308__$1$$,
$APP.$cljs$cst$142$data$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$plugins$delay_open_plugin$$($plugin$jscomp$10$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2543$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$510_map__83308__$1$$,
$APP.$cljs$cst$2236$pages$$),0),$APP.$cljs$cst$2189$project_id$$,$p__83307_project_id__$1$jscomp$5$$,$APP.$cljs$cst$1649$file_id$$,$id$jscomp$1082$$,$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$182$$],null))]))}$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($plugin_url$jscomp$4$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$182$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$51$$)],function(){if($APP.$cljs$core$truth_$$($plugin_url$jscomp$4$$)){$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($plugin$jscomp$14$$){return $APP.$cljs$core$truth_$$($plugin$jscomp$14$$)?
($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-plugin",$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($plugin$jscomp$14$$),$APP.$cljs$cst$1991$url$$,$plugin_url$jscomp$4$$],null))),$open_permissions_dialog$$($plugin$jscomp$14$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plugins.parse-error")))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.plugins.bad-url")))},$APP.$app$main$data$plugins$fetch_manifest$$($plugin_url$jscomp$4$$));var $_STAR_sync_STAR__orig_val__83309$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$session$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$6398$plugin_url$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__83309$$}}else return null})};
$app$main$ui$dashboard$use_templates_import$$=function($can_edit_QMARK_$jscomp$16$$,$template$jscomp$11$$,$project$jscomp$43$$){var $project_id$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$43$$,$APP.$cljs$cst$266$id$$),$team_id$jscomp$183$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($project$jscomp$43$$,$APP.$cljs$cst$1944$team_id$$);$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$16$$),
$APP.$rumext$v2$adapt$$($template$jscomp$11$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$52$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$183$$)],function(){if($template$jscomp$11$$!=null&&$project_id$jscomp$52$$!=null&&$team_id$jscomp$183$$!=null){if($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$16$$)){var $_STAR_sync_STAR__orig_val__83313_valid_url_QMARK__83331$$=$APP.$cuerdas$core$ends_with_QMARK_$$($template$jscomp$11$$,".penpot"),$template_name_83332$$=$APP.$cuerdas$core$starts_with_QMARK_$$($template$jscomp$11$$,
"http")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($template$jscomp$11$$,$APP.$cljs$core$count$$($APP.$app$config$templates_uri$$)):$template$jscomp$11$$,$template_url_83333$$=["/github/penpot-files/",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($template_name_83332$$)].join(""),$on_import_83334$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$project$fetch_files$cljs$0core$0IFn$0_invoke$0arity$01$$($project_id$jscomp$52$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$dashboard$fetch_recent_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$183$$),$app$main$data$dashboard$fetch_projects$$($team_id$jscomp$183$$),$app$main$data$dashboard$clear_selected_files$$(),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-template-from-link-finished",$APP.$cljs$cst$725$name$$,$template_name_83332$$,
$APP.$cljs$cst$1991$url$$,$template_url_83333$$],null))]))};$_STAR_sync_STAR__orig_val__83313_valid_url_QMARK__83331$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"install-template-from-link",$APP.$cljs$cst$725$name$$,$template_name_83332$$,$APP.$cljs$cst$1991$url$$,$template_url_83333$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5453$import$$,$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$52$$,$APP.$cljs$cst$4446$entries$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$template_name_83332$$,$APP.$cljs$cst$1584$uri$$,$template_url_83333$$],null)],null),$APP.$cljs$cst$5454$on_finish_import$$,$on_import_83334$$],null))])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.bad-url")))}else $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.import.no-perms")));
$_STAR_sync_STAR__orig_val__83313_valid_url_QMARK__83331$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$session$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2414$template$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__83313_valid_url_QMARK__83331$$}}else return null})};
$app$main$ui$dashboard$use_nitrate_entry_popup$$=function(){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){if($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$storage$storage$$,$APP.$cljs$cst$5171$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$)===!0){var $_STAR_sync_STAR__orig_val__73697$jscomp$inline_9768$$=$APP.$app$util$storage$_STAR_sync_STAR_$$;$APP.$app$util$storage$_STAR_sync_STAR_$$=!0;try{$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$storage$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5170$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_active$$,$APP.$cljs$cst$5171$app_DOT_main_DOT_data_DOT_nitrate_SLASH_nitrate_entry_pending_popup$$)}finally{$APP.$app$util$storage$_STAR_sync_STAR_$$=$_STAR_sync_STAR__orig_val__73697$jscomp$inline_9768$$}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3252$onboarding_viewed$$,
!0],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$nitrate$show_nitrate_popup$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5229$nitrate_form$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}return null})};
$app$main$ui$dashboard$dashboard_STAR_$$=function($props_83318_team$jscomp$95$$){var $project_id$jscomp$53$$=$props_83318_team$jscomp$95$$.projectId,$profile$jscomp$94$$=$props_83318_team$jscomp$95$$.profile,$team_id$jscomp$184$$=$props_83318_team$jscomp$95$$.teamId,$search_term$jscomp$8$$=$props_83318_team$jscomp$95$$.searchTerm,$plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$=$props_83318_team$jscomp$95$$.pluginUrl,$section$jscomp$45$$=$props_83318_team$jscomp$95$$.section,$template$jscomp$12_template__$1$jscomp$2$$=
$props_83318_team$jscomp$95$$.template;$props_83318_team$jscomp$95$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$);var $projects$jscomp$12$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$projects$$),$project$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($projects$jscomp$12$$,$project_id$jscomp$53$$),$projects__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects$jscomp$12$$),$APP.$rumext$v2$adapt$$($team_id$jscomp$184$$)],
function(){return $APP.$cljs$core$filterv$$(function($p1__83317_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($team_id$jscomp$184$$,$APP.$cljs$cst$1944$team_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83317_SHARP_$$))},$APP.$cljs$core$vals$$($projects$jscomp$12$$))}),$can_edit_QMARK_$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_83318_team$jscomp$95$$,$APP.$cljs$cst$1728$permissions$$),$APP.$cljs$cst$1601$can_edit$$);
$template$jscomp$12_template__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($template$jscomp$12_template__$1$jscomp$2$$)?$template$jscomp$12_template__$1$jscomp$2$$:$APP.$cljs$cst$2414$template$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$session$$);$plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$)?$plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$:$APP.$cljs$cst$6398$plugin_url$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$session$$);
var $default_project$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($projects__$1$jscomp$2$$)],function(){return $APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5017$is_default$$,$projects__$1$jscomp$2$$))});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6399$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts_dashboard$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$184$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$initialize$$($team_id$jscomp$184$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5021$app_DOT_main_DOT_data_DOT_dashboard_SLASH_finalize$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1944$team_id$$,$team_id$jscomp$184$$],null)))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){var $key$jscomp$432$$=$APP.$goog$events$listen$$($APP.$goog$global$$,"keydown",function($event$jscomp$780$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$780$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$780$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$open_selected_file$$())):null});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$432$$)}});$app$main$ui$dashboard$use_plugin_register$$($plugin_url$jscomp$5_plugin_url__$1$jscomp$1$$,
$team_id$jscomp$184$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($default_project$jscomp$3$$));$app$main$ui$dashboard$use_templates_import$$($can_edit_QMARK_$jscomp$17$$,$template$jscomp$12_template__$1$jscomp$2$$,$default_project$jscomp$3$$);$app$main$ui$dashboard$use_nitrate_entry_popup$$();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_project_id$$),{value:$project_id$jscomp$53$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,
{}),(0,$APP.$rumext$v2$jsxs$$)("main",{className:"main_ui_dashboard__dashboard",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$dashboard$sidebar$sidebar_STAR_$$,{team:$props_83318_team$jscomp$95$$,projects:$projects__$1$jscomp$2$$,project:$project$jscomp$44$$,defaultProject:$default_project$jscomp$3$$,profile:$profile$jscomp$94$$,section:$section$jscomp$45$$,searchTerm:$search_term$jscomp$8$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$dashboard_content_STAR_$$,{projects:$projects__$1$jscomp$2$$,
profile:$profile$jscomp$94$$,project:$project$jscomp$44$$,defaultProject:$default_project$jscomp$3$$,section:$section$jscomp$45$$,searchTerm:$search_term$jscomp$8$$,team:$props_83318_team$jscomp$95$$})]},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_83318_team$jscomp$95$$)??""))]})};$APP.$app$main$ui$dashboard$dashboard_page_STAR_$$=function($props_83328$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$dashboard$dashboard_STAR_$$,$props_83328$$)};
$cljs$cst$6395$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.projects","dashboard","app.main.ui.dashboard.projects/dashboard",-556856058);$cljs$cst$6377$search$$=new $APP.$cljs$core$Keyword$$(null,"search","search",1564939822);$cljs$cst$6378$get_all_projects$$=new $APP.$cljs$core$Keyword$$(null,"get-all-projects","get-all-projects",1718710818);
$cljs$cst$6385$can_restore$$=new $APP.$cljs$core$Keyword$$(null,"can-restore","can-restore",388064375);$cljs$cst$6376$is_default_team$$=new $APP.$cljs$core$Keyword$$(null,"is-default-team","is-default-team",1150636297);$cljs$cst$6396$app_DOT_main_DOT_ui_DOT_dashboard_DOT_templates_SLASH_collapsed$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.templates","collapsed","app.main.ui.dashboard.templates/collapsed",1868771256);
$cljs$cst$6399$app_DOT_main_DOT_ui_DOT_dashboard_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard","dashboard","app.main.ui.dashboard/dashboard",25877386);$cljs$cst$6380$thumbnails_SLASH_generate_for_file_wasm$$=new $APP.$cljs$core$Keyword$$("thumbnails","generate-for-file-wasm","thumbnails/generate-for-file-wasm",-1780261229);$cljs$cst$6387$has_files$$=new $APP.$cljs$core$Keyword$$(null,"has-files","has-files",-150994558);
$cljs$cst$6384$limit$$=new $APP.$cljs$core$Keyword$$(null,"limit","limit",-1355822363);$cljs$cst$6386$create_fn$$=new $APP.$cljs$core$Keyword$$(null,"create-fn","create-fn",-1596040813);$cljs$cst$6382$file_if$$=new $APP.$cljs$core$Keyword$$(null,"file-if","file-if",-1983487897);$cljs$cst$6389$font_family_tmp$$=new $APP.$cljs$core$Keyword$$(null,"font-family-tmp","font-family-tmp",1518875480);
$cljs$cst$6381$thumbnails_SLASH_generate_for_file$$=new $APP.$cljs$core$Keyword$$("thumbnails","generate-for-file","thumbnails/generate-for-file",-1533672464);$cljs$cst$6393$app_DOT_main_DOT_ui_DOT_dashboard_DOT_libraries_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.libraries","dashboard","app.main.ui.dashboard.libraries/dashboard",-1567324353);$cljs$cst$6383$sample$$=new $APP.$cljs$core$Keyword$$(null,"sample","sample",79023601);
$cljs$cst$6390$download_font_family$$=new $APP.$cljs$core$Keyword$$(null,"download-font-family","download-font-family",249288215);$cljs$cst$6394$app_DOT_main_DOT_ui_DOT_dashboard_DOT_projects_SLASH_show_team_hero$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.projects","show-team-hero","app.main.ui.dashboard.projects/show-team-hero",-741317864);
$cljs$cst$6388$app_DOT_main_DOT_ui_DOT_dashboard_DOT_files_SLASH_dashboard$$=new $APP.$cljs$core$Keyword$$("app.main.ui.dashboard.files","dashboard","app.main.ui.dashboard.files/dashboard",1600474145);$cljs$cst$6391$download_font$$=new $APP.$cljs$core$Keyword$$(null,"download-font","download-font",-652313214);$cljs$cst$6392$providers$$=new $APP.$cljs$core$Keyword$$(null,"providers","providers",543153826);var $app$main$ui$components$progress$neutral_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_components_progress__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-msg-neutral"})}),$app$main$ui$components$progress$error_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_components_progress__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-delete-text"})}),$app$main$ui$components$progress$close_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",
{width:500,className:"main_ui_components_progress__close-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})});$APP.$app$common$logging$loggers$$.set("app.main.ui.dashboard.grid",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1160$debug$$));var $app$main$ui$dashboard$grid$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_grid__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});var $app$main$ui$dashboard$deleted$ref_COLON_deleted_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5038$deleted_files$$,$APP.$app$main$store$state$$),$app$main$ui$dashboard$deleted$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_deleted__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});var $app$main$ui$dashboard$pin_button$pin_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_pin_button__icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pin"})});var $app$main$ui$dashboard$files$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_files__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})});var $app$common$types$font$font_family_re$$=RegExp("[\\p{L}\\d _.-]+","u"),$app$common$types$font$schema_COLON_font_family$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null),new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,"errors.font-family-invalid-chars"],null),function($s$jscomp$615$$){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$re_matches$$($app$common$types$font$font_family_re$$,$s$jscomp$615$$))}],null)],null);var $app$main$ui$dashboard$fonts$accept_font_types$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$app$common$media$font_types$$)),",.ttf,application/font-woff,.woff,.woff2,.otf"].join(""),$app$main$ui$dashboard$fonts$header_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_83137$$){$app$main$ui$dashboard$fonts$use_page_title$$($props_83137$$.team,$props_83137$$.section);return(0,$APP.$rumext$v2$jsx$$)("header",
{"data-testid":"dashboard-header",className:"main_ui_dashboard_fonts__dashboard-header",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-fonts-title",className:"main_ui_dashboard_fonts__dashboard-title",children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.fonts")})})})}),$app$main$ui$dashboard$fonts$installed_font_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($menu_open_QMARK_$jscomp$4_props_83206$$){var $variants$jscomp$11$$=
$menu_open_QMARK_$jscomp$4_props_83206$$.variants,$font_id$jscomp$41$$=$menu_open_QMARK_$jscomp$4_props_83206$$.fontId,$can_edit$jscomp$16$$=$menu_open_QMARK_$jscomp$4_props_83206$$.canEdit,$font$jscomp$59$$=$APP.$cljs$core$first$$($variants$jscomp$11$$),$menu_open_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$menu_open_QMARK_$jscomp$4_props_83206$$=$APP.$cljs$core$_deref$$($menu_open_STAR_$jscomp$2$$);var $edition_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$edition_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($edition_STAR_$jscomp$3$$),$state_STAR_$jscomp$26$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$59$$)),$font_family$jscomp$11$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$26$$),$variants__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants$jscomp$11$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$149$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$149$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("normal",$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$149$$))?1:2],null)},$variants$jscomp$11$$)}),$on_change$jscomp$103$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$763$$){return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$26$$,(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$763$$))}),
$on_edit$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$3$$,!0)}),$on_menu_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$2$$,!0)}),$on_menu_close$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$2$$,!1)}),$on_save$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_family$jscomp$11$$)],function(){$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$3$$,!1);return $APP.$cuerdas$core$blank_QMARK_$$($font_family$jscomp$11$$)?null:$APP.$cljs$core$truth_$$($APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($app$common$types$font$schema_COLON_font_family$$,$font_family$jscomp$11$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$update_font$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$font_id$jscomp$41$$,$APP.$cljs$cst$725$name$$,$font_family$jscomp$11$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.font-family-invalid-chars")))}),$on_key_down$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_save$jscomp$4$$)],function($event$jscomp$764$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$764$$))?
$on_save$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_save$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$764$$):$on_save$jscomp$4$$($event$jscomp$764$$):null}),$on_cancel$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$3$$,!1);return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$26$$,$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$59$$))}),$on_delete_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_id$jscomp$41$$)],
function(){var $options$jscomp$648$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font.message"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),$APP.$cljs$cst$2490$on_accept$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$delete_font$$($font_id$jscomp$41$$))}],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($options$jscomp$648$$))}),$on_download$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants__$1$$)],function(){var $variant$jscomp$30_variant_id$jscomp$56$$=
$APP.$cljs$core$first$$($variants__$1$$);$variant$jscomp$30_variant_id$jscomp$56$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$30_variant_id$jscomp$56$$);var $multiple_QMARK_$jscomp$11$$=$APP.$cljs$core$count$$($variants__$1$$)>1;return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($blob$jscomp$41_p__83213$$){var $filename$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blob$jscomp$41_p__83213$$,0,null);$blob$jscomp$41_p__83213$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blob$jscomp$41_p__83213$$,1,null);return $APP.$app$util$dom$trigger_download$$($filename$jscomp$15$$,$blob$jscomp$41_p__83213$$)},function($error$jscomp$154$$){console.error("error downloading font",$error$jscomp$154$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")))},$APP.$beicon$v2$core$mapcat$$(function($map__83218__$1_p__83217_uri$jscomp$114$$){$map__83218__$1_p__83217_uri$jscomp$114$$=
$APP.$cljs$core$__destructure_map$$($map__83218__$1_p__83217_uri$jscomp$114$$);var $name$jscomp$509$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83218__$1_p__83217_uri$jscomp$114$$,$APP.$cljs$cst$725$name$$);$map__83218__$1_p__83217_uri$jscomp$114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83218__$1_p__83217_uri$jscomp$114$$,$APP.$cljs$cst$1584$uri$$);return $APP.$beicon$v2$core$map$$(function($blob$jscomp$42$$){return new $APP.$cljs$core$MapEntry$$($name$jscomp$509$$,
$blob$jscomp$42$$,null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1586$body$$,$APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1584$uri$$,$map__83218__$1_p__83217_uri$jscomp$114$$,$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$1596$blob$$],null))))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($multiple_QMARK_$jscomp$11$$?$cljs$cst$6390$download_font_family$$:$cljs$cst$6391$download_font$$,
$multiple_QMARK_$jscomp$11$$?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1763$font_id$$,$font_id$jscomp$41$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$variant$jscomp$30_variant_id$jscomp$56$$],null))))}),$on_delete_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$765_options$jscomp$649$$){var $id$jscomp$1076$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$765_options$jscomp$649$$),
"id"));$event$jscomp$765_options$jscomp$649$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font-variant.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-font-variant.message"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$delete_font_variant$$($id$jscomp$1076$$))}],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($event$jscomp$765_options$jscomp$649$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__font-item main_ui_dashboard_fonts__table-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__family "+($APP.$cljs$core$truth_$$($edition_QMARK_$jscomp$4$$)?"main_ui_dashboard_fonts__is-edition":""),children:$edition_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",autoFocus:!0,defaultValue:$font_family$jscomp$11$$,onKeyDown:$on_key_down$jscomp$32$$,onChange:$on_change$jscomp$103$$}):(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$59$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__variants",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$253$$,$map__83225__$1_p__83224$$){$map__83225__$1_p__83224$$=$APP.$cljs$core$__destructure_map$$($map__83225__$1_p__83224$$);var $id$jscomp$1077$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83225__$1_p__83224$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$253$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_fonts__variant "+($APP.$cljs$core$not$$($can_edit$jscomp$16$$)?"main_ui_dashboard_fonts__inhert-variant":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_dashboard_fonts__label",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$font_variant_display_name_STAR_$$,{variant:$map__83225__$1_p__83224$$})}),$APP.$cljs$core$truth_$$($can_edit$jscomp$16$$)?(0,$APP.$rumext$v2$jsx$$)("span",{"data-id":""+($id$jscomp$1077$$??""),onClick:$on_delete_variant$$,
className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__close",children:$APP.$app$main$ui$icons$add$$}):null]},""+($id$jscomp$1077$$??"")));return $out_arr__44092__auto__$jscomp$253$$},[],$variants__$1$$)}),$edition_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cuerdas$core$blank_QMARK_$$($font_family$jscomp$11$$),onClick:$on_save$jscomp$4$$,
className:"main_ui_dashboard_fonts__btn-primary "+($APP.$cuerdas$core$blank_QMARK_$$($font_family$jscomp$11$$)?"main_ui_dashboard_fonts__btn-disabled":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_cancel$jscomp$10$$,className:"main_ui_dashboard_fonts__icon main_ui_dashboard_fonts__close",children:$APP.$app$main$ui$icons$close$$})]}):$APP.$cljs$core$truth_$$($can_edit$jscomp$16$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_fonts__table-field main_ui_dashboard_fonts__options",children:[(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$on_menu_open$$,className:"main_ui_dashboard_fonts__icon",children:$APP.$app$main$ui$icons$menu$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$fonts$installed_font_context_menu_STAR_$$,{onClose:$on_menu_close$jscomp$6$$,isOpen:$menu_open_QMARK_$jscomp$4_props_83206$$,onDelete:$on_delete_font$$,onDownload:$on_download$jscomp$4$$,onEdit:$on_edit$jscomp$17$$})]}):
null]})}),$app$main$ui$dashboard$fonts$ref_COLON_fonts$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2980$fonts$$,$APP.$app$main$store$state$$);var $app$main$ui$dashboard$libraries$ref_COLON_selected_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($files$jscomp$45_state$jscomp$1253$$){var $selected$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$45_state$jscomp$1253$$,$APP.$cljs$cst$2191$selected_files$$);$files$jscomp$45_state$jscomp$1253$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$45_state$jscomp$1253$$,$APP.$cljs$cst$2187$shared_files$$);return $APP.$app$main$refs$extract_selected_files$$($files$jscomp$45_state$jscomp$1253$$,
$selected$jscomp$218$$)},$APP.$app$main$store$state$$);var $app$main$ui$dashboard$projects$show_more_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_projects__show-more-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})}),$app$main$ui$dashboard$projects$close_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_projects__close-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-close"})}),$app$main$ui$dashboard$projects$add_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",
{width:500,className:"main_ui_dashboard_projects__add-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})}),$app$main$ui$dashboard$projects$menu_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_projects__menu-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-menu"})}),$app$main$ui$dashboard$projects$header_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($can_edit$jscomp$20_props_83207$$){$can_edit$jscomp$20_props_83207$$=
$can_edit$jscomp$20_props_83207$$.canEdit;var $on_click$jscomp$66$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$dashboard$create_project$$())});return(0,$APP.$rumext$v2$jsxs$$)("header",{"data-testid":"dashboard-header",className:"main_ui_dashboard_projects__dashboard-header",children:[(0,$APP.$rumext$v2$jsx$$)("div",{id:"dashboard-projects-title",className:"main_ui_dashboard_projects__dashboard-title",
children:(0,$APP.$rumext$v2$jsx$$)("h1",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.projects-title")})}),$APP.$cljs$core$truth_$$($can_edit$jscomp$20_props_83207$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_click$jscomp$66$$,"data-testid":"new-project-button",className:"main_ui_dashboard_projects__btn-secondary main_ui_dashboard_projects__btn-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.new-project")}):null]})}),$app$main$ui$dashboard$projects$team_hero_STAR_$$=
$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_nav_members_click_props_83210$$){var $on_close$jscomp$48$$=$on_nav_members_click_props_83210$$.onClose,$team$jscomp$90$$=$on_nav_members_click_props_83210$$.team;$on_nav_members_click_props_83210$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_dashboard_members$$())});var $on_invite$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$90$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$check_and_invite_members$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$90$$),$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$5251$hero$$],null)))}),$on_close_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$48$$)],function($event$jscomp$767$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$767$$);
return $on_close$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$on_close$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$767$$):$on_close$jscomp$48$$($event$jscomp$767$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__team-hero",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_projects__img-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/deco-team-banner.png",border:"0",role:"presentation"})}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_dashboard_projects__text",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_dashboard_projects__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dasboard.team-hero.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_dashboard_projects__info",children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dasboard.team-hero.text")}),(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$on_nav_members_click_props_83210$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dasboard.team-hero.management")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_invite$$,className:"main_ui_dashboard_projects__btn-primary main_ui_dashboard_projects__invite",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("onboarding.choice.team-up.invite-members")})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close_SINGLEQUOTE_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
className:"main_ui_dashboard_projects__close",children:$app$main$ui$dashboard$projects$close_icon$$})]})}),$app$main$ui$dashboard$projects$ref_COLON_recent_files$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5029$recent_files$$,$APP.$app$main$store$state$$);var $app$main$ui$dashboard$search$ref_COLON_search_result$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5026$search_result$$,$APP.$app$main$store$state$$),$app$main$ui$dashboard$search$ref_COLON_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1254$$){var $files$jscomp$49$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$cst$5026$search_result$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1254$$));
return $APP.$app$main$refs$extract_selected_files$$($files$jscomp$49$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1254$$,$APP.$cljs$cst$2191$selected_files$$))},$APP.$app$main$store$state$$);var $app$main$ui$dashboard$templates$arrow_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_templates__arrow-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-arrow"})}),$app$main$ui$dashboard$templates$download_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_dashboard_templates__download-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})}),$app$main$ui$dashboard$templates$builtin_templates$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5033$builtin_templates$$,
$APP.$app$main$store$state$$);
//# sourceMappingURL=main-dashboard.js.map
