import { $APP, shadow$provide } from "./shared.js";
import "./main-auth.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$viewer$comments$update_thread_position$$,$app$main$data$common$share_link_created$$,$app$main$data$viewer$set_viewport_size$$,$app$main$data$viewer$exit_fullscreen$$,$app$main$data$viewer$toggle_selection$$,$app$main$data$viewer$complete_animation$$,$app$main$data$viewer$finalize$$,$app$main$data$viewer$reset_nav_scroll$$,$app$main$data$viewer$hover_shape$$,
$app$main$data$viewer$toggle_collapse$$,$app$main$data$common$create_share_link$$,$app$main$data$common$delete_share_link$$,$app$main$data$comments$created_thread_on_viewer$$,$app$render_wasm$api$process_pending_no_sideffects$$,$app$main$data$viewer$fetch_comment_threads$$,$app$main$ui$inspect$selection_feedback$selection_rect$$,$app$main$data$comments$create_thread_on_viewer$$,$app$main$ui$viewer$interactions$animate_close_overlay$$,$app$main$ui$viewer$interactions$animate_open_overlay$$,$app$main$ui$viewer$interactions$animate_go_to_frame$$,
$app$util$dom$fullscreen_QMARK_$$,$app$util$webapi$exit_fullscreen$$,$app$util$webapi$request_fullscreen$$,$app$main$ui$inspect$selection_feedback$selection_feedback$$,$app$main$data$viewer$select_shape$$,$app$main$data$viewer$shift_select_to$$,$app$main$data$viewer$go_to_frame_auto$$,$app$main$data$viewer$go_to_frame$$,$app$main$data$viewer$generate_update_position_data_changes$$,$app$render_wasm$api$set_objects_callback$$,$app$main$data$viewer$apply_changes_viewer$$,$app$main$data$viewer$update_page_position_data$$,
$app$main$data$viewer$bundle_fetched$$,$app$main$data$viewer$fetch_bundle$$,$app$main$data$viewer$initialize$$,$app$main$ui$viewer$comments$comments_layer$$,$app$main$ui$viewer$comments$comments_sidebar_STAR_$$,$app$main$ui$inspect$left_sidebar$make_collapsed_iref$$,$app$main$ui$inspect$left_sidebar$left_sidebar$$,$app$main$ui$inspect$render$handle_hover_shape$$,$app$main$ui$inspect$render$select_shape$$,$app$main$ui$inspect$render$shape_wrapper_factory$$,$app$main$ui$inspect$render$frame_container_factory$$,
$app$main$ui$inspect$render$group_container_factory$$,$app$main$ui$inspect$render$bool_container_factory$$,$app$main$ui$inspect$render$svg_raw_container_factory$$,$app$main$ui$inspect$render$shape_container_factory$$,$app$main$ui$inspect$render$render_frame_svg$$,$app$main$ui$viewer$inspect$handle_select_frame$$,$app$main$ui$viewer$inspect$viewport$$,$app$main$ui$viewer$login$login_register_modal$$,$app$main$ui$viewer$share_link$prepare_params$$,$app$main$ui$viewer$share_link$share_link_dialog$$,
$app$main$ui$viewer$thumbnails$thumbnails_content_STAR_$$,$app$main$ui$viewer$thumbnails$thumbnails_summary_STAR_$$,$app$main$ui$viewer$thumbnails$thumbnails_panel_STAR_$$,$app$main$ui$viewer$calculate_size$$,$app$main$ui$viewer$calculate_delta$$,$app$main$ui$viewer$calculate_wrapper$$,$app$main$ui$viewer$viewer_pagination$$,$app$main$ui$viewer$viewer_overlay$$,$app$main$ui$viewer$viewer_wrapper$$,$app$main$ui$viewer$viewer_content_STAR_$$,$app$main$ui$viewer$viewer_STAR_$$,$app$main$data$common$share_link_created_52498$$,
$app$main$data$common$create_share_link_52535$$,$app$main$data$common$delete_share_link_52566$$,$app$main$data$comments$created_thread_on_viewer_55835$$,$app$main$data$comments$create_thread_on_viewer_55858$$,$app$main$data$viewer$initialize_74306$$,$app$main$data$viewer$finalize_74319$$,$app$main$data$viewer$fetch_bundle_74330$$,$app$main$data$viewer$apply_changes_viewer_74367$$,$app$main$data$viewer$update_page_position_data_74389$$,$app$main$data$viewer$bundle_fetched_74403$$,$app$main$data$viewer$fetch_comment_threads_74440$$,
$app$main$data$viewer$exit_fullscreen_74563$$,$app$main$data$viewer$set_viewport_size_74572$$,$app$main$data$viewer$reset_nav_scroll_74644$$,$app$main$data$viewer$complete_animation_74718$$,$app$main$data$viewer$go_to_frame_auto_74918$$,$app$main$data$viewer$select_shape_74992$$,$app$main$data$viewer$toggle_selection_74995$$,$app$main$data$viewer$shift_select_to_75002$$,$app$main$data$viewer$toggle_collapse_75015$$,$app$main$data$viewer$hover_shape_75018$$,$cljs$cst$6427$left_bar$$,$cljs$cst$6421$email_sent$$,
$cljs$cst$6428$right_bar$$,$cljs$cst$6423$all_pages$$,$cljs$cst$6422$pages_mode$$,$cljs$cst$6426$num_frames$$,$cljs$cst$6420$register$$,$cljs$cst$6425$can_inspect_code$$,$cljs$cst$6431$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer$$,$cljs$cst$6430$wrapper_size$$,$cljs$cst$6429$comment_sidebar$$,$cljs$cst$6418$hide_toggle_QMARK_$$,$cljs$cst$6417$component_child_QMARK_$$,$cljs$cst$6424$can_comment$$,$cljs$cst$6416$item$$,$cljs$cst$6419$viewer_pagination$$;
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$=function($animation_item$jscomp$38$$,$keyframes$jscomp$2$$,$duration$jscomp$3$$,$onfinish$$){$animation_item$jscomp$38$$=$animation_item$jscomp$38$$.animate($keyframes$jscomp$2$$,$duration$jscomp$3$$);return $APP.$cljs$core$truth_$$($onfinish$$)?$animation_item$jscomp$38$$.onfinish=$onfinish$$:null};
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($item$jscomp$37$$,$keyframes$jscomp$1$$,$duration$jscomp$2$$){return $app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($item$jscomp$37$$,$keyframes$jscomp$1$$,$duration$jscomp$2$$,null)};
$app$main$ui$viewer$comments$update_thread_position$$=function($positions$jscomp$3_temp__5823__auto__$jscomp$209$$,$map__75671__$1_p__75670$$){$map__75671__$1_p__75670$$=$APP.$cljs$core$__destructure_map$$($map__75671__$1_p__75670$$);var $id$jscomp$920$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75671__$1_p__75670$$,$APP.$cljs$cst$266$id$$);$positions$jscomp$3_temp__5823__auto__$jscomp$209$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($positions$jscomp$3_temp__5823__auto__$jscomp$209$$,
$id$jscomp$920$$);return $APP.$cljs$core$truth_$$($positions$jscomp$3_temp__5823__auto__$jscomp$209$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__75671__$1_p__75670$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($positions$jscomp$3_temp__5823__auto__$jscomp$209$$)),$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($positions$jscomp$3_temp__5823__auto__$jscomp$209$$)):
$map__75671__$1_p__75670$$};
$app$main$data$common$share_link_created$$=function($link$jscomp$5$$){typeof $app$main$data$common$share_link_created_52498$$==="undefined"&&($app$main$data$common$share_link_created_52498$$=function($link$jscomp$6$$,$meta52499$$){this.link=$link$jscomp$6$$;this.$meta52499$=$meta52499$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$share_link_created_52498$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$share_link_created_52498$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2476$app_DOT_main_DOT_data_DOT_common_SLASH_share_link_created$$},$app$main$data$common$share_link_created_52498$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52500$$,$meta52499__$1$$){return new $app$main$data$common$share_link_created_52498$$(this.link,$meta52499__$1$$)},$app$main$data$common$share_link_created_52498$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52499$},$app$main$data$common$share_link_created_52498$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$share_link_created_52498$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1534$$,$state$jscomp$119$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$119$$,$APP.$cljs$cst$2184$share_links$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),this.link)});return new $app$main$data$common$share_link_created_52498$$($link$jscomp$5$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$set_viewport_size$$=function($p__74570$$){var $map__74571__$1$$=$APP.$cljs$core$__destructure_map$$($p__74570$$),$size$jscomp$139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74571__$1$$,$APP.$cljs$cst$874$size$$);typeof $app$main$data$viewer$set_viewport_size_74572$$==="undefined"&&($app$main$data$viewer$set_viewport_size_74572$$=function($p__74570$jscomp$1$$,$map__74571$jscomp$1$$,$size$jscomp$140$$,$meta74573$$){this.$p__74570$=$p__74570$jscomp$1$$;this.$map__74571$=
$map__74571$jscomp$1$$;this.size=$size$jscomp$140$$;this.$meta74573$=$meta74573$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$set_viewport_size_74572$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_viewport_size_74572$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5369$app_DOT_main_DOT_data_DOT_viewer_SLASH_set_viewport_size$$},$app$main$data$viewer$set_viewport_size_74572$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_74574$$,$meta74573__$1$$){return new $app$main$data$viewer$set_viewport_size_74572$$(this.$p__74570$,this.$map__74571$,this.size,$meta74573__$1$$)},$app$main$data$viewer$set_viewport_size_74572$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74573$},$app$main$data$viewer$set_viewport_size_74572$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$set_viewport_size_74572$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2927$$,$state$jscomp$1128$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1128$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$5363$viewport_size$$],null),this.size)});return new $app$main$data$viewer$set_viewport_size_74572$$($p__74570$$,$map__74571__$1$$,$size$jscomp$139$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$exit_fullscreen$$=function(){typeof $app$main$data$viewer$exit_fullscreen_74563$$==="undefined"&&($app$main$data$viewer$exit_fullscreen_74563$$=function($meta74564$$){this.$meta74564$=$meta74564$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$exit_fullscreen_74563$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$exit_fullscreen_74563$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5368$app_DOT_main_DOT_data_DOT_viewer_SLASH_exit_fullscreen$$},$app$main$data$viewer$exit_fullscreen_74563$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74565$$,$meta74564__$1$$){return new $app$main$data$viewer$exit_fullscreen_74563$$($meta74564__$1$$)},$app$main$data$viewer$exit_fullscreen_74563$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74564$},$app$main$data$viewer$exit_fullscreen_74563$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$exit_fullscreen_74563$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2926$$,$state$jscomp$1127$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1127$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$2242$fullscreen_QMARK_$$],null),!1)});return new $app$main$data$viewer$exit_fullscreen_74563$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$toggle_selection$$=function($id$jscomp$903$$){typeof $app$main$data$viewer$toggle_selection_74995$$==="undefined"&&($app$main$data$viewer$toggle_selection_74995$$=function($id$jscomp$904$$,$meta74996$$){this.id=$id$jscomp$904$$;this.$meta74996$=$meta74996$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$toggle_selection_74995$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_selection_74995$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5400$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_selection$$},$app$main$data$viewer$toggle_selection_74995$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74997$$,$meta74996__$1$$){return new $app$main$data$viewer$toggle_selection_74995$$(this.id,$meta74996__$1$$)},$app$main$data$viewer$toggle_selection_74995$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74996$},$app$main$data$viewer$toggle_selection_74995$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_selection_74995$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2957_selected$jscomp$135$$,$G__75001__$1_state$jscomp$1158$$){$_$jscomp$2957_selected$jscomp$135$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__75001__$1_state$jscomp$1158$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$1938$selected$$],
null));$G__75001__$1_state$jscomp$1158$$=$APP.$cljs$core$not$$($_$jscomp$2957_selected$jscomp$135$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$2957_selected$jscomp$135$$.$cljs$core$IFn$_invoke$arity$1$(this.id):$_$jscomp$2957_selected$jscomp$135$$(this.id))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__75001__$1_state$jscomp$1158$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$1938$selected$$],
null),$APP.$cljs$core$conj$$,this.id):$G__75001__$1_state$jscomp$1158$$;return $APP.$cljs$core$truth_$$($_$jscomp$2957_selected$jscomp$135$$.$cljs$core$IFn$_invoke$arity$1$?$_$jscomp$2957_selected$jscomp$135$$.$cljs$core$IFn$_invoke$arity$1$(this.id):$_$jscomp$2957_selected$jscomp$135$$(this.id))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__75001__$1_state$jscomp$1158$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,
$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$disj$$,this.id):$G__75001__$1_state$jscomp$1158$$});return new $app$main$data$viewer$toggle_selection_74995$$($id$jscomp$903$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$complete_animation$$=function(){typeof $app$main$data$viewer$complete_animation_74718$$==="undefined"&&($app$main$data$viewer$complete_animation_74718$$=function($meta74719$$){this.$meta74719$=$meta74719$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$complete_animation_74718$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$complete_animation_74718$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5385$app_DOT_main_DOT_data_DOT_viewer_SLASH_complete_animation$$},$app$main$data$viewer$complete_animation_74718$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74720$$,$meta74719__$1$$){return new $app$main$data$viewer$complete_animation_74718$$($meta74719__$1$$)},$app$main$data$viewer$complete_animation_74718$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74719$},$app$main$data$viewer$complete_animation_74718$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$complete_animation_74718$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2943$$,$state$jscomp$1143$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1143$$,$APP.$cljs$cst$5374$viewer_animations$$)});return new $app$main$data$viewer$complete_animation_74718$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$finalize$$=function($_$jscomp$2906$$){typeof $app$main$data$viewer$finalize_74319$$==="undefined"&&($app$main$data$viewer$finalize_74319$$=function($_$jscomp$2907$$,$meta74320$$){this.$_$=$_$jscomp$2907$$;this.$meta74320$=$meta74320$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$finalize_74319$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$finalize_74319$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5345$app_DOT_main_DOT_data_DOT_viewer_SLASH_finalize$$},$app$main$data$viewer$finalize_74319$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74321$$,$meta74320__$1$$){return new $app$main$data$viewer$finalize_74319$$(this.$_$,$meta74320__$1$$)},$app$main$data$viewer$finalize_74319$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74320$},$app$main$data$viewer$finalize_74319$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$finalize_74319$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($___$1$jscomp$2029$$,$state$jscomp$1111$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1111$$,$APP.$cljs$cst$1597$viewer$$)});return new $app$main$data$viewer$finalize_74319$$($_$jscomp$2906$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$reset_nav_scroll$$=function(){typeof $app$main$data$viewer$reset_nav_scroll_74644$$==="undefined"&&($app$main$data$viewer$reset_nav_scroll_74644$$=function($meta74645$$){this.$meta74645$=$meta74645$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$reset_nav_scroll_74644$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$reset_nav_scroll_74644$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5382$app_DOT_main_DOT_data_DOT_viewer_SLASH_reset_nav_scroll$$},$app$main$data$viewer$reset_nav_scroll_74644$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74646$$,$meta74645__$1$$){return new $app$main$data$viewer$reset_nav_scroll_74644$$($meta74645__$1$$)},$app$main$data$viewer$reset_nav_scroll_74644$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74645$},$app$main$data$viewer$reset_nav_scroll_74644$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$reset_nav_scroll_74644$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2941$$,$state$jscomp$1141$$){return $APP.$app$common$data$dissoc_in$$($state$jscomp$1141$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$5381$nav_scroll$$],null))});return new $app$main$data$viewer$reset_nav_scroll_74644$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$hover_shape$$=function($id$jscomp$909$$,$hover_QMARK_$jscomp$4$$){typeof $app$main$data$viewer$hover_shape_75018$$==="undefined"&&($app$main$data$viewer$hover_shape_75018$$=function($id$jscomp$910$$,$hover_QMARK_$jscomp$5$$,$meta75019$$){this.id=$id$jscomp$910$$;this.$hover_QMARK_$=$hover_QMARK_$jscomp$5$$;this.$meta75019$=$meta75019$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$hover_shape_75018$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$hover_shape_75018$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5404$app_DOT_main_DOT_data_DOT_viewer_SLASH_hover_shape$$},$app$main$data$viewer$hover_shape_75018$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_75020$$,$meta75019__$1$$){return new $app$main$data$viewer$hover_shape_75018$$(this.id,this.$hover_QMARK_$,$meta75019__$1$$)},$app$main$data$viewer$hover_shape_75018$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta75019$},$app$main$data$viewer$hover_shape_75018$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$hover_shape_75018$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2961$$,$state$jscomp$1162$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1162$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$2212$hover$$],
null),$APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?this.id:null)});return new $app$main$data$viewer$hover_shape_75018$$($id$jscomp$909$$,$hover_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$toggle_collapse$$=function($id$jscomp$907$$){typeof $app$main$data$viewer$toggle_collapse_75015$$==="undefined"&&($app$main$data$viewer$toggle_collapse_75015$$=function($id$jscomp$908$$,$meta75016$$){this.id=$id$jscomp$908$$;this.$meta75016$=$meta75016$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$toggle_collapse_75015$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_collapse_75015$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5403$app_DOT_main_DOT_data_DOT_viewer_SLASH_toggle_collapse$$},$app$main$data$viewer$toggle_collapse_75015$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_75017$$,$meta75016__$1$$){return new $app$main$data$viewer$toggle_collapse_75015$$(this.id,$meta75016__$1$$)},$app$main$data$viewer$toggle_collapse_75015$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta75016$},$app$main$data$viewer$toggle_collapse_75015$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$toggle_collapse_75015$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2960_toggled_QMARK_$$,$state$jscomp$1161$$){$_$jscomp$2960_toggled_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1161$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$2056$collapsed$$],
null)),this.id);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1161$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$2056$collapsed$$],null),$_$jscomp$2960_toggled_QMARK_$$?$APP.$cljs$core$disj$$:$APP.$cljs$core$conj$$,this.id)});return new $app$main$data$viewer$toggle_collapse_75015$$($id$jscomp$907$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$create_share_link$$=function($params$jscomp$145$$){typeof $app$main$data$common$create_share_link_52535$$==="undefined"&&($app$main$data$common$create_share_link_52535$$=function($params$jscomp$146$$,$meta52536$$){this.params=$params$jscomp$146$$;this.$meta52536$=$meta52536$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$create_share_link_52535$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$create_share_link_52535$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2477$app_DOT_main_DOT_data_DOT_common_SLASH_create_share_link$$},$app$main$data$common$create_share_link_52535$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52537$$,$meta52536__$1$$){return new $app$main$data$common$create_share_link_52535$$(this.params,$meta52536__$1$$)},$app$main$data$common$create_share_link_52535$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta52536$},$app$main$data$common$create_share_link_52535$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$create_share_link_52535$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$common$share_link_created$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2478$create_share_link$$,this.params))});return new $app$main$data$common$create_share_link_52535$$($params$jscomp$145$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$delete_share_link$$=function($p__52562$$){var $map__52563__$1$$=$APP.$cljs$core$__destructure_map$$($p__52562$$),$id$jscomp$241$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__52563__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$common$delete_share_link_52566$$==="undefined"&&($app$main$data$common$delete_share_link_52566$$=function($p__52562$jscomp$1$$,$map__52563$jscomp$1$$,$link$jscomp$8$$,$id$jscomp$242$$,$meta52567$$){this.$p__52562$=$p__52562$jscomp$1$$;
this.$map__52563$=$map__52563$jscomp$1$$;this.link=$link$jscomp$8$$;this.id=$id$jscomp$242$$;this.$meta52567$=$meta52567$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$delete_share_link_52566$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$delete_share_link_52566$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2479$app_DOT_main_DOT_data_DOT_common_SLASH_delete_share_link$$},
$app$main$data$common$delete_share_link_52566$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52568$$,$meta52567__$1$$){return new $app$main$data$common$delete_share_link_52566$$(this.$p__52562$,this.$map__52563$,this.link,this.id,$meta52567__$1$$)},$app$main$data$common$delete_share_link_52566$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52567$},$app$main$data$common$delete_share_link_52566$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$common$delete_share_link_52566$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1536$$,$state$jscomp$120$$){var $self__$jscomp$3285$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$120$$,$APP.$cljs$cst$2184$share_links$$,function($links$jscomp$2$$){return $APP.$cljs$core$filterv$$(function($p1__52560_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3285$$.id,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__52560_SHARP_$$))},
$links$jscomp$2$$)})},$app$main$data$common$delete_share_link_52566$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$delete_share_link_52566$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2480$delete_share_link$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$common$delete_share_link_52566$$($p__52562$$,
$map__52563__$1$$,$map__52563__$1$$,$id$jscomp$241$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$comments$created_thread_on_viewer$$=function($p__55832$$){var $map__55833__$1$$=$APP.$cljs$core$__destructure_map$$($p__55832$$),$id$jscomp$426$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55833__$1$$,$APP.$cljs$cst$266$id$$),$comment$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55833__$1$$,$APP.$cljs$cst$3485$comment$$),$page_id$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55833__$1$$,$APP.$cljs$cst$2051$page_id$$);
typeof $app$main$data$comments$created_thread_on_viewer_55835$$==="undefined"&&($app$main$data$comments$created_thread_on_viewer_55835$$=function($p__55832$jscomp$1$$,$map__55833$jscomp$1$$,$thread$jscomp$4$$,$id$jscomp$427$$,$comment$jscomp$3$$,$page_id$jscomp$95$$,$meta55836$$){this.$p__55832$=$p__55832$jscomp$1$$;this.$map__55833$=$map__55833$jscomp$1$$;this.thread=$thread$jscomp$4$$;this.id=$id$jscomp$427$$;this.comment=$comment$jscomp$3$$;this.$page_id$=$page_id$jscomp$95$$;this.$meta55836$=
$meta55836$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3494$app_DOT_main_DOT_data_DOT_comments_SLASH_created_thread_on_viewer$$},$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_55837$$,$meta55836__$1$$){return new $app$main$data$comments$created_thread_on_viewer_55835$$(this.$p__55832$,this.$map__55833$,this.thread,this.id,this.comment,this.$page_id$,$meta55836__$1$$)},$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55836$},$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$1810_position$jscomp$63$$,$state$jscomp$259$$){$_$jscomp$1810_position$jscomp$63$$=$APP.$cljs$core$select_keys$$(this.thread,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1612$frame_id$$],null));return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$259$$,
$APP.$cljs$cst$2183$comment_threads$$,$APP.$cljs$core$assoc$$,this.id,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.thread,$APP.$cljs$cst$3485$comment$$)),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1597$viewer$$,$APP.$cljs$cst$2236$pages$$,this.$page_id$,$APP.$cljs$cst$2069$comment_thread_positions$$],null),$APP.$cljs$core$assoc$$,this.id,$_$jscomp$1810_position$jscomp$63$$),$APP.$cljs$cst$2241$comments_local$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$3487$open$$,this.id),$APP.$cljs$cst$2241$comments_local$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$873$options$$,null),$APP.$cljs$cst$2241$comments_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3488$draft$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3489$comments$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.comment),this.comment)},$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$created_thread_on_viewer_55835$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-comment-thread",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$3490$content_size$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$(this.comment))],null)))});return new $app$main$data$comments$created_thread_on_viewer_55835$$($p__55832$$,$map__55833__$1$$,$map__55833__$1$$,$id$jscomp$426$$,$comment$jscomp$2$$,$page_id$jscomp$94$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$render_wasm$api$process_pending_no_sideffects$$=function($pending_thumbnails$jscomp$3_thumbnails$jscomp$6$$,$full$jscomp$6_pending_full$jscomp$3$$,$on_complete$jscomp$2$$){$pending_thumbnails$jscomp$3_thumbnails$jscomp$6$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2365$callback$$,$pending_thumbnails$jscomp$3_thumbnails$jscomp$6$$);$full$jscomp$6_pending_full$jscomp$3$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$302$key$$,
$APP.$cljs$cst$2365$callback$$,$full$jscomp$6_pending_full$jscomp$3$$);$APP.$cljs$core$seq$$($pending_thumbnails$jscomp$3_thumbnails$jscomp$6$$)||$APP.$cljs$core$seq$$($full$jscomp$6_pending_full$jscomp$3$$)?$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$render_wasm$api$noop_fn$$,$APP.$app$render_wasm$api$noop_fn$$,function(){return $APP.$cljs$core$fn_QMARK_$$($on_complete$jscomp$2$$)?$on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():
$on_complete$jscomp$2$$():null},$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($callback$jscomp$87$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$87$$)?$callback$jscomp$87$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$87$$.$cljs$core$IFn$_invoke$arity$0$():
$callback$jscomp$87$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($pending_thumbnails$jscomp$3_thumbnails$jscomp$6$$))))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$mapcat$$(function($callback$jscomp$88$$){return $APP.$cljs$core$fn_QMARK_$$($callback$jscomp$88$$)?
$callback$jscomp$88$$.$cljs$core$IFn$_invoke$arity$0$?$callback$jscomp$88$$.$cljs$core$IFn$_invoke$arity$0$():$callback$jscomp$88$$():$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$from$$($APP.$cljs$core$vals$$($full$jscomp$6_pending_full$jscomp$3$$))))))):$APP.$cljs$core$truth_$$($on_complete$jscomp$2$$)&&($on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_complete$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_complete$jscomp$2$$())};
$app$main$data$viewer$fetch_comment_threads$$=function($p__74425$$){var $map__74427__$1$$=$APP.$cljs$core$__destructure_map$$($p__74425$$),$file_id$jscomp$347$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74427__$1$$,$APP.$cljs$cst$1649$file_id$$),$page_id$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74427__$1$$,$APP.$cljs$cst$2051$page_id$$),$share_id$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74427__$1$$,$APP.$cljs$cst$3262$share_id$$);
typeof $app$main$data$viewer$fetch_comment_threads_74440$$==="undefined"&&($app$main$data$viewer$fetch_comment_threads_74440$$=function($p__74425$jscomp$1$$,$map__74427$jscomp$1$$,$params$jscomp$386$$,$file_id$jscomp$348$$,$page_id$jscomp$397$$,$share_id$jscomp$21$$,$fetched$jscomp$7$$,$on_error$jscomp$64$$,$meta74441$$){this.$p__74425$=$p__74425$jscomp$1$$;this.$map__74427$=$map__74427$jscomp$1$$;this.params=$params$jscomp$386$$;this.$file_id$=$file_id$jscomp$348$$;this.$page_id$=$page_id$jscomp$397$$;
this.$share_id$=$share_id$jscomp$21$$;this.$fetched$=$fetched$jscomp$7$$;this.$on_error$=$on_error$jscomp$64$$;this.$meta74441$=$meta74441$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$fetch_comment_threads_74440$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$fetch_comment_threads_74440$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5355$app_DOT_main_DOT_data_DOT_viewer_SLASH_fetch_comment_threads$$},
$app$main$data$viewer$fetch_comment_threads_74440$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74442$$,$meta74441__$1$$){return new $app$main$data$viewer$fetch_comment_threads_74440$$(this.$p__74425$,this.$map__74427$,this.params,this.$file_id$,this.$page_id$,this.$share_id$,this.$fetched$,this.$on_error$,$meta74441__$1$$)},$app$main$data$viewer$fetch_comment_threads_74440$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74441$},$app$main$data$viewer$fetch_comment_threads_74440$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$fetch_comment_threads_74440$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7174$$=this;return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7174$$.$on_error$,$APP.$beicon$v2$core$map$$(function($p1__74423_SHARP_$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$7174$$.$fetched$,$p1__74423_SHARP_$$)},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3513$get_comment_threads$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$7174$$.$file_id$,$APP.$cljs$cst$3262$share_id$$,$self__$jscomp$7174$$.$share_id$],null))))});return new $app$main$data$viewer$fetch_comment_threads_74440$$($p__74425$$,$map__74427__$1$$,$map__74427__$1$$,$file_id$jscomp$347$$,$page_id$jscomp$396$$,$share_id$jscomp$20$$,function($data$jscomp$445$$,$state$jscomp$1116$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1116$$,$APP.$cljs$cst$2183$comment_threads$$,
$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__74422_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$396$$,$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__74422_SHARP_$$))},$data$jscomp$445$$)))},function($map__74437__$1_p__74436$$){$map__74437__$1_p__74436$$=$APP.$cljs$core$__destructure_map$$($map__74437__$1_p__74436$$);var $type$jscomp$600$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74437__$1_p__74436$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3181$authentication$$,$type$jscomp$600$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2676$not_found$$,$type$jscomp$600$$)?$APP.$beicon$v2$core$empty$$():$APP.$beicon$v2$core$throw$0$$($map__74437__$1_p__74436$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$inspect$selection_feedback$selection_rect$$=function($map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$){$map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$=$APP.$rumext$v2$util$wrap_props$$($map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$);$map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$=$APP.$cljs$core$__destructure_map$$($map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$);var $selrect$jscomp$81_x$jscomp$1242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$,
$APP.$cljs$cst$1610$selrect$$);$map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$,$APP.$cljs$cst$2204$zoom$$);var $height$jscomp$157_map__75346__$1$$=$APP.$cljs$core$__destructure_map$$($selrect$jscomp$81_x$jscomp$1242$$);$selrect$jscomp$81_x$jscomp$1242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75346__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$462$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75346__$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75346__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$157_map__75346__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$157_map__75346__$1$$,$APP.$cljs$cst$1527$height$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"selection-rect",children:(0,$APP.$rumext$v2$jsx$$)("rect",
{x:$selrect$jscomp$81_x$jscomp$1242$$,y:$y$jscomp$462$$,width:$width$jscomp$180$$,height:$height$jscomp$157_map__75346__$1$$,style:{fill:"none",stroke:"var(--color-accent-tertiary)",strokeWidth:1/$map__75345_map__75345__$1_props_75344_zoom$jscomp$62$$}})})};
$app$main$data$comments$create_thread_on_viewer$$=function($params$jscomp$235$$){typeof $app$main$data$comments$create_thread_on_viewer_55858$$==="undefined"&&($app$main$data$comments$create_thread_on_viewer_55858$$=function($params$jscomp$236$$,$meta55859$$){this.params=$params$jscomp$236$$;this.$meta55859$=$meta55859$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$comments$create_thread_on_viewer_55858$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_thread_on_viewer_55858$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3495$app_DOT_main_DOT_data_DOT_comments_SLASH_create_thread_on_viewer$$},$app$main$data$comments$create_thread_on_viewer_55858$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55860$$,$meta55859__$1$$){return new $app$main$data$comments$create_thread_on_viewer_55858$$(this.params,$meta55859__$1$$)},$app$main$data$comments$create_thread_on_viewer_55858$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55859$},$app$main$data$comments$create_thread_on_viewer_55858$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$comments$create_thread_on_viewer_55858$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1812_frame_id$jscomp$36_params__$1$jscomp$32$$,$state$jscomp$260$$){var $share_id$jscomp$1$$=$APP.$cljs$cst$3262$share_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2239$viewer_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$260$$));
$_$jscomp$1812_frame_id$jscomp$36_params__$1$jscomp$32$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$(this.params);$_$jscomp$1812_frame_id$jscomp$36_params__$1$jscomp$32$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$comments$update_mentions$$(this.params),$APP.$cljs$cst$3262$share_id$$,$share_id$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1612$frame_id$$,$_$jscomp$1812_frame_id$jscomp$36_params__$1$jscomp$32$$]));
return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__55880__$1_p__55879$$){$map__55880__$1_p__55879$$=$APP.$cljs$core$__destructure_map$$($map__55880__$1_p__55879$$);var $type$jscomp$445$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55880__$1_p__55879$$,$APP.$cljs$cst$139$type$$),$code$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55880__$1_p__55879$$,$APP.$cljs$cst$273$code$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$445$$,
$APP.$cljs$cst$2572$restriction$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($code$jscomp$39$$,$APP.$cljs$cst$3435$max_quote_reached$$)?$APP.$beicon$v2$core$throw$0$$($map__55880__$1_p__55879$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$3431$comment_error$$],null))},$APP.$beicon$v2$core$map$$($app$main$data$comments$created_thread_on_viewer$$,$APP.$beicon$v2$core$mapcat$$(function($p1__55856_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3492$get_comment_thread$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55856_SHARP_$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55856_SHARP_$$),$APP.$cljs$cst$3262$share_id$$,$share_id$jscomp$1$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3493$create_comment_thread$$,$_$jscomp$1812_frame_id$jscomp$36_params__$1$jscomp$32$$))))});return new $app$main$data$comments$create_thread_on_viewer_55858$$($params$jscomp$235$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$viewer$interactions$animate_close_overlay$$=function($animation$jscomp$14$$,$overlay_viewport$jscomp$1$$,$wrapper_size$jscomp$2$$,$overlay_size$jscomp$3$$,$overlay_position$jscomp$4$$,$overlay_id$$){if($overlay_viewport$jscomp$1$$!=null){var $G__76025_G__76025__$1_G__76027_G__76027__$1$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$);$G__76025_G__76025__$1_G__76027_G__76027__$1$$=$G__76025_G__76025__$1_G__76027_G__76027__$1$$ instanceof $APP.$cljs$core$Keyword$$?
$G__76025_G__76025__$1_G__76027_G__76027__$1$$.$fqn$:null;switch($G__76025_G__76025__$1_G__76027_G__76027__$1$$){case "dissolve":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"100"},{opacity:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});break;case "slide":switch($G__76025_G__76025__$1_G__76027_G__76027__$1$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),$G__76025_G__76025__$1_G__76027_G__76027__$1$$=
$G__76025_G__76025__$1_G__76027_G__76027__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76025_G__76025__$1_G__76027_G__76027__$1$$.$fqn$:null,$G__76025_G__76025__$1_G__76027_G__76027__$1$$){case "right":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$2$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;case "left":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;case "up":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;case "down":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$4$$)),
"px"].join("")},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$2$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$14$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$viewer$complete_animation$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($overlay_id$$,null)]))});return;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76025_G__76025__$1_G__76027_G__76027__$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76025_G__76025__$1_G__76027_G__76027__$1$$)].join(""));}}};
$app$main$ui$viewer$interactions$animate_open_overlay$$=function($animation$jscomp$13$$,$overlay_viewport$$,$wrapper_size$jscomp$1$$,$overlay_size$jscomp$2$$,$overlay_position$jscomp$3$$){if($overlay_viewport$$!=null){var $G__76021_G__76021__$1_G__76022_G__76022__$1$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$);$G__76021_G__76021__$1_G__76022_G__76022__$1$$=$G__76021_G__76021__$1_G__76022_G__76022__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76021_G__76021__$1_G__76022_G__76022__$1$$.$fqn$:
null;switch($G__76021_G__76021__$1_G__76022_G__76022__$1$$){case "dissolve":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"0"},{opacity:"100"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});break;case "slide":switch($G__76021_G__76021__$1_G__76022_G__76022__$1$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),$G__76021_G__76021__$1_G__76022_G__76022__$1$$=$G__76021_G__76021__$1_G__76022_G__76022__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76021_G__76021__$1_G__76022_G__76022__$1$$.$fqn$:null,$G__76021_G__76021__$1_G__76022_G__76022__$1$$){case "right":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$2$$)),"px"].join("")},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});return;case "left":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$1$$)),
"px"].join("")},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});
return;case "up":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$1$$)),"px"].join("")},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});return;case "down":$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($overlay_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($overlay_size$jscomp$2$$)),"px"].join("")},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$3$$)),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$13$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});return;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76021_G__76021__$1_G__76022_G__76022__$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76021_G__76021__$1_G__76022_G__76022__$1$$)].join(""));}}};
$app$main$ui$viewer$interactions$animate_go_to_frame$$=function($animation$jscomp$12$$,$current_viewport$$,$orig_viewport$$,$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$,$G__76000_G__76000__$1_orig_size$$,$offset$jscomp$200_wrapper_size$$){var $G__75996_G__75996__$1_G__75999_G__75999__$1$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$);$G__75996_G__75996__$1_G__75999_G__75999__$1$$=$G__75996_G__75996__$1_G__75999_G__75999__$1$$ instanceof
$APP.$cljs$core$Keyword$$?$G__75996_G__75996__$1_G__75999_G__75999__$1$$.$fqn$:null;switch($G__75996_G__75996__$1_G__75999_G__75999__$1$$){case "dissolve":return $app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"100%"},{opacity:"0%"},{opacity:"0%"}],null),{delay:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$)/3,duration:2*$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$)/
3,easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{opacity:"0%"},{opacity:"100%"},{opacity:"100%"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())});case "slide":$G__75996_G__75996__$1_G__75999_G__75999__$1$$=$APP.$cljs$cst$1978$way$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$);$G__75996_G__75996__$1_G__75999_G__75999__$1$$=$G__75996_G__75996__$1_G__75999_G__75999__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__75996_G__75996__$1_G__75999_G__75999__$1$$.$fqn$:null;switch($G__75996_G__75996__$1_G__75999_G__75999__$1$$){case "in":switch($G__76000_G__76000__$1_orig_size$$=
$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),$G__76000_G__76000__$1_orig_size$$=$G__76000_G__76000__$1_orig_size$$ instanceof $APP.$cljs$core$Keyword$$?$G__76000_G__76000__$1_orig_size$$.$fqn$:null,$G__76000_G__76000__$1_orig_size$$){case "right":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{left:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{left:"0",opacity:"100%"},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "left":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),
"px"].join("")},{right:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:"0",opacity:"100%"},{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "up":return $offset$jscomp$200_wrapper_size$$=
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$)+($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{bottom:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{bottom:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:"0",opacity:"100%"},{bottom:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):
null;case "down":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$)+($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$))/2,$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{top:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:"0",opacity:"100%"},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$)].join(""));}case "out":switch($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$=
$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$.$fqn$:null,$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$){case "right":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$))/
2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:"0"},{right:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*
.2),"px"].join(""),opacity:"0"},{right:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "left":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$))/2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:"0"},{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"},{left:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "up":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$)+
($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$))/2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:"0"},{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"},{top:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):null;case "down":return $offset$jscomp$200_wrapper_size$$=
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$)+($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__76000_G__76000__$1_orig_size$$))/2,$APP.$app$util$dom$set_css_property_BANG_$$($orig_viewport$$,"z-index",1E4),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[{bottom:"0"},{bottom:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))?
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$*.2),"px"].join(""),opacity:"0"},{bottom:"0",opacity:"100%"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))}):
null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75996_G__75996__$1_G__75999_G__75999__$1$$)].join(""));}break;case "push":switch($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$=$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$.$fqn$:null,$G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$){case "right":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{left:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{left:"0"},{left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});
case "left":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{right:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{right:"0"},{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});case "up":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{bottom:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),
$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{bottom:"0"},{bottom:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});
case "down":return $offset$jscomp$200_wrapper_size$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($current_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:["-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),"px"].join("")},{top:"0"}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),
easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$complete_animation$$())}),$app$util$dom$animate_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($orig_viewport$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[{top:"0"},{top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$200_wrapper_size$$),
"px"].join("")}],null),{duration:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$),easing:$APP.$cljs$core$name$$($APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($animation$jscomp$12$$))});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76006_G__76006__$1_G__76013_G__76013__$1_current_size$jscomp$1$$)].join(""));}default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75996_G__75996__$1_G__75999_G__75999__$1$$)].join(""));
}};
$app$util$dom$fullscreen_QMARK_$$=function(){if("webkitFullscreenElement"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.webkitFullscreenElement);if("mozFullScreen"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.mozFullScreen);if("msFullscreenElement"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.msFullscreenElement);if("fullscreenElement"in $APP.$app$util$globals$document$$)return $APP.$cljs$core$boolean$0$$($APP.$app$util$globals$document$$.fullscreenElement);
$APP.$app$common$logging$enabled_QMARK_$$("app.util.dom",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"Seems like the current browser does not support fullscreen api."],null)],null)}),null,"app.util.dom",$APP.$cljs$cst$849$error$$,
!1);return!1};
$app$util$webapi$exit_fullscreen$$=function(){if("exitFullscreen"in document)return document.exitFullscreen();if("webkitExitFullscreen"in document)return document.webkitExitFullscreen();$APP.$app$common$logging$enabled_QMARK_$$("app.util.webapi",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1551$msg$$,"Seems like the current browser does not support fullscreen api."],null)],null)}),null,"app.util.webapi",$APP.$cljs$cst$849$error$$,!1);return!1};
$app$util$webapi$request_fullscreen$$=function($el$jscomp$5$$){if("requestFullscreen"in $el$jscomp$5$$)return $el$jscomp$5$$.requestFullscreen();if("webkitRequestFullscreen"in $el$jscomp$5$$)return $el$jscomp$5$$.webkitRequestFullscreen();$APP.$app$common$logging$enabled_QMARK_$$("app.util.webapi",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"Seems like the current browser does not support fullscreen api."],null)],null)}),null,"app.util.webapi",$APP.$cljs$cst$849$error$$,!1);return!1};
$app$main$ui$inspect$selection_feedback$selection_feedback$$=function($map__75348_map__75348__$1_props_75347_size$jscomp$141$$){$map__75348_map__75348__$1_props_75347_size$jscomp$141$$=$APP.$rumext$v2$util$wrap_props$$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$);$map__75348_map__75348__$1_props_75347_size$jscomp$141$$=$APP.$cljs$core$__destructure_map$$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$);var $frame$jscomp$56_hover_shape$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$,
$APP.$cljs$cst$1611$frame$$),$local$jscomp$26_map__75349__$1_zoom$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$,$APP.$cljs$cst$2894$local$$),$objects$jscomp$739_selected_shapes$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$,$APP.$cljs$cst$1636$objects$$);$map__75348_map__75348__$1_props_75347_size$jscomp$141$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$,
$APP.$cljs$cst$874$size$$);$local$jscomp$26_map__75349__$1_zoom$jscomp$63$$=$APP.$cljs$core$__destructure_map$$($local$jscomp$26_map__75349__$1_zoom$jscomp$63$$);var $hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$26_map__75349__$1_zoom$jscomp$63$$,$APP.$cljs$cst$2212$hover$$),$selected$jscomp$137_selrect$jscomp$82$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$26_map__75349__$1_zoom$jscomp$63$$,
$APP.$cljs$cst$1938$selected$$);$local$jscomp$26_map__75349__$1_zoom$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$26_map__75349__$1_zoom$jscomp$63$$,$APP.$cljs$cst$2204$zoom$$);$hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$=$APP.$app$main$ui$inspect$selection_feedback$resolve_shapes$$($objects$jscomp$739_selected_shapes$jscomp$13$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$],
null));$hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$=$APP.$cljs$core$first$$($hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$);$frame$jscomp$56_hover_shape$jscomp$1$$=$APP.$cljs$core$truth_$$($hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$)?$hover$jscomp$1_or__5025__auto__$jscomp$inline_9772_shapes$jscomp$172$$:$frame$jscomp$56_hover_shape$jscomp$1$$;$objects$jscomp$739_selected_shapes$jscomp$13$$=$APP.$app$main$ui$inspect$selection_feedback$resolve_shapes$$($objects$jscomp$739_selected_shapes$jscomp$13$$,
$selected$jscomp$137_selrect$jscomp$82$$);$selected$jscomp$137_selrect$jscomp$82$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($objects$jscomp$739_selected_shapes$jscomp$13$$);return $APP.$app$common$data$not_empty_QMARK_$$($objects$jscomp$739_selected_shapes$jscomp$13$$)?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-feedback",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selected-shapes",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$selection_feedback$selection_rect$$,
{selrect:$selected$jscomp$137_selrect$jscomp$82$$,zoom:$local$jscomp$26_map__75349__$1_zoom$jscomp$63$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$size_display_STAR_$$,{selrect:$selected$jscomp$137_selrect$jscomp$82$$,zoom:$local$jscomp$26_map__75349__$1_zoom$jscomp$63$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement_STAR_$$,{bounds:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__75348_map__75348__$1_props_75347_size$jscomp$141$$,$APP.$cljs$cst$1515$x$$,
0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1516$y$$,0])),selectedShapes:$objects$jscomp$739_selected_shapes$jscomp$13$$,hoverShape:$frame$jscomp$56_hover_shape$jscomp$1$$,zoom:$local$jscomp$26_map__75349__$1_zoom$jscomp$63$$})]}):null};
$app$main$data$viewer$select_shape$$=function($id$jscomp$901$$){typeof $app$main$data$viewer$select_shape_74992$$==="undefined"&&($app$main$data$viewer$select_shape_74992$$=function($id$jscomp$902$$,$meta74993$$){this.id=$id$jscomp$902$$;this.$meta74993$=$meta74993$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$select_shape_74992$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$select_shape_74992$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5399$app_DOT_main_DOT_data_DOT_viewer_SLASH_select_shape$$},$app$main$data$viewer$select_shape_74992$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74994$$,$meta74993__$1$$){return new $app$main$data$viewer$select_shape_74992$$(this.id,$meta74993__$1$$)},$app$main$data$viewer$select_shape_74992$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74993$},$app$main$data$viewer$select_shape_74992$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$select_shape_74992$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2956$$,$state$jscomp$1157$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$1157$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.id]))});return new $app$main$data$viewer$select_shape_74992$$($id$jscomp$901$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$shift_select_to$$=function($id$jscomp$905$$){typeof $app$main$data$viewer$shift_select_to_75002$$==="undefined"&&($app$main$data$viewer$shift_select_to_75002$$=function($id$jscomp$906$$,$meta75003$$){this.id=$id$jscomp$906$$;this.$meta75003$=$meta75003$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$shift_select_to_75002$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$shift_select_to_75002$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5401$app_DOT_main_DOT_data_DOT_viewer_SLASH_shift_select_to$$},$app$main$data$viewer$shift_select_to_75002$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_75004$$,$meta75003__$1$$){return new $app$main$data$viewer$shift_select_to_75002$$(this.id,$meta75003__$1$$)},$app$main$data$viewer$shift_select_to_75002$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta75003$},$app$main$data$viewer$shift_select_to_75002$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$shift_select_to_75002$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$,$state$jscomp$1159$$){$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$=$APP.$cljs$cst$2179$route$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1159$$);$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$=
$APP.$cljs$cst$2278$query_params$$.$cljs$core$IFn$_invoke$arity$1$($G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$);$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$=$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$);$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$=
$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$==null?null:$APP.$app$common$uuid$parse$$($G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$);$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1159$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1597$viewer$$,$APP.$cljs$cst$2236$pages$$,$G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$,$APP.$cljs$cst$1636$objects$$],null));var $selection$jscomp$11$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1159$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id);return $APP.$cljs$core$assoc_in$$($state$jscomp$1159$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$1938$selected$$],null),$APP.$app$common$files$helpers$expand_region_selection$$($G__75007$jscomp$inline_9774__$jscomp$2958_objects$jscomp$711_page_id$jscomp$406_qparams$jscomp$6_route$jscomp$17$$,
$selection$jscomp$11$$))});return new $app$main$data$viewer$shift_select_to_75002$$($id$jscomp$905$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_frame_auto$$=function(){typeof $app$main$data$viewer$go_to_frame_auto_74918$$==="undefined"&&($app$main$data$viewer$go_to_frame_auto_74918$$=function($meta74919$$){this.$meta74919$=$meta74919$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$go_to_frame_auto_74918$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_auto_74918$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5390$app_DOT_main_DOT_data_DOT_viewer_SLASH_go_to_frame_auto$$},$app$main$data$viewer$go_to_frame_auto_74918$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74920$$,$meta74919__$1$$){return new $app$main$data$viewer$go_to_frame_auto_74918$$($meta74919__$1$$)},$app$main$data$viewer$go_to_frame_auto_74918$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74919$},$app$main$data$viewer$go_to_frame_auto_74918$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$go_to_frame_auto_74918$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$,$flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$){$G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$=$APP.$cljs$cst$2179$route$$.$cljs$core$IFn$_invoke$arity$1$($flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$);
$G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$=$APP.$cljs$cst$2278$query_params$$.$cljs$core$IFn$_invoke$arity$1$($G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$);$G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$=$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$);
$G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$=$G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$==null?null:$APP.$app$common$uuid$parse$$($G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$);$flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1597$viewer$$,$APP.$cljs$cst$2236$pages$$,$G__74923$jscomp$inline_9776__$jscomp$2948_page_id$jscomp$403_qparams$jscomp$3_route$jscomp$14$$,$APP.$cljs$cst$873$options$$,$APP.$cljs$cst$2064$flows$$],null));return $APP.$cljs$core$seq$$($flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$)?($flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$=$APP.$cljs$cst$2061$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$)),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$($flows$jscomp$5_frame_id$jscomp$125_state$jscomp$1148$$))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$viewer$go_to_frame_by_index$$(0))});return new $app$main$data$viewer$go_to_frame_auto_74918$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$go_to_frame$$=function($var_args$jscomp$1413$$){switch(arguments.length){case 1:return $APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);case 2:return $APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$data$viewer$generate_update_position_data_changes$$=function($shapes$jscomp$153$$,$page_id$jscomp$391$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$336$$,$shape$jscomp$901$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$336$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2623$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$901$$),
$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$391$$,$APP.$cljs$cst$2624$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1899$position_data$$,$APP.$cljs$cst$108$val$$,$APP.$app$render_wasm$api$calculate_position_data$$($shape$jscomp$901$$),$APP.$cljs$cst$2567$ignore_touched$$,!0,$APP.$cljs$cst$2568$ignore_geometry$$,
!0],null)],null)],null))},$APP.$cljs$core$PersistentVector$EMPTY$$,$shapes$jscomp$153$$)};
$app$render_wasm$api$set_objects_callback$$=function($map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$,$set_objects_cb$$){var $full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$=$APP.$cljs$core$count$$($map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$);a:{for(var $G__55079$jscomp$inline_9786_index$jscomp$inline_9778$$=0,$G__55080$jscomp$inline_9787_thumbnails_acc$jscomp$inline_9779$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$G__55081$jscomp$inline_9788_full_acc$jscomp$inline_9780$$=
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__55079$jscomp$inline_9786_index$jscomp$inline_9778$$<$full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$){var $map__54335$jscomp$inline_9782_shape$jscomp$inline_9781_thumbnails$jscomp$inline_9784$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$,$G__55079$jscomp$inline_9786_index$jscomp$inline_9778$$);$map__54335$jscomp$inline_9782_shape$jscomp$inline_9781_thumbnails$jscomp$inline_9784$$=
$APP.$app$render_wasm$api$set_object$$($map__54335$jscomp$inline_9782_shape$jscomp$inline_9781_thumbnails$jscomp$inline_9784$$);var $full$jscomp$inline_9785_map__54335__$1$jscomp$inline_9783$$=$APP.$cljs$core$__destructure_map$$($map__54335$jscomp$inline_9782_shape$jscomp$inline_9781_thumbnails$jscomp$inline_9784$$);$map__54335$jscomp$inline_9782_shape$jscomp$inline_9781_thumbnails$jscomp$inline_9784$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$inline_9785_map__54335__$1$jscomp$inline_9783$$,
$APP.$cljs$cst$2237$thumbnails$$);$full$jscomp$inline_9785_map__54335__$1$jscomp$inline_9783$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$inline_9785_map__54335__$1$jscomp$inline_9783$$,$APP.$cljs$cst$1278$full$$);$G__55079$jscomp$inline_9786_index$jscomp$inline_9778$$+=1;$G__55080$jscomp$inline_9787_thumbnails_acc$jscomp$inline_9779$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__55080$jscomp$inline_9787_thumbnails_acc$jscomp$inline_9779$$,
$map__54335$jscomp$inline_9782_shape$jscomp$inline_9781_thumbnails$jscomp$inline_9784$$);$G__55081$jscomp$inline_9788_full_acc$jscomp$inline_9780$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj_BANG_$$,$G__55081$jscomp$inline_9788_full_acc$jscomp$inline_9780$$,$full$jscomp$inline_9785_map__54335__$1$jscomp$inline_9783$$)}else{$map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2237$thumbnails$$,$APP.$cljs$core$_persistent_BANG_$$($G__55080$jscomp$inline_9787_thumbnails_acc$jscomp$inline_9779$$),
$APP.$cljs$cst$1278$full$$,$APP.$cljs$core$_persistent_BANG_$$($G__55081$jscomp$inline_9788_full_acc$jscomp$inline_9780$$)],null);break a}$map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$=void 0}$full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$);$map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$,$APP.$cljs$cst$2237$thumbnails$$);
$full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$,$APP.$cljs$cst$1278$full$$);$app$render_wasm$api$process_pending_no_sideffects$$($map__54333_shapes$jscomp$31_thumbnails$jscomp$7$$,$full$jscomp$7_map__54333__$1_total_shapes$jscomp$2$$,$set_objects_cb$$)};
$app$main$data$viewer$apply_changes_viewer$$=function($changes$jscomp$327$$){typeof $app$main$data$viewer$apply_changes_viewer_74367$$==="undefined"&&($app$main$data$viewer$apply_changes_viewer_74367$$=function($changes$jscomp$328$$,$meta74368$$){this.$changes$=$changes$jscomp$328$$;this.$meta74368$=$meta74368$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$apply_changes_viewer_74367$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$apply_changes_viewer_74367$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5348$app_DOT_main_DOT_data_DOT_viewer_SLASH_apply_changes_viewer$$},$app$main$data$viewer$apply_changes_viewer_74367$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74369$$,$meta74368__$1$$){return new $app$main$data$viewer$apply_changes_viewer_74367$$(this.$changes$,$meta74368__$1$$)},$app$main$data$viewer$apply_changes_viewer_74367$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74368$},$app$main$data$viewer$apply_changes_viewer_74367$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$apply_changes_viewer_74367$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2909_pages$jscomp$8$$,$state$jscomp$1112$$){var $file$jscomp$145$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1112$$,
$APP.$cljs$cst$1597$viewer$$),$APP.$cljs$cst$208$file$$),$APP.$cljs$cst$142$data$$,$APP.$app$common$files$changes$process_changes$$,this.$changes$,!1);$_$jscomp$2909_pages$jscomp$8$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($page_id$jscomp$390$$){var $data$jscomp$443$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$145$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1635$pages_index$$,$page_id$jscomp$390$$],null)),$JSCompiler_temp_const$jscomp$2042$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$2040$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$2043_objects$jscomp$inline_9790$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$443$$);$JSCompiler_inline_result$jscomp$2043_objects$jscomp$inline_9790$$=
$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2043_objects$jscomp$inline_9790$$,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$2042$$,[$page_id$jscomp$390$$,$JSCompiler_temp_const$jscomp$2040$$.call($APP.$cljs$core$assoc$$,$data$jscomp$443$$,$APP.$cljs$cst$5349$frames$$,$JSCompiler_inline_result$jscomp$2043_objects$jscomp$inline_9790$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5350$all_frames$$,
$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$443$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2096$all_frames_QMARK_$$,!0],null))]))],null)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$145$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2236$pages$$)));return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1112$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1597$viewer$$,$APP.$cljs$cst$208$file$$],null),$file$jscomp$145$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1597$viewer$$,$APP.$cljs$cst$2236$pages$$],null),$_$jscomp$2909_pages$jscomp$8$$)});return new $app$main$data$viewer$apply_changes_viewer_74367$$($changes$jscomp$327$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$update_page_position_data$$=function($file_id$jscomp$344$$,$page_id$jscomp$392$$){typeof $app$main$data$viewer$update_page_position_data_74389$$==="undefined"&&($app$main$data$viewer$update_page_position_data_74389$$=function($file_id$jscomp$345$$,$page_id$jscomp$393$$,$meta74390$$){this.$file_id$=$file_id$jscomp$345$$;this.$page_id$=$page_id$jscomp$393$$;this.$meta74390$=$meta74390$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$viewer$update_page_position_data_74389$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$update_page_position_data_74389$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5351$app_DOT_main_DOT_data_DOT_viewer_SLASH_update_page_position_data$$},$app$main$data$viewer$update_page_position_data_74389$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74391$$,$meta74390__$1$$){return new $app$main$data$viewer$update_page_position_data_74389$$(this.$file_id$,
this.$page_id$,$meta74390__$1$$)},$app$main$data$viewer$update_page_position_data_74389$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74390$},$app$main$data$viewer$update_page_position_data_74389$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$update_page_position_data_74389$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2910_objects$jscomp$710_set_objects_stream$$,$state$jscomp$1113$$){var $self__$jscomp$7165$$=
this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$1113$$,"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1213$available_viewer_wasm$$)){$_$jscomp$2910_objects$jscomp$710_set_objects_stream$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1113$$,$self__$jscomp$7165$$.$file_id$,$self__$jscomp$7165$$.$page_id$);var $shapes$jscomp$154$$=$APP.$cljs$core$reduce_kv$$(function($result$jscomp$337$$,
$___$3$jscomp$242$$,$shape$jscomp$902$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$902$$)&&$APP.$cljs$cst$1899$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$902$$)==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$337$$,$shape$jscomp$902$$):$result$jscomp$337$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$_$jscomp$2910_objects$jscomp$710_set_objects_stream$$);$_$jscomp$2910_objects$jscomp$710_set_objects_stream$$=
$APP.$beicon$v2$core$create$$(function($subs$jscomp$20$$){$APP.$app$render_wasm$api$init_canvas_context$$(new OffscreenCanvas(0,0));$app$render_wasm$api$set_objects_callback$$($shapes$jscomp$154$$,function(){return $subs$jscomp$20$$.next($APP.$cljs$cst$4653$done$$)});return null});return $APP.$app$common$data$not_empty_QMARK_$$($shapes$jscomp$154$$)?$APP.$beicon$v2$core$mapcat$$(function(){var $changes$jscomp$329$$=$app$main$data$viewer$generate_update_position_data_changes$$($shapes$jscomp$154$$,
$self__$jscomp$7165$$.$page_id$);$APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);return $APP.$app$common$data$not_empty_QMARK_$$($changes$jscomp$329$$)?(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$apply_changes_viewer$$($changes$jscomp$329$$)):$APP.$beicon$v2$core$empty$$()},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$constantly$$($_$jscomp$2910_objects$jscomp$710_set_objects_stream$$),$APP.$beicon$v2$core$from$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$module$$)))):
$APP.$beicon$v2$core$empty$$()}return $APP.$beicon$v2$core$empty$$()});return new $app$main$data$viewer$update_page_position_data_74389$$($file_id$jscomp$344$$,$page_id$jscomp$392$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$bundle_fetched$$=function($p__74401$$){var $map__74402__$1$$=$APP.$cljs$core$__destructure_map$$($p__74401$$),$project$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$2238$project$$),$file$jscomp$146$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$208$file$$),$team$jscomp$54$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$2503$team$$),$share_links$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$2184$share_links$$),$libraries$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$5352$libraries$$),$users$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$5353$users$$),$permissions$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$1728$permissions$$),$thumbnails$jscomp$18$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74402__$1$$,$APP.$cljs$cst$2237$thumbnails$$),$pages$jscomp$9$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($page_id$jscomp$394$$){var $data$jscomp$444$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$146$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1635$pages_index$$,$page_id$jscomp$394$$],null)),$JSCompiler_temp_const$jscomp$2046$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,$JSCompiler_temp_const$jscomp$2044$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $JSCompiler_inline_result$jscomp$2047_objects$jscomp$inline_9792$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$444$$);$JSCompiler_inline_result$jscomp$2047_objects$jscomp$inline_9792$$=$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$2047_objects$jscomp$inline_9792$$,
null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$2046$$,[$page_id$jscomp$394$$,$JSCompiler_temp_const$jscomp$2044$$.call($APP.$cljs$core$assoc$$,$data$jscomp$444$$,$APP.$cljs$cst$5349$frames$$,$JSCompiler_inline_result$jscomp$2047_objects$jscomp$inline_9792$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5350$all_frames$$,$APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$444$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2096$all_frames_QMARK_$$,!0],null))]))],null)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$146$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2236$pages$$)));typeof $app$main$data$viewer$bundle_fetched_74403$$==="undefined"&&($app$main$data$viewer$bundle_fetched_74403$$=function($users$jscomp$2$$,$permissions$jscomp$29$$,$p__74401$jscomp$1$$,$libraries$jscomp$130$$,
$file$jscomp$147$$,$map__74402$jscomp$1$$,$bundle$jscomp$6$$,$thumbnails$jscomp$19$$,$pages$jscomp$10$$,$project$jscomp$16$$,$team$jscomp$55$$,$share_links$jscomp$1$$,$meta74404$$){this.users=$users$jscomp$2$$;this.permissions=$permissions$jscomp$29$$;this.$p__74401$=$p__74401$jscomp$1$$;this.libraries=$libraries$jscomp$130$$;this.file=$file$jscomp$147$$;this.$map__74402$=$map__74402$jscomp$1$$;this.$bundle$=$bundle$jscomp$6$$;this.$thumbnails$=$thumbnails$jscomp$19$$;this.$pages$=$pages$jscomp$10$$;
this.project=$project$jscomp$16$$;this.team=$team$jscomp$55$$;this.$share_links$=$share_links$jscomp$1$$;this.$meta74404$=$meta74404$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$bundle_fetched_74403$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$bundle_fetched_74403$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5354$app_DOT_main_DOT_data_DOT_viewer_SLASH_bundle_fetched$$},
$app$main$data$viewer$bundle_fetched_74403$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74405$$,$meta74404__$1$$){return new $app$main$data$viewer$bundle_fetched_74403$$(this.users,this.permissions,this.$p__74401$,this.libraries,this.file,this.$map__74402$,this.$bundle$,this.$thumbnails$,this.$pages$,this.project,this.team,this.$share_links$,$meta74404__$1$$)},$app$main$data$viewer$bundle_fetched_74403$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta74404$},
$app$main$data$viewer$bundle_fetched_74403$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$bundle_fetched_74403$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2911_team_id$jscomp$148$$,$state$jscomp$1114$$){$_$jscomp$2911_team_id$jscomp$148$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.team);var $team__$1$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.team,$APP.$cljs$cst$3321$members$$,
this.users);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1114$$,$APP.$cljs$cst$2184$share_links$$,this.$share_links$),$APP.$cljs$cst$1943$current_team_id$$,$_$jscomp$2911_team_id$jscomp$148$$),$APP.$cljs$cst$2181$teams$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$_$jscomp$2911_team_id$jscomp$148$$,
$team__$1$jscomp$1$$])),$APP.$cljs$cst$1933$files$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.libraries),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.file),this.file)),$APP.$cljs$cst$1597$viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$5352$libraries$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.libraries),
$APP.$cljs$cst$5353$users$$,$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,this.users),$APP.$cljs$cst$1728$permissions$$,this.permissions,$APP.$cljs$cst$2238$project$$,this.project,$APP.$cljs$cst$2236$pages$$,this.$pages$,$APP.$cljs$cst$2237$thumbnails$$,this.$thumbnails$,$APP.$cljs$cst$208$file$$,this.file],null))},$app$main$data$viewer$bundle_fetched_74403$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$bundle_fetched_74403$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2912_index$jscomp$390_route$jscomp$11$$,$frame_id$jscomp$121_state$jscomp$1115$$){$_$jscomp$2912_index$jscomp$390_route$jscomp$11$$=$APP.$cljs$cst$2179$route$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$121_state$jscomp$1115$$);var $qparams$$=$APP.$cljs$cst$2278$query_params$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2912_index$jscomp$390_route$jscomp$11$$);$_$jscomp$2912_index$jscomp$390_route$jscomp$11$$=function(){var $G__74415$$=$APP.$app$main$router$get_query_param$$($qparams$$,
$APP.$cljs$cst$1801$index$$);return $G__74415$$==null?null:$APP.$cljs$core$parse_long$$($G__74415$$)}();$frame_id$jscomp$121_state$jscomp$1115$$=function(){var $G__74416$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($qparams$$);return $G__74416$$==null?null:$APP.$app$common$uuid$parse$$($G__74416$$)}();var $page_id$jscomp$395$$=function(){var $G__74417$$=$APP.$app$main$router$get_query_param$$($qparams$$,$APP.$cljs$cst$2051$page_id$$);return $G__74417$$==null?null:$APP.$app$common$uuid$parse$$($G__74417$$)}(),
$file_id$jscomp$346$$=function(){var $G__74418$$=$APP.$app$main$router$get_query_param$$($qparams$$,$APP.$cljs$cst$1649$file_id$$);return $G__74418$$==null?null:$APP.$app$common$uuid$parse$$($G__74418$$)}();return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)(function(){switch($APP.$cljs$cst$2204$zoom$$.$cljs$core$IFn$_invoke$arity$1$($qparams$$)){case "fit":return $APP.$app$main$data$viewer$zoom_to_fit$$;case "fill":return $APP.$app$main$data$viewer$zoom_to_fill$$;default:return null}}()),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$viewer$update_page_position_data$$($file_id$jscomp$346$$,$page_id$jscomp$395$$),$frame_id$jscomp$121_state$jscomp$1115$$!=null?$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$?$APP.$app$main$data$viewer$go_to_frame$cljs$0core$0IFn$0_invoke$0arity$01$$($frame_id$jscomp$121_state$jscomp$1115$$):$app$main$data$viewer$go_to_frame$$($frame_id$jscomp$121_state$jscomp$1115$$):$_$jscomp$2912_index$jscomp$390_route$jscomp$11$$!=null?$APP.$app$main$data$viewer$go_to_frame_by_index$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$main$data$viewer$go_to_frame_by_index$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2912_index$jscomp$390_route$jscomp$11$$):$APP.$app$main$data$viewer$go_to_frame_by_index$$($_$jscomp$2912_index$jscomp$390_route$jscomp$11$$):$app$main$data$viewer$go_to_frame_auto$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$viewer$go_to_frame_auto$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$viewer$go_to_frame_auto$$()))});return new $app$main$data$viewer$bundle_fetched_74403$$($users$jscomp$1$$,
$permissions$jscomp$28$$,$p__74401$$,$libraries$jscomp$129$$,$file$jscomp$146$$,$map__74402__$1$$,$map__74402__$1$$,$thumbnails$jscomp$18$$,$pages$jscomp$9$$,$project$jscomp$15$$,$team$jscomp$54$$,$share_links$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$fetch_bundle$$=function($p__74327$$){var $map__74328__$1$$=$APP.$cljs$core$__destructure_map$$($p__74327$$),$file_id$jscomp$342$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74328__$1$$,$APP.$cljs$cst$1649$file_id$$),$share_id$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74328__$1$$,$APP.$cljs$cst$3262$share_id$$);typeof $app$main$data$viewer$fetch_bundle_74330$$==="undefined"&&($app$main$data$viewer$fetch_bundle_74330$$=function($p__74327$jscomp$1$$,
$map__74328$jscomp$1$$,$params$jscomp$384$$,$file_id$jscomp$343$$,$share_id$jscomp$19$$,$meta74331$$){this.$p__74327$=$p__74327$jscomp$1$$;this.$map__74328$=$map__74328$jscomp$1$$;this.params=$params$jscomp$384$$;this.$file_id$=$file_id$jscomp$343$$;this.$share_id$=$share_id$jscomp$19$$;this.$meta74331$=$meta74331$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$fetch_bundle_74330$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$fetch_bundle_74330$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5346$app_DOT_main_DOT_data_DOT_viewer_SLASH_fetch_bundle$$},$app$main$data$viewer$fetch_bundle_74330$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74332$$,$meta74331__$1$$){return new $app$main$data$viewer$fetch_bundle_74330$$(this.$p__74327$,this.$map__74328$,this.params,this.$file_id$,this.$share_id$,$meta74331__$1$$)},$app$main$data$viewer$fetch_bundle_74330$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74331$},$app$main$data$viewer$fetch_bundle_74330$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$fetch_bundle_74330$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){function $resolve$jscomp$42$$($p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$){var $key$jscomp$398$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$,0,null);$p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$,1,null);$p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$7157$$.$file_id$,$APP.$cljs$cst$3967$fragment_id$$,$APP.$cljs$core$_deref$$($p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$)],null);$p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$=$APP.$cljs$core$uuid_QMARK_$$($self__$jscomp$7157$$.$share_id$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$,$APP.$cljs$cst$3262$share_id$$,$self__$jscomp$7157$$.$share_id$):$p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$;return $APP.$beicon$v2$core$map$$(function($p1__74326_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$key$jscomp$398$$,$p1__74326_SHARP_$$],null)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$142$data$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3966$get_file_fragment$$,$p__74342_params__$1$jscomp$48_params__$2$jscomp$4_pointer$$)))}var $self__$jscomp$7157$$=this,$params_SINGLEQUOTE_$jscomp$1$$=function(){var $G__74341$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$7157$$.$file_id$,$APP.$cljs$cst$227$features$$,$APP.$app$common$features$supported_features$$],null);return $APP.$cljs$core$uuid_QMARK_$$($self__$jscomp$7157$$.$share_id$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__74341$$,$APP.$cljs$cst$3262$share_id$$,$self__$jscomp$7157$$.$share_id$):$G__74341$$}();return $APP.$beicon$v2$core$mapcat$$(function($JSCompiler_temp_const$jscomp$2049_fonts$jscomp$27_p__74351$$){var $G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$2049_fonts$jscomp$27_p__74351$$);$JSCompiler_temp_const$jscomp$2049_fonts$jscomp$27_p__74351$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$,$APP.$cljs$cst$2980$fonts$$);var $JSCompiler_temp_const$jscomp$2048_team$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$,$APP.$cljs$cst$2503$team$$);$JSCompiler_temp_const$jscomp$2049_fonts$jscomp$27_p__74351$$=$APP.$app$main$data$fonts$fonts_fetched$$($JSCompiler_temp_const$jscomp$2049_fonts$jscomp$27_p__74351$$);
$JSCompiler_temp_const$jscomp$2048_team$jscomp$53$$=$APP.$app$main$features$initialize$$($APP.$cljs$cst$227$features$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$2048_team$jscomp$53$$));$G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$,$self__$jscomp$7157$$.params]));
$G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$=$app$main$data$viewer$bundle_fetched$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$viewer$bundle_fetched$$.$cljs$core$IFn$_invoke$arity$1$($G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$):$app$main$data$viewer$bundle_fetched$$($G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$2049_fonts$jscomp$27_p__74351$$,
$JSCompiler_temp_const$jscomp$2048_team$jscomp$53$$,$G__74353$jscomp$inline_9794_JSCompiler_inline_result$jscomp$2050_map__74352__$1$$)},$APP.$beicon$v2$core$mapcat$$(function($bundle$jscomp$3$$){return $APP.$beicon$v2$core$map$$(function($data$jscomp$442$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($bundle$jscomp$3$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$142$data$$,$data$jscomp$442$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__74357$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74357$$,0,null);var $object$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74357$$,1,null);return $APP.$app$common$transit$pointer_QMARK_$$($object$jscomp$38$$)?$resolve$jscomp$42$$($p__74357$$):(0,$APP.$beicon$v2$core$of$$)($p__74357$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($bundle$jscomp$3$$)))))))},
$APP.$beicon$v2$core$mapcat$$(function($bundle$jscomp$4$$){return $APP.$beicon$v2$core$map$$(function($pages_index$jscomp$2$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($bundle$jscomp$4$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$142$data$$],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1635$pages_index$$,$pages_index$jscomp$2$$)},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__74361$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74361$$,0,null);var $page$jscomp$151$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__74361$$,1,null);return $APP.$app$common$transit$pointer_QMARK_$$($page$jscomp$151$$)?$resolve$jscomp$42$$($p__74361$$):(0,$APP.$beicon$v2$core$of$$)($p__74361$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$seq$$($APP.$cljs$cst$1635$pages_index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$208$file$$.$cljs$core$IFn$_invoke$arity$1$($bundle$jscomp$4$$))))))))},
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5347$get_view_only_bundle$$,$params_SINGLEQUOTE_$jscomp$1$$))))});return new $app$main$data$viewer$fetch_bundle_74330$$($p__74327$$,$map__74328__$1$$,$map__74328__$1$$,$file_id$jscomp$342$$,$share_id$jscomp$18$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$viewer$initialize$$=function($p__74304$$){var $map__74305__$1$$=$APP.$cljs$core$__destructure_map$$($p__74304$$),$file_id$jscomp$340$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74305__$1$$,$APP.$cljs$cst$1649$file_id$$),$share_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74305__$1$$,$APP.$cljs$cst$3262$share_id$$);typeof $app$main$data$viewer$initialize_74306$$==="undefined"&&($app$main$data$viewer$initialize_74306$$=function($p__74304$jscomp$1$$,
$map__74305$jscomp$1$$,$params$jscomp$382$$,$file_id$jscomp$341$$,$share_id$jscomp$17$$,$meta74307$$){this.$p__74304$=$p__74304$jscomp$1$$;this.$map__74305$=$map__74305$jscomp$1$$;this.params=$params$jscomp$382$$;this.$file_id$=$file_id$jscomp$341$$;this.$share_id$=$share_id$jscomp$17$$;this.$meta74307$=$meta74307$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5344$app_DOT_main_DOT_data_DOT_viewer_SLASH_initialize$$},$app$main$data$viewer$initialize_74306$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_74308$$,$meta74307__$1$$){return new $app$main$data$viewer$initialize_74306$$(this.$p__74304$,this.$map__74305$,this.params,this.$file_id$,this.$share_id$,$meta74307__$1$$)},$app$main$data$viewer$initialize_74306$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta74307$},$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2903$$,$state$jscomp$1109$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1109$$,
$APP.$cljs$cst$1934$current_file_id$$,this.$file_id$),$APP.$cljs$cst$3537$current_share_id$$,this.$share_id$),$APP.$cljs$cst$2239$viewer_local$$,function($lstate$jscomp$1$$){return $lstate$jscomp$1$$==null?$APP.$app$main$data$viewer$default_local_state$$:$lstate$jscomp$1$$}),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$3262$share_id$$],null),this.$share_id$)},$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__74316$jscomp$inline_9796_JSCompiler_inline_result$jscomp$2051__$jscomp$2904$$,$state$jscomp$1110$$){$G__74316$jscomp$inline_9796_JSCompiler_inline_result$jscomp$2051__$jscomp$2904$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(this.params);$G__74316$jscomp$inline_9796_JSCompiler_inline_result$jscomp$2051__$jscomp$2904$$=$app$main$data$viewer$fetch_bundle$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$viewer$fetch_bundle$$.$cljs$core$IFn$_invoke$arity$1$($G__74316$jscomp$inline_9796_JSCompiler_inline_result$jscomp$2051__$jscomp$2904$$):$app$main$data$viewer$fetch_bundle$$($G__74316$jscomp$inline_9796_JSCompiler_inline_result$jscomp$2051__$jscomp$2904$$);return(0,$APP.$beicon$v2$core$of$$)($G__74316$jscomp$inline_9796_JSCompiler_inline_result$jscomp$2051__$jscomp$2904$$,$APP.$cljs$cst$1931$profile$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1110$$)!=null?$app$main$data$viewer$fetch_comment_threads$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$data$viewer$fetch_comment_threads$$.$cljs$core$IFn$_invoke$arity$1$(this.params):$app$main$data$viewer$fetch_comment_threads$$(this.params):null,$APP.$cljs$core$truth_$$($APP.$cljs$cst$3262$share_id$$.$cljs$core$IFn$_invoke$arity$1$(this.params))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"shared-prototipe-visited"],null))):null)},$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$viewer$initialize_74306$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){var $name$jscomp$424$$=["viewer-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.$file_id$)].join("");return $APP.$app$util$globals$global$$.name=$name$jscomp$424$$});return new $app$main$data$viewer$initialize_74306$$($p__74304$$,$map__74305__$1$$,$map__74305__$1$$,$file_id$jscomp$340$$,$share_id$jscomp$16$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$viewer$comments$comments_layer$$=function($cursor$jscomp$1_props_75679$$){var $zoom$jscomp$64$$=$cursor$jscomp$1_props_75679$$.zoom,$frame$jscomp$58$$=$cursor$jscomp$1_props_75679$$.frame,$file$jscomp$155$$=$cursor$jscomp$1_props_75679$$.file,$page$jscomp$155$$=$cursor$jscomp$1_props_75679$$.page,$profile$jscomp$70$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$local$jscomp$29$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$);$cursor$jscomp$1_props_75679$$=$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$3489$comments$$);
var $open_thread_id$$=$APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$29$$),$page_id$jscomp$421$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$155$$),$file_id$jscomp$367_on_click$jscomp$29$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$155$$),$frame_id$jscomp$136$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$58$$),$vsize$$=$APP.$cljs$cst$5363$viewport_size$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_local$$)),
$threads$jscomp$10_tpos_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$421$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2236$pages$$,$page_id$jscomp$421$$,$APP.$cljs$cst$2069$comment_thread_positions$$],null)),$APP.$app$main$refs$viewer_data$$)}),$positions$jscomp$4$$=
$APP.$rumext$v2$deref$$($threads$jscomp$10_tpos_ref$$),$threads_map$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$),$frame_corner$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame$jscomp$58$$)],function(){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$58$$)))}),$modifier1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_corner$$)],
function(){return $APP.$app$common$geom$matrix$translate$$($APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$app$common$geom$point$negate$$($frame_corner$$))}),$modifier2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_corner$$)],function(){return $APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($frame_corner$$))});$threads$jscomp$10_tpos_ref$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($threads_map$jscomp$4$$),$APP.$rumext$v2$adapt$$($positions$jscomp$4$$),$APP.$rumext$v2$adapt$$($frame$jscomp$58$$),$APP.$rumext$v2$adapt$$($local$jscomp$29$$),$APP.$rumext$v2$adapt$$($profile$jscomp$70$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__75689__$1_p__75688_position$jscomp$191$$){$map__75689__$1_p__75688_position$jscomp$191$$=$APP.$cljs$core$__destructure_map$$($map__75689__$1_p__75688_position$jscomp$191$$);
$map__75689__$1_p__75688_position$jscomp$191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75689__$1_p__75688_position$jscomp$191$$,$APP.$cljs$cst$1681$position$$);return $APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$($frame$jscomp$58$$,$map__75689__$1_p__75688_position$jscomp$191$$)},$APP.$app$main$data$comments$apply_filters$$($local$jscomp$29$$,$profile$jscomp$70$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__75676_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__75676_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$58$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$viewer$comments$update_thread_position$$,$positions$jscomp$4$$),$APP.$cljs$core$vals$$($threads_map$jscomp$4$$)))))});var $on_bubble_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_thread_id$$)],function($map__75692__$1_p__75691$$){$map__75692__$1_p__75691$$=
$APP.$cljs$core$__destructure_map$$($map__75692__$1_p__75691$$);var $id$jscomp$921$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75692__$1_p__75691$$,$APP.$cljs$cst$266$id$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($open_thread_id$$,$id$jscomp$921$$)?$APP.$app$main$data$comments$close_thread$$():$APP.$cljs$core$with_meta$$($APP.$app$main$data$comments$open_thread$$($map__75692__$1_p__75691$$),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer"],null)))});$file_id$jscomp$367_on_click$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_thread_id$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$64$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$421$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$367_on_click$jscomp$29$$),$APP.$rumext$v2$adapt$$($modifier2$$)],function($event$jscomp$277_params$jscomp$414_position$jscomp$192$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$277_params$jscomp$414_position$jscomp$192$$);
if($open_thread_id$$!=null)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$());$event$jscomp$277_params$jscomp$414_position$jscomp$192$$=$APP.$app$common$geom$point$transform$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$dom$get_offset_position$$($event$jscomp$277_params$jscomp$414_position$jscomp$192$$.nativeEvent),$APP.$cljs$cst$1515$x$$,function($p1__75677_SHARP_$$){return $p1__75677_SHARP_$$/
$zoom$jscomp$64$$}),$APP.$cljs$cst$1516$y$$,function($p1__75678_SHARP_$$){return $p1__75678_SHARP_$$/$zoom$jscomp$64$$}),$modifier2$$);$event$jscomp$277_params$jscomp$414_position$jscomp$192$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1681$position$$,$event$jscomp$277_params$jscomp$414_position$jscomp$192$$,$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$155$$),$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$155$$)],
null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$create_draft$$($event$jscomp$277_params$jscomp$414_position$jscomp$192$$))});var $on_draft_cancel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$())}),$on_draft_submit$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$136$$),
$APP.$rumext$v2$adapt$$($modifier2$$)],function($draft$jscomp$1_params$jscomp$415$$){$draft$jscomp$1_params$jscomp$415$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($draft$jscomp$1_params$jscomp$415$$,$APP.$cljs$cst$1612$frame_id$$,$frame_id$jscomp$136$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$comments$create_thread_on_viewer$$($draft$jscomp$1_params$jscomp$415$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$comments$close_thread$$()]))});
return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$file_id$jscomp$367_on_click$jscomp$29$$,className:"main_ui_viewer_comments__comments-section",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:""+($cursor$jscomp$1_props_75679$$??"")+" main_ui_viewer_comments__viewer-comments-container",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_comments__threads",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$110$$,$item$jscomp$121$$){$out_arr__44092__auto__$jscomp$110$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_bubble_STAR_$$,
{thread:$item$jscomp$121$$,positionModifier:$modifier1$$,zoom:$zoom$jscomp$64$$,onClick:$on_bubble_click$$,isOpen:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$121$$),$APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$29$$)),origin:$APP.$cljs$cst$1597$viewer$$},$APP.$cljs$cst$3479$seqn$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$121$$)));return $out_arr__44092__auto__$jscomp$110$$},[],$threads$jscomp$10_tpos_ref$$),
function(){var $temp__5825__auto__$jscomp$328$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($threads_map$jscomp$4$$,$open_thread_id$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$328$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_thread_STAR_$$,{thread:$temp__5825__auto__$jscomp$328$$,positionModifier:$modifier1$$,viewport:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1655$offset_x$$,0,$APP.$cljs$cst$1656$offset_y$$,0,$APP.$cljs$cst$290$width$$,
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vsize$$),$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vsize$$)],null),zoom:$zoom$jscomp$64$$}):null}(),function(){var $temp__5825__auto__$jscomp$329$$=$APP.$cljs$cst$3488$draft$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$29$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$329$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$comments$comment_floating_thread_draft_STAR_$$,{draft:$temp__5825__auto__$jscomp$329$$,
positionModifier:$modifier1$$,onCancel:$on_draft_cancel$$,onSubmit:$on_draft_submit$$,viewport:null,zoom:$zoom$jscomp$64$$}):null}()]})})})};
$app$main$ui$viewer$comments$comments_sidebar_STAR_$$=function($page$jscomp$156_props_75696$$){var $profiles$jscomp$2$$=$page$jscomp$156_props_75696$$.profiles,$frame$jscomp$59$$=$page$jscomp$156_props_75696$$.frame;$page$jscomp$156_props_75696$$=$page$jscomp$156_props_75696$$.page;var $profile$jscomp$71_threads$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$local$jscomp$30$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$threads_map$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$);
$profile$jscomp$71_threads$jscomp$11$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__75701__$1_p__75698_position$jscomp$193$$){$map__75701__$1_p__75698_position$jscomp$193$$=$APP.$cljs$core$__destructure_map$$($map__75701__$1_p__75698_position$jscomp$193$$);$map__75701__$1_p__75698_position$jscomp$193$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__75701__$1_p__75698_position$jscomp$193$$,$APP.$cljs$cst$1681$position$$);return $APP.$app$common$geom$shapes$intersect$has_point_QMARK_$$($frame$jscomp$59$$,
$map__75701__$1_p__75698_position$jscomp$193$$)},$APP.$app$main$data$comments$apply_filters$$($local$jscomp$30$$,$profile$jscomp$71_threads$jscomp$11$$,$APP.$cljs$core$vals$$($threads_map$jscomp$5$$)));return(0,$APP.$rumext$v2$jsx$$)("aside",{className:"main_ui_viewer_comments__comments-sidebar",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_comments__settings-bar-inside",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$comments$comments_sidebar_STAR_$$,{fromViewer:!0,
profiles:$profiles$jscomp$2$$,threads:$profile$jscomp$71_threads$jscomp$11$$,pageId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$156_props_75696$$)})})})};
$app$main$ui$inspect$left_sidebar$make_collapsed_iref$$=function($id$jscomp$1083$$){return function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2239$viewer_local$$,$APP.$cljs$cst$2056$collapsed$$,$id$jscomp$1083$$],null)),$APP.$app$main$store$state$$)}};
$app$main$ui$inspect$left_sidebar$left_sidebar$$=function($frame$jscomp$109_map__83431_props_83430$$){$frame$jscomp$109_map__83431_props_83430$$=$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$109_map__83431_props_83430$$);var $local$jscomp$36_map__83431__$1_selected$jscomp$221$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$109_map__83431_props_83430$$);$frame$jscomp$109_map__83431_props_83430$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$36_map__83431__$1_selected$jscomp$221$$,
$APP.$cljs$cst$1611$frame$$);var $objects$jscomp$853_page$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$36_map__83431__$1_selected$jscomp$221$$,$APP.$cljs$cst$1629$page$$);$local$jscomp$36_map__83431__$1_selected$jscomp$221$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$36_map__83431__$1_selected$jscomp$221$$,$APP.$cljs$cst$2894$local$$);$local$jscomp$36_map__83431__$1_selected$jscomp$221$$=$APP.$cljs$cst$1938$selected$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$36_map__83431__$1_selected$jscomp$221$$);
$objects$jscomp$853_page$jscomp$180$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$853_page$jscomp$180$$);return(0,$APP.$rumext$v2$jsx$$)("aside",{className:"main_ui_inspect_left_sidebar__settings-bar-left",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_left_sidebar__settings-bar-inside",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_inspect_left_sidebar__element-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$left_sidebar$layer_item$$,
{item:$frame$jscomp$109_map__83431_props_83430$$,selected:$local$jscomp$36_map__83431__$1_selected$jscomp$221$$,index:0,objects:$objects$jscomp$853_page$jscomp$180$$,"sortable?":!1,"filtered?":!1,depth:-2,"hide-toggle?":!0})})})})};
$app$main$ui$inspect$render$handle_hover_shape$$=function($shape$jscomp$1116$$,$hover_QMARK_$jscomp$13$$){return function($event$jscomp$783$$){if($APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1116$$)||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1116$$))return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$783$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$783$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$hover_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1116$$),
$hover_QMARK_$jscomp$13$$))}};
$app$main$ui$inspect$render$select_shape$$=function($shape$jscomp$1117$$){return function($event$jscomp$784$$){if($APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1117$$)||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1117$$))return null;$APP.$app$util$dom$stop_propagation$$($event$jscomp$784$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$784$$);return $APP.$cljs$core$truth_$$($event$jscomp$784$$.shiftKey)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1117$$))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1117$$)))}};
$app$main$ui$inspect$render$shape_wrapper_factory$$=function($component$jscomp$138$$){return function($frame$jscomp$110_props_83432$$){var $shape$jscomp$1118$$=$frame$jscomp$110_props_83432$$.shape,$childs$jscomp$26$$=$frame$jscomp$110_props_83432$$.childs;$frame$jscomp$110_props_83432$$=$frame$jscomp$110_props_83432$$.frame;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1618$svg_raw$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1118$$))||
$APP.$cljs$core$contains_QMARK_$$($APP.$app$main$ui$shapes$svg_raw$graphic_element$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1118$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$78$tag$$],null)))?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$shape$shape_container$$,{shape:$shape$jscomp$1118$$,onPointerEnter:$app$main$ui$inspect$render$handle_hover_shape$$($shape$jscomp$1118$$,
!0),onPointerLeave:$app$main$ui$inspect$render$handle_hover_shape$$($shape$jscomp$1118$$,!1),onClick:$app$main$ui$inspect$render$select_shape$$($shape$jscomp$1118$$),children:(0,$APP.$rumext$v2$jsx$$)($component$jscomp$138$$,{shape:$shape$jscomp$1118$$,frame:$frame$jscomp$110_props_83432$$,childs:$childs$jscomp$26$$,"is-child-selected?":!0})}):(0,$APP.$rumext$v2$jsx$$)($component$jscomp$138$$,{shape:$shape$jscomp$1118$$,frame:$frame$jscomp$110_props_83432$$,childs:$childs$jscomp$26$$})}};
$app$main$ui$inspect$render$frame_container_factory$$=function($objects$jscomp$854$$){var $shape_container$jscomp$8$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$854$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$854$$),$frame_wrapper$jscomp$3$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$frame$frame_shape$$($shape_container$jscomp$8$$));
return $APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_83435_props__$1$jscomp$106$$){var $shape$jscomp$1119$$=$props_83435_props__$1$jscomp$106$$.shape,$childs$jscomp$27$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83434_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$854$$,$p1__83434_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1119$$));$props_83435_props__$1$jscomp$106$$=
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},$props_83435_props__$1$jscomp$106$$),{shape:$shape$jscomp$1119$$,childs:$childs$jscomp$27$$});return(0,$APP.$rumext$v2$create_element$$)($frame_wrapper$jscomp$3$$,$props_83435_props__$1$jscomp$106$$)})};
$app$main$ui$inspect$render$group_container_factory$$=function($objects$jscomp$855$$){var $shape_container$jscomp$9$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$855$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$855$$),$group_wrapper$jscomp$3$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$group$group_shape$$($shape_container$jscomp$9$$));
return function($props_83438_props__$1$jscomp$107$$){var $childs$jscomp$28$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83437_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$855$$,$p1__83437_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_83438_props__$1$jscomp$107$$.shape));$props_83438_props__$1$jscomp$107$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},
$props_83438_props__$1$jscomp$107$$),{childs:$childs$jscomp$28$$});return(0,$APP.$rumext$v2$create_element$$)($group_wrapper$jscomp$3$$,$props_83438_props__$1$jscomp$107$$)}};
$app$main$ui$inspect$render$bool_container_factory$$=function($objects$jscomp$856$$){var $shape_container$jscomp$10$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$856$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$856$$),$bool_wrapper$jscomp$2$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$bool$bool_shape$$($shape_container$jscomp$10$$));
return function($props_83440_props__$1$jscomp$108$$){var $children$jscomp$317$$=$APP.$cljs$core$select_keys$$($objects$jscomp$856$$,$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$856$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_83440_props__$1$jscomp$108$$.shape)));$props_83440_props__$1$jscomp$108$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},
$props_83440_props__$1$jscomp$108$$),{childs:$children$jscomp$317$$});return(0,$APP.$rumext$v2$create_element$$)($bool_wrapper$jscomp$2$$,$props_83440_props__$1$jscomp$108$$)}};
$app$main$ui$inspect$render$svg_raw_container_factory$$=function($objects$jscomp$857$$){var $shape_container$jscomp$11$$=$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$inspect$render$shape_container_factory$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$857$$):$app$main$ui$inspect$render$shape_container_factory$$($objects$jscomp$857$$),$svg_raw_wrapper$jscomp$2$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$svg_raw$svg_raw_shape$$($shape_container$jscomp$11$$));
return function($props_83443_props__$1$jscomp$109$$){var $childs$jscomp$29$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83442_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$857$$,$p1__83442_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_83443_props__$1$jscomp$109$$.shape));$props_83443_props__$1$jscomp$109$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({},
$props_83443_props__$1$jscomp$109$$),{childs:$childs$jscomp$29$$});return(0,$APP.$rumext$v2$create_element$$)($svg_raw_wrapper$jscomp$2$$,$props_83443_props__$1$jscomp$109$$)}};
$app$main$ui$inspect$render$shape_container_factory$$=function($objects$jscomp$858$$){var $path_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$path$path_shape$$),$text_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$text$text_shape$$),$rect_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$rect$rect_shape$$),$image_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$image$image_shape$$),
$circle_wrapper$jscomp$1$$=$app$main$ui$inspect$render$shape_wrapper_factory$$($APP.$app$main$ui$shapes$circle$circle_shape$$);return function($frame_container$jscomp$1_props_83445$$){var $opts$jscomp$313_shape$jscomp$1123$$=$frame_container$jscomp$1_props_83445$$.shape,$G__83447_G__83447__$1_frame$jscomp$111$$=$frame_container$jscomp$1_props_83445$$.frame;$frame_container$jscomp$1_props_83445$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$858$$)],
function(){return $app$main$ui$inspect$render$frame_container_factory$$($objects$jscomp$858$$)});var $group_container$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$858$$)],function(){return $app$main$ui$inspect$render$group_container_factory$$($objects$jscomp$858$$)}),$bool_container$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$858$$)],function(){return $app$main$ui$inspect$render$bool_container_factory$$($objects$jscomp$858$$)}),
$svg_raw_container$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$858$$)],function(){return $app$main$ui$inspect$render$svg_raw_container_factory$$($objects$jscomp$858$$)});if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($opts$jscomp$313_shape$jscomp$1123$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$313_shape$jscomp$1123$$)):$opts$jscomp$313_shape$jscomp$1123$$)){var $shape__$1$jscomp$121$$=
$APP.$cljs$core$truth_$$($G__83447_G__83447__$1_frame$jscomp$111$$)?$APP.$app$common$geom$shapes$translate_to_frame$$($opts$jscomp$313_shape$jscomp$1123$$,$G__83447_G__83447__$1_frame$jscomp$111$$):$opts$jscomp$313_shape$jscomp$1123$$;$opts$jscomp$313_shape$jscomp$1123$$={shape:$shape__$1$jscomp$121$$,frame:$G__83447_G__83447__$1_frame$jscomp$111$$};$G__83447_G__83447__$1_frame$jscomp$111$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$121$$);$G__83447_G__83447__$1_frame$jscomp$111$$=
$G__83447_G__83447__$1_frame$jscomp$111$$ instanceof $APP.$cljs$core$Keyword$$?$G__83447_G__83447__$1_frame$jscomp$111$$.$fqn$:null;switch($G__83447_G__83447__$1_frame$jscomp$111$$){case "frame":return(0,$APP.$rumext$v2$create_element$$)($frame_container$jscomp$1_props_83445$$,$opts$jscomp$313_shape$jscomp$1123$$);case "text":return(0,$APP.$rumext$v2$create_element$$)($text_wrapper$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);case "rect":return(0,$APP.$rumext$v2$create_element$$)($rect_wrapper$jscomp$1$$,
$opts$jscomp$313_shape$jscomp$1123$$);case "path":return(0,$APP.$rumext$v2$create_element$$)($path_wrapper$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);case "image":return(0,$APP.$rumext$v2$create_element$$)($image_wrapper$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);case "circle":return(0,$APP.$rumext$v2$create_element$$)($circle_wrapper$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);case "group":return(0,$APP.$rumext$v2$create_element$$)($group_container$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);
case "bool":return(0,$APP.$rumext$v2$create_element$$)($bool_container$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);case "svg-raw":return(0,$APP.$rumext$v2$create_element$$)($svg_raw_container$jscomp$1$$,$opts$jscomp$313_shape$jscomp$1123$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83447_G__83447__$1_frame$jscomp$111$$)].join(""));}}else return null}};
$app$main$ui$inspect$render$render_frame_svg$$=function($local$jscomp$37_map__83449_props_83448$$){$local$jscomp$37_map__83449_props_83448$$=$APP.$rumext$v2$util$wrap_props$$($local$jscomp$37_map__83449_props_83448$$);var $frame__$1$jscomp$10_map__83449__$1$$=$APP.$cljs$core$__destructure_map$$($local$jscomp$37_map__83449_props_83448$$),$page$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$10_map__83449__$1$$,$APP.$cljs$cst$1629$page$$),$frame$jscomp$112$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$10_map__83449__$1$$,
$APP.$cljs$cst$1611$frame$$);$local$jscomp$37_map__83449_props_83448$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$10_map__83449__$1$$,$APP.$cljs$cst$2894$local$$);var $size$jscomp$172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$10_map__83449__$1$$,$APP.$cljs$cst$874$size$$),$objects$jscomp$859$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$181$$),$APP.$rumext$v2$adapt$$($frame$jscomp$112$$),
$APP.$rumext$v2$adapt$$($size$jscomp$172$$)],function(){return $APP.$app$main$ui$viewer$viewport_common$prepare_objects$$($frame$jscomp$112$$,$size$jscomp$172$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$181$$))});$frame__$1$jscomp$10_map__83449__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$859$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$112$$));
var $render$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$859$$)],function(){return $app$main$ui$inspect$render$frame_container_factory$$($objects$jscomp$859$$)});return(0,$APP.$rumext$v2$jsxs$$)("svg",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$172$$),xmlns:"http://www.w3.org/2000/svg",height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$172$$),children:[(0,$APP.$rumext$v2$jsx$$)($render$jscomp$2$$,
{shape:$frame__$1$jscomp$10_map__83449__$1$$,"view-box":$APP.$cljs$cst$1942$vbox$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$172$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$selection_feedback$selection_feedback$$,{frame:$frame__$1$jscomp$10_map__83449__$1$$,objects:$objects$jscomp$859$$,local:$local$jscomp$37_map__83449_props_83448$$,size:$size$jscomp$172$$})],id:"svg-frame",viewBox:$APP.$cljs$cst$1942$vbox$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$172$$),xmlnsXlink:"http://www.w3.org/1999/xlink",
fill:"none",version:"1.1"})};
$app$main$ui$viewer$inspect$handle_select_frame$$=function($event$jscomp$785$$){var $frame_id$jscomp$170$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$785$$),"value")),$over_section_QMARK_$$=$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$785$$),"inspect-svg-container"),$layout$jscomp$39$$=$APP.$goog$dom$getElement$$("viewer-layout"),$has_force_QMARK_$$=$APP.$app$util$dom$class_QMARK_$$($layout$jscomp$39$$,"force-visible");
$APP.$app$util$dom$prevent_default$$($event$jscomp$785$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$785$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($frame_id$jscomp$170$$));return $over_section_QMARK_$$?$has_force_QMARK_$$?$layout$jscomp$39$$!=null?$layout$jscomp$39$$.classList.remove("force-visible"):null:$APP.$app$util$dom$add_class_BANG_$$($layout$jscomp$39$$,"force-visible"):null};
$app$main$ui$viewer$inspect$viewport$$=function($local$jscomp$38_map__83456_props_83455$$){function $on_mouse_wheel$jscomp$3$$($event$jscomp$786_event__$1$jscomp$8$$){return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$786_event__$1$jscomp$8$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$786_event__$1$jscomp$8$$),$event$jscomp$786_event__$1$jscomp$8$$=$event$jscomp$786_event__$1$jscomp$8$$.getBrowserEvent(),$event$jscomp$786_event__$1$jscomp$8$$.deltaY+$event$jscomp$786_event__$1$jscomp$8$$.deltaX>
0?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$decrease_zoom$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$increase_zoom$$)):null}$local$jscomp$38_map__83456_props_83455$$=$APP.$rumext$v2$util$wrap_props$$($local$jscomp$38_map__83456_props_83455$$);var $map__83456__$1_share_id$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($local$jscomp$38_map__83456_props_83455$$);$local$jscomp$38_map__83456_props_83455$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,$APP.$cljs$cst$2894$local$$);var $file$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,$APP.$cljs$cst$208$file$$),$page$jscomp$182$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,$APP.$cljs$cst$1629$page$$),$frame$jscomp$113$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,
$APP.$cljs$cst$1611$frame$$),$index$jscomp$590$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,$APP.$cljs$cst$1801$index$$),$viewer_pagination$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,$cljs$cst$6419$viewer_pagination$$),$size$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,$APP.$cljs$cst$874$size$$);$map__83456__$1_share_id$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83456__$1_share_id$jscomp$29$$,
$APP.$cljs$cst$3262$share_id$$);var $inspect_svg_container_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_section_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1161$info$$),$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$=$APP.$cljs$core$_deref$$($current_section_STAR_$jscomp$1$$);$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$,
$APP.$cljs$cst$273$code$$);var $map__83457_on_pointer_down$jscomp$24$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$273$code$$,318,318,768,$APP.$cljs$cst$1515$x$$,!0,$APP.$cljs$cst$258$right$$,null),$map__83457__$1_on_pointer_move$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($map__83457_on_pointer_down$jscomp$24$$),$set_right_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83457__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4614$set_size$$),
$right_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83457__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$874$size$$);$map__83457_on_pointer_down$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83457__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4610$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83457__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$);
$map__83457__$1_on_pointer_move$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83457__$1_on_pointer_move$jscomp$18$$,$APP.$cljs$cst$4612$on_pointer_move$$);var $handle_change_section$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($section$jscomp$47$$){return $APP.$cljs$core$reset_BANG_$$($current_section_STAR_$jscomp$1$$,$section$jscomp$47$$)}),$handle_expand$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($right_size$$)],
function(){var $G__83458$$=$right_size$$>318?318:768;return $set_right_size$$.$cljs$core$IFn$_invoke$arity$1$?$set_right_size$$.$cljs$core$IFn$_invoke$arity$1$($G__83458$$):$set_right_size$$($G__83458$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $key1$jscomp$10$$=$APP.$goog$events$listen$$($APP.$goog$global$$,"wheel",$on_mouse_wheel$jscomp$3$$,{passive:!1});return function(){return $APP.$goog$events$unlistenByKey$$($key1$jscomp$10$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$113$$))],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$113$$)))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$left_sidebar$left_sidebar$$,{frame:$frame$jscomp$113$$,local:$local$jscomp$38_map__83456_props_83455$$,page:$page$jscomp$182$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{id:"inspect-svg-wrapper",
"data-value":$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$113$$)])),onClick:$app$main$ui$viewer$inspect$handle_select_frame$$,className:"main_ui_viewer_inspect__inspect-svg-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($viewer_pagination$$,{index:$index$jscomp$590$$,"num-frames":$APP.$cljs$core$count$$($APP.$cljs$cst$5349$frames$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$182$$)),
"left-bar":!0,"right-bar":!0}),(0,$APP.$rumext$v2$jsx$$)("div",{id:"inspect-svg-container",ref:$inspect_svg_container_ref$$,className:"main_ui_viewer_inspect__inspect-svg-container",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$render$render_frame_svg$$,{frame:$frame$jscomp$113$$,page:$page$jscomp$182$$,local:$local$jscomp$38_map__83456_props_83455$$,size:$size$jscomp$173$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--right-sidebar-width":$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?
""+($right_size$$??"")+"px":null},className:"main_ui_viewer_inspect__sidebar-container "+($can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?"":"main_ui_viewer_inspect__not-expand")+" "+($can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?"main_ui_viewer_inspect__expanded":""),children:[$can_be_expanded_QMARK_$jscomp$1_current_section$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__83457_on_pointer_down$jscomp$24$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$12$$,
onPointerMove:$map__83457__$1_on_pointer_move$jscomp$18$$,className:"main_ui_viewer_inspect__resize-area"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$inspect$right_sidebar$right_sidebar_STAR_$$,{frame:$frame$jscomp$113$$,selected:$APP.$cljs$cst$1938$selected$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$38_map__83456_props_83455$$),page:$page$jscomp$182$$,file:$file$jscomp$201$$,onChangeSection:$handle_change_section$$,onExpand:$handle_expand$jscomp$1$$,shareId:$map__83456__$1_share_id$jscomp$29$$})]})]})};
$app$main$ui$viewer$login$login_register_modal$$=function($main_section_props_83451$$){function $success_register$jscomp$1$$($data$jscomp$513$$){$APP.$cljs$core$reset_BANG_$$($register_token$jscomp$1$$,$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$513$$));return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5517$register_validate$$):$set_current_section$$($APP.$cljs$cst$5517$register_validate$$)}
function $success_login$jscomp$1$$(){return window.location.reload(!0)}function $success_email_sent$$($email$jscomp$21$$){$APP.$cljs$core$reset_BANG_$$($user_email$jscomp$1$$,$email$jscomp$21$$);return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$6421$email_sent$$):$set_current_section$$($cljs$cst$6421$email_sent$$)}$APP.$rumext$v2$util$wrap_props$$($main_section_props_83451$$);var $user_email$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),
$register_token$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$current_section_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1172$login$$),$current_section$jscomp$3$$=$APP.$cljs$core$_deref$$($current_section_STAR_$jscomp$2$$),$set_current_section$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__83450_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($current_section_STAR_$jscomp$2$$,$p1__83450_SHARP_$$)}),
$set_section$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$787_section$jscomp$48$$){$event$jscomp$787_section$jscomp$48$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$787_section$jscomp$48$$),"value"));return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$787_section$jscomp$48$$):
$set_current_section$$($event$jscomp$787_section$jscomp$48$$)}),$go_back_to_login$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $set_current_section$$.$cljs$core$IFn$_invoke$arity$1$?$set_current_section$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1172$login$$):$set_current_section$$($APP.$cljs$cst$1172$login$$)});$main_section_props_83451$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$3$$,$APP.$cljs$cst$1172$login$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$3$$,
$cljs$cst$6420$register$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$3$$,$APP.$cljs$cst$5517$register_validate$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_viewer_login__modal-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.continue-with-penpot")}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:function($event$jscomp$788$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$788$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())},className:"main_ui_viewer_login__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__modal-content",children:[function(){var $G__83452__$1$$=$current_section$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$current_section$jscomp$3$$.$fqn$:null;switch($G__83452__$1$$){case "login":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$login$login_dialog_STAR_$$,{onSuccessCallback:$success_login$jscomp$1$$,origin:$APP.$cljs$cst$1597$viewer$$}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__links",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__recovery-request",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"recovery-request",className:"main_ui_viewer_login__recovery-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.forgot-password")})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__register",children:[(0,$APP.$rumext$v2$jsxs$$)("span",
{className:"main_ui_viewer_login__register-text",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register")," "]}),(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"register",className:"main_ui_viewer_login__register-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.register-submit")})]})]})]});case "register":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_methods_STAR_$$,
{onSuccessCallback:$success_register$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__links",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__account",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.already-have-account")," "]}),(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"login",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.login-here")})]})})]});
case "register-validate":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_login__form-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_validate_form_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$_deref$$($register_token$jscomp$1$$)],null),onSuccessCallback:$success_email_sent$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__links",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_viewer_login__register",children:(0,$APP.$rumext$v2$jsx$$)("a",{onClick:$set_section$jscomp$1$$,"data-value":"register",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.go-back")})})})]});case "recovery-request":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$recovery_request$recovery_request_page$$,{"go-back-callback":$go_back_to_login$$,"on-success-callback":$success_email_sent$$});case "email-sent":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__form-container",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$register_success_page_STAR_$$,{params:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3207$email$$,$APP.$cljs$core$_deref$$($user_email$jscomp$1$$)],null)})});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83452__$1$$)].join(""));}}(),$main_section_props_83451$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_login__links",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$auth$register$terms_register_STAR_$$,
{})}):null]})]})})};
$app$main$ui$viewer$share_link$prepare_params$$=function($p__83459_pages$jscomp$12$$){var $map__83460__$1_who_inspect$$=$APP.$cljs$core$__destructure_map$$($p__83459_pages$jscomp$12$$);$p__83459_pages$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83460__$1_who_inspect$$,$APP.$cljs$cst$2236$pages$$);var $who_comment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83460__$1_who_inspect$$,$APP.$cljs$cst$5514$who_comment$$);$map__83460__$1_who_inspect$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83460__$1_who_inspect$$,
$APP.$cljs$cst$5515$who_inspect$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2236$pages$$,$p__83459_pages$jscomp$12$$,$APP.$cljs$cst$5514$who_comment$$,$who_comment$$,$APP.$cljs$cst$5515$who_inspect$$,$map__83460__$1_who_inspect$$],null)};
$app$main$ui$viewer$share_link$share_link_dialog$$=function($perms_visible_QMARK__props_83465$$){function $on_comment_change$$($value$jscomp$1024$$){$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($options_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5514$who_comment$$,$value$jscomp$1024$$)}function $on_inspect_change$$($value$jscomp$1023$$){$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($options_STAR_$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5515$who_inspect$$,$value$jscomp$1023$$)}function $toggle_perms_visibility$$(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($perms_visible_STAR_$$,$APP.$cljs$core$not$$)}function $delete_link$$(){var $params$jscomp$453$$=$app$main$ui$viewer$share_link$prepare_params$$($options$jscomp$650$$),$slink$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83463_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1472$flags$$.$cljs$core$IFn$_invoke$arity$1$($p1__83463_SHARP_$$),
$APP.$cljs$cst$1472$flags$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$453$$))},$slinks$$);$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$delete_share_link$$($slink$jscomp$1$$))}function $try_delete_link$$(){return $APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!0)}function $copy_link$$(){$APP.$app$util$clipboard$to_clipboard$$($current_link$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.link-copied-success"),$APP.$cljs$cst$2364$timeout$$,1E3],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"copy-share-link",
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer"],null))]))}function $create_link$$(){var $params$jscomp$452_params__$1$jscomp$63$$=$app$main$ui$viewer$share_link$prepare_params$$($options$jscomp$650$$);$params$jscomp$452_params__$1$jscomp$63$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($params$jscomp$452_params__$1$jscomp$63$$,$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$202$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$common$create_share_link$$($params$jscomp$452_params__$1$jscomp$63$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-share-link",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"viewer",$cljs$cst$6424$can_comment$$,$APP.$cljs$cst$5514$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$452_params__$1$jscomp$63$$),$cljs$cst$6425$can_inspect_code$$,$APP.$cljs$cst$5515$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$452_params__$1$jscomp$63$$)],
null))]))}function $on_mark_checked_page$$($dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$){$dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$=$APP.$app$util$dom$get_target$$($dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$);var $checked_QMARK_$jscomp$8$$=$APP.$app$util$dom$checked_QMARK_$$($dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$),$page_id$jscomp$476$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$,
"page-id"));$dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$476$$,$APP.$cljs$core$first$$($APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$)));return 1<$APP.$cljs$core$count$$($APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$))||$dif_pages_QMARK__event$jscomp$790_target$jscomp$174$$?($APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($options_STAR_$$,
function($map__83469__$1_p__83468$$){$map__83469__$1_p__83468$$=$APP.$cljs$core$__destructure_map$$($map__83469__$1_p__83468$$);var $pages$jscomp$14_pages__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83469__$1_p__83468$$,$APP.$cljs$cst$2236$pages$$);$pages$jscomp$14_pages__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($checked_QMARK_$jscomp$8$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($pages$jscomp$14_pages__$1$jscomp$1$$,$page_id$jscomp$476$$):$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($pages$jscomp$14_pages__$1$jscomp$1$$,
$page_id$jscomp$476$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__83469__$1_p__83468$$,$APP.$cljs$cst$2236$pages$$,$pages$jscomp$14_pages__$1$jscomp$1$$),$cljs$cst$6423$all_pages$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($pages$jscomp$14_pages__$1$jscomp$1$$),$APP.$cljs$core$count$$($page_ids$jscomp$2$$)))})):null}function $on_toggle_all$$(){$APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,
!1);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($options_STAR_$$,function($state$jscomp$1256$$){return $cljs$cst$6423$all_pages$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1256$$)===!0?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1256$$,$cljs$cst$6423$all_pages$$,!1),$APP.$cljs$cst$2236$pages$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$183$$)])):
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1256$$,$cljs$cst$6423$all_pages$$,!0),$APP.$cljs$cst$2236$pages$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$202$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2236$pages$$],
null))))})}var $file$jscomp$202$$=$perms_visible_QMARK__props_83465$$.file,$page$jscomp$183$$=$perms_visible_QMARK__props_83465$$.page,$current_page_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$183$$),$slinks$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$share_links$$),$router$jscomp$8$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$router$$),$route$jscomp$24$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$route$$),$zoom_type$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_zoom_type$$),
$page_ids$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$202$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2236$pages$$),$perms_visible_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$perms_visible_QMARK__props_83465$$=$APP.$cljs$core$_deref$$($perms_visible_STAR_$$);var $confirm_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$confirm_QMARK_$$=$APP.$cljs$core$_deref$$($confirm_STAR_$$),
$options_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$6422$pages_mode$$,"current",$cljs$cst$6423$all_pages$$,!1,$APP.$cljs$cst$2236$pages$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$183$$)]),$APP.$cljs$cst$5514$who_comment$$,"team",$APP.$cljs$cst$5515$who_inspect$$,"team"],null)),$options$jscomp$650$$=$APP.$cljs$core$_deref$$($options_STAR_$$),
$current_link$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($slinks$$),$APP.$rumext$v2$adapt$$($options$jscomp$650$$),$APP.$rumext$v2$adapt$$($page_ids$jscomp$2$$)],function(){var $href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$=$app$main$ui$viewer$share_link$prepare_params$$($options$jscomp$650$$);$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$=
$APP.$cljs$core$__destructure_map$$($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$);var $pages$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$,$APP.$cljs$cst$2236$pages$$),$who_comment$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$,
$APP.$cljs$cst$5514$who_comment$$),$who_inspect$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$,$APP.$cljs$cst$5515$who_inspect$$),$slink$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83461_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5515$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($p1__83461_SHARP_$$),
$who_inspect$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5514$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($p1__83461_SHARP_$$),$who_comment$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($p1__83461_SHARP_$$),$pages$jscomp$13$$)},$slinks$$);return $APP.$cljs$core$truth_$$($slink$$)?($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83462_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($slink$$),$p1__83462_SHARP_$$)},$page_ids$jscomp$2$$),$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$2278$query_params$$.$cljs$core$IFn$_invoke$arity$1$($route$jscomp$24$$),
$APP.$cljs$cst$3262$share_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($slink$$)),$APP.$cljs$cst$2051$page_id$$,$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$),$APP.$cljs$cst$1801$index$$,"0"),$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$=$zoom_type$jscomp$2$$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$,
$APP.$cljs$cst$2204$zoom$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$,$APP.$cljs$cst$2204$zoom$$,$zoom_type$jscomp$2$$),$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$=$APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$($router$jscomp$8$$,$APP.$cljs$cst$1597$viewer$$,$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$),
""+($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$config$public_uri$$,$APP.$cljs$cst$738$fragment$$,$href$jscomp$22_map__83466_map__83466__$1_page_id$jscomp$475_params__$1$jscomp$62_params__$2$jscomp$8$$)??"")):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__share-modal",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__share-link-dialog",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__share-link-header",
children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_viewer_share_link__share-link-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function($event$jscomp$789$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$789$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$());return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()},title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
className:"main_ui_viewer_share_link__modal-close-button",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__share-link-section",children:[$APP.$cljs$core$not$$($confirm_QMARK_$$)&&$current_link$$!=null?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__custon-input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("input",
{type:"text",value:$APP.$cljs$core$truth_$$($current_link$$)?$current_link$$:"",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.placeholder"),readOnly:!0,className:"main_ui_viewer_share_link__input-text"}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.header.share.copy-link"),onClick:$copy_link$$,className:"main_ui_viewer_share_link__copy-button",children:$APP.$app$main$ui$icons$clipboard$$})]}):null,
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__hint-wrapper",children:[$confirm_QMARK_$$?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__hint",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-hint")}),$confirm_QMARK_$$===!0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__confirm-dialog",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__description",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.confirm-deletion-link-description")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__actions",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",onClick:function(){return $APP.$cljs$core$reset_BANG_$$($confirm_STAR_$$,!1)},value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),className:"main_ui_viewer_share_link__button-cancel"}),(0,$APP.$rumext$v2$jsx$$)("input",
{type:"button",onClick:$delete_link$$,value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.destroy-link"),className:"main_ui_viewer_share_link__button-danger"})]})]}):$current_link$$!=null?(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",onClick:$try_delete_link$$,value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.destroy-link"),className:"main_ui_viewer_share_link__button-danger"}):(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",onClick:$create_link$$,
value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.get-link"),className:"main_ui_viewer_share_link__button-active"})]})]}),$confirm_QMARK_$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__permissions-section",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$toggle_perms_visibility$$,className:"main_ui_viewer_share_link__manage-permissions",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_share_link__icon "+($APP.$cljs$core$truth_$$($perms_visible_QMARK__props_83465$$)?
"main_ui_viewer_share_link__rotated":""),children:$APP.$app$main$ui$icons$arrow$$}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.manage-ops")]}),$perms_visible_QMARK__props_83465$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[function(){var $all_selected_QMARK_$jscomp$2$$=$cljs$cst$6423$all_pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$),$pages$jscomp$15$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__83464_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$202$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$1635$pages_index$$,$p1__83464_SHARP_$$],null))},$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$202$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2236$pages$$],null))),$selected$jscomp$222$$=$APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__view-mode",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-pages")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__items",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($pages$jscomp$15$$))?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_viewer_share_link__checkbox-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:["page-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($current_page_id$jscomp$9$$)].join(""),className:"checked",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_share_link__checked",children:$APP.$app$main$ui$icons$status_tick$$}),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$183$$)]}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",
id:"page-"+($current_page_id$jscomp$9$$??""),"data-page-id":""+($current_page_id$jscomp$9$$??""),onChange:$on_mark_checked_page$$,checked:!0}),(0,$APP.$rumext$v2$jsx$$)("span",{children:[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.current-tag"))].join("")})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__select-all-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__checkbox-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"view-all",className:"main_ui_viewer_share_link__select-all-label",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$2$$)?"checked":"",children:$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$2$$)?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.view-all"),
(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"view-all",checked:$all_selected_QMARK_$jscomp$2$$,name:"pages-mode",onChange:$on_toggle_all$$})]})}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_share_link__count-pages",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("common.share-link.page-shared",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($selected$jscomp$222$$))]))})]}),(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_viewer_share_link__pages-selection",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$258$$,$id$jscomp$1085_p__83479$$){var $map__83480__$1_name$jscomp$511$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1085_p__83479$$);$id$jscomp$1085_p__83479$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83480__$1_name$jscomp$511$$,$APP.$cljs$cst$266$id$$);$map__83480__$1_name$jscomp$511$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83480__$1_name$jscomp$511$$,
$APP.$cljs$cst$725$name$$);$out_arr__44092__auto__$jscomp$258$$.push((0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_viewer_share_link__checkbox-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"page-"+($id$jscomp$1085_p__83479$$??""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$222$$,$id$jscomp$1085_p__83479$$)?"checked":"",children:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$222$$,$id$jscomp$1085_p__83479$$)?$APP.$app$main$ui$icons$status_tick$$:
null}),$map__83480__$1_name$jscomp$511$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_page_id$jscomp$9$$,$id$jscomp$1085_p__83479$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__current-tag",children:" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.current-tag")??"")}):null,(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"page-"+($id$jscomp$1085_p__83479$$??""),"data-page-id":""+($id$jscomp$1085_p__83479$$??""),onChange:$on_mark_checked_page$$,
checked:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$222$$,$id$jscomp$1085_p__83479$$)})]})},""+($id$jscomp$1085_p__83479$$??"")));return $out_arr__44092__auto__$jscomp$258$$},[],$pages$jscomp$15$$)})]})})]})}(),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__access-mode",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-can-comment")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__items",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_viewer_share_link__who-comment-select","default-value":""+($APP.$cljs$cst$5514$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$)??""),options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
"team",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.team-members")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"all",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.all-users")],null)],null),"on-change":$on_comment_change$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_share_link__inspect-mode",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_viewer_share_link__subtitle",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.permissions-can-inspect")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_share_link__items",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_viewer_share_link__who-inspect-select","default-value":""+($APP.$cljs$cst$5515$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$650$$)??""),options:new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"team",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.team-members")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"all",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.share-link.all-users")],null)],null),"on-change":$on_inspect_change$$})})]})]}):
null]})]})]})})};
$app$main$ui$viewer$thumbnails$thumbnails_content_STAR_$$=function($is_expanded$jscomp$2_props_83467$$){function $on_scroll$jscomp$3$$($event$jscomp$791_event__$1$jscomp$9$$){$event$jscomp$791_event__$1$jscomp$9$$=$event$jscomp$791_event__$1$jscomp$9$$.nativeEvent;return $event$jscomp$791_event__$1$jscomp$9$$.deltaY>0?$on_right_arrow_click$jscomp$2$$($event$jscomp$791_event__$1$jscomp$9$$):$on_left_arrow_click$jscomp$2$$($event$jscomp$791_event__$1$jscomp$9$$)}function $on_right_arrow_click$jscomp$2$$(){var $visible$jscomp$4$$=$APP.$cljs$core$_deref$$($width$jscomp$256$$)/
$APP.$cljs$core$_deref$$($element_width$$),$max_val$jscomp$7$$=$total$jscomp$28$$-$visible$jscomp$4$$;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$223$$,function($v$jscomp$698$$){return $v$jscomp$698$$<$max_val$jscomp$7$$?$v$jscomp$698$$+1:$v$jscomp$698$$})}function $on_left_arrow_click$jscomp$2$$(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$223$$,function($v$jscomp$697$$){return $v$jscomp$697$$>0?$v$jscomp$697$$-1:$v$jscomp$697$$})}
var $children$jscomp$318$$=$is_expanded$jscomp$2_props_83467$$.children,$total$jscomp$28$$=$is_expanded$jscomp$2_props_83467$$.total;$is_expanded$jscomp$2_props_83467$$=$is_expanded$jscomp$2_props_83467$$.isExpanded;var $container$jscomp$100$$=(0,$APP.$rumext$v2$use_ref$$)(),$width$jscomp$256$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(document.documentElement.clientWidth),$element_width$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(152),$offset$jscomp$223$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($width$jscomp$256$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$100$$),"clientWidth"))});return $APP.$cljs$core$truth_$$($is_expanded$jscomp$2_props_83467$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-list-expanded",
children:$children$jscomp$318$$})}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-content",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_left_arrow_click$jscomp$2$$,className:"main_ui_viewer_thumbnails__left-scroll-handler",children:$APP.$app$main$ui$icons$arrow$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_right_arrow_click$jscomp$2$$,className:"main_ui_viewer_thumbnails__right-scroll-handler",children:$APP.$app$main$ui$icons$arrow$$}),(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$container$jscomp$100$$,onWheel:$on_scroll$jscomp$3$$,className:"main_ui_viewer_thumbnails__thumbnails-list",children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($offset$jscomp$223$$)*152),"px"].join("")},className:"main_ui_viewer_thumbnails__thumbnails-list-inside",children:$children$jscomp$318$$})})]})};
$app$main$ui$viewer$thumbnails$thumbnails_summary_STAR_$$=function($props_83470$$){var $on_close$jscomp$51$$=$props_83470$$.onClose,$on_toggle_expand$jscomp$2$$=$props_83470$$.onToggleExpand;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer_thumbnails__thumbnails-summary",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer_thumbnails__counter",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.num-of-frames",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($props_83470$$.total)]))}),
(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_viewer_thumbnails__actions",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_toggle_expand$jscomp$2$$,className:"main_ui_viewer_thumbnails__expand-btn",children:$APP.$app$main$ui$icons$arrow$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_close$jscomp$51$$,className:"main_ui_viewer_thumbnails__close-btn",children:$APP.$app$main$ui$icons$close$$})]})]})};
$app$main$ui$viewer$thumbnails$thumbnails_panel_STAR_$$=function($container$jscomp$101_props_83474$$){function $on_close$jscomp$52$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$toggle_thumbnails_panel$$)}var $thumbnail_data$jscomp$2$$=$container$jscomp$101_props_83474$$.thumbnailData,$show$jscomp$9$$=$container$jscomp$101_props_83474$$.show,$index$jscomp$592$$=$container$jscomp$101_props_83474$$.index,$frames$jscomp$35$$=$container$jscomp$101_props_83474$$.frames,
$page$jscomp$184$$=$container$jscomp$101_props_83474$$.page,$expanded_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$expanded_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($expanded_state$$);$container$jscomp$101_props_83474$$=(0,$APP.$rumext$v2$use_ref$$)();var $objects$jscomp$861$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$184$$),$selected$jscomp$223$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_item_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($expanded_QMARK_$jscomp$4$$)],
function($_$jscomp$3198$$,$index__$1$jscomp$25$$){$APP.$cljs$core$compare_and_set_BANG_$$($selected$jscomp$223$$,!1,!0);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_frame_by_index$$($index__$1$jscomp$25$$));return $APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$4$$)?$on_close$jscomp$52$$():null}),$toggle_expand$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($expanded_state$$,
$APP.$cljs$core$not$$)});return(0,$APP.$rumext$v2$jsxs$$)("section",{style:{display:$APP.$cljs$core$not$$($show$jscomp$9$$)?"none":null},ref:$container$jscomp$101_props_83474$$,className:"main_ui_viewer_thumbnails__viewer-thumbnails "+($APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$4$$)?"main_ui_viewer_thumbnails__expanded":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnails_summary_STAR_$$,{onToggleExpand:$toggle_expand$$,onClose:$on_close$jscomp$52$$,total:$APP.$cljs$core$count$$($frames$jscomp$35$$)}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnails_content_STAR_$$,{isExpanded:$expanded_QMARK_$jscomp$4$$,total:$APP.$cljs$core$count$$($frames$jscomp$35$$),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$259$$,$frame$jscomp$115_p__83475$$){var $i$jscomp$545$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame$jscomp$115_p__83475$$,0,null);$frame$jscomp$115_p__83475$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($frame$jscomp$115_p__83475$$,
1,null);$out_arr__44092__auto__$jscomp$259$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnail_item_STAR_$$,{index:$i$jscomp$545$$,frame:$frame$jscomp$115_p__83475$$,pageId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$184$$),objects:$objects$jscomp$861$$,onClick:$on_item_click$$,isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$545$$,$index$jscomp$592$$),thumbnailData:$thumbnail_data$jscomp$2$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$115_p__83475$$)??
"")+"-"+($i$jscomp$545$$??"")));return $out_arr__44092__auto__$jscomp$259$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($frames$jscomp$35$$))})]})};
$app$main$ui$viewer$calculate_size$$=function($map__83482_objects$jscomp$862_x$jscomp$1368$$,$frame$jscomp$116_y$jscomp$551$$,$zoom$jscomp$183$$){$map__83482_objects$jscomp$862_x$jscomp$1368$$=$APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($map__83482_objects$jscomp$862_x$jscomp$1368$$,$frame$jscomp$116_y$jscomp$551$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1928$ignore_margin_QMARK_$$,!1],null));var $height$jscomp$222_map__83482__$1$$=
$APP.$cljs$core$__destructure_map$$($map__83482_objects$jscomp$862_x$jscomp$1368$$);$map__83482_objects$jscomp$862_x$jscomp$1368$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$222_map__83482__$1$$,$APP.$cljs$cst$1515$x$$);$frame$jscomp$116_y$jscomp$551$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$222_map__83482__$1$$,$APP.$cljs$cst$1516$y$$);var $width$jscomp$257$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$222_map__83482__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$222_map__83482__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$222_map__83482__$1$$,$APP.$cljs$cst$1527$height$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$5500$base_width$$,$width$jscomp$257$$,$APP.$cljs$cst$5501$base_height$$,$height$jscomp$222_map__83482__$1$$,$APP.$cljs$cst$1515$x$$,$map__83482_objects$jscomp$862_x$jscomp$1368$$,$APP.$cljs$cst$1516$y$$,$frame$jscomp$116_y$jscomp$551$$,$APP.$cljs$cst$290$width$$,
$width$jscomp$257$$*$zoom$jscomp$183$$,$APP.$cljs$cst$1527$height$$,$height$jscomp$222_map__83482__$1$$*$zoom$jscomp$183$$,$APP.$cljs$cst$1942$vbox$$,"0 0 "+($width$jscomp$257$$??"")+" "+($height$jscomp$222_map__83482__$1$$??"")],null)};
$app$main$ui$viewer$calculate_delta$$=function($size$jscomp$174$$,$selrect$jscomp$100$$,$delta_x$jscomp$8_p__83483$$,$zoom$jscomp$184$$){var $snap_v$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta_x$jscomp$8_p__83483$$,0,null),$snap_h$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta_x$jscomp$8_p__83483$$,1,null);$delta_x$jscomp$8_p__83483$$=function(){var $G__83487__$1$$=$snap_h$$ instanceof $APP.$cljs$core$Keyword$$?$snap_h$$.$fqn$:null;switch($G__83487__$1$$){case "left":return $APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$)-
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$);case "right":return $APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$)-($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)/$zoom$jscomp$184$$);case "center":return($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)/
$zoom$jscomp$184$$)/2-($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)-$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83487__$1$$)].join(""));}}();var $delta_y$jscomp$6$$=function(){var $G__83488__$1$$=$snap_v$$ instanceof $APP.$cljs$core$Keyword$$?$snap_v$$.$fqn$:null;switch($G__83488__$1$$){case "top":return $APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$)-
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$);case "bottom":return $APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$)-($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)/$zoom$jscomp$184$$);case "center":return($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)/
$zoom$jscomp$184$$)/2-($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$174$$)-$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$100$$));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__83488__$1$$)].join(""));}}();return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($delta_x$jscomp$8_p__83483$$*$zoom$jscomp$184$$,$delta_y$jscomp$6$$*$zoom$jscomp$184$$)};
$app$main$ui$viewer$calculate_wrapper$$=function($size1$$,$size2$$,$zoom$jscomp$185$$){if($size1$$==null)return $size2$$;if($size2$$==null)return $size1$$;var $width$jscomp$258$$=function(){var $x__5110__auto__$jscomp$201$$=$APP.$cljs$cst$5500$base_width$$.$cljs$core$IFn$_invoke$arity$1$($size1$$),$y__5111__auto__$jscomp$201$$=$APP.$cljs$cst$5500$base_width$$.$cljs$core$IFn$_invoke$arity$1$($size2$$);return $x__5110__auto__$jscomp$201$$>$y__5111__auto__$jscomp$201$$?$x__5110__auto__$jscomp$201$$:
$y__5111__auto__$jscomp$201$$}(),$height$jscomp$223$$=function(){var $x__5110__auto__$jscomp$202$$=$APP.$cljs$cst$5501$base_height$$.$cljs$core$IFn$_invoke$arity$1$($size1$$),$y__5111__auto__$jscomp$202$$=$APP.$cljs$cst$5501$base_height$$.$cljs$core$IFn$_invoke$arity$1$($size2$$);return $x__5110__auto__$jscomp$202$$>$y__5111__auto__$jscomp$202$$?$x__5110__auto__$jscomp$202$$:$y__5111__auto__$jscomp$202$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$290$width$$,$width$jscomp$258$$*
$zoom$jscomp$185$$,$APP.$cljs$cst$1527$height$$,$height$jscomp$223$$*$zoom$jscomp$185$$,$APP.$cljs$cst$1942$vbox$$,["0 0 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$258$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($height$jscomp$223$$)].join("")],null)};
$app$main$ui$viewer$viewer_pagination$$=function($index$jscomp$593_map__83491_props_83490$$){$index$jscomp$593_map__83491_props_83490$$=$APP.$rumext$v2$util$wrap_props$$($index$jscomp$593_map__83491_props_83490$$);var $comment_sidebar_map__83491__$1$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$593_map__83491_props_83490$$);$index$jscomp$593_map__83491_props_83490$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__83491__$1$$,$APP.$cljs$cst$1801$index$$);var $num_frames$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__83491__$1$$,$cljs$cst$6426$num_frames$$),$left_bar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__83491__$1$$,$cljs$cst$6427$left_bar$$),$right_bar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__83491__$1$$,$cljs$cst$6428$right_bar$$);$comment_sidebar_map__83491__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($comment_sidebar_map__83491__$1$$,$cljs$cst$6429$comment_sidebar$$);
var $go_prev_frame$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_prev_frame$$)}),$go_next_frame$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_next_frame$$)}),$go_first_frame$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$select_first_frame$$)});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$index$jscomp$593_map__83491_props_83490$$>0?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_prev_frame$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.previous"),className:"main_ui_viewer__viewer-go-prev "+($APP.$cljs$core$truth_$$($left_bar$$)?"main_ui_viewer__left-bar":""),children:$APP.$app$main$ui$icons$arrow$$}):null,$index$jscomp$593_map__83491_props_83490$$+1<$num_frames$$?(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$go_next_frame$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"),className:"main_ui_viewer__viewer-go-next "+($APP.$cljs$core$truth_$$($comment_sidebar_map__83491__$1$$)?"main_ui_viewer__comment-sidebar":"")+" "+($APP.$cljs$core$truth_$$($right_bar$$)?"main_ui_viewer__right-bar":""),children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer__viewer-bottom "+($APP.$cljs$core$truth_$$($left_bar$$)?"main_ui_viewer__left-bar":
""),children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$go_first_frame$$,className:"main_ui_viewer__reset-button",children:$APP.$app$main$ui$icons$reload$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_viewer__counter",children:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" / ",new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$593_map__83491_props_83490$$+1,$num_frames$$],null))}),(0,$APP.$rumext$v2$jsx$$)("span",
{})]})]})};
$app$main$ui$viewer$viewer_overlay$$=function($frame$jscomp$118_map__83496_props_83494$$){$frame$jscomp$118_map__83496_props_83494$$=$APP.$rumext$v2$util$wrap_props$$($frame$jscomp$118_map__83496_props_83494$$);var $interactions_mode$jscomp$4_map__83496__$1$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$118_map__83496_props_83494$$),$overlay$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$4_map__83496__$1$$,$APP.$cljs$cst$2034$overlay$$),$page$jscomp$186$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$4_map__83496__$1$$,$APP.$cljs$cst$1629$page$$);$frame$jscomp$118_map__83496_props_83494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$4_map__83496__$1$$,$APP.$cljs$cst$1611$frame$$);var $zoom$jscomp$186$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$4_map__83496__$1$$,$APP.$cljs$cst$2204$zoom$$),$wrapper_size$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$4_map__83496__$1$$,
$cljs$cst$6430$wrapper_size$$);$interactions_mode$jscomp$4_map__83496__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interactions_mode$jscomp$4_map__83496__$1$$,$APP.$cljs$cst$5339$interactions_mode$$);var $close_click_outside_QMARK_$jscomp$1$$=$APP.$cljs$cst$1988$close_click_outside$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$background_overlay_QMARK_$jscomp$1$$=$APP.$cljs$cst$1989$background_overlay$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$overlay_frame$$=
$APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$overlay_position$jscomp$5$$=$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$fixed_base_QMARK_$jscomp$2$$=$APP.$cljs$cst$5393$fixed_source_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$size$jscomp$175$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page$jscomp$186$$),$APP.$rumext$v2$adapt$$($overlay$jscomp$1$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$186$$)],
function(){return $app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$186$$),$APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$zoom$jscomp$186$$)}),$delta$jscomp$73$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($size$jscomp$175$$),$APP.$rumext$v2$adapt$$($overlay_frame$$),$APP.$rumext$v2$adapt$$($overlay$jscomp$1$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$186$$)],function(){return $app$main$ui$viewer$calculate_delta$$($size$jscomp$175$$,
$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($overlay_frame$$),$APP.$cljs$cst$5392$snap_to$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),$zoom$jscomp$186$$)}),$on_click$jscomp$71$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($overlay$jscomp$1$$),$APP.$rumext$v2$adapt$$($close_click_outside_QMARK_$jscomp$1$$)],function(){if($APP.$cljs$core$truth_$$($close_click_outside_QMARK_$jscomp$1$$)){var $JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$=
$APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$))$JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$),
$APP.$app$common$types$shape$interactions$invert_direction$$($JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$)));else{$JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1396_frame_id$jscomp$inline_9804$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$1$$);$JSCompiler_inline_result$jscomp$1396_frame_id$jscomp$inline_9804$$=
$APP.$app$main$data$viewer$close_overlay$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1396_frame_id$jscomp$inline_9804$$,null);$JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$=$JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1396_frame_id$jscomp$inline_9804$$)}return $JSCompiler_temp$jscomp$1393_JSCompiler_temp_const$jscomp$1394_temp__5823__auto__$jscomp$262$$}return null});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($close_click_outside_QMARK_$jscomp$1$$)?$close_click_outside_QMARK_$jscomp$1$$:$background_overlay_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$3$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$3$$),position:"absolute",left:0,top:0},onClick:$on_click$jscomp$71$$,
className:"main_ui_viewer__viewer-overlay-background "+($APP.$cljs$core$truth_$$($background_overlay_QMARK_$jscomp$1$$)?"main_ui_viewer__visible":"")}):null,$APP.$cljs$core$truth_$$($fixed_base_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"absolute",left:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$186$$,top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$186$$,width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$175$$),
height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$175$$),zIndex:2},className:"main_ui_viewer__viewport-container-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"overlay-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay_frame$$)??""),style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$175$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$175$$),position:"fixed"},className:"main_ui_viewer__viewer-overlay main_ui_viewer__viewport-container",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport_STAR_$$,{frame:$overlay_frame$$,baseFrame:$frame$jscomp$118_map__83496_props_83494$$,frameOffset:$overlay_position$jscomp$5$$,size:$size$jscomp$175$$,delta:$delta$jscomp$73$$,page:$page$jscomp$186$$,interactionsMode:$interactions_mode$jscomp$4_map__83496__$1$$})})}):(0,$APP.$rumext$v2$jsx$$)("div",{id:"overlay-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay_frame$$)??""),style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$175$$),
height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$175$$),left:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$186$$,top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($overlay_position$jscomp$5$$)*$zoom$jscomp$186$$},className:"main_ui_viewer__viewer-overlay main_ui_viewer__viewport-container",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport_STAR_$$,{frame:$overlay_frame$$,baseFrame:$frame$jscomp$118_map__83496_props_83494$$,
frameOffset:$overlay_position$jscomp$5$$,size:$size$jscomp$175$$,delta:$delta$jscomp$73$$,page:$page$jscomp$186$$,interactionsMode:$interactions_mode$jscomp$4_map__83496__$1$$})})]})};
$app$main$ui$viewer$viewer_wrapper$$=function($props_83512$$){var $users$jscomp$5$$=$props_83512$$.users,$overlays$jscomp$12$$=$props_83512$$.overlays,$zoom$jscomp$187$$=$props_83512$$.zoom,$wrapper_size$jscomp$4$$=$props_83512$$["wrapper-size"],$frame$jscomp$119$$=$props_83512$$.frame,$orig_frame$jscomp$3$$=$props_83512$$["orig-frame"],$file$jscomp$203$$=$props_83512$$.file,$orig_viewport_ref$$=$props_83512$$["orig-viewport-ref"],$section$jscomp$50$$=$props_83512$$.section,$orig_size$jscomp$1$$=
$props_83512$$["orig-size"],$current_viewport_ref$$=$props_83512$$["current-viewport-ref"],$page$jscomp$187$$=$props_83512$$.page,$interactions_mode$jscomp$5$$=$props_83512$$["interactions-mode"],$size$jscomp$176$$=$props_83512$$.size;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_pagination_and_sidebar$$,{section:$section$jscomp$50$$,index:$props_83512$$.index,page:$page$jscomp$187$$,users:$users$jscomp$5$$,frame:$frame$jscomp$119$$,
"interactions-mode":$interactions_mode$jscomp$5$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$4$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($wrapper_size$jscomp$4$$)},className:"main_ui_viewer__viewer-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer__viewer-clipper",children:[$APP.$cljs$core$truth_$$($orig_frame$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$orig_viewport_ref$$,
style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_size$jscomp$1$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($orig_size$jscomp$1$$),position:"relative"},className:"main_ui_viewer__viewport-container",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport_STAR_$$,{frame:$orig_frame$jscomp$3$$,baseFrame:$orig_frame$jscomp$3$$,frameOffset:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),size:$orig_size$jscomp$1$$,
page:$page$jscomp$187$$,users:$users$jscomp$5$$,interactionsMode:$interactions_mode$jscomp$5$$})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$current_viewport_ref$$,style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$176$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$176$$),position:"relative"},className:"main_ui_viewer__viewport-container",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$viewer$interactions$viewport_STAR_$$,
{frame:$frame$jscomp$119$$,baseFrame:$frame$jscomp$119$$,frameOffset:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),size:$size$jscomp$176$$,page:$page$jscomp$187$$,interactionsMode:$interactions_mode$jscomp$5$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$260$$,$overlay$jscomp$2$$){$out_arr__44092__auto__$jscomp$260$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_overlay$$,{overlay:$overlay$jscomp$2$$,page:$page$jscomp$187$$,
frame:$frame$jscomp$119$$,zoom:$zoom$jscomp$187$$,"wrapper-size":$wrapper_size$jscomp$4$$,"interactions-mode":$interactions_mode$jscomp$5$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($overlay$jscomp$2$$)??"")));return $out_arr__44092__auto__$jscomp$260$$},[],$overlays$jscomp$12$$)]})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$50$$,$APP.$cljs$cst$3489$comments$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$comments$comments_layer$$,{file:$file$jscomp$203$$,
users:$users$jscomp$5$$,frame:$frame$jscomp$119$$,page:$page$jscomp$187$$,zoom:$zoom$jscomp$187$$}):null]})]})};
$app$main$ui$viewer$viewer_content_STAR_$$=function($props_83525$$){var $data$jscomp$514$$=$props_83525$$.data,$index$jscomp$596$$=$props_83525$$.index,$section$jscomp$51$$=$props_83525$$.section,$interactions_mode$jscomp$6$$=$props_83525$$.interactionsMode,$page_id$jscomp$478$$=$props_83525$$.pageId,$share$jscomp$2$$=$props_83525$$.share,$share_id$jscomp$30$$=$props_83525$$.shareId,$map__83527__$1$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$514$$),$file$jscomp$204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83527__$1$$,
$APP.$cljs$cst$208$file$$),$users$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83527__$1$$,$APP.$cljs$cst$5353$users$$),$project$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83527__$1$$,$APP.$cljs$cst$2238$project$$),$permissions$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83527__$1$$,$APP.$cljs$cst$1728$permissions$$),$allowed$jscomp$1$$=function(){var $and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$51$$,$APP.$cljs$cst$2059$interactions$$);if($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$)return $and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$;
if($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$51$$,$APP.$cljs$cst$3489$comments$$))$and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$=
$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$45$$),$and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$)?
$and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$:$APP.$cljs$cst$5511$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$45$$)===!0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5514$who_comment$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$45$$),"all");return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$)?
$and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$:($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$51$$,$APP.$cljs$cst$2683$inspect$$))?
($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$45$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$)?
$and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$:$APP.$cljs$cst$5511$is_logged$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$45$$)===!0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5515$who_inspect$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$45$$),"all")):$and__5023__auto__$jscomp$1084_and__5023__auto__$jscomp$inline_9806_or__5025__auto__$jscomp$1479_or__5025__auto____$1$jscomp$166_or__5025__auto____$1$jscomp$inline_9807_or__5025__auto____$2$jscomp$43$$}(),
$local$jscomp$39$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_local$$),$nav_scroll$$=$APP.$cljs$cst$5381$nav_scroll$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$39$$),$orig_viewport_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_viewport_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$viewer_section_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_animations$$=$APP.$rumext$v2$deref$$($app$main$ui$viewer$current_animations_ref$$),$page_id__$1$jscomp$27$$=$APP.$cljs$core$truth_$$($page_id$jscomp$478$$)?
$page_id$jscomp$478$$:$APP.$cljs$core$first$$($APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$204$$))),$page$jscomp$188$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$514$$),$APP.$rumext$v2$adapt$$($page_id__$1$jscomp$27$$)],function(){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$514$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2236$pages$$,$page_id__$1$jscomp$27$$],null))}),$text_shapes$jscomp$5$$=$APP.$app$main$ui$hooks$use_equal_memo$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$)))),$zoom$jscomp$188$$=$APP.$cljs$cst$2204$zoom$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$39$$),$zoom_type$jscomp$3$$=
$APP.$cljs$cst$2243$zoom_type$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$39$$),$frames$jscomp$36$$=$APP.$cljs$cst$5349$frames$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$frame$jscomp$120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frames$jscomp$36$$,$index$jscomp$596$$),$fullscreen_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$ui$viewer$header$fullscreen_ref$$),$overlays$jscomp$13$$=$APP.$rumext$v2$deref$$($app$main$ui$viewer$current_overlays_ref$$),$orig_frame$jscomp$4$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_animations$$)],function(){var $animation_with_origin$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5389$orig_frame_id$$,$APP.$cljs$core$vals$$($current_animations$$));return $APP.$cljs$core$truth_$$($animation_with_origin$$)?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83517_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83517_SHARP_$$),
$APP.$cljs$cst$5389$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($animation_with_origin$$))},$frames$jscomp$36$$):null}),$size$jscomp$177$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame$jscomp$120$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$188$$)],function(){return $APP.$cljs$core$truth_$$($frame$jscomp$120$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$frame$jscomp$120$$,$zoom$jscomp$188$$):
null}),$orig_size$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($orig_frame$jscomp$4$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$188$$)],function(){return $APP.$cljs$core$truth_$$($orig_frame$jscomp$4$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$orig_frame$jscomp$4$$,$zoom$jscomp$188$$):null}),$wrapper_size$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($size$jscomp$177$$),
$APP.$rumext$v2$adapt$$($orig_size$jscomp$2$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$188$$)],function(){return $app$main$ui$viewer$calculate_wrapper$$($size$jscomp$177$$,$orig_size$jscomp$2$$,$zoom$jscomp$188$$)}),$click_on_screen$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$792_over_section_QMARK_$jscomp$1$$){$event$jscomp$792_over_section_QMARK_$jscomp$1$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($event$jscomp$792_over_section_QMARK_$jscomp$1$$),
"viewer-section");var $layout$jscomp$40$$=$APP.$goog$dom$getElement$$("viewer-layout"),$has_force_QMARK_$jscomp$1$$=$APP.$app$util$dom$get_data$$($layout$jscomp$40$$,"force-visible");return $APP.$cljs$core$truth_$$($event$jscomp$792_over_section_QMARK_$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($has_force_QMARK_$jscomp$1$$,"true")?$APP.$app$util$dom$set_data_BANG_$$($layout$jscomp$40$$,"force-visible",!1):$APP.$app$util$dom$set_data_BANG_$$($layout$jscomp$40$$,"force-visible",
!0):null}),$on_click$jscomp$72$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($section$jscomp$51$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$51$$,$APP.$cljs$cst$3489$comments$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$close_thread$$()):null}),$set_up_new_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $size__$1$jscomp$10_viewer_section$jscomp$1$$=
$APP.$goog$dom$getElement$$("viewer-section");$size__$1$jscomp$10_viewer_section$jscomp$1$$=$APP.$app$util$dom$get_client_size$$($size__$1$jscomp$10_viewer_section$jscomp$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$set_viewport_size$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$874$size$$,$size__$1$jscomp$10_viewer_section$jscomp$1$$],null)))}),$on_wheel$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$793_event__$1$jscomp$10$$){$event$jscomp$793_event__$1$jscomp$10$$=
$event$jscomp$793_event__$1$jscomp$10$$.getBrowserEvent();var $or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$=$APP.$goog$dom$getElement$$("inspect-svg-wrapper"),$section__$1$jscomp$3$$=$APP.$goog$dom$getElement$$("inspect-svg-container"),$JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$=$event$jscomp$793_event__$1$jscomp$10$$.target;$or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$=$APP.$app$util$dom$child_QMARK_$$($JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$,
$or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$);$JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$)?$or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$:$JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$.id,
"inspect-svg-container"):null;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$)){var $new_scroll_pos_norm_event$jscomp$1$$=$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$($event$jscomp$793_event__$1$jscomp$10$$);$JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$793_event__$1$jscomp$10$$);$or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$=
$event$jscomp$793_event__$1$jscomp$10$$.shiftKey;$new_scroll_pos_norm_event$jscomp$1$$=($or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$?$section__$1$jscomp$3$$!=null?$section__$1$jscomp$3$$.scrollLeft:null:$section__$1$jscomp$3$$!=null?$section__$1$jscomp$3$$.scrollTop:null)+$new_scroll_pos_norm_event$jscomp$1$$.pixelY;if($JSCompiler_inline_result$jscomp$2055_mod_QMARK_$jscomp$17_target$jscomp$175$$)return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$793_event__$1$jscomp$10$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$793_event__$1$jscomp$10$$);return $or__5025__auto__$jscomp$inline_9809_shift_QMARK_$jscomp$46_wrapper$jscomp$10$$?$section__$1$jscomp$3$$!=null?$APP.$app$util$object$set_BANG_$$($section__$1$jscomp$3$$,"scrollLeft",$new_scroll_pos_norm_event$jscomp$1$$):null:$section__$1$jscomp$3$$!=null?$APP.$app$util$object$set_BANG_$$($section__$1$jscomp$3$$,"scrollTop",$new_scroll_pos_norm_event$jscomp$1$$):null}return null}),$on_thumbnails_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$close_thumbnails_panel$$)}),
$on_exit_fullscreen$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$util$dom$fullscreen_QMARK_$$()?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$exit_fullscreen$$())});$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6431$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer$$,$APP.$app$main$data$viewer$shortcuts$shortcuts$$);if($page$jscomp$188$$==null)throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("not-found",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2676$not_found$$],null),null])),null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$not$$($allowed$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$go_to_section$$($APP.$cljs$cst$2059$interactions$$)):
null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$204$$))],function(){var $name$jscomp$512$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$204$$);return $APP.$app$util$dom$set_html_title$$(["▶ ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.viewer",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$512$$])))].join(""))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){for(var $events$jscomp$5$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"click",$on_click$jscomp$72$$),$APP.$goog$events$listen$$($APP.$rumext$v2$ref_val$$($viewer_section_ref$$),"wheel",$on_wheel$jscomp$2$$,{passive:!1})],null),$c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$=$APP.$cljs$core$seq$$($APP.$app$util$dom$fullscreen_events$$),
$G__83597_chunk__83542_83585_seq__83541_83594__$1$$=null,$G__83598_count__83543_83586$$=0,$G__83596_i__83544_83587$$=0;;)if($G__83596_i__83544_83587$$<$G__83598_count__83543_83586$$){var $event_83588$$=$G__83597_chunk__83542_83585_seq__83541_83594__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__83596_i__83544_83587$$);$APP.$app$util$globals$document$$.addEventListener($event_83588$$,$on_exit_fullscreen$$,!1);$G__83596_i__83544_83587$$+=1}else if($c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$=
$APP.$cljs$core$seq$$($c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$))$G__83597_chunk__83542_83585_seq__83541_83594__$1$$=$c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__83597_chunk__83542_83585_seq__83541_83594__$1$$)?($c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$=$APP.$cljs$core$_chunked_first$$($G__83597_chunk__83542_83585_seq__83541_83594__$1$$),$G__83596_i__83544_83587$$=
$APP.$cljs$core$_chunked_rest$$($G__83597_chunk__83542_83585_seq__83541_83594__$1$$),$G__83597_chunk__83542_83585_seq__83541_83594__$1$$=$c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$,$G__83598_count__83543_83586$$=$APP.$cljs$core$count$$($c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$),$c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$=$G__83596_i__83544_83587$$):($c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$=
$APP.$cljs$core$first$$($G__83597_chunk__83542_83585_seq__83541_83594__$1$$),$APP.$app$util$globals$document$$.addEventListener($c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$,$on_exit_fullscreen$$,!1),$c__5548__auto___83595_event_83600_seq__83541_83584_temp__5825__auto___83593$$=$APP.$cljs$core$next$$($G__83597_chunk__83542_83585_seq__83541_83594__$1$$),$G__83597_chunk__83542_83585_seq__83541_83594__$1$$=null,$G__83598_count__83543_83586$$=0),$G__83596_i__83544_83587$$=
0;else break;return function(){for(var $c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$seq$$($events$jscomp$5$$),$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=null,$G__83619_G__83632_count__83547_83607_event$jscomp$794$$=0,$G__83617_G__83630_count__83551_i__83548_83608$$=0;;)if($G__83617_G__83630_count__83551_i__83548_83608$$<$G__83619_G__83632_count__83547_83607_event$jscomp$794$$){var $i__83552_key_83609$$=
$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__83617_G__83630_count__83551_i__83548_83608$$);$APP.$goog$events$unlistenByKey$$($i__83552_key_83609$$);$G__83617_G__83630_count__83551_i__83548_83608$$+=1}else if($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$))$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=
$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$)?($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$_chunked_first$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),
$G__83617_G__83630_count__83551_i__83548_83608$$=$APP.$cljs$core$_chunked_rest$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$,$G__83619_G__83632_count__83547_83607_event$jscomp$794$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$),
$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$G__83617_G__83630_count__83551_i__83548_83608$$):($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$first$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),$APP.$goog$events$unlistenByKey$$($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$),
$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$next$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=null,$G__83619_G__83632_count__83547_83607_event$jscomp$794$$=0),$G__83617_G__83630_count__83551_i__83548_83608$$=0;else break;$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=
$APP.$cljs$core$seq$$($APP.$app$util$dom$fullscreen_events$$);$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=null;for($i__83552_key_83609$$=$G__83617_G__83630_count__83551_i__83548_83608$$=0;;)if($i__83552_key_83609$$<$G__83617_G__83630_count__83551_i__83548_83608$$)$G__83619_G__83632_count__83547_83607_event$jscomp$794$$=$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__83552_key_83609$$),
$APP.$app$util$globals$document$$.removeEventListener($G__83619_G__83632_count__83547_83607_event$jscomp$794$$,$on_exit_fullscreen$$),$i__83552_key_83609$$+=1;else if($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$))$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=
$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$)?($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$_chunked_first$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),
$G__83617_G__83630_count__83551_i__83548_83608$$=$APP.$cljs$core$_chunked_rest$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$,$G__83619_G__83632_count__83547_83607_event$jscomp$794$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$),
$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$G__83617_G__83630_count__83551_i__83548_83608$$,$G__83617_G__83630_count__83551_i__83548_83608$$=$G__83619_G__83632_count__83547_83607_event$jscomp$794$$):($G__83619_G__83632_count__83547_83607_event$jscomp$794$$=$APP.$cljs$core$first$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),$APP.$app$util$globals$document$$.removeEventListener($G__83619_G__83632_count__83547_83607_event$jscomp$794$$,
$on_exit_fullscreen$$),$c__5548__auto__$jscomp$50_c__5548__auto___83616_key_83621_seq__83545_83605_seq__83549_temp__5825__auto__$jscomp$480_temp__5825__auto___83614$$=$APP.$cljs$core$next$$($G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$),$G__83618_G__83631_chunk__83546_83606_chunk__83550_seq__83545_83615__$1_seq__83549__$1$$=null,$G__83617_G__83630_count__83551_i__83548_83608$$=0),$i__83552_key_83609$$=0;else return null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$set_up_new_size$$.$cljs$core$IFn$_invoke$arity$0$?
$set_up_new_size$$.$cljs$core$IFn$_invoke$arity$0$():$set_up_new_size$$();window.addEventListener("resize",$set_up_new_size$$);return function(){return window.removeEventListener("resize",$set_up_new_size$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($nav_scroll$$)],function(){if(typeof $nav_scroll$$==="number"){var $viewer_section$jscomp$2$$=$APP.$goog$dom$getElement$$("viewer-section");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$reset_nav_scroll$$());
return $viewer_section$jscomp$2$$!=null?$APP.$app$util$object$set_BANG_$$($viewer_section$jscomp$2$$,"scrollTop",$nav_scroll$$):null}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fullscreen_QMARK_$jscomp$1$$)],function(){var $wrapper$jscomp$11$$=$APP.$goog$dom$getElement$$("viewer-layout"),$fullscreen_dom_QMARK__layout$jscomp$41$$=$app$util$dom$fullscreen_QMARK_$$();return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fullscreen_QMARK_$jscomp$1$$,
$fullscreen_dom_QMARK__layout$jscomp$41$$)?$APP.$cljs$core$truth_$$($fullscreen_QMARK_$jscomp$1$$)?($fullscreen_dom_QMARK__layout$jscomp$41$$=$APP.$goog$dom$getElement$$("viewer-layout"),$APP.$app$util$dom$set_data_BANG_$$($fullscreen_dom_QMARK__layout$jscomp$41$$,"force-visible",!1),$app$util$webapi$request_fullscreen$$($wrapper$jscomp$11$$)):$app$util$webapi$exit_fullscreen$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($zoom_type$jscomp$3$$)],
function(){switch($zoom_type$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$zoom_type$jscomp$3$$.$fqn$:null){case "fit":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fit$$);case "fill":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fill$$);default:return null}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$596$$),$APP.$rumext$v2$adapt$$($current_animations$$),
$APP.$rumext$v2$adapt$$($zoom_type$jscomp$3$$)],function(){switch($zoom_type$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?$zoom_type$jscomp$3$$.$fqn$:null){case "fit":$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fit$$);break;case "fill":$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$viewer$zoom_to_fill$$)}var $nav_animation$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__83521_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($p1__83521_SHARP_$$),
$APP.$cljs$cst$5388$go_to_frame$$)},$APP.$cljs$core$vals$$($current_animations$$));if($APP.$cljs$core$truth_$$($nav_animation$$)){var $orig_viewport$jscomp$1$$=$APP.$rumext$v2$ref_val$$($orig_viewport_ref$jscomp$1$$),$current_viewport$jscomp$1$$=$APP.$rumext$v2$ref_val$$($current_viewport_ref$jscomp$1$$);return $app$main$ui$viewer$interactions$animate_go_to_frame$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($nav_animation$$),$current_viewport$jscomp$1$$,$orig_viewport$jscomp$1$$,
$size$jscomp$177$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_animations$$)],function(){if($APP.$cljs$core$truth_$$($current_animations$$))for(var $c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$=$APP.$cljs$core$seq$$($current_animations$$),$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=null,$G__83659_count__83557$$=0,$i__83558$$=
0;;)if($i__83558$$<$G__83659_count__83557$$){var $G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$=$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__83558$$),$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,0,null),$G__83658_animation_vals$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,1,null),$overlay_viewport_83642_seq__83555__$1$$=$APP.$app$util$dom$get_element$$(["overlay-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5394$overlay_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$))].join("")),$overlay_83643_overlay_viewport_83661$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83555$jscomp$1$$,
$chunk__83556$jscomp$1$$,$count__83557$jscomp$1$$,$i__83558$jscomp$1$$,$overlay_viewport_83642$jscomp$1$$,$vec__83567$jscomp$1$$,$overlay_frame_id$jscomp$1$$){return function($p1__83522_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__83522_SHARP_$$)),$overlay_frame_id$jscomp$1$$)}}($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,
$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$G__83659_count__83557$$,$i__83558$$,$overlay_viewport_83642_seq__83555__$1$$,$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$G__83658_animation_vals$$,$data$jscomp$514$$,$map__83527__$1$$,$file$jscomp$204$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$45$$,$allowed$jscomp$1$$,$local$jscomp$39$$,$nav_scroll$$,
$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$188$$,$text_shapes$jscomp$5$$,$zoom$jscomp$188$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$120$$,$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$13$$,$orig_frame$jscomp$4$$,$size$jscomp$177$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$72$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,
$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$596$$,$section$jscomp$51$$,$interactions_mode$jscomp$6$$,$page_id$jscomp$478$$,$share$jscomp$2$$,$share_id$jscomp$30$$),$overlays$jscomp$13$$),$overlay_83662_overlay_size_83644$$=$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83643_overlay_viewport_83661$$),$zoom$jscomp$188$$),$overlay_position_83645_overlay_size_83663$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83643_overlay_viewport_83661$$))*$zoom$jscomp$188$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83643_overlay_viewport_83661$$))*$zoom$jscomp$188$$],null);$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$5389$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$))?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83555$jscomp$2$$,$chunk__83556$jscomp$2$$,$count__83557$jscomp$2$$,$i__83558$jscomp$2$$,$overlay_viewport_83642$jscomp$2$$,$overlay_83643$jscomp$1$$,$overlay_size_83644$jscomp$1$$,$overlay_position_83645$jscomp$1$$,$vec__83567$jscomp$2$$,$overlay_frame_id$jscomp$2$$,$animation_vals$jscomp$2$$){return function($p1__83523_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83523_SHARP_$$),
$APP.$cljs$cst$5389$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($animation_vals$jscomp$2$$))}}($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$G__83659_count__83557$$,$i__83558$$,$overlay_viewport_83642_seq__83555__$1$$,$overlay_83643_overlay_viewport_83661$$,$overlay_83662_overlay_size_83644$$,$overlay_position_83645_overlay_size_83663$$,$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,
$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$G__83658_animation_vals$$,$data$jscomp$514$$,$map__83527__$1$$,$file$jscomp$204$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$45$$,$allowed$jscomp$1$$,$local$jscomp$39$$,$nav_scroll$$,$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$188$$,$text_shapes$jscomp$5$$,$zoom$jscomp$188$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$120$$,
$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$13$$,$orig_frame$jscomp$4$$,$size$jscomp$177$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$72$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$596$$,$section$jscomp$51$$,$interactions_mode$jscomp$6$$,$page_id$jscomp$478$$,$share$jscomp$2$$,$share_id$jscomp$30$$),$frames$jscomp$36$$):null;$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$=
$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$frame$jscomp$120$$,$zoom$jscomp$188$$);$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$=$APP.$cljs$core$truth_$$($G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,
$zoom$jscomp$188$$):null;$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$=$app$main$ui$viewer$calculate_wrapper$$($overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,$zoom$jscomp$188$$);$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$=$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$);switch($G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$ instanceof
$APP.$cljs$core$Keyword$$?$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$.$fqn$:null){case "open-overlay":$app$main$ui$viewer$interactions$animate_open_overlay$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$),$overlay_viewport_83642_seq__83555__$1$$,$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$overlay_83662_overlay_size_83644$$,$overlay_position_83645_overlay_size_83663$$);break;case "close-overlay":$app$main$ui$viewer$interactions$animate_close_overlay$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$),
$overlay_viewport_83642_seq__83555__$1$$,$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$overlay_83662_overlay_size_83644$$,$overlay_position_83645_overlay_size_83663$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83643_overlay_viewport_83661$$)))}$i__83558$$+=1}else{var $temp__5825__auto__$jscomp$481$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$);if($temp__5825__auto__$jscomp$481$$){$overlay_viewport_83642_seq__83555__$1$$=
$temp__5825__auto__$jscomp$481$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($overlay_viewport_83642_seq__83555__$1$$))$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$=$APP.$cljs$core$_chunked_first$$($overlay_viewport_83642_seq__83555__$1$$),$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=$APP.$cljs$core$_chunked_rest$$($overlay_viewport_83642_seq__83555__$1$$),$G__83658_animation_vals$$=$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,
$G__83659_count__83557$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$),$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$=$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=$G__83658_animation_vals$$;else{var $vec__83571$$=$APP.$cljs$core$first$$($overlay_viewport_83642_seq__83555__$1$$);$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__83571$$,0,null);$G__83658_animation_vals$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__83571$$,1,null);$overlay_83643_overlay_viewport_83661$$=$APP.$app$util$dom$get_element$$(["overlay-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5394$overlay_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$))].join(""));$overlay_83662_overlay_size_83644$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83555$jscomp$3$$,
$chunk__83556$jscomp$3$$,$count__83557$jscomp$3$$,$i__83558$jscomp$3$$,$overlay_viewport_83661$jscomp$1$$,$vec__83571$jscomp$1$$,$overlay_frame_id$jscomp$3$$){return function($p1__83522_SHARP_$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($p1__83522_SHARP_$jscomp$1$$)),$overlay_frame_id$jscomp$3$$)}}($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,
$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$G__83659_count__83557$$,$i__83558$$,$overlay_83643_overlay_viewport_83661$$,$vec__83571$$,$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$G__83658_animation_vals$$,$overlay_viewport_83642_seq__83555__$1$$,$temp__5825__auto__$jscomp$481$$,$data$jscomp$514$$,$map__83527__$1$$,$file$jscomp$204$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$45$$,$allowed$jscomp$1$$,$local$jscomp$39$$,$nav_scroll$$,
$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$188$$,$text_shapes$jscomp$5$$,$zoom$jscomp$188$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$120$$,$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$13$$,$orig_frame$jscomp$4$$,$size$jscomp$177$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$72$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,
$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$596$$,$section$jscomp$51$$,$interactions_mode$jscomp$6$$,$page_id$jscomp$478$$,$share$jscomp$2$$,$share_id$jscomp$30$$),$overlays$jscomp$13$$);$overlay_position_83645_overlay_size_83663$$=$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83662_overlay_size_83644$$),$zoom$jscomp$188$$);$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83662_overlay_size_83644$$))*$zoom$jscomp$188$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83662_overlay_size_83644$$))*$zoom$jscomp$188$$],null);$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$5389$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$))?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($seq__83555$jscomp$4$$,$chunk__83556$jscomp$4$$,$count__83557$jscomp$4$$,$i__83558$jscomp$4$$,$overlay_viewport_83661$jscomp$2$$,$overlay_83662$jscomp$1$$,$overlay_size_83663$jscomp$1$$,$overlay_position_83664$jscomp$1$$,$vec__83571$jscomp$2$$,$overlay_frame_id$jscomp$4$$,$animation_vals$jscomp$4$$){return function($p1__83523_SHARP_$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__83523_SHARP_$jscomp$1$$),
$APP.$cljs$cst$5389$orig_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($animation_vals$jscomp$4$$))}}($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$G__83659_count__83557$$,$i__83558$$,$overlay_83643_overlay_viewport_83661$$,$overlay_83662_overlay_size_83644$$,$overlay_position_83645_overlay_size_83663$$,$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,
$vec__83571$$,$overlay_frame_id_size_83647__$1_wrapper_size_83649__$1$$,$G__83658_animation_vals$$,$overlay_viewport_83642_seq__83555__$1$$,$temp__5825__auto__$jscomp$481$$,$data$jscomp$514$$,$map__83527__$1$$,$file$jscomp$204$$,$users$jscomp$6$$,$project$jscomp$45$$,$permissions$jscomp$45$$,$allowed$jscomp$1$$,$local$jscomp$39$$,$nav_scroll$$,$orig_viewport_ref$jscomp$1$$,$current_viewport_ref$jscomp$1$$,$viewer_section_ref$$,$current_animations$$,$page_id__$1$jscomp$27$$,$page$jscomp$188$$,$text_shapes$jscomp$5$$,
$zoom$jscomp$188$$,$zoom_type$jscomp$3$$,$frames$jscomp$36$$,$frame$jscomp$120$$,$fullscreen_QMARK_$jscomp$1$$,$overlays$jscomp$13$$,$orig_frame$jscomp$4$$,$size$jscomp$177$$,$orig_size$jscomp$2$$,$wrapper_size$jscomp$5$$,$click_on_screen$$,$on_click$jscomp$72$$,$set_up_new_size$$,$on_wheel$jscomp$2$$,$on_thumbnails_close$$,$on_exit_fullscreen$$,$data$jscomp$514$$,$index$jscomp$596$$,$section$jscomp$51$$,$interactions_mode$jscomp$6$$,$page_id$jscomp$478$$,$share$jscomp$2$$,$share_id$jscomp$30$$),
$frames$jscomp$36$$):null;$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$=$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),$frame$jscomp$120$$,$zoom$jscomp$188$$);$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=$APP.$cljs$core$truth_$$($G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$)?$app$main$ui$viewer$calculate_size$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$188$$),
$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$zoom$jscomp$188$$):null;$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$=$app$main$ui$viewer$calculate_wrapper$$($c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$,$zoom$jscomp$188$$);$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$);
switch($G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$.$fqn$:null){case "open-overlay":$app$main$ui$viewer$interactions$animate_open_overlay$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$),$overlay_83643_overlay_viewport_83661$$,$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,
$overlay_position_83645_overlay_size_83663$$,$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$);break;case "close-overlay":$app$main$ui$viewer$interactions$animate_close_overlay$$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__83658_animation_vals$$),$overlay_83643_overlay_viewport_83661$$,$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$,$overlay_position_83645_overlay_size_83663$$,$G__83570_83650_orig_frame_83646__$1_orig_size_83648__$1_overlay_position_83664_vec__83567$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1611$frame$$.$cljs$core$IFn$_invoke$arity$1$($overlay_83662_overlay_size_83644$$)))}$c__5548__auto__$jscomp$51_seq__83555_size_83666__$1_wrapper_size_83668__$1$$=$APP.$cljs$core$next$$($overlay_viewport_83642_seq__83555__$1$$);$G__83574_83669_G__83657_chunk__83556_orig_frame_83665__$1_orig_size_83667__$1$$=null;$G__83659_count__83557$$=0}$i__83558$$=0}else return null}else return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes$jscomp$5$$)],
function(){var $fonts$jscomp$45_text_nodes$jscomp$2$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__83524_SHARP_$$){return $APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($p1__83524_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$text_shapes$jscomp$5$$]));$fonts$jscomp$45_text_nodes$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1763$font_id$$),$fonts$jscomp$45_text_nodes$jscomp$2$$);return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,$fonts$jscomp$45_text_nodes$jscomp$2$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{id:"viewer-layout","data-fullscreen":$fullscreen_QMARK_$jscomp$1$$,"data-force-visible":$APP.$cljs$cst$5371$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$39$$),className:($APP.$cljs$core$truth_$$($APP.$cljs$cst$5371$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$39$$))?
"main_ui_viewer__force-visible":"")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$51$$,$APP.$cljs$cst$2683$inspect$$)?"main_ui_viewer__viewer-layout":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$51$$,$APP.$cljs$cst$2683$inspect$$)?"main_ui_viewer__inspect-layout":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_viewer__viewer-content",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_thumbnails_close$$,className:"main_ui_viewer__thumbnails-close "+
($APP.$cljs$core$not$$($APP.$cljs$cst$5371$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$39$$,!1))?"main_ui_viewer__invisible":"")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$thumbnails$thumbnails_panel_STAR_$$,{frames:$frames$jscomp$36$$,show:$APP.$cljs$cst$5371$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$39$$,!1),page:$page$jscomp$188$$,index:$index$jscomp$596$$,thumbnailData:$APP.$cljs$cst$2237$thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$204$$)}),
(0,$APP.$rumext$v2$jsx$$)("section",{id:"viewer-section",ref:$viewer_section_ref$$,"data-viewer-section":!0,onClick:$click_on_screen$$,className:"main_ui_viewer__viewer-section "+($APP.$cljs$core$truth_$$($fullscreen_QMARK_$jscomp$1$$)?"main_ui_viewer__fullscreen":""),children:$APP.$cljs$core$empty_QMARK_$$($frames$jscomp$36$$)?(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_viewer__empty-state",children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.empty-state")})}):
$frame$jscomp$120$$==null?(0,$APP.$rumext$v2$jsx$$)("section",{className:"main_ui_viewer__empty-state",children:$index$jscomp$596$$!=null?(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("viewer.frame-not-found")}):null}):$frame$jscomp$120$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2683$inspect$$,$section$jscomp$51$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$inspect$viewport$$,{"viewer-pagination":$app$main$ui$viewer$viewer_pagination$$,
frame:$frame$jscomp$120$$,index:$index$jscomp$596$$,section:$section$jscomp$51$$,file:$file$jscomp$204$$,page:$page$jscomp$188$$,size:$size$jscomp$177$$,"interactions-mode":$interactions_mode$jscomp$6$$,"share-id":$share_id$jscomp$30$$,local:$local$jscomp$39$$}):(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_zoom$$),{value:$zoom$jscomp$188$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_wrapper$$,{overlays:$overlays$jscomp$13$$,"wrapper-size":$wrapper_size$jscomp$5$$,
zoom:$zoom$jscomp$188$$,"orig-frame":$orig_frame$jscomp$4$$,frame:$frame$jscomp$120$$,index:$index$jscomp$596$$,section:$section$jscomp$51$$,file:$file$jscomp$204$$,"orig-viewport-ref":$orig_viewport_ref$jscomp$1$$,"orig-size":$orig_size$jscomp$2$$,"current-viewport-ref":$current_viewport_ref$jscomp$1$$,page:$page$jscomp$188$$,size:$size$jscomp$177$$,"interactions-mode":$interactions_mode$jscomp$6$$,users:$users$jscomp$6$$})}):null})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$viewer$header$header$$,
{zoom:$zoom$jscomp$188$$,permissions:$permissions$jscomp$45$$,frame:$frame$jscomp$120$$,index:$index$jscomp$596$$,section:$section$jscomp$51$$,file:$file$jscomp$204$$,"shown-thumbnails":$APP.$cljs$cst$5371$show_thumbnails$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$39$$),page:$page$jscomp$188$$,"interactions-mode":$interactions_mode$jscomp$6$$,project:$project$jscomp$45$$,share:$share$jscomp$2$$})]})};
$app$main$ui$viewer$viewer_STAR_$$=function($props_83575_props__$1$jscomp$110$$){var $file_id$jscomp$457$$=$props_83575_props__$1$jscomp$110$$.fileId,$page_id$jscomp$483$$=$props_83575_props__$1$jscomp$110$$.pageId,$share_id$jscomp$35$$=$props_83575_props__$1$jscomp$110$$.shareId;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$457$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$483$$),$APP.$rumext$v2$adapt$$($share_id$jscomp$35$$)],function(){var $params$jscomp$454$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$457$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$483$$,$APP.$cljs$cst$3262$share_id$$,$share_id$jscomp$35$$],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$initialize$$($params$jscomp$454$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$finalize$$($params$jscomp$454$$))}});var $temp__5823__auto__$jscomp$263$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$viewer_data$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$263$$)?($props_83575_props__$1$jscomp$110$$=$APP.$app$util$object$merge$cljs$0core$0IFn$0_invoke$0arity$02$$($props_83575_props__$1$jscomp$110$$,{data:$temp__5823__auto__$jscomp$263$$,key:""+($file_id$jscomp$457$$??"")}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,{}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$viewer$viewer_content_STAR_$$,
$props_83575_props__$1$jscomp$110$$)]})):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),overlay:!0})};$APP.$app$main$ui$viewer$viewer_page_STAR_$$=function($props_83580$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$viewer$viewer_STAR_$$,$props_83580$$)};$cljs$cst$6427$left_bar$$=new $APP.$cljs$core$Keyword$$(null,"left-bar","left-bar",569281306);
$cljs$cst$6421$email_sent$$=new $APP.$cljs$core$Keyword$$(null,"email-sent","email-sent",-1405729778);$cljs$cst$6428$right_bar$$=new $APP.$cljs$core$Keyword$$(null,"right-bar","right-bar",149870584);$cljs$cst$6423$all_pages$$=new $APP.$cljs$core$Keyword$$(null,"all-pages","all-pages",1017563062);$cljs$cst$6422$pages_mode$$=new $APP.$cljs$core$Keyword$$(null,"pages-mode","pages-mode",1390854462);$cljs$cst$6426$num_frames$$=new $APP.$cljs$core$Keyword$$(null,"num-frames","num-frames",1569426540);
$cljs$cst$6420$register$$=new $APP.$cljs$core$Keyword$$(null,"register","register",1968522516);$cljs$cst$6425$can_inspect_code$$=new $APP.$cljs$core$Keyword$$(null,"can-inspect-code","can-inspect-code",-411585714);$cljs$cst$6431$app_DOT_main_DOT_ui_DOT_viewer_SLASH_viewer$$=new $APP.$cljs$core$Keyword$$("app.main.ui.viewer","viewer","app.main.ui.viewer/viewer",-223008833);$cljs$cst$6430$wrapper_size$$=new $APP.$cljs$core$Keyword$$(null,"wrapper-size","wrapper-size",-1999142846);
$cljs$cst$6429$comment_sidebar$$=new $APP.$cljs$core$Keyword$$(null,"comment-sidebar","comment-sidebar",-717905737);$cljs$cst$6418$hide_toggle_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hide-toggle?","hide-toggle?",-1874012773);$cljs$cst$6417$component_child_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"component-child?","component-child?",166589243);$cljs$cst$6424$can_comment$$=new $APP.$cljs$core$Keyword$$(null,"can-comment","can-comment",718623455);
$cljs$cst$6416$item$$=new $APP.$cljs$core$Keyword$$(null,"item","item",249373802);$cljs$cst$6419$viewer_pagination$$=new $APP.$cljs$core$Keyword$$(null,"viewer-pagination","viewer-pagination",-181925280);var $app$main$ui$inspect$left_sidebar$layer_item$$=function $app$main$ui$inspect$left_sidebar$layer_item$$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$){$hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$=$APP.$rumext$v2$util$wrap_props$$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$);$hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$=$APP.$cljs$core$__destructure_map$$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$);var $item$jscomp$152$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,$cljs$cst$6416$item$$),$selected$jscomp$220$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,$APP.$cljs$cst$1938$selected$$),$objects$jscomp$852$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,$APP.$cljs$cst$1636$objects$$),$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,$APP.$cljs$cst$839$depth$$),$component_child_QMARK__select_shape$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,$cljs$cst$6417$component_child_QMARK_$$);$hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,
$cljs$cst$6418$hide_toggle_QMARK_$$);var $id$jscomp$1084$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$152$$),$selected_QMARK_$jscomp$25$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$220$$,$id$jscomp$1084$$),$item_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(null),$depth__$1$jscomp$1$$=$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$+1,$component_tree_QMARK_$$=$APP.$cljs$core$truth_$$($component_child_QMARK__select_shape$jscomp$1$$)?$component_child_QMARK__select_shape$jscomp$1$$:
$APP.$app$common$types$component$instance_root_QMARK_$$($item$jscomp$152$$)||$APP.$app$common$types$component$instance_head_QMARK_$$($item$jscomp$152$$);$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1084$$)],$app$main$ui$inspect$left_sidebar$make_collapsed_iref$$($id$jscomp$1084$$));var $expanded_QMARK_$jscomp$3$$=$APP.$cljs$core$not$$($APP.$rumext$v2$deref$$($collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$));
$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1084$$)],function($event$jscomp$781$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$781$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_collapse$$($id$jscomp$1084$$))});$component_child_QMARK__select_shape$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1084$$)],
function($event$jscomp$782$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$782$$);return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$782$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$toggle_selection$$($id$jscomp$1084$$)):$event$jscomp$782$$.shiftKey?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$shift_select_to$$($id$jscomp$1084$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$viewer$select_shape$$($id$jscomp$1084$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$220$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$220$$),1)&&$selected_QMARK_$jscomp$25$$?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($item_ref$jscomp$8$$),!0):null});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_inner_STAR_$$,
{onSelectShape:$component_child_QMARK__select_shape$jscomp$1$$,children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1081$$=$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$152$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1081$$)?$expanded_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$1081$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"children-"+($id$jscomp$1084$$??""),className:"main_ui_inspect_left_sidebar__element-children "+($selected_QMARK_$jscomp$25$$?
"main_ui_inspect_left_sidebar__parent-selected":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$257$$,$JSCompiler_temp_const$jscomp$2052_p__83426$$){var $JSCompiler_inline_result$jscomp$2054_index$jscomp$589$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2052_p__83426$$,0,null),$id__$1$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$2052_p__83426$$,
1,null);$JSCompiler_temp_const$jscomp$2052_p__83426$$=$out_arr__44092__auto__$jscomp$257$$.push;var $temp__5825__auto__$jscomp$inline_9798$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$852$$,$id__$1$jscomp$22$$);$JSCompiler_inline_result$jscomp$2054_index$jscomp$589$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_9798$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$inspect$left_sidebar$layer_item$$,{item:$temp__5825__auto__$jscomp$inline_9798$$,selected:$selected$jscomp$220$$,
index:$JSCompiler_inline_result$jscomp$2054_index$jscomp$589$$,objects:$objects$jscomp$852$$,depth:$depth__$1$jscomp$1$$,"component-child?":$component_tree_QMARK_$$},""+($id__$1$jscomp$22$$??"")):null;$JSCompiler_temp_const$jscomp$2052_p__83426$$.call($out_arr__44092__auto__$jscomp$257$$,$JSCompiler_inline_result$jscomp$2054_index$jscomp$589$$);return $out_arr__44092__auto__$jscomp$257$$},[],$APP.$cljs$core$reverse$$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$152$$))))}):
null,isComponentTree:$component_tree_QMARK_$$,isExpanded:$expanded_QMARK_$jscomp$3$$,isFiltered:!1,item:$item$jscomp$152$$,hideToggle:$hide_toggle_QMARK__map__83425_map__83425__$1_props_83424$$,isHighlighted:!1,ref:$item_ref$jscomp$8$$,depth:$depth__$1$jscomp$1$$,isSelected:$selected_QMARK_$jscomp$25$$,isReadOnly:!0,onToggleCollapse:$collapsed_iref_depth$jscomp$21_toggle_collapse$jscomp$1$$})};$APP.$app$common$logging$loggers$$.set("app.main.ui.viewer.login",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$54$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$54$$,$APP.$cljs$cst$5507$login_register$$,$app$main$ui$viewer$login$login_register_modal$$)});$APP.$app$common$logging$loggers$$.set("app.main.ui.viewer.share-link",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$55$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$55$$,$APP.$cljs$cst$5509$share_link$$,$app$main$ui$viewer$share_link$share_link_dialog$$)});var $app$main$ui$viewer$thumbnails$thumbnail_item_STAR_$$,$p1__83471_SHARP_$jscomp$inline_9800$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($page_id$jscomp$477_props_83473$$){var $thumbnail_data$jscomp$1$$=$page_id$jscomp$477_props_83473$$.thumbnailData,$frame$jscomp$114$$=$page_id$jscomp$477_props_83473$$.frame,$index$jscomp$591$$=$page_id$jscomp$477_props_83473$$.index,$objects$jscomp$860$$=$page_id$jscomp$477_props_83473$$.objects,$is_selected$jscomp$17$$=$page_id$jscomp$477_props_83473$$.isSelected,
$on_click$jscomp$70$$=$page_id$jscomp$477_props_83473$$.onClick;$page_id$jscomp$477_props_83473$$=$page_id$jscomp$477_props_83473$$.pageId;var $children_bounds$jscomp$3_children_ids$jscomp$13$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$860$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$114$$));$children_bounds$jscomp$3_children_ids$jscomp$13$$=$APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame$jscomp$114$$],null),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($objects$jscomp$860$$),$children_bounds$jscomp$3_children_ids$jscomp$13$$)));return(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:function($p1__83472_SHARP_$$){return $on_click$jscomp$70$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$70$$.$cljs$core$IFn$_invoke$arity$2$($p1__83472_SHARP_$$,$index$jscomp$591$$):$on_click$jscomp$70$$($p1__83472_SHARP_$$,
$index$jscomp$591$$)},className:"main_ui_viewer_thumbnails__thumbnail-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_viewer_thumbnails__thumbnail-preview "+($APP.$cljs$core$truth_$$($is_selected$jscomp$17$$)?"main_ui_viewer_thumbnails__selected":""),children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$frame_svg$$,{frame:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($frame$jscomp$114$$,$APP.$cljs$cst$5269$thumbnail$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($thumbnail_data$jscomp$1$$,""+($page_id$jscomp$477_props_83473$$??"")+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$114$$)??""))),$APP.$cljs$cst$1930$children_bounds$$,$children_bounds$jscomp$3_children_ids$jscomp$13$$),objects:$objects$jscomp$860$$,"use-thumbnails":!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$114$$),className:"main_ui_viewer_thumbnails__thumbnail-info",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$114$$)})]})});$app$main$ui$viewer$thumbnails$thumbnail_item_STAR_$$=$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__83471_SHARP_$jscomp$inline_9800$$,$APP.$app$util$timers$idle_then_raf$$);var $app$main$ui$viewer$current_animations_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5374$viewer_animations$$,$APP.$app$main$store$state$$),$app$main$ui$viewer$current_overlays_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2240$viewer_overlays$$,$APP.$app$main$store$state$$),$app$main$ui$viewer$viewer_pagination_and_sidebar$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$594_map__83493_props_83492$$){$index$jscomp$594_map__83493_props_83492$$=
$APP.$rumext$v2$util$wrap_props$$($index$jscomp$594_map__83493_props_83492$$);var $map__83493__$1_page$jscomp$185$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$594_map__83493_props_83492$$),$and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83493__$1_page$jscomp$185$$,$APP.$cljs$cst$1371$section$$);$index$jscomp$594_map__83493_props_83492$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83493__$1_page$jscomp$185$$,
$APP.$cljs$cst$1801$index$$);var $users$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83493__$1_page$jscomp$185$$,$APP.$cljs$cst$5353$users$$),$frame$jscomp$117$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83493__$1_page$jscomp$185$$,$APP.$cljs$cst$1611$frame$$);$map__83493__$1_page$jscomp$185$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__83493__$1_page$jscomp$185$$,$APP.$cljs$cst$1629$page$$);var $comments_local$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$);
$and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$=($and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$,$APP.$cljs$cst$3489$comments$$))?$APP.$cljs$cst$5127$show_sidebar_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($comments_local$$):$and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$;
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$viewer_pagination$$,{index:$index$jscomp$594_map__83493_props_83492$$,"num-frames":$APP.$cljs$core$count$$($APP.$cljs$cst$5349$frames$$.$cljs$core$IFn$_invoke$arity$1$($map__83493__$1_page$jscomp$185$$)),"comment-sidebar":$and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$}),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9802_section$jscomp$49_show_sidebar_QMARK_$jscomp$1$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$viewer$comments$comments_sidebar_STAR_$$,{profiles:$users$jscomp$4$$,frame:$frame$jscomp$117$$,page:$map__83493__$1_page$jscomp$185$$}):null]})});
//# sourceMappingURL=main-viewer.js.map
